@@ -6,13 +6,26 @@
    Leave the following blank line there!!  Autoheader needs it.  */
 
 
+/* Define if your version of GNU libc has buggy inline assembly code
+   for math functions like exp.  */
+#undef __NO_MATH_INLINES
+
 /* Define if you want bounds checking on element references for
    internal array and matrix classes. */
 #undef BOUNDS_CHECKING
 
+/* Define to the C++ ABI your compiler uses.  */
+#undef CXX_ABI
+
+/* Define if your C++ runtime library is ISO compliant. */
+#undef CXX_ISO_COMPLIANT_LIBRARY
+
 /* Define if your compiler supports `<>' stuff for template friends. */
 #undef CXX_NEW_FRIEND_TEMPLATE_DECL
 
+/* Define if your compiler prepends underscores to external names. */
+#undef CXX_PREPENDS_UNDERSCORE
+
 /* Define if your math.h declares struct exception for matherr() */
 #undef EXCEPTION_IN_MATH
 
@@ -36,6 +49,9 @@
 /* Define if your system's struct group has a gr_passwd field. */
 #undef HAVE_GR_PASSWD
 
+/* Define if you have (and are using) the HDF5 library and headers. */
+#undef HAVE_HDF5
+
 /* Define if you have isinf(). */
 #undef HAVE_ISINF
 
@@ -45,6 +61,9 @@
 /* Define if you have BSD style signals. */
 #undef HAVE_BSD_SIGNALS
 
+/* Define if you have FFTW installed. */
+#undef HAVE_FFTW
+
 /* Define if you have POSIX style signals. */
 #undef HAVE_POSIX_SIGNALS
 
@@ -54,6 +73,9 @@
 /* Define if your system has a sys_siglist variable. */
 #undef HAVE_SYS_SIGLIST
 
+/* Define if your system defines struct timeval. */
+#undef HAVE_TIMEVAL
+
 /* Define if you have System V Release 3 style signals. */
 #undef HAVE_USG_SIGHOLD
 
@@ -121,3 +143,27 @@
    If you're adding to this file, keep in mind:
    The entries are in sort -df order: alphabetical, case insensitive,
    ignoring punctuation (such as underscores).  */
+
+@BOTTOM@
+
+#if defined (__GNUC__)
+#define GCC_ATTR_NORETURN __attribute__ ((__noreturn__))
+#define GCC_ATTR_UNUSED __attribute__ ((__unused__))
+#else
+#define GCC_ATTR_NORETURN
+#define GCC_ATTR_UNUSED
+#endif
+
+#define CONST_CAST(T, E) (T) (E)
+
+#define DYNAMIC_CAST(T, E) (T) (E)
+
+#define REINTERPRET_CAST(T, E) (T) (E)
+
+#define STATIC_CAST(T, E) (T) (E)
+
+#define X_CAST(T, E) (T) (E)
+
+#define HEAVYWEIGHT_INDEXING 1
+
+#define WITH_KPATHSEARCH 1
