@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -33,6 +33,22 @@ template class Array<bool>;
 
 template int assign (Array<bool>&, const Array<bool>&);
 
+template int assign (Array<bool>&, const Array<bool>&, const bool&);
+
+#include "Array2.h"
+#include "Array2.cc"
+
+template class Array2<bool>;
+
+template int assign (Array2<bool>&, const Array2<bool>&);
+
+template int assign (Array2<bool>&, const Array2<bool>&, const bool&);
+
+#include "DiagArray2.h"
+#include "DiagArray2.cc"
+
+template class DiagArray2<bool>;
+
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
