@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -35,6 +35,10 @@ template int assign (Array<int>&, const Array<int>&);
 template int assign (Array<int>&, const Array<short>&);
 template int assign (Array<int>&, const Array<char>&);
 
+template int assign (Array<int>&, const Array<int>&, const int&);
+template int assign (Array<int>&, const Array<short>&, const int&);
+template int assign (Array<int>&, const Array<char>&, const int&);
+
 #include "Array2.h"
 #include "Array2.cc"
 
@@ -44,6 +48,10 @@ template int assign (Array2<int>&, const Array2<int>&);
 template int assign (Array2<int>&, const Array2<short>&);
 template int assign (Array2<int>&, const Array2<char>&);
 
+template int assign (Array2<int>&, const Array2<int>&, const int&);
+template int assign (Array2<int>&, const Array2<short>&, const int&);
+template int assign (Array2<int>&, const Array2<char>&, const int&);
+
 #include "DiagArray2.h"
 #include "DiagArray2.cc"
 
