@@ -1,7 +1,7 @@
 // Template array classes
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -43,10 +43,7 @@ Array2<T>::value (void)
     }
   else if (n_idx == 1)
     {
-      idx_vector *tmp = get_idx ();
-      idx_vector idx = tmp[0];
-
-      return index (idx);
+      return index (idx[0]);
     }
   else
     (*current_liboctave_error_handler)
@@ -59,34 +56,39 @@ Array2<T>::value (void)
 
 template <class T>
 Array2<T>
-Array2<T>::index (idx_vector& idx) const
+Array2<T>::index (idx_vector& idx_arg) const
 {
   Array2<T> retval;
 
   int nr = d1;
   int nc = d2;
 
-  if (nr == 1 && nc == 1)
+  int idx_orig_rows = idx_arg.orig_rows ();
+  int idx_orig_columns = idx_arg.orig_columns ();
+
+  if (idx_arg.is_colon ())
     {
-      Array<T> tmp = Array<T>::index (idx);
+      // Fast magic colon processing.
 
-      int len = tmp.length ();
+      int result_nr = nr * nc;
+      int result_nc = result_nr ? 1 : 0;
 
-      if (len == 0)
-	retval = Array2<T> (0, 0);
+      retval = Array2<T> (*this, result_nr, result_nc);
+    }
+  else if (nr == 1 && nc == 1)
+    {
+      Array<T> tmp = Array<T>::index (idx_arg);
+
+      if (tmp.length () != 0)
+	retval = Array2<T> (tmp, idx_orig_rows, idx_orig_columns);
       else
-	{
-	  if (liboctave_pcv_flag)
-	    retval = Array2<T> (tmp, len, 1);
-	  else
-	    retval = Array2<T> (tmp, 1, len);
-	}
+	retval = Array2<T> (tmp, 0, 0);
     }
   else if (nr == 1 || nc == 1)
     {
-      int result_is_column_vector = (nc == 1 || idx.is_colon ());
+      int result_is_column_vector = (nc == 1);
 
-      Array<T> tmp = Array<T>::index (idx);
+      Array<T> tmp = Array<T>::index (idx_arg);
 
       int len = tmp.length ();
 
@@ -100,26 +102,24 @@ Array2<T>::index (idx_vector& idx) const
 	    retval = Array2<T> (tmp, 1, len);
 	}
     }
-  else if (liboctave_dfi_flag || idx.is_colon ())
+  else if (liboctave_dfi_flag
+	   || (idx_arg.one_zero_only ()
+	       && idx_orig_rows == nr
+	       && idx_orig_columns == nc))
     {
       // This code is only for indexing matrices.  The vector
       // cases are handled above.
 
-      idx.freeze (nr * nc, "matrix", liboctave_pzo_flag);
+      idx_arg.freeze (nr * nc, "matrix");
 
-      if (idx)
+      if (idx_arg)
 	{
-	  int result_nr = idx.orig_rows ();
-	  int result_nc = idx.orig_columns ();
+	  int result_nr = idx_orig_rows;
+	  int result_nc = idx_orig_columns;
 
-	  if (idx.is_colon ())
+	  if (idx_arg.one_zero_only ())
 	    {
-	      result_nr = nr * nc;
-	      result_nc = result_nr ? 1 : 0;
-	    }
-	  else if (idx.one_zero_only ())
-	    {
-	      result_nr = idx.ones_count ();
+	      result_nr = idx_arg.ones_count ();
 	      result_nc = (result_nr > 0 ? 1 : 0);
 	    }
 
@@ -130,7 +130,7 @@ Array2<T>::index (idx_vector& idx) const
 	    {
 	      for (int i = 0; i < result_nr; i++)
 		{
-		  int ii = idx.elem (k++);
+		  int ii = idx_arg.elem (k++);
 		  int fr = ii % nr;
 		  int fc = (ii - fr) / nr;
 		  retval.elem (i, j) = elem (fr, fc);
@@ -155,8 +155,8 @@ Array2<T>::index (idx_vector& idx_i, idx_vector& idx_j) const
   int nr = d1;
   int nc = d2;
 
-  int n = idx_i.freeze (nr, "row", liboctave_pzo_flag);
-  int m = idx_j.freeze (nc, "column", liboctave_pzo_flag);
+  int n = idx_i.freeze (nr, "row");
+  int m = idx_j.freeze (nc, "column");
 
   if (idx_i && idx_j)
     {
@@ -211,6 +211,105 @@ Array2<T>::index (idx_vector& idx_i, idx_vector& idx_j) const
   return retval;
 }
 
+template <class T>
+void
+Array2<T>::maybe_delete_elements (idx_vector& idx_arg)
+{
+  int nr = d1;
+  int nc = d2;
+
+  if (nr == 0 && nc == 0)
+    return;
+
+  int n;
+  if (nr == 1)
+    n = nc;
+  else if (nc == 1)
+    n = nr;
+  else
+    {
+      (*current_liboctave_error_handler)
+	("A(idx) = []: expecting A to be row or column vector or scalar");
+
+      return;
+    }
+
+  if (idx_arg.is_colon_equiv (n, 1))
+    {
+      // Either A(:) = [] or A(idx) = [] with idx enumerating all
+      // elements, so we delete all elements and return [](0x0).  To
+      // preserve the orientation of the vector, you have to use
+      // A(idx,:) = [] (delete rows) or A(:,idx) (delete columns).
+
+      resize (0, 0);
+      return;
+    }
+
+  idx_arg.sort (true);
+
+  int num_to_delete = idx_arg.length (n);
+
+  if (num_to_delete != 0)
+    {
+      int new_n = n;
+
+      int iidx = 0;
+
+      for (int i = 0; i < n; i++)
+	if (i == idx_arg.elem (iidx))
+	  {
+	    iidx++;
+	    new_n--;
+
+	    if (iidx == num_to_delete)
+	      break;
+	  }
+
+      if (new_n > 0)
+	{
+	  T *new_data = new T [new_n];
+
+	  int ii = 0;
+	  iidx = 0;
+	  for (int i = 0; i < n; i++)
+	    {
+	      if (iidx < num_to_delete && i == idx_arg.elem (iidx))
+		iidx++;
+	      else
+		{
+		  if (nr == 1)
+		    new_data[ii] = elem (0, i);
+		  else
+		    new_data[ii] = elem (i, 0);
+
+		  ii++;
+		}
+	    }
+
+	  if (--rep->count <= 0)
+	    delete rep;
+
+	  rep = new ArrayRep (new_data, new_n);
+
+	  if (nr == 1)
+	    {
+	      d1 = 1;
+	      d2 = new_n;
+	    }
+	  else
+	    {
+	      d1 = new_n;
+	      d2 = 1;
+	    }
+
+	  set_max_indices (2);
+	}
+      else
+	(*current_liboctave_error_handler)
+	  ("A(idx) = []: index out of range");
+    }
+}
+
 template <class T>
 void
 Array2<T>::maybe_delete_elements (idx_vector& idx_i, idx_vector& idx_j)
@@ -221,6 +320,38 @@ Array2<T>::maybe_delete_elements (idx_vector& idx_i, idx_vector& idx_j)
   if (nr == 0 && nc == 0)
     return;
 
+  if (idx_i.is_colon ())
+    {
+      if (idx_j.is_colon ())
+	{
+	  // A(:,:) -- We are deleting columns and rows, so the result
+	  // is [](0x0).
+
+	  resize (0, 0);
+	  return;
+	}
+
+      if (idx_j.is_colon_equiv (nc, 1))
+	{
+	  // A(:,j) -- We are deleting columns by enumerating them,
+	  // If we enumerate all of them, we should have zero columns
+	  // with the same number of rows that we started with.
+
+	  resize (nr, 0);
+	  return;
+	}
+    }
+
+  if (idx_j.is_colon () && idx_i.is_colon_equiv (nr, 1))
+    {
+      // A(i,:) -- We are deleting rows by enumerating them.  If we
+      // enumerate all of them, we should have zero rows with the
+      // same number of columns that we started with.
+
+      resize (0, nc);
+      return;
+    }
+
   if (idx_i.is_colon_equiv (nr, 1))
     {
       if (idx_j.is_colon_equiv (nc, 1))
@@ -239,15 +370,15 @@ Array2<T>::maybe_delete_elements (idx_vector& idx_i, idx_vector& idx_j)
 		{
 		  int new_nc = nc;
 
-		  int idx = 0;
+		  int iidx = 0;
 
 		  for (int j = 0; j < nc; j++)
-		    if (j == idx_j.elem (idx))
+		    if (j == idx_j.elem (iidx))
 		      {
-			idx++;
+			iidx++;
 			new_nc--;
 
-			if (idx == num_to_delete)
+			if (iidx == num_to_delete)
 			  break;
 		      }
 
@@ -256,11 +387,11 @@ Array2<T>::maybe_delete_elements (idx_vector& idx_i, idx_vector& idx_j)
 		      T *new_data = new T [nr * new_nc];
 
 		      int jj = 0;
-		      idx = 0;
+		      iidx = 0;
 		      for (int j = 0; j < nc; j++)
 			{
-			  if (idx < num_to_delete && j == idx_j.elem (idx))
-			    idx++;
+			  if (iidx < num_to_delete && j == idx_j.elem (iidx))
+			    iidx++;
 			  else
 			    {
 			      for (int i = 0; i < nr; i++)
@@ -303,15 +434,15 @@ Array2<T>::maybe_delete_elements (idx_vector& idx_i, idx_vector& idx_j)
 		{
 		  int new_nr = nr;
 
-		  int idx = 0;
+		  int iidx = 0;
 
 		  for (int i = 0; i < nr; i++)
-		    if (i == idx_i.elem (idx))
+		    if (i == idx_i.elem (iidx))
 		      {
-			idx++;
+			iidx++;
 			new_nr--;
 
-			if (idx == num_to_delete)
+			if (iidx == num_to_delete)
 			  break;
 		      }
 
@@ -320,11 +451,11 @@ Array2<T>::maybe_delete_elements (idx_vector& idx_i, idx_vector& idx_j)
 		      T *new_data = new T [new_nr * nc];
 
 		      int ii = 0;
-		      idx = 0;
+		      iidx = 0;
 		      for (int i = 0; i < nr; i++)
 			{
-			  if (idx < num_to_delete && i == idx_i.elem (idx))
-			    idx++;
+			  if (iidx < num_to_delete && i == idx_i.elem (iidx))
+			    iidx++;
 			  else
 			    {
 			      for (int j = 0; j < nc; j++)
@@ -362,14 +493,14 @@ Array2<T>::maybe_delete_elements (idx_vector& idx_i, idx_vector& idx_j)
 	  int new_nr = max_row_idx > lhs_nr ? max_row_idx : lhs_nr; \
 	  int new_nc = max_col_idx > lhs_nc ? max_col_idx : lhs_nc; \
  \
-	  lhs.resize (new_nr, new_nc, 0.0); \
+	  lhs.resize (new_nr, new_nc, resize_fill_value); \
 	} \
     } \
   while (0)
 
 template <class LT, class RT>
 int
-assign (Array2<LT>& lhs, const Array2<RT>& rhs)
+assign (Array2<LT>& lhs, const Array2<RT>& rhs, const LT& resize_fill_value)
 {
   int retval = 1;
 
@@ -381,18 +512,22 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
   int rhs_nr = rhs.rows ();
   int rhs_nc = rhs.cols ();
 
+  idx_vector *tmp = lhs.get_idx ();
+
+  idx_vector idx_i;
+  idx_vector idx_j;
+
+  if (n_idx > 1)
+    idx_j = tmp[1];
+
+  if (n_idx > 0)
+    idx_i = tmp[0];
+
   if (n_idx == 2)
     {
-      idx_vector *tmp = lhs.get_idx ();
+      int n = idx_i.freeze (lhs_nr, "row", liboctave_rre_flag);
 
-      idx_vector idx_i = tmp[0];
-      idx_vector idx_j = tmp[1];
-
-      int n = idx_i.freeze (lhs_nr, "row", liboctave_pzo_flag,
-			    liboctave_rre_flag);
-
-      int m = idx_j.freeze (lhs_nc, "column", liboctave_pzo_flag,
-			    liboctave_rre_flag);
+      int m = idx_j.freeze (lhs_nc, "column", liboctave_rre_flag);
 
       int idx_i_is_colon = idx_i.is_colon ();
       int idx_j_is_colon = idx_j.is_colon ();
@@ -473,27 +608,19 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
 
       if (lhs_is_empty || (lhs_nr == 1 && lhs_nc == 1))
 	{
-	  idx_vector *tmp = lhs.get_idx ();
-
-	  idx_vector idx = tmp[0];
-
 	  int lhs_len = lhs.length ();
 
-	  int n = idx.freeze (lhs_len, 0, liboctave_pzo_flag,
-			      liboctave_rre_flag);
+	  int n = idx_i.freeze (lhs_len, 0, liboctave_rre_flag);
 
-	  if (idx)
+	  if (idx_i)
 	    {
 	      if (rhs_nr == 0 && rhs_nc == 0)
 		{
 		  if (n != 0 && (lhs_nr != 0 || lhs_nc != 0))
-		    {
-		      idx_vector tmp (':');
-		      lhs.maybe_delete_elements (idx, tmp);
-		    }
+		    lhs.maybe_delete_elements (idx_i);
 		}
 	      else if (! liboctave_dfi_flag && lhs_is_empty
-		       && idx.is_colon ()
+		       && idx_i.is_colon ()
 		       && ! (rhs_nr == 1 || rhs_nc == 1))
 		{
 		  (*current_liboctave_error_handler)
@@ -507,8 +634,8 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
 
 		      if (len > 0)
 			{
-			  int idx_nr = idx.orig_rows ();
-			  int idx_nc = idx.orig_columns ();
+			  int idx_nr = idx_i.orig_rows ();
+			  int idx_nc = idx_i.orig_columns ();
 
 			  // lhs_is_empty now means that lhs was
 			  // *originally* empty, and lhs_len is the
@@ -516,8 +643,7 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
 
 			  if (liboctave_dfi_flag
 			      || (idx_nr == 1 && idx_nc == 1)
-			      || (rhs_nr == 1 && rhs_nc == 1
-				  && lhs_len == 1 || lhs_len == 0))
+			      || (rhs_nr == 1 && rhs_nc == 1 && lhs_len == 1))
 			    {
 			      if (liboctave_pcv_flag)
 				{
@@ -530,17 +656,24 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
 				  lhs.d2 = lhs.length ();
 				}
 			    }
-			  else if (lhs_is_empty && idx.is_colon ())
+			  else if (lhs_is_empty && idx_i.is_colon ())
 			    {
 			      lhs.d1 = rhs.d1;
 			      lhs.d2 = rhs.d2;
 			    }
-			  else if (rhs_nr == 1 && idx_nr == 1)
+			  else if (lhs_is_empty && idx_i.one_zero_only ())
+			    {
+			      lhs.d1 = idx_nr;
+			      lhs.d2 = idx_nc;
+			    }
+			  else if (rhs_nr == 1
+				   && (idx_nr == 1 || lhs_len == 1))
 			    {
 			      lhs.d1 = 1;
 			      lhs.d2 = lhs.length ();
 			    }
-			  else if (rhs_nc == 1 && idx_nc == 1)
+			  else if (rhs_nc == 1
+				   && (idx_nc == 1 || lhs_len == 1))
 			    {
 			      lhs.d1 = lhs.length ();
 			      lhs.d2 = 1;
@@ -570,20 +703,12 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
 	}
       else if (lhs_nr == 1)
 	{
-	  idx_vector *tmp = lhs.get_idx ();
+	  idx_i.freeze (lhs_nc, "vector", liboctave_rre_flag);
 
-	  idx_vector idx = tmp[0];
-
-	  idx.freeze (lhs_nc, "vector", liboctave_pzo_flag,
-		      liboctave_rre_flag);
-
-	  if (idx)
+	  if (idx_i)
 	    {
 	      if (rhs_nr == 0 && rhs_nc == 0)
-		{
-		  idx_vector tmp (':');
-		  lhs.maybe_delete_elements (tmp, idx);
-		}
+		lhs.maybe_delete_elements (idx_i);
 	      else
 		{
 		  if (assign ((Array<LT>&) lhs, (Array<RT>&) rhs))
@@ -596,20 +721,12 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
 	}
       else if (lhs_nc == 1)
 	{
-	  idx_vector *tmp = lhs.get_idx ();
+	  idx_i.freeze (lhs_nr, "vector", liboctave_rre_flag);
 
-	  idx_vector idx = tmp[0];
-
-	  idx.freeze (lhs_nr, "vector", liboctave_pzo_flag,
-		      liboctave_rre_flag);
-
-	  if (idx)
+	  if (idx_i)
 	    {
 	      if (rhs_nr == 0 && rhs_nc == 0)
-		{
-		  idx_vector tmp (':');
-		  lhs.maybe_delete_elements (idx, tmp);
-		}
+		lhs.maybe_delete_elements (idx_i);
 	      else
 		{
 		  if (assign ((Array<LT>&) lhs, (Array<RT>&) rhs))
@@ -620,15 +737,15 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
 	    }
 	  // idx_vector::freeze() printed an error message for us.
 	}
-      else if (liboctave_dfi_flag)
+      else if (liboctave_dfi_flag
+	       || idx_i.is_colon ()
+	       || (idx_i.one_zero_only ()
+		   && idx_i.orig_rows () == lhs_nr
+		   && idx_i.orig_columns () == lhs_nc))
 	{
-	  idx_vector *tmp = lhs.get_idx ();
-	  idx_vector idx = tmp[0];
+	  int len = idx_i.freeze (lhs_nr * lhs_nc, "matrix");
 
-	  int len = idx.freeze (lhs_nr * lhs_nc, "matrix",
-				liboctave_pzo_flag);
-
-	  if (idx)
+	  if (idx_i)
 	    {
 	      if (len == 0)
 		{
@@ -644,7 +761,7 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
 		    {
 		      for (int i = 0; i < rhs_nr; i++)
 			{
-			  int ii = idx.elem (k++);
+			  int ii = idx_i.elem (k++);
 			  int fr = ii % lhs_nr;
 			  int fc = (ii - fr) / lhs_nr;
 			  lhs.elem (fr, fc) = rhs.elem (i, j);
@@ -657,7 +774,7 @@ assign (Array2<LT>& lhs, const Array2<RT>& rhs)
 
 		  for (int i = 0; i < len; i++)
 		    {
-		      int ii = idx.elem (i);
+		      int ii = idx_i.elem (i);
 		      int fr = ii % lhs_nr;
 		      int fc = (ii - fr) / lhs_nr;
 		      lhs.elem (fr, fc) = scalar;
