@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -27,7 +27,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #pragma interface
 #endif
 
-class ostream;
+#include <iostream>
 
 #include "dColVector.h"
 
@@ -126,7 +126,7 @@ public:
   Bounds& set_lower_bounds (const ColumnVector lb);
   Bounds& set_upper_bounds (const ColumnVector ub);
 
-  friend ostream& operator << (ostream& os, const Bounds& b);
+  friend std::ostream& operator << (std::ostream& os, const Bounds& b);
 
 protected:
 
