@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -31,7 +31,8 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "mx-defs.h"
 
-class ComplexColumnVector : public MArray<Complex>
+class
+ComplexColumnVector : public MArray<Complex>
 {
 friend class ComplexMatrix;
 friend class ComplexRowVector;
@@ -39,12 +40,18 @@ friend class ComplexRowVector;
 public:
 
   ComplexColumnVector (void) : MArray<Complex> () { }
-  ComplexColumnVector (int n) : MArray<Complex> (n) { }
-  ComplexColumnVector (int n, const Complex& val) : MArray<Complex> (n, val) { }
-  ComplexColumnVector (const ColumnVector& a);
-  ComplexColumnVector (const MArray<Complex>& a) : MArray<Complex> (a) { }
+
+  explicit ComplexColumnVector (int n) : MArray<Complex> (n) { }
+
+  ComplexColumnVector (int n, const Complex& val)
+    : MArray<Complex> (n, val) { }
+
   ComplexColumnVector (const ComplexColumnVector& a) : MArray<Complex> (a) { }
 
+  ComplexColumnVector (const MArray<Complex>& a) : MArray<Complex> (a) { }
+
+  explicit ComplexColumnVector (const ColumnVector& a);
+
   ComplexColumnVector& operator = (const ComplexColumnVector& a)
     {
       MArray<Complex>::operator = (a);
@@ -81,49 +88,6 @@ public:
   ComplexColumnVector& operator += (const ColumnVector& a);
   ComplexColumnVector& operator -= (const ColumnVector& a);
 
-  ComplexColumnVector& operator += (const ComplexColumnVector& a);
-  ComplexColumnVector& operator -= (const ComplexColumnVector& a);
-
-  // column vector by scalar -> column vector operations
-
-  friend ComplexColumnVector operator + (const ComplexColumnVector& a,
-					 double s);
-  friend ComplexColumnVector operator - (const ComplexColumnVector& a,
-					 double s);
-  friend ComplexColumnVector operator * (const ComplexColumnVector& a,
-					 double s);
-  friend ComplexColumnVector operator / (const ComplexColumnVector& a,
-					 double s);
-
-  friend ComplexColumnVector operator + (const ColumnVector& a,
-					 const Complex& s);  
-  friend ComplexColumnVector operator - (const ColumnVector& a,
-					 const Complex& s);
-  friend ComplexColumnVector operator * (const ColumnVector& a,
-					 const Complex& s);
-  friend ComplexColumnVector operator / (const ColumnVector& a,
-					 const Complex& s);
-
-  // scalar by column vector -> column vector operations
-
-  friend ComplexColumnVector operator + (double s,
-					 const ComplexColumnVector& a); 
-  friend ComplexColumnVector operator - (double s,
-					 const ComplexColumnVector& a);
-  friend ComplexColumnVector operator * (double s,
-					 const ComplexColumnVector& a);
-  friend ComplexColumnVector operator / (double s,
-					 const ComplexColumnVector& a);
-
-  friend ComplexColumnVector operator + (const Complex& s,
-					 const ColumnVector& a); 
-  friend ComplexColumnVector operator - (const Complex& s,
-					 const ColumnVector& a);
-  friend ComplexColumnVector operator * (const Complex& s,
-					 const ColumnVector& a);
-  friend ComplexColumnVector operator / (const Complex& s,
-					 const ColumnVector& a);
-
   // matrix by column vector -> column vector operations
 
   friend ComplexColumnVector operator * (const ComplexMatrix& a,
@@ -132,28 +96,6 @@ public:
   friend ComplexColumnVector operator * (const ComplexMatrix& a,
 					 const ComplexColumnVector& b);
 
-  // column vector by column vector -> column vector operations
-
-  friend ComplexColumnVector operator + (const ComplexColumnVector& a,
-					 const ColumnVector& b);
-  friend ComplexColumnVector operator - (const ComplexColumnVector& a,
-					 const ColumnVector& b);
-
-  friend ComplexColumnVector operator + (const ColumnVector& a,
-					 const ComplexColumnVector& b);
-  friend ComplexColumnVector operator - (const ColumnVector& a,
-					 const ComplexColumnVector& b); 
-
-  friend ComplexColumnVector product (const ComplexColumnVector& a,
-				      const ColumnVector& b);
-  friend ComplexColumnVector quotient (const ComplexColumnVector& a,
-				       const ColumnVector& b);
-
-  friend ComplexColumnVector product (const ColumnVector& a,
-				      const ComplexColumnVector& b); 
-  friend ComplexColumnVector quotient (const ColumnVector& a,
-				       const ComplexColumnVector& b); 
-
   // matrix by column vector -> column vector operations
 
   friend ComplexColumnVector operator * (const Matrix& a,
@@ -182,14 +124,16 @@ public:
 
   // i/o
 
-  friend ostream& operator << (ostream& os, const ComplexColumnVector& a);
-  friend istream& operator >> (istream& is, ComplexColumnVector& a);
+  friend std::ostream& operator << (std::ostream& os, const ComplexColumnVector& a);
+  friend std::istream& operator >> (std::istream& is, ComplexColumnVector& a);
 
 private:
 
   ComplexColumnVector (Complex *d, int l) : MArray<Complex> (d, l) { }
 };
 
+MARRAY_FORWARD_DEFS (MArray, ComplexColumnVector, Complex)
+
 #endif
 
 /*
