@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -36,25 +36,37 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "mx-defs.h"
 
-class ComplexDiagMatrix : public MDiagArray2<Complex>
+class
+ComplexDiagMatrix : public MDiagArray2<Complex>
 {
 public:
 
   ComplexDiagMatrix (void) : MDiagArray2<Complex> () { }
+
   ComplexDiagMatrix (int r, int c) : MDiagArray2<Complex> (r, c) { }
+
   ComplexDiagMatrix (int r, int c, const Complex& val)
     : MDiagArray2<Complex> (r, c, val) { }
-  ComplexDiagMatrix (const RowVector& a)
+
+  explicit ComplexDiagMatrix (const RowVector& a)
     : MDiagArray2<Complex> (ComplexRowVector (a)) { }
-  ComplexDiagMatrix (const ComplexRowVector& a) : MDiagArray2<Complex> (a) { }
-  ComplexDiagMatrix (const ColumnVector& a)
-    : MDiagArray2<Complex> (ComplexColumnVector (a)) { }
-  ComplexDiagMatrix (const ComplexColumnVector& a)
+
+  explicit ComplexDiagMatrix (const ComplexRowVector& a)
     : MDiagArray2<Complex> (a) { }
-  ComplexDiagMatrix (const DiagMatrix& a);
+
+  explicit ComplexDiagMatrix (const ColumnVector& a)
+    : MDiagArray2<Complex> (ComplexColumnVector (a)) { }
+
+  explicit ComplexDiagMatrix (const ComplexColumnVector& a)
+    : MDiagArray2<Complex> (a) { }
+
+  explicit ComplexDiagMatrix (const DiagMatrix& a);
+
   ComplexDiagMatrix (const MDiagArray2<Complex>& a)
     : MDiagArray2<Complex> (a) { }
-  ComplexDiagMatrix (const ComplexDiagMatrix& a) : MDiagArray2<Complex> (a) { }
+
+  ComplexDiagMatrix (const ComplexDiagMatrix& a)
+    : MDiagArray2<Complex> (a) { }
 
   ComplexDiagMatrix& operator = (const ComplexDiagMatrix& a)
     {
@@ -103,48 +115,6 @@ public:
   ComplexDiagMatrix& operator += (const DiagMatrix& a);
   ComplexDiagMatrix& operator -= (const DiagMatrix& a);
 
-  ComplexDiagMatrix& operator += (const ComplexDiagMatrix& a);
-  ComplexDiagMatrix& operator -= (const ComplexDiagMatrix& a);
-
-  // diagonal matrix by scalar -> diagonal matrix operations
-
-  friend ComplexDiagMatrix operator * (const ComplexDiagMatrix& a, double s);
-  friend ComplexDiagMatrix operator / (const ComplexDiagMatrix& a, double s);
-
-  friend ComplexDiagMatrix operator * (const DiagMatrix& a, const Complex& s);
-  friend ComplexDiagMatrix operator / (const DiagMatrix& a, const Complex& s);
-
-  // scalar by diagonal matrix -> diagonal matrix operations
-
-  friend ComplexDiagMatrix operator * (double s, const ComplexDiagMatrix& a);
-
-  friend ComplexDiagMatrix operator * (const Complex& s, const DiagMatrix& a);
-
-  // diagonal matrix by diagonal matrix -> diagonal matrix operations
-
-  friend ComplexDiagMatrix operator * (const ComplexDiagMatrix& a,
-				       const ComplexDiagMatrix& b);
-
-  friend ComplexDiagMatrix operator + (const ComplexDiagMatrix& a,
-				       const DiagMatrix& b);
-  friend ComplexDiagMatrix operator - (const ComplexDiagMatrix& a,
-				       const DiagMatrix& b);
-  friend ComplexDiagMatrix operator * (const ComplexDiagMatrix& a,
-				       const DiagMatrix& b);
-
-  friend ComplexDiagMatrix operator + (const DiagMatrix& a,
-				       const ComplexDiagMatrix& b);
-  friend ComplexDiagMatrix operator - (const DiagMatrix& a,
-				       const ComplexDiagMatrix& b);
-  friend ComplexDiagMatrix operator * (const DiagMatrix& a,
-				       const ComplexDiagMatrix& b);
-
-  friend ComplexDiagMatrix product (const ComplexDiagMatrix& a,
-				    const DiagMatrix& b); 
-
-  friend ComplexDiagMatrix product (const DiagMatrix& a,
-				    const ComplexDiagMatrix& b);
-
   // other operations
 
   ComplexColumnVector diag (void) const;
@@ -152,7 +122,7 @@ public:
 
   // i/o
 
-  friend ostream& operator << (ostream& os, const ComplexDiagMatrix& a);
+  friend std::ostream& operator << (std::ostream& os, const ComplexDiagMatrix& a);
 
 private:
 
@@ -160,6 +130,19 @@ private:
     : MDiagArray2<Complex> (d, nr, nc) { }
 };
 
+// diagonal matrix by diagonal matrix -> diagonal matrix operations
+
+ComplexDiagMatrix
+operator * (const ComplexDiagMatrix& a, const ComplexDiagMatrix& b);
+
+ComplexDiagMatrix
+operator * (const ComplexDiagMatrix& a, const DiagMatrix& b);
+
+ComplexDiagMatrix
+operator * (const DiagMatrix& a, const ComplexDiagMatrix& b);
+
+MDIAGARRAY2_FORWARD_DEFS (MDiagArray2, ComplexDiagMatrix, Complex)
+
 #endif
 
 /*
