@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -27,7 +27,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #pragma interface
 #endif
 
-class ostream;
+#include <iostream>
 
 #include "dDiagMatrix.h"
 #include "CMatrix.h"
@@ -73,7 +73,7 @@ public:
 
   ComplexMatrix right_singular_matrix (void) const;
 
-  friend ostream&  operator << (ostream& os, const ComplexSVD& a);
+  friend std::ostream&  operator << (std::ostream& os, const ComplexSVD& a);
 
 private:
 
