@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -26,11 +26,6 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 class Matrix;
 class ColumnVector;
 
-#if !defined (octave_DAEFunc_typedefs)
-#define octave_DAEFunc_typedefs 1
-
-#endif
-
 class
 DAEFunc
 {
@@ -43,7 +38,8 @@ public:
     };
 
   typedef ColumnVector (*DAERHSFunc) (const ColumnVector& x,
-				      const ColumnVector& xdot, double); 
+				      const ColumnVector& xdot,
+				      double, int&); 
 
   typedef DAEJac (*DAEJacFunc) (const ColumnVector& x,
 				const ColumnVector& xdot, double);
