@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -31,24 +31,24 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <cfloat>
 #include <cmath>
 
-#include <iostream.h>
+#include <iostream>
 
 #include "LSODE.h"
 #include "f77-fcn.h"
 #include "lo-error.h"
 
-extern "C"
-{
-  int F77_FCN (lsode, LSODE) (int (*)(const int&, const double&,
-				      double*, double*, int&),
-			      int&, double*, double&, double&, int&,
-			      double&, double&, int&, int&, int&,
-			      double*, int&, int*, int&,
-			      int (*)(const int&, const double&,
-				      double*, const int&, const int&,
-				      double*, const int&),
+typedef int (*lsode_fcn_ptr) (const int&, const double&, double*,
+			      double*, int&);
+
+typedef int (*lsode_jac_ptr) (const int&, const double&, double*,
+			      const int&, const int&, double*, const
 			      int&);
-}
+
+extern "C"
+int F77_FCN (lsode, LSODE) (lsode_fcn_ptr, int&, double*, double&,
+			    double&, int&, double&, double&, int&,
+			    int&, int&, double*, int&, int*, int&,
+			    lsode_jac_ptr, int&);
 
 static ODEFunc::ODERHSFunc user_fun;
 static ODEFunc::ODEJacFunc user_jac;
@@ -218,12 +218,6 @@ LSODE::do_integrate (double tout)
       sanity_checked = 1;
     }
 
-  if (step_limit () > 0)
-    {
-      iwork.elem (5) = step_limit ();
-      iopt = 1;
-    }
-
   if (stop_time_set)
     {
       itask = 4;
@@ -256,6 +250,12 @@ LSODE::do_integrate (double tout)
       iopt = 1;
     }
 
+  if (step_limit () > 0)
+    {
+      iwork.elem (5) = step_limit ();
+      iopt = 1;
+    }
+
   int *piwork = iwork.fortran_vec ();
   double *prwork = rwork.fortran_vec ();
 
@@ -286,7 +286,7 @@ LSODE::do_integrate (double tout)
 	case -1:  // excess work done on this call (perhaps wrong mf).
 	  (*current_liboctave_error_handler)
 	    ("giving up after more than %d steps attempted in lsode",
-	     iwork.elem (5));
+	     step_limit ());
 	  integration_error = 1;
 	  break;
 
@@ -305,34 +305,6 @@ LSODE::do_integrate (double tout)
   return retval;
 }
 
-#if 0
-void
-LSODE::integrate (int nsteps, double tstep, ostream& s)
-{
-  int time_to_quit = 0;
-  double tout = t;
-
-  s << t << " " << x << "\n";
-
-  for (int i = 0; i < nsteps; i++)
-    {
-      tout += tstep;
-      if (stop_time_set && tout > stop_time)
-	{
-	  tout = stop_time;
-	  time_to_quit = 1;
-	}
-
-      x = integrate (tout);
-
-      s << t << " " << x << "\n";
-
-      if (time_to_quit)
-	return;
-    }
-}
-#endif
-
 Matrix
 LSODE::do_integrate (const ColumnVector& tout)
 {
@@ -362,7 +334,7 @@ LSODE::do_integrate (const ColumnVector& tout)
 }
 
 Matrix
-LSODE::integrate (const ColumnVector& tout, const ColumnVector& tcrit)
+LSODE::do_integrate (const ColumnVector& tout, const ColumnVector& tcrit)
 {
   Matrix retval;
   int n_out = tout.capacity ();
