@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,7 +28,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 
 #include "LinConst.h"
 #include "lo-error.h"
@@ -41,8 +41,8 @@ LinConst::error (const char* msg)
   (*current_liboctave_error_handler) ("fatal LinConst error: %s", msg);
 }
 
-ostream&
-operator << (ostream& os, const LinConst& c)
+std::ostream&
+operator << (std::ostream& os, const LinConst& c)
 {
   for (int i = 0; i < c.size (); i++)
     os << c.lower_bound (i) << " " << c.upper_bound (i) << "\n";
