@@ -1,7 +1,6 @@
-//                                  -*- C++ -*-
 /*
 
-Copyright (C) 1992, 1993, 1994, 1995 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -17,50 +16,54 @@ for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 #if !defined (octave_DiagMatrix_h)
 #define octave_DiagMatrix_h 1
 
-#include "Array.h"
+#if defined (__GNUG__)
+#pragma interface
+#endif
+
+#include "MDiagArray2.h"
 
 #include "dRowVector.h"
 #include "dColVector.h"
 
 #include "mx-defs.h"
 
-extern "C++" {
-
-class DiagMatrix : public DiagArray<double>
+class
+DiagMatrix : public MDiagArray2<double>
 {
 friend class SVD;
 friend class ComplexSVD;
 
 public:
 
-  DiagMatrix (void) : DiagArray<double> () { }
-  DiagMatrix (int n) : DiagArray<double> (n) { }
-  DiagMatrix (int n, double val) : DiagArray<double> (n, val) { }
-  DiagMatrix (int r, int c) : DiagArray<double> (r, c) { }
-  DiagMatrix (int r, int c, double val) : DiagArray<double> (r, c, val) { }
-  DiagMatrix (const RowVector& a) : DiagArray<double> (a) { }
-  DiagMatrix (const ColumnVector& a) : DiagArray<double> (a) { }
-  DiagMatrix (const DiagArray<double>& a) : DiagArray<double> (a) { }
-  DiagMatrix (const DiagMatrix& a) : DiagArray<double> (a) { }
-//  DiagMatrix (double a) : DiagArray<double> (1, a) { }
+  DiagMatrix (void) : MDiagArray2<double> () { }
+
+  DiagMatrix (int r, int c) : MDiagArray2<double> (r, c) { }
+
+  DiagMatrix (int r, int c, double val) : MDiagArray2<double> (r, c, val) { }
+
+  DiagMatrix (const DiagMatrix& a) : MDiagArray2<double> (a) { }
+
+  DiagMatrix (const MDiagArray2<double>& a) : MDiagArray2<double> (a) { }
+
+  explicit DiagMatrix (const RowVector& a) : MDiagArray2<double> (a) { }
+
+  explicit DiagMatrix (const ColumnVector& a) : MDiagArray2<double> (a) { }
 
   DiagMatrix& operator = (const DiagMatrix& a)
     {
-      DiagArray<double>::operator = (a);
+      MDiagArray2<double>::operator = (a);
       return *this;
     }
 
-//  operator DiagArray<double>& () const { return *this; }
-
-  int operator == (const DiagMatrix& a) const;
-  int operator != (const DiagMatrix& a) const;
+  bool operator == (const DiagMatrix& a) const;
+  bool operator != (const DiagMatrix& a) const;
 
   DiagMatrix& fill (double val);
   DiagMatrix& fill (double val, int beg, int end);
@@ -74,11 +77,11 @@ public:
   friend DiagMatrix real (const ComplexDiagMatrix& a);
   friend DiagMatrix imag (const ComplexDiagMatrix& a);
 
-// resize is the destructive analog for this one
+  // resize is the destructive analog for this one
 
   Matrix extract (int r1, int c1, int r2, int c2) const;
 
-// extract row or column i.
+  // extract row or column i.
 
   RowVector row (int i) const;
   RowVector row (char *s) const;
@@ -89,45 +92,31 @@ public:
   DiagMatrix inverse (void) const;
   DiagMatrix inverse (int& info) const;
 
-// diagonal matrix by diagonal matrix -> diagonal matrix operations
-
-  DiagMatrix& operator += (const DiagMatrix& a);
-  DiagMatrix& operator -= (const DiagMatrix& a);
-
-// diagonal matrix by diagonal matrix -> diagonal matrix operations
-
-  friend DiagMatrix operator * (const DiagMatrix& a,
-				const DiagMatrix& b);
-
-// other operations
+  // other operations
 
   ColumnVector diag (void) const;
   ColumnVector diag (int k) const;
 
-// i/o
+  // i/o
 
-  friend ostream& operator << (ostream& os, const DiagMatrix& a);
-
-#define KLUDGE_DIAG_MATRICES
-#define TYPE double
-#define KL_DMAT_TYPE DiagMatrix
-#include "mx-kludge.h"
-#undef KLUDGE_DIAG_MATRICES
-#undef TYPE
-#undef KL_DMAT_TYPE
+  friend std::ostream& operator << (std::ostream& os, const DiagMatrix& a);
 
 private:
 
-  DiagMatrix (double *d, int nr, int nc) : DiagArray<double> (d, nr, nc) { }
+  DiagMatrix (double *d, int nr, int nc) : MDiagArray2<double> (d, nr, nc) { }
 };
 
-} // extern "C++"
+// diagonal matrix by diagonal matrix -> diagonal matrix operations
+
+DiagMatrix
+operator * (const DiagMatrix& a, const DiagMatrix& b);
+
+MDIAGARRAY2_FORWARD_DEFS (MDiagArray2, DiagMatrix, double)
 
 #endif
 
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
-;;; page-delimiter: "^/\\*" ***
 ;;; End: ***
 */
