@@ -1,7 +1,6 @@
-//                                  -*- C++ -*-
 /*
 
-Copyright (C) 1992, 1993, 1994, 1995 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -17,55 +16,65 @@ for more details.
 
 You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
 #if !defined (octave_Matrix_int_h)
 #define octave_Matrix_int_h 1
 
-// For FILE...
-#include <stdio.h>
+#if defined (__GNUG__)
+#pragma interface
+#endif
 
-#include "Array.h"
+#include "MArray2.h"
+#include "MDiagArray2.h"
 
 #include "mx-defs.h"
+#include "mx-op-defs.h"
 
-extern "C++" {
+#include "data-conv.h"
+#include "mach-info.h"
 
-class Matrix : public Array2<double>
+class
+Matrix : public MArray2<double>
 {
-friend class ComplexMatrix;
-friend class AEPBAL;
-friend class CHOL;
-friend class GEPBAL;
-friend class HESS;
-friend class LU;
-friend class QR;
-friend class QRP;
-friend class SCHUR;
-friend class SVD;
-
 public:
 
-  Matrix (void) : Array2<double> () { }
-  Matrix (int r, int c) : Array2<double> (r, c) { }
-  Matrix (int r, int c, double val) : Array2<double> (r, c, val) { }
-  Matrix (const Array2<double>& a) : Array2<double> (a) { }
-  Matrix (const Matrix& a) : Array2<double> (a) { }
-  Matrix (const DiagArray<double>& a) : Array2<double> (a) { }
-  Matrix (const DiagMatrix& a);
+  typedef void (*solve_singularity_handler) (double rcond);
+
+  Matrix (void) : MArray2<double> () { }
+
+  Matrix (int r, int c) : MArray2<double> (r, c) { }
+
+  Matrix (int r, int c, double val) : MArray2<double> (r, c, val) { }
+
+  Matrix (const Matrix& a) : MArray2<double> (a) { }
+
+  Matrix (const MArray2<double>& a) : MArray2<double> (a) { }
+
+  explicit Matrix (const RowVector& rv);
+
+  explicit Matrix (const ColumnVector& cv);
+
+  explicit Matrix (const DiagMatrix& a);
+
+  explicit Matrix (const boolMatrix& a);
+
+  explicit Matrix (const charMatrix& a);
 
   Matrix& operator = (const Matrix& a)
     {
-      Array2<double>::operator = (a);
+      MArray2<double>::operator = (a);
       return *this;
     }
 
-  int operator == (const Matrix& a) const;
-  int operator != (const Matrix& a) const;
+  bool operator == (const Matrix& a) const;
+  bool operator != (const Matrix& a) const;
 
-// destructive insert/delete/reorder operations
+  bool is_symmetric (void) const;
+
+  // destructive insert/delete/reorder operations
 
   Matrix& insert (const Matrix& a, int r, int c);
   Matrix& insert (const RowVector& a, int r, int c);
@@ -85,16 +94,16 @@ public:
   Matrix stack (const ColumnVector& a) const;
   Matrix stack (const DiagMatrix& a) const;
 
-  Matrix transpose (void) const;
-
   friend Matrix real (const ComplexMatrix& a);
   friend Matrix imag (const ComplexMatrix& a);
 
-// resize is the destructive equivalent for this one
+  Matrix transpose (void) const { return MArray2<double>::transpose (); }
+
+  // resize is the destructive equivalent for this one
 
   Matrix extract (int r1, int c1, int r2, int c2) const;
 
-// extract row or column i.
+  // extract row or column i.
 
   RowVector row (int i) const;
   RowVector row (char *s) const;
@@ -104,7 +113,7 @@ public:
 
   Matrix inverse (void) const;
   Matrix inverse (int& info) const;
-  Matrix inverse (int& info, double& rcond) const;
+  Matrix inverse (int& info, double& rcond, int force = 0) const;
 
   Matrix pseudo_inverse (double tol = 0.0);
 
@@ -121,19 +130,28 @@ public:
   Matrix solve (const Matrix& b) const;
   Matrix solve (const Matrix& b, int& info) const;
   Matrix solve (const Matrix& b, int& info, double& rcond) const;
+  Matrix solve (const Matrix& b, int& info, double& rcond,
+		solve_singularity_handler sing_handler) const;
 
   ComplexMatrix solve (const ComplexMatrix& b) const;
   ComplexMatrix solve (const ComplexMatrix& b, int& info) const;
   ComplexMatrix solve (const ComplexMatrix& b, int& info, double& rcond) const;
+  ComplexMatrix solve (const ComplexMatrix& b, int& info, double& rcond,
+		       solve_singularity_handler sing_handler) const;
 
   ColumnVector solve (const ColumnVector& b) const;
   ColumnVector solve (const ColumnVector& b, int& info) const;
   ColumnVector solve (const ColumnVector& b, int& info, double& rcond) const;
+  ColumnVector solve (const ColumnVector& b, int& info, double& rcond,
+		      solve_singularity_handler sing_handler) const;
 
   ComplexColumnVector solve (const ComplexColumnVector& b) const;
   ComplexColumnVector solve (const ComplexColumnVector& b, int& info) const;
   ComplexColumnVector solve (const ComplexColumnVector& b, int& info,
 			     double& rcond) const;
+  ComplexColumnVector solve (const ComplexColumnVector& b, int& info,
+			     double& rcond,
+			     solve_singularity_handler sing_handler) const;
 
   Matrix lssolve (const Matrix& b) const;
   Matrix lssolve (const Matrix& b, int& info) const;
@@ -153,106 +171,97 @@ public:
   ComplexColumnVector lssolve (const ComplexColumnVector& b, int& info,
 			       int& rank) const;
 
-  Matrix& operator += (const Matrix& a);
-  Matrix& operator -= (const Matrix& a);
+  Matrix expm (void) const;
 
   Matrix& operator += (const DiagMatrix& a);
   Matrix& operator -= (const DiagMatrix& a);
 
-// unary operations
+  // unary operations
 
-  Matrix operator ! (void) const;
+  boolMatrix operator ! (void) const;
 
-// column vector by row vector -> matrix operations
+  // column vector by row vector -> matrix operations
 
-  friend Matrix operator * (const ColumnVector& a, const RowVector& a);
+  friend Matrix operator * (const ColumnVector& a, const RowVector& b);
 
-// diagonal matrix by scalar -> matrix operations
+  // other operations
 
-  friend Matrix operator + (const DiagMatrix& a, double s);
-  friend Matrix operator - (const DiagMatrix& a, double s);
+  Matrix map (d_d_Mapper f) const;
+  boolMatrix map (b_d_Mapper f) const;
 
-// scalar by diagonal matrix -> matrix operations
+  Matrix& apply (d_d_Mapper f);
 
-  friend Matrix operator + (double s, const DiagMatrix& a);
-  friend Matrix operator - (double s, const DiagMatrix& a);
+  bool any_element_is_negative (void) const;
+  bool any_element_is_inf_or_nan (void) const;
+  bool all_elements_are_int_or_inf_or_nan (void) const;
+  bool all_integers (double& max_val, double& min_val) const;
+  bool too_large_for_float (void) const;
+ 
+  boolMatrix all (void) const;
+  boolMatrix any (void) const;
 
-// matrix by diagonal matrix -> matrix operations
-
-  friend Matrix operator + (const Matrix& a, const DiagMatrix& b);
-  friend Matrix operator - (const Matrix& a, const DiagMatrix& b);
-  friend Matrix operator * (const Matrix& a, const DiagMatrix& b);
-
-// diagonal matrix by matrix -> matrix operations
-
-  friend Matrix operator + (const DiagMatrix& a, const Matrix& b);
-  friend Matrix operator - (const DiagMatrix& a, const Matrix& b);
-  friend Matrix operator * (const DiagMatrix& a, const Matrix& b);
-
-// matrix by matrix -> matrix operations
-
-  friend Matrix operator * (const Matrix& a, const Matrix& b);
-
-// other operations
-
-  friend Matrix map (d_d_Mapper f, const Matrix& a);
-  friend Matrix map (d_c_Mapper f, const ComplexMatrix& a);
-  void map (d_d_Mapper f);
-
-  Matrix all (void) const;
-  Matrix any (void) const;
-
-  Matrix cumprod (void) const;
-  Matrix cumsum (void) const;
-  Matrix prod (void) const;
-  Matrix sum (void) const;
-  Matrix sumsq (void) const;
+  Matrix cumprod (int dim = 0) const; //optional dimension argument
+  Matrix cumsum (int dim = 0) const;
+  Matrix prod (int dim = 0) const;
+  Matrix sum (int dim = 0) const;
+  Matrix sumsq (int dim = 0) const;
+  Matrix abs (void) const;
 
   ColumnVector diag (void) const;
   ColumnVector diag (int k) const;
 
   ColumnVector row_min (void) const;
-  ColumnVector row_min_loc (void) const;
-
   ColumnVector row_max (void) const;
-  ColumnVector row_max_loc (void) const;
+
+  ColumnVector row_min (Array<int>& index) const;
+  ColumnVector row_max (Array<int>& index) const;
 
   RowVector column_min (void) const;
-  RowVector column_min_loc (void) const;
-
   RowVector column_max (void) const;
-  RowVector column_max_loc (void) const;
 
-// i/o
+  RowVector column_min (Array<int>& index) const;
+  RowVector column_max (Array<int>& index) const;
 
-  friend ostream& operator << (ostream& os, const Matrix& a);
-  friend istream& operator >> (istream& is, Matrix& a);
+  // i/o
 
-  int read (FILE *fptr, char *type);
-  int write (FILE *fptr, char *type);
+  friend std::ostream& operator << (std::ostream& os, const Matrix& a);
+  friend std::istream& operator >> (std::istream& is, Matrix& a);
 
-// Until templates really work with g++:
+  int read (std::istream& is, int nr, int nc, oct_data_conv::data_type dt,
+	    int skip, oct_mach_info::float_format flt_fmt);
 
-#define KLUDGE_MATRICES
-#define TYPE double
-#define KL_MAT_TYPE Matrix
-#include "mx-kludge.h"
-#undef KLUDGE_MATRICES
-#undef TYPE
-#undef KL_MAT_TYPE
+  int write (std::ostream& os, oct_data_conv::data_type dt, int skip,
+	     oct_mach_info::float_format flt_fmt);
 
 private:
 
-  Matrix (double *d, int r, int c) : Array2<double> (d, r, c) { }
+  Matrix (double *d, int r, int c) : MArray2<double> (d, r, c) { }
 };
 
-} // extern "C++"
+extern Matrix Givens (double, double);
+
+extern Matrix Sylvester (const Matrix&, const Matrix&, const Matrix&);
+
+extern Matrix operator * (const Matrix& a, const Matrix& b);
+
+MS_CMP_OP_DECLS (Matrix, double)
+MS_BOOL_OP_DECLS (Matrix, double)
+
+SM_CMP_OP_DECLS (double, Matrix)
+SM_BOOL_OP_DECLS (double, Matrix)
+
+MM_CMP_OP_DECLS (Matrix, Matrix)
+MM_BOOL_OP_DECLS (Matrix, Matrix)
+
+MARRAY_FORWARD_DEFS (MArray2, Matrix, double)
+
+template <class T>
+void read_int (std::istream& is, bool swap_bytes, T& val);
 
 #endif
 
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
-;;; page-delimiter: "^/\\*" ***
 ;;; End: ***
 */
