@@ -1,7 +1,7 @@
 // RowVector manipulations.
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,7 +29,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 
 #include "f77-fcn.h"
 #include "lo-error.h"
@@ -59,7 +59,7 @@ RowVector::operator == (const RowVector& a) const
   int len = length ();
   if (len != a.length ())
     return 0;
-  return equal (data (), a.data (), len);
+  return mx_inline_equal (data (), a.data (), len);
 }
 
 bool
@@ -135,7 +135,7 @@ real (const ComplexRowVector& a)
   int a_len = a.length ();
   RowVector retval;
   if (a_len > 0)
-    retval = RowVector (real_dup (a.data (), a_len), a_len);
+    retval = RowVector (mx_inline_real_dup (a.data (), a_len), a_len);
   return retval;
 }
 
@@ -145,7 +145,7 @@ imag (const ComplexRowVector& a)
   int a_len = a.length ();
   RowVector retval;
   if (a_len > 0)
-    retval = RowVector (imag_dup (a.data (), a_len), a_len);
+    retval = RowVector (mx_inline_imag_dup (a.data (), a_len), a_len);
   return retval;
 }
 
@@ -164,52 +164,6 @@ RowVector::extract (int c1, int c2) const
   return result;
 }
 
-// row vector by row vector -> row vector operations
-
-RowVector&
-RowVector::operator += (const RowVector& a)
-{
-  int len = length ();
-
-  int a_len = a.length ();
-
-  if (len != a_len)
-    {
-      gripe_nonconformant ("operator +=", len, a_len);
-      return *this;
-    }
-
-  if (len == 0)
-    return *this;
-
-  double *d = fortran_vec (); // Ensures only one reference to my privates!
-
-  add2 (d, a.data (), len);
-  return *this;
-}
-
-RowVector&
-RowVector::operator -= (const RowVector& a)
-{
-  int len = length ();
-
-  int a_len = a.length ();
-
-  if (len != a_len)
-    {
-      gripe_nonconformant ("operator -=", len, a_len);
-      return *this;
-    }
-
-  if (len == 0)
-    return *this;
-
-  double *d = fortran_vec (); // Ensures only one reference to my privates!
-
-  subtract2 (d, a.data (), len);
-  return *this;
-}
-
 // row vector by matrix -> row vector
 
 RowVector
@@ -304,8 +258,8 @@ RowVector::max (void) const
   return res;
 }
 
-ostream&
-operator << (ostream& os, const RowVector& a)
+std::ostream&
+operator << (std::ostream& os, const RowVector& a)
 {
 //  int field_width = os.precision () + 7;
 
@@ -314,13 +268,13 @@ operator << (ostream& os, const RowVector& a)
   return os;
 }
 
-istream&
-operator >> (istream& is, RowVector& a)
+std::istream&
+operator >> (std::istream& is, RowVector& a)
 {
   int len = a.length();
 
   if (len < 1)
-    is.clear (ios::badbit);
+    is.clear (std::ios::badbit);
   else
     {
       double tmp;
@@ -343,7 +297,7 @@ linspace (double x1, double x2, int n)
 {
   RowVector retval;
 
-  if (n > 0)
+  if (n > 1)
     {
       retval.resize (n);
       double delta = (x2 - x1) / (n - 1);
@@ -352,6 +306,20 @@ linspace (double x1, double x2, int n)
 	retval.elem (i) = x1 + i * delta;
       retval.elem (n-1) = x2;
     }
+  else if (n == 1)
+    {
+      if (x1 == x2)
+	{
+	  retval.resize (1);
+	  retval.elem (0) = x1;
+	}
+      else
+	(*current_liboctave_error_handler)
+	  ("linspace: npoints is 1, but x1 != x2");
+    }
+  else
+    (*current_liboctave_error_handler)
+      ("linspace: npoints must be greater than 0");
 
   return retval;
 }
