@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -31,18 +31,21 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "mx-defs.h"
 
-class RowVector : public MArray<double>
+class
+RowVector : public MArray<double>
 {
-friend class ColumnVector;
-
 public:
 
   RowVector (void) : MArray<double> () { }
-  RowVector (int n) : MArray<double> (n) { }
+
+  explicit RowVector (int n) : MArray<double> (n) { }
+
   RowVector (int n, double val) : MArray<double> (n, val) { }
-  RowVector (const MArray<double>& a) : MArray<double> (a) { }
+
   RowVector (const RowVector& a) : MArray<double> (a) { }
 
+  RowVector (const MArray<double>& a) : MArray<double> (a) { }
+
   RowVector& operator = (const RowVector& a)
     {
       MArray<double>::operator = (a);
@@ -70,11 +73,6 @@ public:
 
   RowVector extract (int c1, int c2) const;
 
-  // row vector by row vector -> row vector operations
-
-  RowVector& operator += (const RowVector& a);
-  RowVector& operator -= (const RowVector& a);
-
   // row vector by matrix -> row vector
 
   friend RowVector operator * (const RowVector& a, const Matrix& b);
@@ -90,8 +88,8 @@ public:
 
   // i/o
 
-  friend ostream& operator << (ostream& os, const RowVector& a);
-  friend istream& operator >> (istream& is, RowVector& a);
+  friend std::ostream& operator << (std::ostream& os, const RowVector& a);
+  friend std::istream& operator >> (std::istream& is, RowVector& a);
 
 private:
 
@@ -108,6 +106,8 @@ Complex operator * (const RowVector& a, const ComplexColumnVector& b);
 
 RowVector linspace (double x1, double x2, int n);
 
+MARRAY_FORWARD_DEFS (MArray, RowVector, double)
+
 #endif
 
 /*
