@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -26,26 +26,104 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <cctype>
 
-#include <iostream.h>
+#include <iostream>
 
 #include "byte-swap.h"
 #include "data-conv.h"
 #include "lo-error.h"
 
+#define FIND_SIZED_INT_TYPE(VAL, BITS, TQ, Q) \
+  do \
+    { \
+      int sz = BITS / CHAR_BIT; \
+      if (sizeof (TQ char) == sz) \
+	VAL = oct_data_conv::dt_ ## Q ## char; \
+      else if (sizeof (TQ short) == sz) \
+	VAL = oct_data_conv::dt_ ## Q ## short; \
+      else if (sizeof (TQ int) == sz) \
+	VAL = oct_data_conv::dt_ ## Q ## int; \
+      else if (sizeof (TQ long) == sz) \
+	VAL = oct_data_conv::dt_ ## Q ## long; \
+      else \
+        VAL = oct_data_conv::dt_unknown; \
+    } \
+  while (0)
+
+#define FIND_SIZED_FLOAT_TYPE(VAL, BITS) \
+  do \
+    { \
+      int sz = BITS / CHAR_BIT; \
+      if (sizeof (float) == sz) \
+	VAL = oct_data_conv::dt_float; \
+      else if (sizeof (double) == sz) \
+	VAL = oct_data_conv::dt_double; \
+      else \
+        VAL = oct_data_conv::dt_unknown; \
+    } \
+  while (0)
+
+// I'm not sure it is worth the trouble, but let's use a lookup table
+// for the types that are supposed to be a specific number of bits
+// wide.  Given the macros above, this should work as long as CHAR_BIT
+// is a multiple of 8 and there are types with the right sizes.
+//
+// The sized data type lookup table has the following format:
+//
+//                            bits
+//                    +----+----+----+----+
+//                    |  8 | 16 | 32 | 64 |
+//                    +----+----+----+----+
+//     signed integer |    |    |    |    |
+//                    +----+----+----+----+
+//   unsigned integer |    |    |    |    |
+//                    +----+----+----+----+
+//     floating point |    |    |    |    |
+//                    +----+----+----+----+
+//
+// So, the 0,3 element is supposed to contain the oct_data_conv enum
+// value corresponding to the correct native data type for a signed
+// 32-bit integer.
+
+static void
+init_sized_type_lookup_table (oct_data_conv::data_type table[3][4])
+{
+  int bits = 8;
+
+  for (int i = 0; i < 4; i++)
+    {
+      FIND_SIZED_INT_TYPE (table[0][i], bits, , );
+
+      FIND_SIZED_INT_TYPE (table[1][i], bits, unsigned, u);
+
+      FIND_SIZED_FLOAT_TYPE (table[2][i], bits);
+
+      bits *= 2;
+    }
+}
+
 oct_data_conv::data_type
-oct_data_conv::string_to_data_type (const string& str)
+oct_data_conv::string_to_data_type (const std::string& str)
 {
   data_type retval = dt_unknown;
 
-    // XXX FIXME XXX -- finish implementing this.
+  static bool initialized = false;
 
-  // XXX FIXME XXX -- before checking s, need to strip spaces and downcase.
+  static data_type sized_type_table[3][4];
+
+  if (! initialized)
+    {
+      init_sized_type_lookup_table (sized_type_table);
+
+      initialized = true;
+    }
+
+  // XXX FIXME XXX -- finish implementing this.
 
   int n = str.length ();
 
   int k = 0;
 
-  string s (n, ' ');
+  std::string s (n, ' ');
 
   for (int i = 0; i < n; i++)
     if (! isspace (str[i]))
@@ -53,7 +131,7 @@ oct_data_conv::string_to_data_type (const string& str)
 
   s.resize (k);
 
-  if (s == "char" || s == "char*1" || s == "integer*1" || s == "int8")
+  if (s == "char")
     retval = dt_char;
   else if (s == "schar" || s == "signedchar")
     retval = dt_schar;
@@ -71,65 +149,49 @@ oct_data_conv::string_to_data_type (const string& str)
     retval = dt_long;
   else if (s == "ulong" || s == "unsignedlong")
     retval = dt_ulong;
-  else if (s == "float" || s == "float32" || s == "real*4")
+  else if (s == "float")
     retval = dt_float;
-  else if (s == "double" || s == "float64" || s == "real*8")
+  else if (s == "double")
     retval = dt_double;
+  else if (s == "int8" || s == "char*1" || s == "integer*1")
+    retval = sized_type_table[0][0];
   else if (s == "int16" || s == "integer*2")
-    {
-      if (sizeof (short) == 2)
-	retval = dt_short;
-      else if (sizeof (int) == 2)
-	retval = dt_int;
-      else
-	(*current_liboctave_error_handler)
-	  ("unable to find matching native data type for %s", s.c_str ());
-    }
+    retval = sized_type_table[0][1];
   else if (s == "int32" || s == "integer*4")
-    {
-      if (sizeof (int) == 4)
-	retval = dt_int;
-      else if (sizeof (long) == 4)
-	retval = dt_long;
-      else
-	(*current_liboctave_error_handler)
-	  ("unable to find matching native data type for %s", s.c_str ());
-    }
+    retval = sized_type_table[0][2];
+  else if (s == "int64" || s == "integer*8")
+    retval = sized_type_table[0][3];
+  else if (s == "uint8")
+    retval = sized_type_table[1][0];
   else if (s == "uint16")
-    {
-      if (sizeof (unsigned short) == 2)
-        retval = dt_ushort;
-      else if (sizeof (unsigned int) == 2)
-        retval = dt_uint;
-      else
-       (*current_liboctave_error_handler)
-         ("unable to find matching native data type for %s", s.c_str ());
-    }
+    retval = sized_type_table[1][1];
   else if (s == "uint32")
-    {
-      if (sizeof (unsigned int) == 4)
-        retval = dt_uint;
-      else if (sizeof (unsigned long) == 4)
-        retval = dt_ulong;
-      else
-       (*current_liboctave_error_handler)
-         ("unable to find matching native data type for %s", s.c_str ());
-    }
+    retval = sized_type_table[1][2];
+  else if (s == "uint64")
+    retval = sized_type_table[1][3];
+  else if (s == "float32" || s == "real*4")
+    retval = sized_type_table[2][2];
+  else if (s == "float64" || s == "real*8")
+    retval = sized_type_table[2][3];
   else
     (*current_liboctave_error_handler) ("invalid data type specified");
 
+  if (retval == dt_unknown)
+    (*current_liboctave_error_handler)
+      ("unable to find matching native data type for %s", s.c_str ());
+
   return retval;
 }
 
 #define swap_1_bytes(x, y)
 
-#define LS_DO_READ(TYPE,swap,data,size,len,stream) \
+#define LS_DO_READ(TYPE, swap, data, size, len, stream) \
   do \
     { \
-      volatile TYPE *ptr = (TYPE *) data; \
-      stream.read ((TYPE *) ptr, size * len); \
+      volatile TYPE *ptr = X_CAST (volatile TYPE *, data); \
+      stream.read (X_CAST (char *, ptr), size * len); \
       if (swap) \
-        swap_ ## size ## _bytes ((char *) ptr, len); \
+        swap_ ## size ## _bytes (ptr, len); \
       TYPE tmp = ptr[0]; \
       for (int i = len - 1; i > 0; i--) \
         data[i] = ptr[i]; \
@@ -140,15 +202,15 @@ oct_data_conv::string_to_data_type (const string& str)
 // Have to use copy here to avoid writing over data accessed via
 // Matrix::data().
 
-#define LS_DO_WRITE(TYPE,data,size,len,stream) \
+#define LS_DO_WRITE(TYPE, data, size, len, stream) \
   do \
     { \
-      char tmp_type = (char) type; \
+      char tmp_type = static_cast<char> (type); \
       stream.write (&tmp_type, 1); \
       TYPE *ptr = new TYPE [len]; \
       for (int i = 0; i < len; i++) \
-        ptr[i] = (TYPE) data[i]; \
-      stream.write ((TYPE *) ptr, size * len); \
+        ptr[i] = X_CAST (TYPE, data[i]); \
+      stream.write (X_CAST (char *, ptr), size * len); \
       delete [] ptr ; \
     } \
   while (0)
@@ -181,7 +243,7 @@ gripe_data_conversion (const char *from, const char *to)
 static void
 IEEE_big_double_to_IEEE_little_double (double *d, int len)
 {
-  swap_8_bytes ((char *) d, len);
+  swap_8_bytes (d, len);
 }
 
 static void
@@ -205,7 +267,7 @@ Cray_to_IEEE_little_double (double * /* d */, int /* len */)
 static void
 IEEE_big_float_to_IEEE_little_float (float *d, int len)
 {
-  swap_4_bytes ((char *) d, len);
+  swap_4_bytes (d, len);
 }
 
 static void
@@ -229,7 +291,7 @@ Cray_to_IEEE_little_float (float * /* d */, int /* len */)
 static void
 IEEE_little_double_to_IEEE_big_double (double *d, int len)
 {
-  swap_8_bytes ((char *) d, len);
+  swap_8_bytes (d, len);
 }
 
 static void
@@ -253,7 +315,7 @@ Cray_to_IEEE_big_double (double * /* d */, int /* len */)
 static void
 IEEE_little_float_to_IEEE_big_float (float *d, int len)
 {
-  swap_4_bytes ((char *) d, len);
+  swap_4_bytes (d, len);
 }
 
 static void
@@ -623,7 +685,7 @@ do_float_format_conversion (float *data, int len,
 }
 
 void
-read_doubles (istream& is, double *data, save_type type, int len,
+read_doubles (std::istream& is, double *data, save_type type, int len,
 	      int swap, oct_mach_info::float_format fmt)
 {
   switch (type)
@@ -654,9 +716,9 @@ read_doubles (istream& is, double *data, save_type type, int len,
 
     case LS_FLOAT:
       {
-	volatile float *ptr = (float *) data;
-	is.read (data, 4 * len);
-	do_float_format_conversion ((float *) data, len, fmt);
+	volatile float *ptr = X_CAST (float *, data);
+	is.read (X_CAST (char *, data), 4 * len);
+	do_float_format_conversion (X_CAST (float *, data), len, fmt);
 	float tmp = ptr[0];
 	for (int i = len - 1; i > 0; i--)
 	  data[i] = ptr[i];
@@ -664,19 +726,19 @@ read_doubles (istream& is, double *data, save_type type, int len,
       }
       break;
 
-    case LS_DOUBLE:
-      is.read (data, 8 * len);
+    case LS_DOUBLE: // No conversion necessary.
+      is.read (X_CAST (char *, data), 8 * len);
       do_double_format_conversion (data, len, fmt);
       break;
 
     default:
-      is.clear (ios::failbit|is.rdstate ());
+      is.clear (std::ios::failbit|is.rdstate ());
       break;
     }
 }
 
 void
-write_doubles (ostream& os, const double *data, save_type type, int len)
+write_doubles (std::ostream& os, const double *data, save_type type, int len)
 {
   switch (type)
     {
@@ -708,11 +770,11 @@ write_doubles (ostream& os, const double *data, save_type type, int len)
       LS_DO_WRITE (float, data, 4, len, os);
       break;
 
-    case LS_DOUBLE:
+    case LS_DOUBLE: // No conversion necessary.
       {
-	char tmp_type = (char) type;
+	char tmp_type = X_CAST (char, type);
 	os.write (&tmp_type, 1);
-	os.write (data, 8 * len);
+	os.write (X_CAST (char *, data), 8 * len);
       }
       break;
 
