@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -46,7 +46,7 @@ extern "C"
 }
 
 int
-AEPBALANCE::init (const Matrix& a, const string& balance_job)
+AEPBALANCE::init (const Matrix& a, const std::string& balance_job)
 {
   int n = a.cols ();
 
