@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -27,8 +27,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #pragma interface
 #endif
 
-class ostream;
-
+#include <iostream>
 #include <string>
 
 #include "dMatrix.h"
@@ -40,7 +39,7 @@ public:
 
   AEPBALANCE (void) : balanced_mat (), balancing_mat () { }
 
-  AEPBALANCE (const Matrix& a,const string& balance_job)
+  AEPBALANCE (const Matrix& a,const std::string& balance_job)
     {
       init (a, balance_job); 
     }
@@ -64,14 +63,14 @@ public:
 
   Matrix balancing_matrix (void) const { return balancing_mat; }
 
-  friend ostream& operator << (ostream& os, const AEPBALANCE& a);
+  friend std::ostream& operator << (std::ostream& os, const AEPBALANCE& a);
 
 private:
 
   Matrix balanced_mat;
   Matrix balancing_mat;
 
-  int init (const Matrix& a, const string& balance_job);
+  int init (const Matrix& a, const std::string& balance_job);
 };
 
 #endif
