@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -27,7 +27,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #pragma interface
 #endif
 
-class ostream;
+#include <iostream>
 
 #include "dbleQR.h"
 
@@ -59,7 +59,7 @@ public:
 
   Matrix P (void) const { return p; }
 
-  friend ostream&  operator << (ostream&, const QRP&);
+  friend std::ostream&  operator << (std::ostream&, const QRP&);
 
 protected:
 
