@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,12 +28,11 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 
 #include "dbleSCHUR.h"
 #include "f77-fcn.h"
 #include "lo-error.h"
-#include "mx-inlines.cc"
 
 extern "C"
 {
@@ -59,7 +58,7 @@ select_dig (const double& a, const double& b)
 }
 
 int
-SCHUR::init (const Matrix& a, const string& ord)
+SCHUR::init (const Matrix& a, const std::string& ord)
 {
   int a_nr = a.rows ();
   int a_nc = a.cols ();
@@ -70,6 +69,9 @@ SCHUR::init (const Matrix& a, const string& ord)
       return -1;
     }
 
+  // Workspace requirements may need to be fixed if any of the
+  // following change.
+
   char jobvs = 'V';
   char sense = 'N';
   char sort = 'N';
@@ -109,20 +111,12 @@ SCHUR::init (const Matrix& a, const string& ord)
   Array<double> work (lwork);
   double *pwork = work.fortran_vec ();
 
-  // These are not referenced for the non-ordered Schur routine.
-
-  Array<int> bwork;
-  Array<int> iwork;
-
-  if (ord_char == 'A' || ord_char == 'D' || ord_char == 'a' || ord_char == 'd')
-    {
-      bwork.resize (n);
-      iwork.resize (liwork);
-    }
-
+  // BWORK is not referenced for the non-ordered Schur routine.
+  Array<int> bwork ((ord_char == 'N' || ord_char == 'n') ? 0 : n);
   int *pbwork = bwork.fortran_vec ();
-  int *piwork = iwork.fortran_vec ();
 
+  Array<int> iwork (liwork);
+  int *piwork = iwork.fortran_vec ();
 
   F77_XFCN (dgeesx, DGEESX, (&jobvs, &sort, selector, &sense, n, s,
 			     n, sdim, pwr, pwi, q, n, rconde, rcondv,
@@ -135,8 +129,8 @@ SCHUR::init (const Matrix& a, const string& ord)
   return info;
 }
 
-ostream&
-operator << (ostream& os, const SCHUR& a)
+std::ostream&
+operator << (std::ostream& os, const SCHUR& a)
 {
   os << a.schur_matrix () << "\n";
   os << a.unitary_matrix () << "\n";
