@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -57,7 +57,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define M_PI 3.14159265358979323846
 #endif
 
-// Double -> double mappers.
+// double -> double mappers.
 
 double
 arg (double x)
@@ -144,71 +144,57 @@ xerfc (double x)
 #endif
 }
 
-double
+// double -> bool mappers.
+
+bool
 xisnan (double x)
 {
 #if defined (HAVE_ISNAN)
-  return (double) (isnan (x) != 0);
+  return isnan (x) != 0;
 #else
-  return 0;
+  return false;
 #endif
 }
 
-double
+bool
 xfinite (double x)
 {
 #if defined (HAVE_FINITE)
-  return (double) (finite (x) != 0);
+  return finite (x) != 0;
 #elif defined (HAVE_ISINF) && defined (HAVE_ISNAN)
-  return (double) (! isinf (x) && ! isnan (x));
+  return (! isinf (x) && ! isnan (x));
 #else
-  return 1;
+  return true;
 #endif
 }
 
-double
+bool
 xisinf (double x)
 {
 #if defined (HAVE_ISINF)
-  return (double) isinf (x);
+  return isinf (x);
 #elif defined (HAVE_FINITE) && defined (HAVE_ISNAN)
-  return (double) (! (finite (x) || isnan (x)));
+  return (! (finite (x) || isnan (x)));
 #else
-  return 0;
+  return false;
 #endif
 }
 
-// Complex -> double mappers.
+// (double, double) -> double mappers.
 
 double
-xisnan (const Complex& x)
+xmin (double x, double y)
 {
-#if defined (HAVE_ISNAN)
-  double rx = real (x);
-  double ix = imag (x);
-  return (double) (isnan (rx) || isnan (ix));
-#else
-  return 0;
-#endif
+  return x < y ? x : (xisnan (x) ? x : y);
 }
 
 double
-xfinite (const Complex& x)
+xmax (double x, double y)
 {
-  double rx = real (x);
-  double ix = imag (x);
-  return (double) ((int) xfinite (rx) && (int) xfinite (ix));
+  return x > y ? x : (xisnan (x) ? x : y);
 }
 
-double
-xisinf (const Complex& x)
-{
-  double rx = real (x);
-  double ix = imag (x);
-  return (double) ((int) xisinf (rx) || (int) xisinf (ix));
-}
-
-// Complex -> complex mappers.
+// complex -> complex mappers.
 
 Complex
 acos (const Complex& x)
@@ -221,47 +207,63 @@ acos (const Complex& x)
 Complex
 acosh (const Complex& x)
 {
-  Complex retval = log (x + sqrt (x*x - 1.0));
-  return retval;
+  return log (x + sqrt (x*x - 1.0));
 }
 
 Complex
 asin (const Complex& x)
 {
   static Complex i (0, 1);
-  Complex retval = -i * log (i*x + sqrt (1.0 - x*x));
-  return retval;
+
+  return -i * log (i*x + sqrt (1.0 - x*x));
 }
 
 Complex
 asinh (const Complex& x)
 {
-  Complex retval = log (x + sqrt (x*x + 1.0));
-  return retval;
+  return log (x + sqrt (x*x + 1.0));
 }
 
 Complex
 atan (const Complex& x)
 {
   static Complex i (0, 1);
-  Complex retval = i * log ((i + x) / (i - x)) / 2.0;
-  return retval;
+
+  return i * log ((i + x) / (i - x)) / 2.0;
 }
 
 Complex
 atanh (const Complex& x)
 {
-  static Complex i (0, 1);
-  Complex retval = log ((1.0 + x) / (1.0 - x)) / 2.0;
-  return retval;
+  return log ((1.0 + x) / (1.0 - x)) / 2.0;
 }
 
+#if !defined (CXX_ISO_COMPLIANT_LIBRARY)
+
+Complex
+log10 (const Complex& x)
+{
+  return M_LOG10E * log (x);
+}
+
+Complex
+tan (const Complex& x)
+{
+  return sin (x) / cos (x);
+}
+
+Complex
+tanh (const Complex& x)
+{
+  return sinh (x) / cosh (x);
+}
+
+#endif
+
 Complex
 ceil (const Complex& x)
 {
-  int re = (int) ceil (real (x));
-  int im = (int) ceil (imag (x));
-  return Complex (re, im);
+  return Complex (ceil (real (x)), ceil (imag (x)));
 }
 
 Complex
@@ -273,23 +275,13 @@ fix (const Complex& x)
 Complex
 floor (const Complex& x)
 {
-  int re = (int) floor (real (x));
-  int im = (int) floor (imag (x));
-  return Complex (re, im);
-}
-
-Complex
-log10 (const Complex& x)
-{
-  return M_LOG10E * log (x);
+  return Complex (floor (real (x)), floor (imag (x)));
 }
 
 Complex
 round (const Complex& x)
 {
-  double re = D_NINT (real (x));
-  double im = D_NINT (imag (x));
-  return Complex (re, im);
+  return Complex (D_NINT (real (x)), D_NINT (imag (x)));
 }
 
 Complex
@@ -298,18 +290,42 @@ signum (const Complex& x)
   return x / abs (x);
 }
 
-Complex
-tan (const Complex& x)
+// complex -> bool mappers.
+
+bool
+xisnan (const Complex& x)
 {
-  Complex retval = sin (x) / cos (x);
-  return retval;
+#if defined (HAVE_ISNAN)
+  return (isnan (real (x)) || isnan (imag (x)));
+#else
+  return false;
+#endif
+}
+
+bool
+xfinite (const Complex& x)
+{
+  return (xfinite (real (x)) && xfinite (imag (x)));
+}
+
+bool
+xisinf (const Complex& x)
+{
+  return (xisinf (real (x)) || xisinf (imag (x)));
+}
+
+// (complex, complex) -> complex mappers.
+
+Complex
+xmin (const Complex& x, const Complex& y)
+{
+  return abs (x) <= abs (y) ? x : (xisnan (x) ? x : y);
 }
 
 Complex
-tanh (const Complex& x)
+xmax (const Complex& x, const Complex& y)
 {
-  Complex retval = sinh (x) / cosh (x);
-  return retval;
+  return abs (x) >= abs (y) ? x : (xisnan (x) ? x : y);
 }
 
 /*
