@@ -33,7 +33,6 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "lo-error.h"
 #include "lo-ieee.h"
 #include "lo-specfun.h"
-#include "lo-utils.h"
 #include "mx-inlines.cc"
 
 extern "C"
@@ -675,10 +674,11 @@ biry (const ComplexMatrix& z, bool deriv, bool scaled, Array2<int>& ierr)
 }
 
 static void
-gripe_betainc_nonconformant (int r1, int c1, int r2, int c2, int r3, int c3)
+gripe_betainc_nonconformant (int r1, int c1, int r2, int c2, int r3,
+			     int c3)
 {
   (*current_liboctave_error_handler)
-    ("betainc: nonconformant arguments (x is %dx%d, a is %dx%d, b is %dx%d)",
+   ("betainc: nonconformant arguments (x is %dx%d, a is %dx%d, b is %dx%d)",
      r1, c1, r2, c2, r3, c3);
 }
 
