@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,9 +23,27 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_liboctave_utils_h)
 #define octave_liboctave_utils_h 1
 
+#include <cstdio>
+
+#include <string>
+
 extern int NINT (double x);
 extern double D_NINT (double x);
 
+extern char *strsave (const char *);
+
+extern void octave_putenv (const std::string&, const std::string&);
+
+extern std::string octave_fgets (std::FILE *);
+
+extern "C" int octave_gethostname (char *, int);
+
+extern "C" void octave_qsort (void *base, size_t n, size_t size,
+			      int (*cmp) (const void *, const void *));
+
+extern "C" char *oct_strptime (const char *buf, const char *format,
+			       struct tm *tm);
+
 #endif
 
 /*
