@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,6 +28,10 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 class
 oct_mach_info
 {
+protected:
+
+  oct_mach_info (void);
+
 public:
 
   enum float_format
@@ -41,7 +45,7 @@ public:
       cray
     };
 
-  oct_mach_info (void);
+  static bool instance_ok (void);
 
   static float_format native_float_format (void);
 
@@ -49,23 +53,23 @@ public:
 
   static bool words_little_endian (void);
 
-  static float_format string_to_float_format (const string&);
+  static float_format string_to_float_format (const std::string&);
 
-  static string float_format_as_string (float_format);
+  static std::string float_format_as_string (float_format);
 
 private:
 
   static oct_mach_info *instance;
 
-  void init_float_format (void);
+  void init_float_format (void) const;
 
-  void ten_little_endians (void);
+  void ten_little_endians (void) const;
 
   // The floating point format for the current machine.
-  float_format native_float_fmt;
+  mutable float_format native_float_fmt;
 
   // TRUE if the byte order on this system is big endian.
-  bool big_chief;
+  mutable bool big_chief;
 
   // No copying!
 
