@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -32,20 +32,23 @@ dir_path
 {
 public:
 
-  dir_path (const string& s = string ())
-    : p_orig (s), initialized (false)
+  dir_path (const std::string& s = std::string (),
+	    const std::string& d = std::string ())
+    : p_orig (s), p_default (d), initialized (false)
     {
       if (! p_orig.empty ())
 	init ();
     }
 
   dir_path (const dir_path& dp)
-    : p_orig (dp.p_orig), initialized (dp.initialized), p (dp.p), pv (dp.pv)
+    : p_orig (dp.p_orig), p_default (dp.p_default),
+      initialized (dp.initialized), p (dp.p), pv (dp.pv)
   { }
 
   dir_path& operator = (const dir_path& dp)
     {
       p_orig = dp.p_orig;
+      p_default = dp.p_default;
       initialized = dp.initialized;
       p = dp.p;
       pv = dp.pv;
@@ -54,7 +57,7 @@ public:
 
   ~dir_path (void) { }
 
-  void set (const string& s)
+  void set (const std::string& s)
     {
       initialized = false;
       p_orig = s;
@@ -64,30 +67,38 @@ public:
   string_vector elements (void);
   string_vector all_directories (void);
 
-  string find_first (const string&);
-  string find (const string& nm) { return find_first (nm); }
+  std::string find_first (const std::string&);
+  std::string find (const std::string& nm) { return find_first (nm); }
 
-  string_vector find_all (const string&);
+  string_vector find_all (const std::string&);
 
-  static void init_program_name (const string&);
+  static void set_program_name (const std::string&);
+
+  void rehash (void)
+    {
+      initialized = false;
+      init ();
+    }
 
 private:
 
   // The colon separated list that we were given.
-  string p_orig;
+  std::string p_orig;
+
+  // The default path.  If specified, replaces leading, trailing, or
+  // doubled colons in p_orig.
+  std::string p_default;
 
   // TRUE means we've unpacked p.
   bool initialized;
 
   // A version of the colon separate list on which we have performed
-  // tilde and variable expansion.
-  string p;
+  // tilde, variable, and possibly default path expansion.
+  std::string p;
 
   // The elements of the list.
   string_vector pv;
 
-  static string program_name;
-
   void init (void);
 };
 
