@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,10 +17,13 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage:  y = lin2mu (x)
-##
-## x is a vector of an 8- or 16-bit linearly encoded audio sample,
-## This is transformed into a mu-law encoded vector.
+## -*- texinfo -*-
+## @deftypefn {Function File} {} lin2mu (@var{x})
+## If the vector @var{x} represents mono audio data in 8- or 16-bit
+## linear encoding, @code{lin2mu (@var{x})} is the corresponding mu-law
+## encoding.
+## @end deftypefn
+## @seealso{mu2lin, loadaudio, saveaudio, playaudio, setaudio, and record}
 
 ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
 ## Created: 17 October 1994
