@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,17 +17,15 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage:  saveaudio (name, X, [, ext [, bit]])
-##
-## Saves a vector X of audio data in the file "name.ext".
-## The format of the audio file is determined by ext which has to be
-## written without an inital ".";  default value for ext is "lin".
-##
-## Currently, the following audio formats are supported:
-## *) mu-law files with extension "mu", "au" or "snd"
-## *) linearly encoded files with extension "lin" or "raw"
-## If the data is saved linearly, the bit argument decides whether an
-## 8-bit (default) or a 16-bit format is used.
+## -*- texinfo -*-
+## @deftypefn {Function File} {} saveaudio (@var{name}, @var{x}, @var{ext}, @var{bps})
+## Saves a vector @var{x} of audio data to the file
+## @file{@var{name}.@var{ext}}.  The optional parameters @var{ext} and
+## @var{bps} determine the encoding and the number of bits per sample used
+## in the audio file (see @code{loadaudio});  defaults are @file{lin} and
+## 8, respectively.
+## @end deftypefn
+## @seealso{lin2mu, mu2lin, loadaudio, playaudio, setaudio, and record}
 
 ## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
 ## Created: 5 September 1994
@@ -36,7 +34,7 @@
 function saveaudio (name, X, ext, bit)
 
   if (nargin < 2 || nargin > 4)
-    usage ("saveaudio (X, name [, ext [, bit]])");
+    usage ("saveaudio (X, name, ext, bit)");
   endif
 
   if (nargin == 2)
@@ -55,29 +53,30 @@ function saveaudio (name, X, ext, bit)
       X = X';
       nr = nc;
     else
-      error ("saveaudio: X must be a vector.");
+      error ("saveaudio: X must be a vector");
     endif
   endif
 
-  num = fopen ([name, ".", ext], "w");
+  num = fopen ([name, ".", ext], "wb");
 
   if (strcmp (ext, "lin") || strcmp (ext, "raw"))
     if (bit == 8)
       ld = max (abs (X));
       if (ld > 127)   # convert 16 to 8 bit
-	if (ld < 16384)
-	  sc = 64 / ld;
-	else
-	  sc = 1 / 256;
-	endif
-	X = fix (X * sc);
+        if (ld < 16384)
+          sc = 64 / ld;
+        else
+          sc = 1 / 256;
+        endif
+        X = fix (X * sc);
       endif
       X = X + 127;
       c = fwrite (num, X, "uchar");
     else
       c = fwrite (num, X, "short");
     endif
-  elseif (strcmp (ext, "mu") || strcmp (ext, "au") || strcmp (ext, "snd"))
+  elseif (strcmp (ext, "mu") || strcmp (ext, "au")
+	  || strcmp (ext, "snd") || strcmp (ext, "ul"))
     Y = lin2mu (X);
     c = fwrite (num, Y, "uchar");
   else
