@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,13 +17,30 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: gcd (a, ...)
+## -*- texinfo -*-
+## @deftypefn {Mapping Function} {} gcd (@var{x}, @code{...})
+## Compute the greatest common divisor of the elements of @var{x}, or the
+## list of all the arguments.  For example,
 ##
-## [g [, v]] = gcd (a) returns the greatest common divisor g of the
-## entries of the integer vector a, and an integer vector v such that
-## g = v(1) * a(k) + ... + v(k) * a(k).
+## @example
+## gcd (a1, ..., ak)
+## @end example
 ##
-## [g [, v]] = gcd (a1, ..., ak) is the same with a = [a1, ..., ak].
+## @noindent
+## is the same as
+##
+## @example
+## gcd ([a1, ..., ak])
+## @end example
+##
+## An optional second return value, @var{v}
+## contains an integer vector such that
+##
+## @example
+## g = v(1) * a(k) + ... + v(k) * a(k)
+## @end example
+## @end deftypefn
+## @seealso{lcm, min, max, ceil, and floor}
 
 ## Author: KH <Kurt.Hornik@ci.tuwien.ac.at>
 ## Created: 16 September 1994
