@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,23 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: lcm (a, ...)
+## -*- texinfo -*-
+## @deftypefn {Mapping Function} {} lcm (@var{x}, @code{...})
+## Compute the least common multiple of the elements elements of @var{x}, or
+## the list of all the arguments.  For example,
 ##
-## lcm (a) returns the least common multiple of the entries of the
-## integer vector a.
-## lcm (a1, ..., ak) is the same as lcm([a1, ..., ak]).
+## @example
+## lcm (a1, ..., ak)
+## @end example
+##
+## @noindent
+## is the same as
+##
+## @example
+## lcm ([a1, ..., ak]).
+## @end example
+## @end deftypefn
+## @seealso{gcd, min, max, ceil, and floor}
 
 ## Author: KH <Kurt.Hornik@ci.tuwien.ac.at>
 ## Created: 16 September 1994
@@ -41,7 +53,7 @@ function l = lcm (a, ...)
   endif
 
   if (round (a) != a)
-    error ("lcm:  all arguments must be integer");
+    error ("lcm: all arguments must be integer");
   endif
 
   if (any (a) == 0)
