@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,20 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: fliplr (x)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} fliplr (@var{x})
+## Return a copy of @var{x} with the order of the columns reversed.  For
+## example,
 ##
-## Return x with the columns swapped.
-##
-## See also: flipu, rot90
+## @example
+## @group
+## fliplr ([1, 2; 3, 4])
+##      @result{}  2  1
+##          4  3
+## @end group
+## @end example
+## @end deftypefn
+## @seealso{flipud and rot90}
 
 ## Author: jwe
 
@@ -31,7 +40,6 @@ function y = fliplr (x)
     usage ("fliplr (x)");
   endif
 
-  y = x;
   nc = columns (x);
   y = x (:, nc:-1:1);
 
