@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,20 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: flipud (x)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} flipud (@var{x})
+## Return a copy of @var{x} with the order of the rows reversed.  For
+## example,
 ##
-## Return x with the rows swapped.
-##
-## See also: fliplr, rot90
+## @example
+## @group
+## flipud ([1, 2; 3, 4])
+##      @result{}  3  4
+##          1  2
+## @end group
+## @end example
+## @end deftypefn
+## @seealso{fliplr and rot90}
 
 ## Author: jwe
 
@@ -31,7 +40,6 @@ function y = flipud (x)
     usage ("flipud (x)");
   endif
 
-  y = x;
   nr = rows (x);
   y = x (nr:-1:1, :);
 
