@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,19 +17,23 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: is_scalar (x)
-##
-## Return 1 if the number of rows and columns of x are both equal to 1.
-##
-## See also: size, rows, columns, length, is_scalar, is_matrix
+## -*- texinfo -*-
+## @deftypefn {Function File} {} is_scalar (@var{a})
+## Return 1 if @var{a} is a scalar.  Otherwise, return 0.
+## @end deftypefn
+## @seealso{size, rows, columns, length, is_scalar, and is_matrix}
 
 ## Author: jwe
 
 function retval = is_scalar (x)
 
+  retval = 0;
+
   if (nargin == 1)
-    [nr, nc] = size (x);
-    retval = (nr == 1 && nc == 1);
+    if (is_matrix (x))
+      [nr, nc] = size (x);
+      retval = (nr == 1 && nc == 1);
+    endif
   else
     usage ("is_scalar (x)");
   endif
