@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,12 +17,12 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: is_square (x)
-##
-## If x is square, then return value is the dimension of x.
-## otherwise, returns a value of 0
-##
-## See also: size, rows, columns, length, is_matrix, is_scalar, is_vector
+## -*- texinfo -*-
+## @deftypefn {Function File} {} is_square (@var{x})
+## If @var{x} is a square matrix, then return the dimension of @var{x}.
+## Otherwise, return 0.
+## @end deftypefn
+## @seealso{size, rows, columns, length, is_matrix, is_scalar, and is_vector}
 
 ## Author: A. S. Hodel <scotte@eng.auburn.edu>
 ## Created: August 1993
@@ -30,12 +30,14 @@
 
 function retval = is_square (x)
 
+  retval = 0;
+
   if (nargin == 1)
-    [nr, nc] = size (x);
-    if (nr == nc && nr > 0)
-      retval = nr;
-    else
-      retval = 0;
+    if (is_matrix (x))
+      [nr, nc] = size (x);
+      if (nr == nc && nr > 0)
+        retval = nr;
+      endif
     endif
   else
     usage ("is_square (x)");
