@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,12 +17,14 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## Usage: is_symmetric (x {,tol})
-##
-## If x is symmetric, return the dimension of x, otherwise, return 0.
-##
-## See also: size, rows, columns, length, is_matrix, is_scalar,
-## is_square, is_vector
+## -*- texinfo -*-
+## @deftypefn {Function File} {} is_symmetric (@var{x}, @var{tol})
+## If @var{x} is symmetric within the tolerance specified by @var{tol},
+## then return the dimension of @var{x}.  Otherwise, return 0.  If
+## @var{tol} is omitted, use a tolerance equal to the machine precision.
+## @end deftypefn
+## @seealso{size, rows, columns, length, is_matrix, is_scalar,
+## is_square, and is_vector}
 
 ## Author: A. S. Hodel <scotte@eng.auburn.edu>
 ## Created: August 1993
@@ -30,19 +32,14 @@
 
 function retval = is_symmetric (x,tol)
 
-  retval = 0;
-
   if (nargin == 1 || nargin == 2)
-    [nr, nc] = size (x);
-    if (nr == nc && nr > 0)
+    retval = is_square (x);
+    if (retval != 0)
       if (nargin == 1)
-	tol = eps;
+        tol = eps;
       endif
-      if (isstr (x))
-	x = toascii (x);
-      endif
-      if (norm (x - x') / norm(x) <= tol)
-        retval = nr;
+      if (norm (x - x') / norm(x) > tol)
+        retval = 0;
       endif
     endif
   else
