@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,14 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: num2str (x)
-##
-## Format x as a string.
-##
-## See also: sprintf, int2str
+## -*- texinfo -*-
+## @deftypefn {Function File} {} int2str (@var{n})
+## @deftypefnx {Function File} {} num2str (@var{x})
+## Convert a number to a string.  These functions are not very flexible,
+## but are provided for compatibility with @sc{Matlab}.  For better control
+## over the results, use @code{sprintf} (@pxref{Formatted Output}).
+## @end deftypefn
+## @seealso{sprintf and int2str}
 
 ## Author: jwe
 
