@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,29 +17,33 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## prepad (x, l)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} prepad (@var{x}, @var{l}, @var{c})
+## @deftypefnx {Function File} {} postpad (@var{x}, @var{l}, @var{c})
 ##
-## Prepends zeros to the vector x until it is of length l.
-## prepad(x,l,c) prepends the constant c instead of zero.
+## Prepends (appends) the scalar value @var{c} to the vector @var{x}
+## until it is of length @var{l}.  If the third argument is not
+## supplied, a value of 0 is used.
 ##
-## If length (x) > l, elements from the beginning of x are removed
-## until a vector of length l is obtained.
+## If @code{length (@var{x}) > @var{l}}, elements from the beginning (end) of
+## @var{x} are removed until a vector of length @var{l} is obtained.
+##
+## If @var{x} is a matrix, elements are prepended or removed from each row.
+## @end deftypefn
+
+## Author: Tony Richardson <arichard@stark.cc.oh.us>
+## Created: June 1994
 
 function y = prepad (x, l, c)
 
-  ## Author:
-  ##  Tony Richardson
-  ##  arichard@stark.cc.oh.us
-  ##  June 1994
-
   if (nargin == 2)
     c = 0;
   elseif (nargin < 2 || nargin > 3)
     usage ("prepad (x, l) or prepad (x, l, c)");
   endif
 
-  if (! is_vector (x))
-    error ("first argument must be a vector");
+  if (! is_matrix (x))
+    error ("first argument must be a vector or matrix");
   elseif (! is_scalar (l))
     error ("second argument must be a scaler");
   endif
@@ -48,17 +52,18 @@ function y = prepad (x, l, c)
     error ("second argument must be non-negative");
   endif
 
-  lx = length (x);
-
-  if (lx >= l)
-    y = x(lx-l+1:lx);
-  else
-    if (rows (x) > 1)
-      tmp = c * ones (l-lx, 1);
-      y = [tmp; x];
+  [nr, nc] = size (x);
+  if (nr == 1)
+    if (nc >= l)
+      y = x(nc-l+1:nc);
     else
-      tmp = c * ones (1, l-lx);
-      y = [tmp, x];
+      y = [c*ones(1,l-nc), x];
+    endif
+  else
+    if (nr >= l)
+      y = x(nr-l+1:nr,:);
+    else
+      y = [c*ones(l-nr,nc); x];
     endif
   endif
 
