@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,16 +17,28 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: rem (x, y)
+## -*- texinfo -*-
+## @deftypefn {Mapping Function} {} rem (@var{x}, @var{y})
+## Return the remainder of @code{@var{x} / @var{y}}, computed using the
+## expression
 ##
-## Return remainder (x, y).
+## @example
+## x - y .* fix (x ./ y)
+## @end example
+##
+## An error message is printed if the dimensions of the arguments do not
+## agree, or if either of the arguments is complex.
+## @end deftypefn
+## @seealso{round}
 
 ## Author: jwe
 
 function retval = rem (x, y)
 
+  usage_msg = "rem (x, y)";
+
   if (nargin != 2)
-    usage ("rem (x, y)");
+    usage (usage_msg);
   endif
 
   if (any (size (x) != size (y)) && ! (is_scalar (x) || is_scalar (y)))
@@ -43,7 +55,7 @@ function retval = rem (x, y)
   if (nargin == 2)
     retval = x - y .* fix (x ./ y);
   else
-    error ("usage: rem (x, y)");
+    error (usage_msg);
   endif
 
 endfunction
