@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,11 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: rows (x)
-##
-## Return the the number of rows in x.
-##
-## See also: size, columns, length, is_scalar, is_vector, is_matrix
+## -*- texinfo -*-
+## @deftypefn {Function File} {} rows (@var{a})
+## Return the number of rows of @var{a}.
+## @end deftypefn
+## @seealso{size, columns, length, is_scalar, is_vector, and is_matrix}
 
 ## Author: jwe
 
