@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,10 +17,13 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: msg = strerror (name, err)
-##
-## Return the text of an error message for error number `err' from
-## function "name".
+## -*- texinfo -*-
+## @deftypefn {Function File} {} strerror (@var{name}, @var{num})
+## Return the text of an error message for function @var{name}
+## corresponding to the error number @var{num}.  This function is intended
+## to be used to print useful error messages for those functions that
+## return numeric error codes.
+## @end deftypefn
 
 ## Author: jwe
 
