@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,30 +17,33 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## Save a matrix to disk in image format.
+## -*- texinfo -*-
+## @deftypefn {Function File} {} saveimage (@var{file}, @var{x}, @var{fmt}, @var{map})
+## Save the matrix @var{x} to @var{file} in image format @var{fmt}.  Valid
+## values for @var{fmt} are
 ##
-## saveimage (filename, x) saves matrix x to file filename in octave's
-## image format.  The current colormap is saved in the file also.
+## @table @code
+## @item "img"
+## Octave's image format.  The current colormap is also saved in the file.
 ##
-## saveimage (filename, x, "img") saves the image in the default format
-## and is the same as saveimage (filename, x).
+## @item "ppm"
+## Portable pixmap format.
 ##
-## saveimage (filename, x, "ppm") saves the image in ppm format instead
-## of the default octave image format.
+## @item "ps"
+## PostScript format.  Note that images saved in PostScript format can not
+## be read back into Octave with loadimage.
+## @end table
 ##
-## saveimage (filename, x, "ps") saves the image in PostScript format
-## instead of the default octave image format. (Note: images saved in
-## PostScript format can not be read back into octave with loadimage.)
-##
-## saveimage (filename, x, format, map) saves the image along with the
-## specified colormap in the specified format.
-##
-## Note: If the colormap contains only two entries and these entries
-## are black and white, the bitmap ppm and PostScript formats are used.
-## If the image is a gray scale image (the entries within each row of
-## the colormap are equal) the gray scale ppm and PostScript image
-## formats are used, otherwise the full color formats are used.
+## If the fourth argument is supplied, the specified colormap will also be
+## saved along with the image.
 ##
+## Note: if the colormap contains only two entries and these entries are
+## black and white, the bitmap ppm and PostScript formats are used.  If the
+## image is a gray scale image (the entries within each row of the colormap
+## are equal) the gray scale ppm and PostScript image formats are used,
+## otherwise the full color formats are used.
+## @end deftypefn
+
 ## The conversion to PostScript is based on pbmtolps.c, which was
 ## written by
 ##
@@ -49,8 +52,7 @@
 ##   University of British Columbia
 ##
 ## and is part of the portable bitmap utilities,
-##
-## SEE ALSO: loadimage, save, load, colormap
+## @seealso{loadimage, save, load, and colormap}
 
 ## Author: Tony Richardson <arichard@stark.cc.oh.us>
 ## Created: July 1994
@@ -94,7 +96,7 @@ function saveimage (filename, img, img_form, map)
     error ("image format specification must be a string");
   elseif (! (strcmp (img_form, "img")
              || strcmp (img_form, "ppm")
-	     || strcmp (img_form, "ps")))
+             || strcmp (img_form, "ps")))
     error ("unsupported image format specification");
   endif
 
@@ -148,47 +150,51 @@ function saveimage (filename, img, img_form, map)
   img (idx) = ones (size (idx));
 
   if (strcmp (img_form, "ppm"))
-    if (grey && map_nr == 2 && bw)
+
+    ## Would be nice to make this consistent with the line used by the
+    ## load/save functions, but we need a good way to get username and
+    ## hostname information.
+
+    time_string = ctime (time ());
+    time_string = time_string (1:length (time_string)-1);
+    tagline = sprintf ("# Created by Octave %s, %s",
+		       __OCTAVE_VERSION__, time_string);
+
+    if (grey && bw)
 
       if (map(1) != 0)
-      	map = [1; 0];
+        map = [0; 1];
       else
-      	map = [0; 1];
+        map = [1; 0];
       endif
 
       n_long = rem (img_nc, 8);
       tmp = zeros (ceil (img_nc/8), img_nr);
 
-      for i = 1:img_nr
-	idx = (i-1)*img_nc+1:i*img_nc;
-      	if (n_long > 0)
-	  img_row = [map(img(idx)); (zeros (8-n_long, 1))];
-	else
-      	  img_row = map(img(idx));
-	endif
-	img_row
-	tmp
-	if (img_nc < 8)
-	  for j = 1:8
-	    tmp(:,i) = tmp(:,i) + img_row (j) * 2^(8-j);
-	  endfor
-	else
-	  for j = 1:8
-	    tmp(:,i) = tmp(:,i) + img_row (j:8:img_nc) * 2^(8-j);
-	  endfor
-	endif
+      k = ceil (img_nr/8);
+      tmp = zeros (k, img_nc);
+
+      ## Append columns with zeros to original image so that
+      ## mod (cols, 8) = 0.
+
+      bwimg = postpad (reshape (map(img), img_nr, img_nc), k * 8, 0);
+
+      b = kron (pow2 (7:-1:0)', ones (1, img_nc));
+
+      for i = 1:k
+        tmp(i,:) = sum (bwimg(8*(i-1)+1:8*i,:) .* b);
       endfor
 
       fid = fopen (filename, "w");
-      fprintf (fid, "P4\n%d %d\n", img_nr, img_nc);
-      fwrite (fid, tmp, "uchar");
+      fprintf (fid, "P4\n%s\n%d %d\n", tagline, img_nr, img_nc);
+      fwrite (fid, tmp, "char");
       fprintf (fid, "\n");
       fclose (fid);
 
     elseif (grey)
 
       fid = fopen (filename, "w");
-      fprintf (fid, "P5\n%d %d\n255\n", img_nr, img_nc);
+      fprintf (fid, "P5\n%s\n%d %d\n255\n", tagline, img_nr, img_nc);
       fwrite (fid, map(img), "uchar");
       fprintf (fid, "\n");
       fclose (fid);
@@ -210,7 +216,7 @@ function saveimage (filename, img, img_form, map)
       tmp(img_idx--) = tmap(img);
 
       fid = fopen (filename, "w");
-      fprintf (fid, "P6\n%d %d\n255\n", img_nr, img_nc);
+      fprintf (fid, "P6\n%s\n%d %d\n255\n", tagline, img_nr, img_nc);
       fwrite (fid, tmp, "uchar");
       fprintf (fid, "\n");
       fclose (fid);
@@ -242,14 +248,14 @@ function saveimage (filename, img, img_form, map)
 
     if (scols > pagewid * MARGIN || srows > pagehgt * MARGIN)
       if (scols > pagewid * MARGIN)
-	scale = scale * (pagewid / scols * MARGIN);
-	scols = scale * img_nr * pixfac;
-	srows = scale * img_nc * pixfac;
+        scale = scale * (pagewid / scols * MARGIN);
+        scols = scale * img_nr * pixfac;
+        srows = scale * img_nc * pixfac;
       endif
       if (srows > pagehgt * MARGIN)
-	scale = scale * (pagehgt / srows * MARGIN);
-	scols = scale * img_nr * pixfac;
-	srows = scale * img_nc * pixfac;
+        scale = scale * (pagehgt / srows * MARGIN);
+        scols = scale * img_nr * pixfac;
+        srows = scale * img_nc * pixfac;
       endif
       warning ("image too large for page, rescaling to %g", scale);
     endif
@@ -267,7 +273,7 @@ function saveimage (filename, img, img_form, map)
     fprintf (fid, "%%%%Pages: 1\n");
     fprintf (fid, "%%%%BoundingBox: %d %d %d %d\n",
              fix (llx), fix (lly), fix (urx), fix (ury));
-    fprintf (fid, "%%%%EndComments\n" );
+    fprintf (fid, "%%%%EndComments\n");
     fprintf (fid, "/readstring {\n");
     fprintf (fid, "  currentfile exch readhexstring pop\n");
     fprintf (fid, "} bind def\n");
@@ -280,21 +286,21 @@ function saveimage (filename, img, img_form, map)
     fprintf (fid, "%g %g scale\n", scols, srows);
     fprintf (fid, "%d %d %d\n", img_nr, img_nc, bps);
     fprintf (fid, "[ %d 0 0 -%d 0 %d ]\n", img_nr, img_nc, img_nc);
-    fprintf (fid, "{ picstr readstring }\n" );
-    fprintf (fid, "image\n" );
+    fprintf (fid, "{ picstr readstring }\n");
+    fprintf (fid, "image\n");
 
     img = map(img);
 
-    fmt = "%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x%x\n";
+    fmt = "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x\n";
     fprintf (fid, fmt, img);
 
     if (rem (img_sz, 30) != 0)
-      fprintf (fid, "\n" );
+      fprintf (fid, "\n");
     endif
 
-    fprintf (fid, "grestore\n" );
-    fprintf (fid, "showpage\n" );
-    fprintf (fid, "%%%%Trailer\n" );
+    fprintf (fid, "grestore\n");
+    fprintf (fid, "showpage\n");
+    fprintf (fid, "%%%%Trailer\n");
     fclose (fid);
 
   else
