@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,13 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: printf (fmt, ...)
-##
-## Formatted write to standard output.
-##
-## See also: fprintf sprintf
+## -*- texinfo -*-
+## @deftypefn {Function File} {} printf (@var{template}, @dots{})
+## The @code{printf} function prints the optional arguments under the
+## control of the template string @var{template} to the stream
+## @code{stdout}.
+## @end deftypefn
+## @seealso{fprintf and sprintf}
 
 ## Author: jwe
 
