@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,11 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: puts (string)
-##
-## Write string to the standard output.
-##
-## See also: fputs, printf, fprintf
+## -*- texinfo -*-
+## @deftypefn {Function File} {} puts (@var{string})
+## Write a string to the standard output with no formatting.
+## @end deftypefn
+## @seealso{fputs, printf and fprintf}
 
 ## Author: jwe
 
