@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,12 +17,25 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## Usage: x = kron (a, b)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} kron (@var{a}, @var{b})
+## Form the kronecker product of two matrices, defined block by block as
 ##
-## Form the Kronecker product of two matrices, defined block by block
-## as
+## @example
+## x = [a(i, j) b]
+## @end example
 ##
-##   x = [a(i,j) b]
+## For example,
+##
+## @example
+## @group
+## kron (1:4, ones (3, 1))
+##      @result{}  1  2  3  4
+##          1  2  3  4
+##          1  2  3  4
+## @end group
+## @end example
+## @end deftypefn
 
 ## Author: A. S. Hodel <scotte@eng.auburn.edu>
 ## Created: August 1993
@@ -35,17 +48,17 @@ function x = kron (a, b)
     [m, n] = size (b);
     [ma, na] = size (a);
 
-    x = zeros (ma*m, na*n);	
+    x = zeros (ma*m, na*n);
     i_vec = 1:m;
     j_vec = 1:n;
 
     for jj = 1:na
       for ii = 1:ma
-	x(i_vec+(ii-1)*m,j_vec) = a(ii,jj) * b;
+        x(i_vec+(ii-1)*m,j_vec) = a(ii,jj) * b;
       endfor
       j_vec = j_vec + n;
     endfor
-    
+
   else
     usage ("kron (a, b)");
   endif
