@@ -17,8 +17,10 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## Usage: __axis_label__ (caller, text)
-## Utility function for xabel, ylabel, and zlabel.
+## -*- texinfo -*-
+## @deftypefn {Function File} {} __axis_label__ (@var{caller}, @var{text})
+## Utility function for @code{xlabel}, @code{ylabel}, and @code{zlabel}.
+## @end deftypefn
 
 ## Author: jwe
 
