@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,6 +17,10 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
+## -*- texinfo -*-
+## @deftypefn {Function File} {} __plr2__ (@var{theta}, @var{rho}, @var{fmt})
+## @end deftypefn
+
 ## Author: jwe
 
 function __plr2__ (theta, rho, fmt)
@@ -42,13 +46,13 @@ function __plr2__ (theta, rho, fmt)
   elseif (is_vector (theta))
     if (is_vector (rho))
       if (length (theta) != length (rho))
-	error ("polar: vector lengths must match");
+        error ("polar: vector lengths must match");
       endif
       if (rows (rho) == 1)
-	rho = rho';
+        rho = rho';
       endif
       if (rows (theta) == 1)
-	theta = theta';
+        theta = theta';
       endif
       x = rho .* cos (theta);
       y = rho .* sin (theta);
@@ -56,20 +60,20 @@ function __plr2__ (theta, rho, fmt)
     elseif (is_matrix (rho))
       [t_nr, t_nc] = size (theta);
       if (t_nr == 1)
-	theta = theta';
-	tmp = t_nr;
-	t_nr = t_nc;
-	t_nc = tmp;
+        theta = theta';
+        tmp = t_nr;
+        t_nr = t_nc;
+        t_nc = tmp;
       endif
       [r_nr, r_nc] = size (rho);
       if (t_nr != r_nr)
-	rho = rho';
-	tmp = r_nr;
-	r_nr = r_nc;
-	r_nc = tmp;
+        rho = rho';
+        tmp = r_nr;
+        r_nr = r_nc;
+        r_nc = tmp;
       endif
       if (t_nr != r_nr)
-	error ("polar: vector and matrix sizes must match");
+        error ("polar: vector and matrix sizes must match");
       endif
       x = diag (cos (theta)) * rho;
       y = diag (sin (theta)) * rho;
@@ -79,20 +83,20 @@ function __plr2__ (theta, rho, fmt)
     if (is_vector (rho))
       [r_nr, r_nc] = size (rho);
       if (r_nr == 1)
-	rho = rho';
-	tmp = r_nr;
-	r_nr = r_nc;
-	r_nc = tmp;
+        rho = rho';
+        tmp = r_nr;
+        r_nr = r_nc;
+        r_nc = tmp;
       endif
       [t_nr, t_nc] = size (theta);
       if (r_nr != t_nr)
-	theta = theta';
-	tmp = t_nr;
-	t_nr = t_nc;
-	t_nc = tmp;
+        theta = theta';
+        tmp = t_nr;
+        t_nr = t_nc;
+        t_nc = tmp;
       endif
       if (r_nr != t_nr)
-	error ("polar: vector and matrix sizes must match");
+        error ("polar: vector and matrix sizes must match");
       endif
       diag_r = diag (rho);
       x = diag_r * cos (theta);
@@ -100,7 +104,7 @@ function __plr2__ (theta, rho, fmt)
       __plt2mv__ (x, y, fmt);
     elseif (is_matrix (rho))
       if (size (rho) != size (theta))
-	error ("polar: matrix dimensions must match");
+        error ("polar: matrix dimensions must match");
       endif
       x = rho .* cos (theta);
       y = rho .* sin (theta);
