@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,6 +17,10 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
+## -*- texinfo -*-
+## @deftypefn {Function File} {} __plt2vm__ (@var{x}, @var{y}, @var{fmt})
+## @end deftypefn
+
 ## Author: jwe
 
 function __plt2vm__ (x, y, fmt)
@@ -55,15 +59,15 @@ function __plt2vm__ (x, y, fmt)
   if (y_nc > 0)
     tmp = [x, y];
     cmd = sprintf ("gplot tmp(:,%d:%d:%d) %s", 1, x_nc, x_nc+1,
-		   deblank (fmt (k, :)));
+                   deblank (fmt (k, :)));
     if (k < fmt_nr)
       k++;
     endif
     for i = 2:y_nc
       cmd = sprintf ("%s, tmp(:,%d:%d:%d) %s", cmd, 1, i, i+1,
-		     deblank (fmt (k, :)));
+                     deblank (fmt (k, :)));
       if (k < fmt_nr)
-      	k++;
+        k++;
       endif
     endfor
     eval (cmd);
