@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,6 +17,10 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
+## -*- texinfo -*-
+## @deftypefn {Function File} {} __plt__ (@code{caller}, @dots{})
+## @end deftypefn
+
 ## Author: jwe
 
 function __plt__ (caller, ...)
@@ -41,54 +45,47 @@ function __plt__ (caller, ...)
 
       while (nargin-- > 0)
 
-	fmt = "";
-	new = va_arg ();
+        fmt = "";
+        new = va_arg ();
 
-	if (isstr (new))
-	  if (! x_set)
-	    error ("plot: no data to plot");
-	  endif
-	  fmt = __pltopt__ (caller, new);
-	  if (! y_set)
-	    __plt1__ (x, fmt);
-	  else
-	    __plt2__ (x, y, fmt);
-	  endif
-	  hold on;
-	  x_set = 0;
-	  y_set = 0;
-	elseif (x_set)
-	  if (y_set)
-	    __plt2__ (x, y, fmt);
-	    hold on;
-	    x = new;
-	    y_set = 0;
-	  else
-	    y = new;
-	    y_set = 1;
-	  endif
-	else
-	  x = new;
-	  x_set = 1;
-	endif
-
-	## Something fishy is going on.  I don't think this should be
-	## necessary, but without it, sometimes not all the lines from a
-	## given plot command appear on the screen.  Even with it, the
-	## delay might not be long enough for some systems...
-
-	usleep (1e5);
+        if (isstr (new))
+          if (! x_set)
+            error ("plot: no data to plot");
+          endif
+          fmt = __pltopt__ (caller, new);
+          if (! y_set)
+            __plt1__ (x, fmt);
+          else
+            __plt2__ (x, y, fmt);
+          endif
+          hold on;
+          x_set = 0;
+          y_set = 0;
+        elseif (x_set)
+          if (y_set)
+            __plt2__ (x, y, fmt);
+            hold on;
+            x = new;
+            y_set = 0;
+          else
+            y = new;
+            y_set = 1;
+          endif
+        else
+          x = new;
+          x_set = 1;
+        endif
 
       endwhile
 
       ## Handle last plot.
 
       if  (x_set)
-	if (y_set)
-	  __plt2__ (x, y, fmt);
-	else
-	  __plt1__ (x, fmt);
-	endif
+        if (y_set)
+          __plt2__ (x, y, fmt);
+        else
+          __plt1__ (x, fmt);
+        endif
       endif
 
     unwind_protect_cleanup
