@@ -17,11 +17,11 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: fmt = __pltopt1__ (caller, opt)
-##
+## -*- texinfo -*-
+## @deftypefn {Function File} {} __pltopt1__ (@var{caller}, @var{opt})
 ## Really decode plot option strings.
-##
-## See also: __pltopt__
+## @end deftypefn
+## @seealso{__pltopt__}
 
 ## Author: Rick Niles <niles@axp745.gsfc.nasa.gov>
 ## Adapted-By: jwe
@@ -37,8 +37,11 @@ function fmt = __pltopt1__ (caller, opt)
   set_impulses = 0;
   set_steps = 0;
   set_boxes = 0;
-  set_errbars = 0;
+  set_yerrbars = 0;
+  set_xerrbars = 0;
   set_key = 0;
+  set_linestyle = "solid";
+
   more_opts = 1;
 
   WITH = "w";
@@ -50,7 +53,9 @@ function fmt = __pltopt1__ (caller, opt)
   DOTS = "d";
   IMPULSES = "i";
   STEPS = "s";
-  ERRORBARS = "e";
+  YERRORBARS = "yerr";
+  XERRORBARS = "xerr";
+  XYERRORBARS = "xyerr";
   TITLE = "title";
 
   if (nargin != 2)
@@ -77,9 +82,20 @@ function fmt = __pltopt1__ (caller, opt)
     ## Now set flags based on char.
 
     if (strcmp (char, "-"))
-      set_lines = 1;
+      if (set_lines)
+	set_linestyle = "dash";
+      else
+      	set_lines = 1;
+      endif
     elseif (strcmp (char, "."))
-      set_dots  = 1;
+      if (set_lines)
+	set_linestyle = "dashdot";
+      else
+      	set_dots  = 1;
+      endif
+    elseif (strcmp (char, ":"))
+      set_lines = 1;
+      set_linestyle = "dot";
     elseif (strcmp (char, "@"))
       set_points = 1;
     elseif (strcmp (char, "^"))
@@ -87,7 +103,9 @@ function fmt = __pltopt1__ (caller, opt)
     elseif (strcmp (char, "L"))
       set_steps = 1;
     elseif (strcmp (char, "~"))
-      set_errbars = 1;
+      set_yerrbars = 1;
+    elseif (strcmp (char, ">"))
+      set_xerrbars = 1;  
     elseif (strcmp (char, "#"))
       set_boxes = 1;
     elseif (strcmp (char, "0") || strcmp (char, "1") ...
@@ -96,12 +114,12 @@ function fmt = __pltopt1__ (caller, opt)
             || strcmp (char, "6") || strcmp (char, "7") ...
             || strcmp (char, "8") || strcmp (char, "9"))
       if (set_color)
-	set_points = 1;
-	symbol = char;
-	set_symbol = 1;
+        set_points = 1;
+        symbol = char;
+        set_symbol = 1;
       else
-	color = char;
-	set_color = 1;
+        color = char;
+        set_color = 1;
       endif
     elseif (strcmp (char, "r"))
       set_color = 1;
@@ -140,14 +158,14 @@ function fmt = __pltopt1__ (caller, opt)
     elseif (strcmp (char, ";"))  # title mode.
       set_key = 1;
       working = 1;
-      key_title = ""; 
+      key_title = "";
       while (working)
         if (max (size (opt)) > 1)
-	  char = opt(1);
-	  opt = opt(2:length(opt));
+          char = opt(1);
+          opt = opt(2:length(opt));
         else
-	  char = opt;
-	  if (! strcmp (char, ";"))
+          char = opt;
+          if (! strcmp (char, ";"))
             error ("%s: unfinished key label", caller);
           end
           more_opts = 0;
@@ -156,14 +174,14 @@ function fmt = __pltopt1__ (caller, opt)
         if strcmp (char, ";")
           working = 0;
         else
-	  if (isempty (key_title))  # needs this to avoid empty matrix warning.
+          if (isempty (key_title))  # needs this to avoid empty matrix warning.
             key_title = char;
-	  else
+          else
             key_title = strcat (key_title, char);
-	  endif
+          endif
         endif
       endwhile
-    elseif (strcmp (char, " ")) 
+    elseif (strcmp (char, " "))
       ## whitespace -- do nothing.
     else
       error ("%s: unrecognized format character: '%s'", caller, char);
@@ -181,7 +199,7 @@ function fmt = __pltopt1__ (caller, opt)
       fmt = strcat (fmt, " ", LINES);
     endif
   elseif (set_boxes)
-    if (set_errbars)
+    if (set_yerrbars)
       fmt = strcat (fmt, " ", BOXERRORBARS);
     else
       fmt = strcat (fmt, " ", BOXES);
@@ -194,8 +212,14 @@ function fmt = __pltopt1__ (caller, opt)
     fmt = strcat (fmt, " ", IMPULSES);
   elseif (set_steps)
     fmt = strcat (fmt, " ", STEPS);
-  elseif (set_errbars)
-    fmt = strcat (fmt, " ", ERRORBARS);
+  elseif (set_yerrbars)
+    if(set_xerrbars)
+        fmt = strcat (fmt, " ", XYERRORBARS);
+    else
+        fmt = strcat (fmt, " ", YERRORBARS);
+    endif
+  elseif (set_xerrbars)
+    fmt = strcat (fmt, " ", XERRORBARS);
   endif
 
   if (strcmp (fmt, WITH))
