@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,9 +17,9 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: [xb, yb] = bar (x, y)
-##
-## Given two vectors of x-y data, bar produces a `bar' graph.
+## -*- texinfo -*-
+## @deftypefn {Function File} {} bar (@var{x}, @var{y})
+## Given two vectors of x-y data, @code{bar} produces a bar graph.
 ##
 ## If only one argument is given, it is taken as a vector of y-values
 ## and the x coordinates are taken to be the indices of the elements.
@@ -27,17 +27,23 @@
 ## If two output arguments are specified, the data are generated but
 ## not plotted.  For example,
 ##
-##   bar (x, y);
+## @example
+## bar (x, y);
+## @end example
 ##
+## @noindent
 ## and
 ##
-##   [xb, yb] = bar (x, y);
-##   plot (xb, yb);
+## @example
+## [xb, yb] = bar (x, y);
+## plot (xb, yb);
+## @end example
 ##
+## @noindent
 ## are equivalent.
-##
-## See also: plot, semilogx, semilogy, loglog, polar, mesh, contour,
-##           stairs, gplot, gsplot, replot, xlabel, ylabel, title
+## @end deftypefn
+## @seealso{plot, semilogx, semilogy, loglog, polar, mesh, contour,
+## stairs, gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
@@ -77,27 +83,27 @@ function [xb, yb] = bar (x, y)
         delta_m = delta_p;
         tmp_xb(1) = x(1) - delta_m;
         tmp_yb(1) = 0.0;
-	k = 1;
+        k = 1;
         for i = 2:3:len
           tmp_xb(i) = tmp_xb(i-1);
           tmp_xb(i+1) = x(k) + delta_p;
           tmp_xb(i+2) = tmp_xb(i+1);
-	  tmp_yb(i) = y(k);
-	  tmp_yb(i+1) = y(k);
-	  tmp_yb(i+2) = 0.0;
+          tmp_yb(i) = y(k);
+          tmp_yb(i+1) = y(k);
+          tmp_yb(i+2) = 0.0;
           if (k < xlen)
             if (x(k+1) < x(k))
               error ("bar: x vector values must be in ascending order");
             endif
-	    delta_m = x(k+1) - cutoff(k);
+            delta_m = x(k+1) - cutoff(k);
             k++;
             if (k < xlen)
               delta_p = cutoff(k) - x(k);
-	    else
-	      delta_p = delta_m;
+            else
+              delta_p = delta_m;
             endif
-	  endif
-	endfor
+          endif
+        endfor
       else
         error ("bar: arguments must be the same length");
       endif
