@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,14 +17,10 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: bottom_title (text)
-##
-## NOTE: this will work only with gnuplot installed with
-##       multiplot patch
-##
-## makes a title with the given text at the bottom of the plot
-## rather than the top.
-##
+## -*- texinfo -*-
+## @deftypefn {Function File} {} bottom_title (@var{string})
+## See top_title.
+## @end deftypefn
 
 ## Author: Vinayak Dutt <Dutt.Vinayak@mayo.EDU>
 ## Adapted-By: jwe
@@ -42,7 +38,8 @@ function bottom_title (text)
   if (isstr (text))
     gset top_title;
     gset title;
-    eval (sprintf ("gset bottom_title \"%s\"", text));
+    eval (sprintf ("gset bottom_title \"%s\"",
+		   undo_string_escapes (undo_string_escapes (text))));
   else
     error ("bottom_title: text must be a string");
   endif
