@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,36 +17,43 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: contour (z, n, x, y)
-##
-## See also: plot, semilogx, semilogy, loglog, polar, mesh, contour,
-##           bar, stairs, gplot, gsplot, replot, xlabel, ylabel, title
+## -*- texinfo -*-
+## @deftypefn {Function File} {} contour (@var{z}, @var{n})
+## @deftypefnx {Function File} {} contour (@var{x}, @var{y}, @var{z}, @var{n})
+## Make a contour plot of the three-dimensional surface described by
+## @var{z}.  Someone needs to improve @code{gnuplot}'s contour routines
+## before this will be very useful.
+## @end deftypefn
+## @seealso{plot, semilogx, semilogy, loglog, polar, mesh, contour,
+## bar, stairs, gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
-function contour (z, n, x, y)
-
-  if (nargin == 1)
-    n = 10;
-  endif
+function contour (x, y, z, n)
 
   ## XXX FIXME XXX -- these plot states should really just be set
   ## temporarily, probably inside an unwind_protect block, but there is
   ## no way to determine their current values.
 
   if (nargin == 1 || nargin == 2)
+    z = x;
+    if (nargin == 1) 
+      n = 10;
+    else
+      n = y; 
+    endif
     if (is_matrix (z))
       gset nosurface;
       gset contour;
       gset cntrparam bspline;
       if (is_scalar (n))
-	command = sprintf ("gset cntrparam levels %d", n);
+        command = sprintf ("gset cntrparam levels %d", n);
       elseif (is_vector (n))
-	tmp = sprintf ("%f", n(1));
-	for i = 2:length (n)
-	  tmp = sprintf ("%s, %f", tmp, n(i));
-	endfor
-	command = sprintf ("gset cntrparam levels discrete %s", tmp);
+        tmp = sprintf ("%f", n(1));
+        for i = 2:length (n)
+          tmp = sprintf ("%s, %f", tmp, n(i));
+        endfor
+        command = sprintf ("gset cntrparam levels discrete %s", tmp);
       endif
       eval (command);
       gset noparametric;
@@ -75,19 +82,19 @@ function contour (z, n, x, y)
         gset nosurface;
         gset contour;
         gset cntrparam bspline;
-	if (is_scalar (n))
+        if (is_scalar (n))
           command = sprintf ("gset cntrparam levels %d", n);
-	elseif (is_vector (n))
-	  tmp = sprintf ("%f", n(1));
-	  for i = 2:length (n)
-	    tmp = sprintf ("%s, %f", tmp, n(i));
-	  endfor
-	  command = sprintf ("gset cntrparam levels discrete %s", tmp);
-	endif
+        elseif (is_vector (n))
+          tmp = sprintf ("%f", n(1));
+          for i = 2:length (n)
+            tmp = sprintf ("%s, %f", tmp, n(i));
+          endfor
+          command = sprintf ("gset cntrparam levels discrete %s", tmp);
+        endif
         eval (command);
-	gset parametric;
+        gset parametric;
         gset view 0, 0, 1, 1;
-	gsplot zz w l 1;
+        gsplot zz w l 1;
       else
         msg = "contour: rows (z) must be the same as length (x) and";
         msg = sprintf ("%s\ncolumns (z) must be the same as length (y)", msg);
