@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,27 +17,45 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: figure (n)
-##
-## Set the current plot window to plot window N.  This function
-## currently requires X11 and a recent version of gnuplot.
+## -*- texinfo -*-
+## @deftypefn {Function File} {} figure (@var{n})
+## Set the current plot window to plot window @var{n}.  This function
+## currently requires X11 and a version of gnuplot that supports multiple
+## frames.
+## @end deftypefn
 
 ## Author: jwe
 
-function figure (n)
+function f = figure (n)
 
-  if (nargin == 1)
+  static figure_list = create_set (0);
+  static figure_called = 0;
+
+  if (nargin == 0)
+    f = max (figure_list) + 1;
+  else
+    f = n;
+  endif
+
+  if (nargin < 2)
     if (gnuplot_has_frames)
       if (! isempty (getenv ("DISPLAY")))
-	oneplot ();
-	eval (sprintf ("gset term x11 %d\n", n));
+        oneplot ();
+        figure_list = union (figure_list, f);
+        eval (sprintf ("gset term x11 %d\n", f));
       else
-	error ("figure: requires X11 and valid DISPLAY");
+        error ("figure: requires X11 and valid DISPLAY");
       endif
     else
       error ("figure: gnuplot doesn't appear to support this feature");
     endif
+  elseif (rem (nargin, 2) == 0)
+    if (! figure_called)
+      figure_called = 1;
+      warning ("figure: setting figure properties is unsupported");
+    endif
   else
     usage ("figure (n)");
   endif
+
 endfunction
