@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,19 +17,21 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: grid ("on" | "off")
-##
-## Turn grid lines on or off for plotting.
-##
-## If the argument is omitted, "on" is assumed.
-##
-## See also: plot, semilogx, semilogy, loglog, polar, mesh, contour,
-##           bar, stairs, gplot, gsplot, replot, xlabel, ylabel, title
+## -*- texinfo -*-
+## @deftypefn {Function File} {} grid (@var{arg})
+## For two-dimensional plotting, force the display of a grid on the plot.
+## The argument may be either @code{"on"} or @code{"off"}.  If it is
+## omitted, @code{"on"} is assumed.
+## @end deftypefn
+## @seealso{plot, semilogx, semilogy, loglog, polar, mesh, contour,
+## bar, stairs, gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
 function grid (x)
 
+  usage_msg = "grid (\"on\" | \"off\")";
+
   if (nargin == 0)
     gset grid;
   elseif (nargin == 1)
@@ -39,13 +41,13 @@ function grid (x)
       elseif (strcmp ("on", x))
         gset grid;
       else
-    usage ("grid (\"on\" | \"off\")");
+    usage (usage_msg);
       endif
     else
       error ("grid: argument must be a string");
     endif
   else
-    error ("usage: grid (\"on\" | \"off\")");
+    usage (usage_msg);
   endif
 
 endfunction
