@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,8 +17,8 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: [NN, XX] = hist (Y, X)  or  hist (Y, X)
-##
+## -*- texinfo -*-
+## @deftypefn {Function File} {} hist (@var{y}, @var{x}, @var{norm})
 ## Produce histogram counts or plots.
 ##
 ## With one vector input argument, plot a histogram of the values with
@@ -28,22 +28,25 @@
 ## Given a second scalar argument, use that as the number of bins.
 ##
 ## Given a second vector argument, use that as the centers of the bins,
-## with the width of the bins determened from the adjacent values in
+## with the width of the bins determined from the adjacent values in
 ## the vector.
 ##
+## If third argument is provided, the histogram is normalised such that
+## the sum of the bars is equal to @var{norm}.
+##
 ## Extreme values are lumped in the first and last bins.
 ##
-## With two output arguments, produce the values NN and XX such that
-## bar (XX, NN) will plot the histogram.
-##
-## See also: bar
+## With two output arguments, produce the values @var{nn} and @var{xx} such
+## that @code{bar (@var{xx}, @var{nn})} will plot the histogram.
+## @end deftypefn
+## @seealso{bar}
 
 ## Author: jwe
 
-function [nn, xx] = hist (y, x)
+function [nn, xx] = hist (y, x, norm)
 
-  if (nargin < 1 || nargin > 2)
-    usage ("[nn, xx] = hist (y, x)");
+  if (nargin < 1 || nargin > 3)
+    usage ("[nn, xx] = hist (y, x, norm)");
   endif
 
   if (is_vector (y))
@@ -58,7 +61,8 @@ function [nn, xx] = hist (y, x)
     delta = (max_val - min_val) / n / 2;
     x = linspace (min_val+delta, max_val-delta, n);
     cutoff = x + delta;
-  elseif (nargin == 2)
+  else
+    ## nargin is either 2 or 3
     if (is_scalar (x))
       n = x;
       if (n <= 0)
@@ -90,6 +94,11 @@ function [nn, xx] = hist (y, x)
   endfor
   freq (n) = sum (y >= cutoff (n-1));
 
+  if (nargin == 3)
+    ## Normalise the histogram.
+    freq = freq / length(y) * norm;
+  endif
+
   if (nargout > 0)
     nn = freq;
     xx = x;
