@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,17 +17,14 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: loglog (x, y)
-##        loglog (x1, y1, x2, y2, ...)
-##        loglog (x, y, fmt)
-##
-## Make a 2D plot of y versus x using a log scale for the x axis.
-##
-## See the help message for the plot command for a description of how
-## the arguments are interpreted.
-##
-## See also: plot, semilogy, loglog, polar, mesh, contour, bar, stairs,
-##           gplot, gsplot, replot, xlabel, ylabel, title
+## -*- texinfo -*-
+## @deftypefn {Function File} {} loglog (@var{args})
+## Make a two-dimensional plot using log scales for both axes.  See the
+## description of @code{plot} for a description of the arguments that
+## @code{loglog} will accept.
+## @end deftypefn
+## @seealso{plot, semilogy, loglog, polar, mesh, contour, bar, stairs,
+## gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
