@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,22 +17,23 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: mesh (x, y, z)
-##
-## Surface plot.  If x, y, and z are matrices with the same dimensions,
-## then corresponding elements represent vertices of the plot.  If x and
-## y are vectors, then a typical vertex is (x(j), y(i), z(i,j)).  Thus,
-## columns of z correspond to different x values and rows of z correspond
-## to different y values.
-##
-## See also: plot, semilogx, semilogy, loglog, polar, meshgrid, meshdom,
-##           contour, bar, stairs, gplot, gsplot, replot, xlabel, ylabel, title
+## -*- texinfo -*-
+## @deftypefn {Function File} {} mesh (@var{x}, @var{y}, @var{z})
+## Plot a mesh given matrices @var{x}, and @var{y} from @code{meshdom} and
+## a matrix @var{z} corresponding to the @var{x} and @var{y} coordinates of
+## the mesh.  If @var{x} and @var{y} are vectors, then a typical vertex
+## is (@var{x}(j), @var{y}(i), @var{z}(i,j)).  Thus, columns of @var{z}
+## correspond to different @var{x} values and rows of @var{z} correspond
+## to different @var{y} values.
+## @end deftypefn
+## @seealso{plot, semilogx, semilogy, loglog, polar, meshgrid, meshdom,
+## contour, bar, stairs, gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
 function mesh (x, y, z)
 
-  ## XXX FIXME XXX -- these plot states should really just be set
+  ## XXX FIXME XXX -- the plot states should really just be set
   ## temporarily, probably inside an unwind_protect block, but there is
   ## no way to determine their current values.
 
@@ -44,6 +45,7 @@ function mesh (x, y, z)
       gset surface;
       gset nocontour;
       gset noparametric;
+      gset nologscale;
       gset view 60, 30, 1, 1
       gsplot (z');
     else
@@ -66,14 +68,15 @@ function mesh (x, y, z)
           zz(:,i+2) = z(:,k);
           k++;
         endfor
-	gset hidden3d;
-	gset data style lines;
+        gset hidden3d;
+        gset data style lines;
         gset surface;
         gset nocontour;
-	gset parametric;
+        gset nologscale;
+        gset parametric;
         gset view 60, 30, 1, 1
-	gsplot (zz);
-	gset noparametric;
+        gsplot (zz);
+        gset noparametric;
       else
         msg = "mesh: rows (z) must be the same as length (y) and";
         msg = sprintf ("%s\ncolumns (z) must be the same as length (x)", msg);
@@ -83,7 +86,7 @@ function mesh (x, y, z)
       xlen = columns (z);
       ylen = rows (z);
       if (xlen == columns (x) && xlen == columns (y) &&
-	ylen == rows (x) && ylen == rows(y))
+        ylen == rows (x) && ylen == rows(y))
         len = 3 * xlen;
         zz = zeros (ylen, len);
         k = 1;
@@ -93,14 +96,15 @@ function mesh (x, y, z)
           zz(:,i+2) = z(:,k);
           k++;
         endfor
-	gset hidden3d;
-	gset data style lines;
+        gset hidden3d;
+        gset data style lines;
         gset surface;
         gset nocontour;
-	gset parametric;
+        gset nologscale;
+        gset parametric;
         gset view 60, 30, 1, 1
-	gsplot (zz);
-	gset noparametric;
+        gsplot (zz);
+        gset noparametric;
       else
         error ("mesh: x, y, and z must have same dimensions");
       endif
