@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,18 +17,15 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: [xx, yy] = meshgrid (x, y)
-##
-## Given vectors of x and y coordinates, return two matrices corresponding
-## to the x and y coordinates of a mesh.  The rows of xx are copies of x,
-## and the columns of yy are copies of y.
-##
-## [xx, yy] = meshgrid (x) is an abbreviation for [xx, yy] = meshgrid (x, x).
-##
-## See sombrero.m for an example of using meshgrid.
-##
-## See also: plot, semilogx, semilogy, loglog, polar, mesh, meshdom, contour,
-##           bar, stairs, gplot, gsplot, replot, xlabel, ylabel, title
+## -*- texinfo -*-
+## @deftypefn {Function File} {[@var{xx}, @var{yy}] =} meshgrid (@var{x}, @var{y})
+## @deftypefnx {Function File} {[@var{xx}, @var{yy}] =} meshgrid (@var{x})
+## Given vectors of @var{x} and @var{y} coordinates, return two matrices corresponding
+## to the @var{x} and @var{y} coordinates of a mesh.  The rows of @var{xx} are copies of @var{x},
+## and the columns of @var{yy} are copies of @var{y}.
+## @end deftypefn
+## @seealso{sombrero, plot, semilogx, semilogy, loglog, polar, mesh, meshdom, contour,
+## bar, stairs, gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
@@ -39,22 +36,8 @@ function [xx, yy] = meshgrid (x, y)
   endif
   if (nargin > 0 && nargin < 3)
     if (is_vector (x) && is_vector (y))
-      xlen = length (x);
-      ylen = length (y);
-      xx = zeros (ylen, xlen);
-      yy = zeros (ylen, xlen);
-      if (columns (x) == 1)
-        x = x';
-      endif
-      if (rows (y) == 1)
-        y = y';
-      endif
-      for i = 1:ylen
-        xx(i,:) = x;
-      endfor
-      for i = 1:xlen
-        yy(:,i) = y;
-      endfor
+      xx = ones (length (y), 1) * x(:).';
+      yy = y(:) * ones (1, length (x));
     else
       error ("meshgrid: arguments must be vectors");
     endif
