@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,22 +17,23 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: semilogy (x, y)
-##        semilogy (x1, y1, x2, y2, ...)
-##        semilogy (x, y, fmt)
-##
-## Make a 2D plot of y versus x using a log scale for the x axis.
-##
-## See the help message for the plot command for a description of how
-## the arguments are interpreted.
-##
-## See also: plot, semilogx, loglog, polar, mesh, contour, bar, stairs,
-##           gplot, gsplot, replot, xlabel, ylabel, title
+## -*- texinfo -*-
+## @deftypefn {Function File} {} semilogy (@var{args})
+## Make a two-dimensional plot using a log scale for the @var{y} axis.  See
+## the description of @code{plot} for a description of the arguments
+## that @code{semilogy} will accept.
+## @end deftypefn
+## @seealso{plot, semilogx, loglog, polar, mesh, contour, bar, stairs,
+## gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
 function semilogy (...)
 
+  ## XXX FIXME XXX -- these plot states should really just be set
+  ## temporarily, probably inside an unwind_protect block, but there is
+  ## no way to determine their current values.
+
   gset nologscale x;
   gset logscale y;
   gset nopolar;
