@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,27 +17,33 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: [xs, ys] = stairs (x, y)
-##
-## Given two vectors of x-y data, stairs produces a `stairstep' plot.
+## -*- texinfo -*-
+## @deftypefn {Function File} {} stairs (@var{x}, @var{y})
+## Given two vectors of x-y data, bar produces a `stairstep' plot.
 ##
 ## If only one argument is given, it is taken as a vector of y-values
-## and the x coordiates are taken to be the indices of the elements.
+## and the x coordinates are taken to be the indices of the elements.
 ##
 ## If two output arguments are specified, the data are generated but
 ## not plotted.  For example,
 ##
-##   stairs (x, y);
+## @example
+## stairs (x, y);
+## @end example
 ##
+## @noindent
 ## and
 ##
-##   [xs, ys] = stairs (x, y);
-##   plot (xs, ys);
+## @example
+## [xs, ys] = stairs (x, y);
+## plot (xs, ys);
+## @end example
 ##
+## @noindent
 ## are equivalent.
-##
-## See also: plot, semilogx, semilogy, loglog, polar, mesh, contour,
-##           bar, gplot, gsplot, replot, xlabel, ylabel, title
+## @end deftypefn
+## @seealso{plot, semilogx, semilogy, loglog, polar, mesh, contour,
+## bar, gplot, gsplot, replot, xlabel, ylabel, and title}
 
 ## Author: jwe
 
@@ -65,18 +71,18 @@ function [xs, ys] = stairs (x, y)
       if (xlen == ylen)
         len = 2 * xlen;
         tmp_xs = tmp_ys = zeros (len, 1);
-	k = 1;
+        k = 1;
         len_m2 = len - 2;
-	for i = 1:2:len_m2
-	  tmp_xs(i) = x(k);
-	  tmp_ys(i) = y(k);
-	  tmp_ys(i+1) = y(k);
+        for i = 1:2:len_m2
+          tmp_xs(i) = x(k);
+          tmp_ys(i) = y(k);
+          tmp_ys(i+1) = y(k);
           k++;
-	  tmp_xs(i+1) = x(k);
+          tmp_xs(i+1) = x(k);
           if (x(k) < x(k-1))
             error ("stairs: x vector values must be in ascending order");
           endif
-	endfor
+        endfor
         tmp_xs(len-1) = x(xlen);
         delta = x(xlen) - x(xlen-1);
         tmp_xs(len) = x(xlen) + delta;
