@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,13 +17,13 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: title (text)
-##
-## Defines a title for a plot.  The title will appear the next time a
-## plot is displayed.
-##
-## See also: plot, semilogx, semilogy, loglog, polar, mesh, contour,
-##           bar, stairs, gplot, gsplot, replot, xlabel, ylabel
+## -*- texinfo -*-
+## @deftypefn {Function File} {} title (@var{string})
+## Specify a title for a plot.  If you already have a plot displayed, use
+## the command @code{replot} to redisplay it with the new title.
+## @end deftypefn
+## @seealso{plot, semilogx, semilogy, loglog, polar, mesh, contour,
+## bar, stairs, gplot, gsplot, replot, xlabel, and ylabel}
 
 ## Author: jwe
 
@@ -34,8 +34,8 @@ function title (text)
   endif
 
   if (isstr (text))
-    command = sprintf ("gset title \"%s\"", text);
-    eval (command);
+    eval (sprintf ("gset title \"%s\"",
+		   undo_string_escapes (undo_string_escapes (text))));
   else
     error ("title: text must be a string");
   endif
