@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,12 +17,11 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: top_title (text)
-##
-## NOTE: this will work only with gnuplot installed with
-##       multiplot patch
-##
-## makes a title with text "text" at the top of the plot
+## -*- texinfo -*-
+## @deftypefn {Function File} {} top_title (@var{string})
+## @deftypefnx {Function File} {} bottom_title (@var{string})
+## Makes a title with text @var{string} at the top (bottom) of the plot.
+## @end deftypefn
 
 ## Author: Vinayak Dutt <Dutt.Vinayak@mayo.EDU>
 ## Created: 3 July 95
@@ -41,7 +40,8 @@ function top_title (text)
   if (isstr (text))
     gset bottom_title;
     gset title;
-    eval (sprintf ("gset top_title \"%s\"", text));
+    eval (sprintf ("gset top_title \"%s\"",
+		   undo_string_escapes (undo_string_escapes (text))));
   else
     error ("error: top_title: text must be a string");
   endif
