@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,27 +17,15 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: ylabel (text)
-##
-## Defines a label for the y-axis of a plot.  The label will appear the
-## next time a plot is displayed.
-##
-## See also: plot, semilogx, semilogy, loglog, polar, mesh, contour,
-##           bar, stairs, gplot, gsplot, replot, xlabel, title
+## -*- texinfo -*-
+## @deftypefn {Function File} {} ylabel (@var{string})
+## See xlabel.
+## @end deftypefn
 
 ## Author: jwe
 
-function ylabel (text)
+function ylabel (...)
 
-  if (nargin != 1)
-    usage ("ylabel (text)");
-  endif
-
-  if (isstr (text))
-    command = sprintf ("gset ylabel \"%s\"", text);
-    eval (command);
-  else
-    error ("ylabel: text must be a string");
-  endif
+  __axis_label__ ("ylabel", all_va_args);
 
 endfunction
