@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,12 +17,10 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: zlabel (text)
-##
-## Defines a label for the z-axis of a plot.  The label will appear the
-## next time a plot is displayed.
-##
-## See other plotting commands also.
+## -*- texinfo -*-
+## @deftypefn {Function File} {} zlabel (@var{string})
+## See xlabel.
+## @end deftypefn
 
 ## Author: Vinayak Dutt <Dutt.Vinayak@mayo.EDU>
 ## Created: 3 July 95
