@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,17 +17,16 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: conv (a, b)
-##
+## -*- texinfo -*-
+## @deftypefn {Function File} {} conv (@var{a}, @var{b})
 ## Convolve two vectors.
 ##
-## y = conv (a, b) returns a vector of length equal to length (a) +
-## length (b) -1.
-##
-## If a and b are polynomial coefficient vectors, conv returns the
-## coefficients of the product polynomial.
-##
-## SEE ALSO: deconv, poly, roots, residue, polyval, polyderiv, polyinteg
+## @code{y = conv (a, b)} returns a vector of length equal to
+## @code{length (a) + length (b) - 1}.
+## If @var{a} and @var{b} are polynomial coefficient vectors, @code{conv}
+## returns the coefficients of the product polynomial.
+## @end deftypefn
+## @seealso{deconv, poly, roots, residue, polyval, polyderiv, and polyinteg}
 
 ## Author: Tony Richardson <arichard@stark.cc.oh.us>
 ## Created: June 1994
