@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,19 +17,18 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: deconv (y, a)
-##
+## -*- texinfo -*-
+## @deftypefn {Function File} {} deconv (@var{y}, @var{a})
 ## Deconvolve two vectors.
 ##
-## [b, r] = deconv (y, a) solves for b and r such that
-##    y = conv(a,b) + r
+## @code{[b, r] = deconv (y, a)} solves for @var{b} and @var{r} such that
+## @code{y = conv (a, b) + r}.
 ##
-## If y and a are polynomial coefficient vectors, b will contain the
-## coefficients of the polynomial quotient and r will be a remander
-## polynomial of lowest order.
-##
-## SEE ALSO: conv, poly, roots, residue, polyval, polyderiv,
-## polyinteg
+## If @var{y} and @var{a} are polynomial coefficient vectors, @var{b} will
+## contain the coefficients of the polynomial quotient and @var{r} will be
+## a remander polynomial of lowest order.
+## @end deftypefn
+## @seealso{conv, poly, roots, residue, polyval, polyderiv, and polyinteg}
 
 ## Author: Tony Richardson <arichard@stark.cc.oh.us>
 ## Created: June 1994
@@ -58,8 +57,6 @@ function [b, r] = deconv (y, a)
     b = 0;
   endif
 
-  b = polyreduce (b);
-
   lc = la + length (b) - 1;
   if (ly == lc)
     r = y - conv (a, b);
@@ -67,6 +64,4 @@ function [b, r] = deconv (y, a)
     r = [(zeros (1, lc - ly)), y] - conv (a, b);
   endif
 
-  r = polyreduce (r);
-
 endfunction
