@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,13 +17,13 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: polyderiv (p)
-##
-## Returns the coefficients of the derivative of the polynomial whose
-## coefficients are given by vector p.
-##
-## SEE ALSO: poly, polyinteg, polyreduce, roots, conv, deconv, residue,
-##           filter, polyval, polyvalm
+## -*- texinfo -*-
+## @deftypefn {Function File} {} polyderiv (@var{c})
+## Return the coefficients of the derivative of the polynomial whose
+## coefficients are given by vector @var{c}.
+## @end deftypefn
+## @seealso{poly, polyinteg, polyreduce, roots, conv, deconv, residue,
+## filter, polyval, and polyvalm}
 
 ## Author: Tony Richardson <arichard@stark.cc.oh.us>
 ## Created: June 1994
