@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,14 +17,29 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage:  [p, yf] = polyfit (x, y, n)
+## -*- texinfo -*-
+## @deftypefn {Function File} {[@var{p}, @var{yf}] =} polyfit (@var{x}, @var{y}, @var{n})
+## Return the coefficients of a polynomial @var{p}(@var{x}) of degree
+## @var{n} that minimizes
+## @iftex
+## @tex
+## $$
+## \sum_{i=1}^N (p(x_i) - y_i)^2
+## $$
+## @end tex
+## @end iftex
+## @ifinfo
+## @code{sumsq (p(x(i)) - y(i))},
+## @end ifinfo
+##  to best fit the data in the least squares sense.
 ##
-## Returns the coefficients of a polynomial p(x) of degree n that
-## minimizes sumsq (p(x(i)) - y(i)), i.e., that best fits the data
-## in the least squares sense.
+## The polynomial coefficients are returned in a row vector if @var{x}
+## and @var{y} are both row vectors; otherwise, they are returned in a
+## column vector.
 ##
-## If two outputs are requested, also return the values of the
-## polynomial for each value of x.
+## If two output arguments are requested, the second contains the values of
+## the polynomial for each value of @var{x}.
+## @end deftypefn
 
 ## Author: KH <Kurt.Hornik@ci.tuwien.ac.at>
 ## Created: 13 December 1994
@@ -59,14 +74,14 @@ function [p, yf] = polyfit (x, y, n)
     yf = X * p;
 
     if (y_is_row_vector)
-      yf = yf';
+      yf = yf.';
     endif
   endif
 
   p = flipud (p);
 
-  if (! prefer_column_vectors)
-    p = p.';
+  if (y_is_row_vector && rows (x) == 1)
+    p = p';
   endif
 
 endfunction
