@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,15 +17,15 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: polyinteg (p)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} polyinteg (@var{c})
+## Return the coefficients of the integral of the polynomial whose
+## coefficients are represented by the vector @var{c}.
 ##
-## Returns the coefficients of the integral the polynomial whose coefficients
-## are represented by the vector p.
-##
-## The constant of integration is zero.
-##
-## SEE ALSO: poly, polyderiv, polyreduce, roots, conv, deconv, residue,
-##           filter, polyval, polyvalm
+## The constant of integration is set to zero.
+## @end deftypefn
+## @seealso{poly, polyderiv, polyreduce, roots, conv, deconv, residue,
+## filter, polyval, and polyvalm}
 
 ## Author: Tony Richardson <arichard@stark.cc.oh.us>
 ## Created: June 1994
