@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,25 +17,20 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: polyval (c, x)
-##
+## -*- texinfo -*-
+## @deftypefn {Function File} {} polyval (@var{c}, @var{x})
 ## Evaluate a polynomial.
 ##
-## In octave, a polynomial is represented by it's coefficients (arranged
-## in descending order). For example a vector c of length n+1 corresponds
-## to the following nth order polynomial
+## @code{polyval (@var{c}, @var{x})} will evaluate the polynomial at the
+## specified value of @var{x}.
 ##
-##   p(x) = c(1) x^n + ... + c(n) x + c(n+1).
-##
-## polyval(c,x) will evaluate the polynomial at the specified value of x.
-##
-## If x is a vector or matrix, the polynomial is evaluated at each of the
-## elements of x.
-##
-## SEE ALSO: polyvalm, poly, roots, conv, deconv, residue, filter,
-##           polyderiv, polyinteg
+## If @var{x} is a vector or matrix, the polynomial is evaluated at each of
+## the elements of @var{x}.
+## @end deftypefn
+## @seealso{polyvalm, poly, roots, conv, deconv, residue, filter,
+## polyderiv, and polyinteg}
 
-## Author: Tony Richardson <amr@mpl.ucsd.edu>
+## Author: Tony Richardson <arichard@stark.cc.oh.us>
 ## Created: June 1994
 ## Adapted-By: jwe
 
@@ -46,7 +41,7 @@ function y = polyval (c, x)
   endif
 
   if (! (is_vector (c) || isempty (c)))
-    error ("polyval: first argument must be a vector.");
+    error ("polyval: first argument must be a vector");
   endif
 
   if (isempty (x))
