@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,19 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: union(a,b)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} union (@var{x}, @var{y})
+## Return the set of elements that are in either of the sets @var{x} and
+## @var{y}.  For example,
 ##
-## Returns the union of sets a and b.
-##
-## See - create_set, intersection, complement
+## @example
+## @group
+## union ([ 1, 2, 4 ], [ 2, 3, 5 ])
+##      @result{} [ 1, 2, 3, 4, 5 ]
+## @end group
+## @end example
+## @end deftypefn
+## @seealso{create_set, intersection, and complement}
 
 ## Author: jwe
 
