@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,35 +17,30 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: sinc(x)
-##
-##        Returns sin(pi*x)/(pi*x).
+## -*- texinfo -*-
+## @deftypefn {Function File} {} sinc (@var{x})
+## Return
+## @iftex
+## @tex
+## $ \sin (\pi x)/(\pi x)$.
+## @end tex
+## @end iftex
+## @ifinfo
+##  sin(pi*x)/(pi*x).
+## @end ifinfo
+## @end deftypefn
 
-## Author: jwe
+## Author: jwe ???
 
 function result = sinc (x)
 
-  ## We either need to set the do_fortran_indexing variable to "true"
-  ## or use reshape to convert the input matrix to a vector, so that
-  ## we can use find to determine the elements of x that equal zero.
-  ## I prefer reshaping.
+  result = ones (size (x));
 
-  [nr, nc] = size(x);
+  i = (x != 0);
 
-  nels = nr*nc;
-
-  x = reshape(x,nels,1);
-
-  ## Set result to all ones initially.
-  result = ones(nels,1);
-
-  ## Find non-zero elements in the input matrix.
-  i = find(x);
-
-  if (!isempty(i))
-    result(i) = sin(pi*x(i))./(pi*x(i));
+  if (any (i))
+    t = pi * x(i);
+    result(i) = sin (t) ./ t;
   endif
 
-  result = reshape(result,nr,nc);
-
 endfunction
