@@ -1,37 +1,39 @@
 ## Copyright (C) 1995, 1996, 1997  Friedrich Leisch
-## 
+##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details. 
-## 
+## General Public License for more details.
+##
 ## You should have received a copy of the GNU General Public License
 ## along with this file.  If not, write to the Free Software Foundation,
 ## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-## usage:  retval = spectral_adf (c, [win, [b]])
-## 
-## Returns the spectral density estimator.
-## c ....... vector of autocovariances (starting at lag 0)
-## win ..... window name, eg. "triangle" or "rectangle"
-##           spectral_adf searches for a function called win_lw ()
-## b ....... bandwidth
-## 
-## If win is omitted, the triangle window is used as default.
-## If b is omitted, 1 / sqrt( length (c)) is used as default.
-  
-## Author:  FL <Friedrich.Leisch@ci.tuwien.ac.at>
-## Description:  Spectral density estimation
-  
+## -*- texinfo -*-
+## @deftypefn {Function File} {} spectral_adf (@var{c}, @var{win}, @var{b})
+## Return the spectral density estimator given a vector of
+## autocovariances @var{c}, window name @var{win}, and bandwidth,
+## @var{b}.
+##
+## The window name, e.g., @code{"triangle"} or @code{"rectangle"} is
+## used to search for a function called @code{@var{win}_sw}.
+##
+## If @var{win} is omitted, the triangle window is used.  If @var{b} is
+## omitted, @code{1 / sqrt (length (@var{x}))} is used.
+## @end deftypefn
+
+## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
+## Description: Spectral density estimation
+
 function retval = spectral_adf (c, win, b)
-  
+
   cr = length (c);
-  
+
   if (columns (c) > 1)
     c=c';
   endif
@@ -46,16 +48,16 @@ function retval = spectral_adf (c, win, b)
     win = [win, "_lw"];
     w = feval (win, cr, b);
   endif
-      
+
   c = c .* w;
-  
+
   retval = 2 * real (fft (c)) - c(1);
   retval = [(zeros (cr, 1)), retval];
-  retval(:, 1) = (0 : xr-1)' / xr;
-  
+  retval(:, 1) = (0 : cr-1)' / cr;
+
 endfunction
-    
 
-  
+
+
 
 
