@@ -1,45 +1,51 @@
 ## Copyright (C) 1995, 1996, 1997  Andreas Weingessel
-## 
+##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details. 
-## 
+## General Public License for more details.
+##
 ## You should have received a copy of the GNU General Public License
 ## along with this file.  If not, write to the Free Software Foundation,
 ## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-## usage:  X = synthesis (Y, c)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} synthesis (@var{y}, @var{c})
+## Compute a signal from its short-time Fourier transform @var{y} and a
+## 3-element vector @var{c} specifying window size, increment, and
+## window type.
 ##
-## recovers a signal X from its short-time Fourier transform Y. c =
-## [win_size, increment, window_type].
+## The values @var{y} and @var{c} can be derived by
 ##
-## Y and c can be derived by [Y, c] = stft (X [, ...]).
-  
-## Author:  AW <Andreas.Weingessel@ci.tuwien.ac.at>
-## Description:  Recover a signal from its short-term Fourier transform
+## @example
+## [@var{y}, @var{c}] = stft (@var{x} , @dots{})
+## @end example
+## @end deftypefn
+
+## Author: AW <Andreas.Weingessel@ci.tuwien.ac.at>
+## Description: Recover a signal from its short-term Fourier transform
 
 function X = synthesis (Y, c)
-  
+
   if (nargin != 2)
     usage ("X = synthesis (Y, c)");
   endif
-  
+
   [nr, nc] = size (c);
   if (nr * nc != 3)
-    error ("synthesis:  c must contain exactly 3 elements");
+    error ("synthesis: c must contain exactly 3 elements");
   endif
-  
+
   ## not necessary, enables better reading
-  win = c(1);      
+  win = c(1);
   inc = c(2);
   w_type = c(3);
-  
+
   if (w_type == 1)
     H = hanning (win);
   elseif (w_type == 2)
@@ -47,9 +53,9 @@ function X = synthesis (Y, c)
   elseif (w_type == 3)
     H = ones (win, 1);
   else
-    error ("synthesis:  window_type must be 1, 2, or 3");
+    error ("synthesis: window_type must be 1, 2, or 3");
   endif
-    
+
   Z = real (ifft (Y));
   st = fix ((win-inc) / 2);
   Z = Z(st:st+inc-1, :);
@@ -59,7 +65,7 @@ function X = synthesis (Y, c)
   for i = 1:nc
     Z(:, i) = Z(:, i) ./ H;
   endfor
-  
+
   X = reshape(Z, inc * nc, 1);
-  
+
 endfunction
