@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,14 +17,33 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: hilb (n)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} hilb (@var{n})
+## Return the Hilbert matrix of order @var{n}.  The
+## @iftex
+## @tex
+## $i,\,j$
+## @end tex
+## @end iftex
+## @ifinfo
+## i, j
+## @end ifinfo
+## element of a Hilbert matrix is defined as
+## @iftex
+## @tex
+## $$
+## H (i, j) = {1 \over (i + j - 1)}
+## $$
+## @end tex
+## @end iftex
+## @ifinfo
 ##
-## Return the Hilbert matrix of order n.  The i, j element of a Hilbert
-## matrix is defined as
-##
-##  H (i, j) = 1 / (i + j - 1);
-##
-## See also: hankel, vander, sylvester_matrix, invhilb, toeplitz
+## @example
+## H (i, j) = 1 / (i + j - 1)
+## @end example
+## @end ifinfo
+## @end deftypefn
+## @seealso{hankel, vander, sylvester_matrix, invhilb, and toeplitz}
 
 ## Author: jwe
 
