@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,19 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: sylvester_matrix (k)
-##
-## Return the Sylvester matrix of order n = 2^k.
-##
-## See also: hankel, vander, hilb, invhilb, toeplitz
+## -*- texinfo -*-
+## @deftypefn {Function File} {} sylvester_matrix (@var{k})
+## Return the Sylvester matrix of order
+## @iftex
+## @tex
+## $n = 2^k$.
+## @end tex
+## @end iftex
+## @ifinfo
+## n = 2^k.
+## @end ifinfo
+## @end deftypefn
+## @seealso{hankel, vander, hilb, invhilb, and toeplitz}
 
 ## Author: jwe
 
