@@ -1,34 +1,35 @@
 ## Copyright (C) 1995, 1996, 1997  Kurt Hornik
-## 
+##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 2, or (at your option)
 ## any later version.
-## 
+##
 ## This program is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details. 
-## 
+## General Public License for more details.
+##
 ## You should have received a copy of the GNU General Public License
 ## along with this file.  If not, write to the Free Software Foundation,
 ## 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-## usage:   meansq (x)
-##
+## -*- texinfo -*-
+## @deftypefn {Function File} {} meansq (@var{x})
 ## For vector arguments, return the mean square of the values.
 ## For matrix arguments, return a row vector contaning the mean square
 ## of each column.
-  
-## Author:  KH <Kurt.Hornik@ci.tuwien.ac.at>
-## Description:  Compute mean square
+## @end deftypefn
+
+## Author: KH <Kurt.Hornik@ci.tuwien.ac.at>
+## Description: Compute mean square
 
 function y = meansq (x)
-  
+
   if (nargin != 1)
     usage ("meansq (x)");
   endif
-  
+
   y = mean (x.^2);
-  
+
 endfunction
