@@ -17,12 +17,18 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage:  index (s, t)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} index (@var{s}, @var{t})
+## Return the position of the first occurrence of the string @var{t} in the
+## string @var{s}, or 0 if no occurrence is found.  For example,
 ##
-## Returns the position of the first occurence of the string T in the
-## string S or 0 if no occurence is found.
+## @example
+## index ("Teststring", "t")
+##      @result{} 4
+## @end example
 ##
-## NOTE: this function does not work for arrays of strings.
+## @strong{Note:}  This function does not work for arrays of strings.
+## @end deftypefn
 
 ## Author: Kurt Hornik <Kurt.Hornik@ci.tuwien.ac.at>
 ## Adapted-By: jwe
@@ -42,6 +48,10 @@ function n = index (s, t)
     [nr_s, l_s] = size (s);
     [nr_t, l_t] = size (t);
 
+    if (nr_s == 0 || nr_t == 0)
+      return;
+    endif
+
     if (nr_s != 1 || nr_t != 1)
       error ("index: arguments cannot be string arrays");
     endif
@@ -49,10 +59,10 @@ function n = index (s, t)
     if (l_t <= l_s)
       tmp = l_s - l_t + 1;
       for idx = 1 : tmp
-	if (strcmp (substr (s, idx, l_t), t))
-	  n = idx;
-	  return;
-	endif
+        if (strcmp (substr (s, idx, l_t), t))
+          n = idx;
+          return;
+        endif
       endfor
     endif
 
