@@ -17,9 +17,11 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: lower (s)
-##
-## See also: tolower
+## -*- texinfo -*-
+## @deftypefn {Function File} {} lower (@var{s})
+## Transform all letters in the string @var{s} to lower case.
+## @end deftypefn
+## @seealso{tolower}
 
 ## Author: jwe
 
