@@ -17,12 +17,18 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: rindex (s, t)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} rindex (@var{s}, @var{t})
+## Return the position of the last occurrence of the string @var{t} in the
+## string @var{s}, or 0 if no occurrence is found.  For example,
 ##
-## Returns the position of the last occurence of the string T in the
-## string S or 0 if no occurence is found.
+## @example
+## rindex ("Teststring", "t")
+##      @result{} 6
+## @end example
 ##
-## NOTE: this function does not work for arrays of strings.
+## @strong{Note:}  This function does not work for arrays of strings.
+## @end deftypefn
 
 ## Author: Kurt Hornik <Kurt.Hornik@ci.tuwien.ac.at>
 ## Adapted-By: jwe
@@ -45,10 +51,10 @@ function n = rindex (s, t)
     if (l_t <= l_s)
       tmp = l_s - l_t + 1;
       for idx = tmp : -1 : 1
-	if (strcmp (substr (s, idx, l_t), t))
-	  n = idx;
-	  return;
-	endif
+        if (strcmp (substr (s, idx, l_t), t))
+          n = idx;
+          return;
+        endif
       endfor
     endif
 
