@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,29 +17,45 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: strcat (s, t, ...)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} strcat (@var{s1}, @var{s2}, @dots{})
+## Return a string containing all the arguments concatenated.  For example,
 ##
-## Concatenate strings.
+## @example
+## @group
+## s = [ "ab"; "cde" ];
+## strcat (s, s, s)
+##      @result{} "ab ab ab "
+##         "cdecdecde"
+## @end group
+## @end example
+## @end deftypefn
 
 ## Author: jwe
 
 function st = strcat (s, t, ...)
 
   if (nargin > 1)
-    if (isstr (s) && isstr (t))
-      tmpst = [s, t];
-    else
-      error ("strcat: all arguments must be strings");
-    endif
-    n = nargin - 2;
-    while (n--)
-      tmp = va_arg ();
-      if (isstr (tmp))
-        tmpst = [tmpst, tmp];
+    save_empty_list_elements_ok = empty_list_elements_ok;
+    unwind_protect
+      empty_list_elements_ok = 1;
+      if (isstr (s) && isstr (t))
+        tmpst = [s, t];
       else
         error ("strcat: all arguments must be strings");
       endif
-    endwhile
+      n = nargin - 2;
+      while (n--)
+        tmp = va_arg ();
+        if (isstr (tmp))
+          tmpst = [tmpst, tmp];
+        else
+          error ("strcat: all arguments must be strings");
+        endif
+      endwhile
+    unwind_protect_cleanup
+      empty_list_elements_ok = save_empty_list_elements_ok;
+    end_unwind_protect
   else
     usage ("strcat (s, t, ...)");
   endif
