@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,17 +17,14 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: strcmp (s1, s2)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} strcmp (@var{s1}, @var{s2})
+## Compares two strings, returning 1 if they are the same, and 0 otherwise.
 ##
-## Compare two strings.  Trailing blanks are significant.
-##
-## WARNING:  Unlike the C function of the same name, this function
-## returns 1 for equal and zero for not equal.  Why?  To be compatible
-## with Matlab, of course.
-##
-## Why doesn't this always return a scalar instead of vector with
-## elements corresponding to the rows of the string array?  To be
-## compatible with Matlab, of course.
+## @strong{Note:}  For compatibility with @sc{Matlab}, Octave's strcmp
+## function returns 1 if the strings are equal, and 0 otherwise.  This is
+## just the opposite of the corresponding C library function.
+## @end deftypefn
 
 ## Author: jwe
 
@@ -39,9 +36,9 @@ function status = strcmp (s1, s2)
 
   status = 0;
   if (isstr (s1) && isstr(s2))
-    c1 = columns (s1);
-    c2 = columns (s2);
-    if (c1 == c2)
+    [r1, c1] = size (s1);
+    [r2, c2] = size (s2);
+    if (r1 == r2 && c1 == c2)
       if (c1 == 0)
         status = 1;
       else
