@@ -1,4 +1,4 @@
-## Copyright (C) 1996 John W. Eaton
+## Copyright (C) 1996, 1997 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -17,11 +17,21 @@
 ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
 ## 02111-1307, USA.
 
-## usage: clock ()
+## -*- texinfo -*-
+## @deftypefn {Function File} {} clock ()
+## Return a vector containing the current year, month (1-12), day (1-31),
+## hour (0-23), minute (0-59) and second (0-61).  For example,
 ##
-## Return current date and time in vector with elements
+## @example
+## @group
+## clock ()
+##      @result{} [ 1993, 8, 20, 4, 56, 1 ]
+## @end group
+## @end example
 ##
-##   [ year, month, day-of-month, hour, minute, second ]
+## The function clock is more accurate on systems that have the
+## @code{gettimeofday} function.
+## @end deftypefn
 
 ## Author: jwe
 
