@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -41,12 +41,13 @@ License as published by the Free Software Foundation.
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 
 #include "Map.h"
 
-static unsigned int
-hash (const string& str)
+template <class C>
+unsigned int
+CHMap<C>::hash (const std::string& str) const
 {
   unsigned h = 0;
   for (unsigned i = 0; i < str.length (); i++)
@@ -56,7 +57,7 @@ hash (const string& str)
 
 template <class C>
 Pix
-Map<C>::seek (const string& item) const
+Map<C>::seek (const std::string& item) const
 {
   Pix i = 0;
 
@@ -94,52 +95,28 @@ Map<C>::clear (void)
 
 template <class C>
 int
-Map<C>::contains (const string& item) const
+Map<C>::contains (const std::string& item) const
 {
   return seek (item) != 0;
 }
 
 template <class C>
 void
-Map<C>::error (const string& msg) const
+Map<C>::error (const std::string& msg) const
 {
-  cerr << "Map: " << msg << "\n";
+  std::cerr << "Map: " << msg << "\n";
 }
 
 // CHMap class.
 
-// The nodes are linked together serially via a version of a trick
-// used in some vtables: odd pointers are actually links to the next
-// table entry.  Not terrible, but not wonderful either.
-
-template <class C>
-static int
-goodCHptr (CHNode<C> *t)
-{
-  return ((((unsigned) t) & 1) == 0);
-}
-
-// This sucks, but avoids g++ 2.6.0 `type unification failed' errors.
-
-static void *
-index_to_CHptr (int i)
-{
-  return (void *) ((i << 1) + 1);
-}
-
-template <class C>
-static unsigned int
-CHptr_to_index (CHNode<C> *t)
-{
-  return ((unsigned) t) >> 1;
-}
+#define index_to_CHptr(i) (X_CAST (void *, (i << 1) + 1))
 
 template <class C>
 CHMap<C>::CHMap (const C& dflt, unsigned int sz) : Map<C> (dflt)
 {
   tab = new CHNode<C>* [size = sz];
   for (unsigned int i = 0; i < size; ++i)
-    tab[i] = (CHNode<C> *) index_to_CHptr (i+1);
+    tab[i] = static_cast<CHNode<C> *> (index_to_CHptr (i+1));
   count = 0;
 }
 
@@ -148,19 +125,55 @@ CHMap<C>::CHMap (const CHMap& a) : Map<C> (a.def)
 {
   tab = new CHNode<C>* [size = a.size];
   for (unsigned int i = 0; i < size; ++i)
-    tab[i] = (CHNode<C> *) index_to_CHptr (i+1);
+    tab[i] = static_cast<CHNode<C> *> (index_to_CHptr (i+1));
   count = 0;
   for (Pix p = a.first (); p; a.next (p))
     (*this) [a.key (p)] = a.contents (p);
 }
 
+template <class C>
+CHMap<C>&
+CHMap<C>::operator = (const CHMap& a)
+{
+  Map<C>::operator = (*this);
+
+  unsigned int old_size = a.size;
+
+  CHNode<C> **old_tab = tab;
+  old_size = a.size;
+
+  size = old_size;
+  tab = new CHNode<C>* [size];
+
+  for (unsigned int i = 0; i < size; ++i)
+    tab[i] = static_cast<CHNode<C> *> (index_to_CHptr (i+1));
+
+  for (Pix p = a.first (); p; a.next (p))
+    (*this) [a.key (p)] = a.contents (p);
+
+  for (unsigned int i = 0; i < old_size; ++i)
+    {
+      CHNode<C> *p = old_tab[i];
+      old_tab[i] = static_cast<CHNode<C> *> (index_to_CHptr (i+1));
+      while (p->goodCHptr ())
+	{
+	  CHNode<C> *nxt = p->tl;
+	  delete p;
+	  p = nxt;
+	}
+    }
+  delete [] old_tab;
+
+  return *this;
+}
+
 template <class C>
 Pix
-CHMap<C>::seek (const string& key) const
+CHMap<C>::seek (const std::string& key) const
 {
   unsigned int h = hash (key) % size;
 
-  for (CHNode<C> *t = tab[h]; goodCHptr (t); t = t->tl)
+  for (CHNode<C> *t = tab[h]; t->goodCHptr (); t = t->tl)
     if (key == t->hd)
       return Pix (t);
 
@@ -169,12 +182,12 @@ CHMap<C>::seek (const string& key) const
 
 template <class C>
 C&
-CHMap<C>::operator [] (const string& item)
+CHMap<C>::operator [] (const std::string& item)
 {
   unsigned int h = hash (item) % size;
 
   CHNode<C> *t = 0;
-  for (t = tab[h]; goodCHptr (t); t = t->tl)
+  for (t = tab[h]; t->goodCHptr (); t = t->tl)
     if (item == t->hd)
       return t->cont;
 
@@ -186,13 +199,13 @@ CHMap<C>::operator [] (const string& item)
 
 template <class C>
 void
-CHMap<C>::del (const string& key)
+CHMap<C>::del (const std::string& key)
 {
   unsigned int h = hash (key) % size;
 
   CHNode<C> *t = tab[h];
   CHNode<C> *trail = t;
-  while (goodCHptr (t))
+  while (t->goodCHptr ())
     {
       if (key == t->hd)
 	{
@@ -216,8 +229,8 @@ CHMap<C>::clear (void)
   for (unsigned int i = 0; i < size; ++i)
     {
       CHNode<C> *p = tab[i];
-      tab[i] = (CHNode<C> *) index_to_CHptr (i+1);
-      while (goodCHptr (p))
+      tab[i] = static_cast<CHNode<C> *> (index_to_CHptr (i+1));
+      while (p->goodCHptr ())
 	{
 	  CHNode<C> *nxt = p->tl;
 	  delete p;
@@ -232,7 +245,7 @@ Pix
 CHMap<C>::first (void) const
 {
   for (unsigned int i = 0; i < size; ++i)
-    if (goodCHptr (tab[i]))
+    if (tab[i]->goodCHptr ())
       return Pix (tab[i]);
   return 0;
 }
@@ -241,14 +254,14 @@ template <class C>
 void
 CHMap<C>::next (Pix& p) const
 {
-  CHNode<C> *t = ((CHNode<C> *) p)->tl;
-  if (goodCHptr (t))
+  CHNode<C> *t = (static_cast<CHNode<C> *> (p))->tl;
+  if (t->goodCHptr ())
     p = Pix (t);
   else
     {
-      for (unsigned int i = CHptr_to_index (t); i < size; ++i)
+      for (unsigned int i = t->CHptr_to_index (); i < size; ++i)
 	{
-	  if (goodCHptr (tab[i]))
+	  if (tab[i]->goodCHptr ())
 	    {
 	      p =  Pix (tab[i]);
 	      return;
@@ -269,10 +282,10 @@ CHMap<C>::OK (void) const
     {
       CHNode<C> *p = 0;
 
-      for (p = tab[i]; goodCHptr (p); p = p->tl)
+      for (p = tab[i]; p->goodCHptr (); p = p->tl)
 	++n;
 
-      v &= CHptr_to_index (p) == i + 1;
+      v &= p->CHptr_to_index () == i + 1;
     }
 
   v &= count == n;
