@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -45,39 +45,50 @@ License as published by the Free Software Foundation.
 #include <Pix.h>
 
 template <class C>
-class Map
+class
+Map
 {
 protected:
   int count;
   C def;
 
 public:
-  Map (const C& dflt) : def (dflt) { count = 0; }
+  Map (const C& dflt) : count (0), def (dflt) { }
+
+  Map (const Map& m) : count (m.count), def (m.def) { }
+
+  Map& operator = (const Map& m)
+    {
+      count = m.count;
+      def = m.def;
+
+      return *this;
+    }
 
   virtual ~Map (void) { }
 
   int length (void) const { return count; }	// current number of items
   int empty (void) const { return count == 0; }
 
-  virtual int contains (const string& key) const;  // is key mapped?
+  virtual int contains (const std::string& key) const;  // is key mapped?
 
   virtual void clear (void);			// delete all items
 	      
-  virtual C& operator [] (const string& key) = 0;  // access contents by key
+  virtual C& operator [] (const std::string& key) = 0;  // access contents by key
 	      
-  virtual void del (const string& key) = 0;	// delete entry
+  virtual void del (const std::string& key) = 0;	// delete entry
 	      
   virtual Pix first (void) const = 0;		// Pix of first item or 0
   virtual void next (Pix& i) const = 0;		// advance to next or 0
-  virtual string key (Pix i) const = 0;		// access key at i
+  virtual std::string key (Pix i) const = 0;		// access key at i
   virtual C& contents (Pix i) const = 0;	// access contents at i
 
   virtual int owns (Pix i) const;		// is i a valid Pix  ?
-  virtual Pix seek (const string& key) const;	// Pix of key
+  virtual Pix seek (const std::string& key) const;	// Pix of key
 
   C& dflt (void) { return def; }		// access default val
 
-  void error (const string& msg) const;
+  void error (const std::string& msg) const;
 
   virtual int OK (void) const = 0;		// rep invariant
 };
@@ -86,15 +97,25 @@ template <class C>
 struct CHNode
 {
   CHNode *tl;
-  string hd;
+  std::string hd;
   C cont;
 
   CHNode (void) : tl (0), hd (), cont () { }
 
-  CHNode (const string& h, const C& c, CHNode *t = 0)
+  CHNode (const std::string& h, const C& c, CHNode *t = 0)
     : tl (t), hd (h), cont (c) { }
 
   ~CHNode (void) { }
+
+  // The nodes are linked together serially via a version of a trick
+  // used in some vtables: odd pointers are actually links to the next
+  // table entry.  Not terrible, but not wonderful either.
+
+  int goodCHptr (void)
+    { return ((((unsigned long) this) & 1) == 0); }
+
+  unsigned int CHptr_to_index (void)
+    { return (((unsigned long) this) >> 1); }
 };
 
 #ifndef DEFAULT_INITIAL_CAPACITY
@@ -102,7 +123,8 @@ struct CHNode
 #endif
 
 template <class C>
-class CHMap : public Map<C>
+class
+CHMap : public Map<C>
 {
 protected:
   CHNode<C> **tab;
@@ -113,20 +135,22 @@ public:
 
   CHMap (const CHMap& a);
 
+  CHMap& operator = (const CHMap& a);
+
   ~CHMap (void)
     {
       clear ();
-      delete tab;
+      delete [] tab;
     }
 
-  C& operator [] (const string& key);
+  C& operator [] (const std::string& key);
 
-  void del (const string& key);
+  void del (const std::string& key);
 
   Pix first (void) const;
   void next (Pix& i) const;
 
-  string key (Pix p) const
+  std::string key (Pix p) const
     {
       if (p == 0)
 	error ("null Pix");
@@ -139,18 +163,20 @@ public:
       if (p == 0)
 	error ("null Pix");
 
-     return ((CHNode<C> *) p)->cont;
-   }
+      return ((CHNode<C> *) p)->cont;
+    }
 
-  Pix seek (const string& key) const;
+  Pix seek (const std::string& key) const;
 
-  int contains (const string& key) const
+  int contains (const std::string& key) const
     {
       return seek (key) != 0;
     }
 
   void clear (void);
   int  OK (void) const;
+
+  unsigned int hash (const std::string& str) const;
 };
 
 #endif
