@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,7 +28,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 
 #include "Stack.h"
 
@@ -36,7 +36,7 @@ template <class T>
 void
 Stack<T>::error (const char *msg)
 {
-  cerr << msg;
+  std::cerr << msg;
 }
 
 /*
