@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -35,10 +35,6 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 //   defn is the initial value for the variable.
 //
-//   inst_as_fcn is a flag that says whether to install the variable as
-//     if it were a function (allowing the name to also be used as a
-//     variable by users, but recover its original definition if cleared).
-//
 //   protect is a flag that says whether it should be possible to give
 //     the variable a new value.
 //
@@ -46,42 +42,28 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //     clear the variable.  Most builtin variables are eternal, and
 //     cannot be cleared.
 //
-//   sv_fcn is a pointer to a function that should be called whenever
+//   chg_fcn is a pointer to a function that should be called whenever
 //     this variable is given a new value.  It can be 0 if there is no
 //     function to call.  See also the code in user-prefs.cc.
 //
 //   doc is the simple help text for this variable.
 
-#define DEFVAR(name, defn, inst_as_fcn, sv_fcn, doc) \
-  DEFVAR_INT (#name, SBV_ ## name, defn, inst_as_fcn, 0, sv_fcn, doc)
+#define DEFVAR(name, defn, chg_fcn, doc) \
+  DEFVAR_INTERNAL (#name, SBV_ ## name, defn, false, chg_fcn, doc)
 
-// Define a builtin-constant `__name__', and a corresponding variable
-// `name' that can be redefined.  (The variable is actually installed
-// in the symbol table as a function, so that it doesn't work like a
-// global variable when redefined.)
+// Define a builtin constant `name' (which may be redefined, but will
+// retain its original value when cleared) and also an alias to it
+// called `__name__' (which may not be redefined).
 
 #define DEFCONST(name, defn, doc) \
-  DEFVAR_INT (#name, SBV_ ## name, defn, 1, 0, 0, doc); \
-  DEFVAR_INT ("__" ## #name ## "__", XSBV_ ## name, defn, 0, 1, 0, doc)
+  DEFCONST_INTERNAL (name, defn, doc)
 
 // This one can be used when `name' cannot be used directly (if it is
 // already defined as a macro).  In that case, name is already a
-// quoted string, and the name of the structure has to be passed too.
+// quoted string, and the name of the structure must to be passed too.
 
 #define DEFCONSTX(name, sname, defn, doc) \
-  DEFVAR_INT (name, sname, defn, 1, 0, 0, doc); \
-  DEFVAR_INT ("__" ## name ## "__", X ## sname, defn, 0, 1, 0, doc)
-
-// How builtin variables are actually installed.
-
-#define DEFVAR_INT(name, sname, defn, inst_as_fcn, protect, sv_fcn, doc) \
-  do \
-    { \
-      builtin_variable sname (name, octave_value (defn), inst_as_fcn, \
-			      protect, (sv_fcn != 0), sv_fcn, doc); \
-      install_builtin_variable (sname); \
-    } \
-  while (0)
+  DEFCONSTX_INTERNAL (name, sname, defn, doc)
 
 // Define a builtin function.
 //
@@ -96,7 +78,15 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //   doc is the simple help text for the function.
 
 #define DEFUN(name, args_name, nargout_name, doc) \
-  DEFUN_INTERNAL (name, args_name, nargout_name, 0, doc)
+  DEFUN_INTERNAL (name, args_name, nargout_name, false, doc)
+
+// This one can be used when `name' cannot be used directly (if it is
+// already defined as a macro).  In that case, name is already a
+// quoted string, and the internal name of the function must be passed
+// too (the convetion is to use a prefix of "F", so "foo" becomes "Ffoo").
+
+#define DEFUNX(name, fname, args_name, nargout_name, doc) \
+  DEFUNX_INTERNAL (name, fname, args_name, nargout_name, false, doc)
 
 // Define a builtin text-style function.
 //
@@ -105,16 +95,22 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // surround the arguments). 
 
 #define DEFUN_TEXT(name, args_name, nargout_name, doc) \
-  DEFUN_INTERNAL (name, args_name, nargout_name, 1, doc)
+  DEFUN_INTERNAL (name, args_name, nargout_name, true, doc)
 
 // Define a mapper function.
 //
 //   name is the name of the function, unquoqted.
 //
 //   ch_map is a pointer to a function that should be called for
-//     integer arguments that are expected to creat integer results.
+//     integer arguments that are expected to create integer results.
 //     (It's a kluge to handle character mappers like isalpha.)
 //
+//   d_b_map is a pointer to a function that should be called for real
+//     arguments that are expected to create bool results.
+//
+//   c_b_map is a pointer to a function that should be called for
+//     complex arguments that are expected to create bool results.
+//
 //   d_d_map is a pointer to a function that should be called for real
 //     arguments that are expected to create real results.
 //
@@ -136,17 +132,10 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 //   doc is the simple help text for the function.
 
-#define DEFUN_MAPPER(name, ch_map, d_d_map, d_c_map, c_c_map, \
-		     lo, hi, can_ret_cmplx_for_real, doc) \
-  do \
-    { \
-      builtin_mapper_function S ## name (ch_map, d_d_map, \
-					 d_c_map, c_c_map, lo, hi, \
-					 can_ret_cmplx_for_real, \
-					 #name, doc); \
-      install_builtin_mapper (S ## name); \
-    } \
-  while (0)
+#define DEFUN_MAPPER(name, ch_map, d_b_map, c_b_map, d_d_map, d_c_map, \
+		     c_c_map, lo, hi, can_ret_cmplx_for_real, doc) \
+  DEFUN_MAPPER_INTERNAL(name, ch_map, d_b_map, c_b_map, d_d_map, d_c_map, \
+			c_c_map, lo, hi, can_ret_cmplx_for_real, doc)
 
 // Make alias another name for the existing function name.  This macro
 // must be used in the same file where name is defined, after the
