@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,20 +23,47 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_dynamic_ld_h)
 #define octave_dynamic_ld_h 1
 
-#include "oct-obj.h"
+#include <string>
 
-class tree_fvc;
-class string_vector;
+#include "oct-shlib.h"
 
-typedef octave_value_list (*Octave_builtin_fcn)(const octave_value_list&, int);
+class
+octave_dynamic_loader
+{
+protected:
 
-extern int load_octave_oct_file (const string& name);
+  octave_dynamic_loader (void) { }
 
-extern string_vector clear_oct_file_fcn (void *library, void *function);
+public:
 
-extern void init_dynamic_linker (void);
+  virtual ~octave_dynamic_loader (void) { }
 
-extern void symbols_of_dynamic_ld (void);
+  static bool load (const std::string& fcn_name);
+
+  static bool remove (const std::string& fcn_name, octave_shlib& shl);
+
+private:
+
+  // No copying!
+
+  octave_dynamic_loader (const octave_dynamic_loader&);
+
+  octave_dynamic_loader& operator = (const octave_dynamic_loader&);
+
+  static octave_dynamic_loader *instance;
+
+  static bool instance_ok (void);
+
+  bool do_load (const std::string& fcn_name);
+
+  bool do_remove (const std::string& fcn_name, octave_shlib& shl);
+
+  static bool doing_load;
+
+protected:
+
+  static std::string mangle_name (const std::string& name);
+};
 
 #endif
 
