@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,7 +23,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_error_h)
 #define octave_error_h 1
 
-class ostrstream;
+#include <strstream>
 
 #define panic_impossible() \
   panic ("impossible state reached in file `%s' at line %d", \
@@ -39,15 +39,16 @@ extern void panic (const char *fmt, ...) GCC_ATTR_NORETURN;
 // Current error state.
 extern int error_state;
 
+// Current warning state.
+extern int warning_state;
+
 // Tell the error handler whether to print messages, or just store
 // them for later.  Used for handling errors in eval() and
 // the `unwind_protect' statement.
-extern int buffer_error_messages;
+extern bool buffer_error_messages;
 
-// The message buffer
-extern ostrstream *error_message_buffer;
-
-extern void symbols_of_error (void);
+// TRUE means error messages are turned off.
+extern bool discard_error_messages;
 
 #endif
 
