@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -24,16 +24,14 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <csignal>
 #include <cstdlib>
 #include <cstring>
 
+#include <iostream>
+#include <fstream>
+#include <strstream>
 #include <string>
 
-#include <iostream.h>
-#include <fstream.h>
-#include <strstream.h>
-
 #ifdef HAVE_UNISTD_H
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -41,6 +39,9 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <unistd.h>
 #endif
 
+#include "cmd-edit.h"
+#include "file-ops.h"
+#include "oct-env.h"
 #include "str-vec.h"
 
 #include <defaults.h>
@@ -52,31 +53,42 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "help.h"
 #include "input.h"
 #include "oct-obj.h"
+#include "ov-usr-fcn.h"
 #include "pager.h"
+#include "parse.h"
 #include "pathsearch.h"
-#include "pt-const.h"
-#include "pt-exp.h"
-#include "pt-pr-code.h"
+#include "procstream.h"
 #include "sighandlers.h"
 #include "symtab.h"
 #include "syswait.h"
 #include "toplev.h"
-#include "unwind-prot.h"
 #include "utils.h"
 #include "variables.h"
+#include "version.h"
 
 // Name of the info file specified on command line.
 // (--info-file file)
-string Vinfo_file;
+std::string Vinfo_file;
 
 // Name of the info reader we'd like to use.
 // (--info-program program)
-string Vinfo_prog;
+std::string Vinfo_prog;
+
+// Name of the makeinfo program to run.
+static std::string Vmakeinfo_prog = "makeinfo";
 
 // If TRUE, don't print additional help message in help and usage
 // functions.
 static bool Vsuppress_verbose_help_message;
 
+// XXX FIXME XXX -- maybe this should use string instead of char*.
+
+struct help_list
+{
+  const char *name;
+  const char *help;
+};
+
 static help_list operators[] =
 {
   { "!",
@@ -287,12 +299,12 @@ static help_list keywords[] =
 
 // Return a copy of the operator or keyword names.
 
-string_vector
-names (help_list *lst, int& count)
+static string_vector
+names (help_list *lst)
 {
   string_vector retval;
 
-  count = 0;
+  int count = 0;
   help_list *ptr = lst;
   while (ptr->name)
     {
@@ -315,143 +327,102 @@ names (help_list *lst, int& count)
   return retval;
 }
 
-help_list *
+static help_list *
 operator_help (void)
 {
   return operators;
 }
 
-help_list *
+static help_list *
 keyword_help (void)
 {
   return keywords;
 }
 
-static void
-additional_help_message (ostream& os)
+// It's not likely that this does the right thing now.  XXX FIXME XXX
+
+string_vector
+make_name_list (void)
+{
+  string_vector key = names (keyword_help ());
+  int key_len = key.length ();
+
+  string_vector glb = global_sym_tab->name_list ();
+  int glb_len = glb.length ();
+
+  string_vector top = top_level_sym_tab->name_list ();
+  int top_len = top.length ();
+
+  string_vector lcl;
+  if (top_level_sym_tab != curr_sym_tab)
+    lcl = curr_sym_tab->name_list ();
+  int lcl_len = lcl.length ();
+
+  string_vector ffl = octave_fcn_file_name_cache::list_no_suffix ();
+  int ffl_len = ffl.length ();
+
+  int total_len = key_len + glb_len + top_len + lcl_len + ffl_len;
+
+  string_vector list (total_len);
+
+  // Put all the symbols in one big list.
+
+  int j = 0;
+  int i = 0;
+  for (i = 0; i < key_len; i++)
+    list[j++] = key[i];
+
+  for (i = 0; i < glb_len; i++)
+    list[j++] = glb[i];
+
+  for (i = 0; i < top_len; i++)
+    list[j++] = top[i];
+
+  for (i = 0; i < lcl_len; i++)
+    list[j++] = lcl[i];
+
+  for (i = 0; i < ffl_len; i++)
+    list[j++] = ffl[i];
+
+  return list;
+}
+
+void
+additional_help_message (std::ostream& os)
 {
   if (! Vsuppress_verbose_help_message)
     os << "\n\
-Additional help for builtin functions, operators, and variables\n\
+Additional help for built-in functions, operators, and variables\n\
 is available in the on-line version of the manual.  Use the command\n\
-`help -i <topic>' to search the manual index.\n";
-
-  if (! Vsuppress_verbose_help_message)
-    os << "\n\
+`help -i <topic>' to search the manual index.\n\
+\n\
 Help and information about Octave is also available on the WWW\n\
 at http://www.che.wisc.edu/octave/octave.html and via the\n\
 help-octave@bevo.che.wisc.edu mailing list.\n";
 }
 
-void
-print_usage (const string& nm, int just_usage)
-{
-  symbol_record *sym_rec = global_sym_tab->lookup (nm, 0, 0);
-  if (sym_rec)
-    {
-      string h = sym_rec->help ();
-
-      if (h.length () > 0)
-	{
-	  octave_stdout << "\n*** " << nm << ":\n\n"
-	    << h << "\n";
-
-	  if (! just_usage)
-	    additional_help_message (octave_stdout);
-	}
-    }
-  else
-    warning ("no usage message found for `%s'", nm.c_str ());
-}
+// XXX FIXME XXX -- this needs a major overhaul to cope with new
+// symbol table stuff.
 
 static void
-display_names_from_help_list (ostream& os, help_list *list,
+display_names_from_help_list (std::ostream& os, help_list *list,
 			      const char *desc)
 {
-  int count = 0;
-  string_vector symbols = names (list, count);
+  string_vector symbols = names (list);
+
   if (! symbols.empty ())
     {
       os << "\n*** " << desc << ":\n\n";
+
+      symbols.qsort ();
+
       symbols.list_in_columns (os);
     }
 }
 
-static string
-print_symbol_type (ostream& os, symbol_record *sym_rec,
-		   const string& name, int print)
-{
-  string retval;
-
-  if (sym_rec->is_user_function ())
-    {
-      tree_fvc *defn = sym_rec->def ();
-
-      string fn = defn->fcn_file_name ();
-
-      if (! fn.empty ())
-	{
-	  string ff = fcn_file_in_path (fn);
-
-	  ff = ff.length () > 0 ? ff : fn;
-
-	  if (print)
-	    os << name
-	       << " is the function defined from: "
-	       << ff << "\n";
-	  else
-	    retval = ff;
-	}
-      else
-	{
-	  if (print)
-	    os << name << " is a user-defined function\n";
-	  else
-	    retval = "user-defined function";
-	}
-    }
-  else if (sym_rec->is_text_function ())
-    {
-      if (print)
-	os << name << " is a builtin text-function\n";
-      else
-	retval = "builtin text-function";
-    }
-  else if (sym_rec->is_builtin_function ())
-    {
-      if (print)
-	os << name << " is a builtin function\n";
-      else
-	retval = "builtin function";
-    }
-  else if (sym_rec->is_user_variable ())
-    {
-      if (print)
-	os << name << " is a user-defined variable\n";
-      else
-	retval = "user-defined variable";
-    }
-  else if (sym_rec->is_builtin_variable ())
-    {
-      if (print)
-	os << name << " is a builtin variable\n";
-      else
-	retval = "builtin variable";
-    }
-  else
-    {
-      if (print)
-	os << "which: `" << name << "' has unknown type\n";
-      else
-	retval = "unknown type";
-    }
-
-  return retval;
-}
-
 static void
-display_symtab_names (ostream& os, const string_vector& names,
-		      int /* count */, const string& desc)
+display_symtab_names (std::ostream& os, const string_vector& names,
+		      const std::string& desc)
 {
   if (! names.empty ())
     {
@@ -460,6 +431,18 @@ display_symtab_names (ostream& os, const string_vector& names,
     }
 }
 
+#ifdef LIST_SYMBOLS
+#undef LIST_SYMBOLS
+#endif
+#define LIST_SYMBOLS(type, msg) \
+  do \
+    { \
+      string_vector names \
+	= global_sym_tab->name_list (string_vector (), true, type); \
+      display_symtab_names (octave_stdout, names, msg); \
+    } \
+  while (0)
+
 static void
 simple_help (void)
 {
@@ -473,28 +456,18 @@ simple_help (void)
   display_names_from_help_list (octave_stdout, keyword_help (),
 				"reserved words");
 
-#ifdef LIST_SYMBOLS
-#undef LIST_SYMBOLS
-#endif
-#define LIST_SYMBOLS(type, msg) \
-  do \
-    { \
-      int count; \
-      string_vector names = global_sym_tab->list (count, 0, 0, 1, type); \
-      display_symtab_names (octave_stdout, names, count, msg); \
-    } \
-  while (0)
-
   // XXX FIXME XXX -- is this distinction needed?
 
-  LIST_SYMBOLS (symbol_def::TEXT_FUNCTION,
+  LIST_SYMBOLS (symbol_record::BUILTIN_CONSTANT, "built-in constants");
+
+  LIST_SYMBOLS (symbol_record::BUILTIN_VARIABLE, "built-in variables");
+
+  LIST_SYMBOLS (symbol_record::TEXT_FUNCTION,
 		"text functions (these names are also reserved)");
 
-  LIST_SYMBOLS (symbol_def::MAPPER_FUNCTION, "mapper functions");
+  LIST_SYMBOLS (symbol_record::MAPPER_FUNCTION, "mapper functions");
 
-  LIST_SYMBOLS (symbol_def::BUILTIN_FUNCTION, "general functions");
-
-  LIST_SYMBOLS (symbol_def::BUILTIN_VARIABLE, "builtin variables");
+  LIST_SYMBOLS (symbol_record::BUILTIN_FUNCTION, "general functions");
 
   // Also need to list variables and currently compiled functions from
   // the symbol table, if there are any.
@@ -511,9 +484,12 @@ simple_help (void)
 
       if (! names.empty ())
 	{
-	  octave_stdout << "\n*** function files in "
-			<< make_absolute (dirs[i], Vcurrent_directory)
-			<< ":\n\n";
+	  std::string dir
+	    = octave_env::make_absolute (dirs[i], octave_env::getcwd ());
+
+	  octave_stdout << "\n*** function files in " << dir << ":\n\n";
+
+	  names.qsort ();
 
 	  names.list_in_columns (octave_stdout);
 	}
@@ -521,7 +497,7 @@ simple_help (void)
 }
 
 static int
-try_info (const string& nm)
+try_info (const std::string& nm)
 {
   int status = 0;
 
@@ -530,11 +506,11 @@ try_info (const string& nm)
   delete [] cmd_str;
   cmd_str = 0;
 
-  ostrstream cmd_buf;
+  std::ostrstream cmd_buf;
 
   cmd_buf << Vinfo_prog << " --file " << Vinfo_file;
 
-  string directory_name = Vinfo_file;
+  std::string directory_name = Vinfo_file;
   size_t pos = directory_name.rfind ('/');
 
   if (pos != NPOS)
@@ -546,7 +522,7 @@ try_info (const string& nm)
   if (nm.length () > 0)
     cmd_buf << " --index-search " << nm;
 
-  cmd_buf << ends;
+  cmd_buf << std::ends;
 
   cmd_str = cmd_buf.str ();
 
@@ -569,7 +545,7 @@ static void
 help_from_info (const string_vector& argv, int idx, int argc)
 {
   if (idx == argc)
-    try_info (string ());
+    try_info (std::string ());
   else
     {
       for (int i = idx; i < argc; i++)
@@ -586,8 +562,7 @@ help_from_info (const string_vector& argv, int idx, int argc)
 		}
 	      else
 		{
-		  message ("help",
-			   "sorry, `%s' is not indexed in the manual",
+		  message ("help", "sorry, `%s' is not indexed in the manual",
 			   argv[i].c_str ());
 		}
 	    }
@@ -595,11 +570,112 @@ help_from_info (const string_vector& argv, int idx, int argc)
     }
 }
 
-int
-help_from_list (ostream& os, const help_list *list,
-		const string& nm, int usage)
+static bool
+looks_like_texinfo (const std::string& msg, size_t& p1)
 {
-  char *name;
+  p1 = msg.find ('\n');
+
+  std::string t = msg.substr (0, p1);
+
+  if (p1 == NPOS)
+    p1 = 0;
+
+  size_t p2 = t.find ("-*- texinfo -*-");
+
+  return (p2 != NPOS);
+}
+
+void
+display_help_text (std::ostream& os, const std::string& msg)
+{
+  // Look for "-*- texinfo -*-" in first line of help message.  If it
+  // is present, use makeinfo to format the rest of the message before
+  // sending it to the output stream.  Otherwise, just print the
+  // message.
+
+  size_t pos;
+
+  if (looks_like_texinfo (msg, pos))
+    {
+      std::string tmp_file_name = file_ops::tempnam ("", "");
+
+      int cols = command_editor::terminal_cols ();
+
+      if (cols > 16)
+	cols--;
+
+      if (cols > 64)
+	cols -= 7;
+
+      if (cols > 80)
+	cols = 72;
+
+      std::ostrstream buf;
+      buf << "sed -e 's/^[#%]+ *//' -e 's/^ *@/@/' | "
+	  << Vmakeinfo_prog
+	  << " -D \"VERSION " << OCTAVE_VERSION << "\""
+	  << " -D \"OCTAVEHOME " << OCTAVE_PREFIX << "\""
+	  << " -D \"TARGETHOSTTYPE " << OCTAVE_CANONICAL_HOST_TYPE << "\""
+	  << " --fill-column " << cols
+	  << " --no-warn"
+	  << " --no-validate"
+	  << " --no-headers"
+	  << " --force"
+	  << " --output " << tmp_file_name
+	  << " > /dev/null 2>&1"
+	  << std::ends;
+
+      char *cmd = buf.str ();
+
+      oprocstream filter (cmd);
+
+      delete [] cmd;
+
+      if (filter && filter.is_open ())
+	{
+	  filter << "@macro seealso {args}\n"
+		 << "\n"
+		 << "@noindent\n"
+		 << "See also: \\args\\.\n"
+                 << "@end macro\n";
+
+	  filter << msg.substr (pos+1) << std::endl;
+
+	  int status = filter.close ();
+
+	  std::ifstream tmp_file (tmp_file_name.c_str ());
+
+	  if (WIFEXITED (status) && WEXITSTATUS (status) == 0)
+	    {
+	      int c;
+	      while ((c = tmp_file.get ()) != EOF)
+		os << (char) c;
+
+	      tmp_file.close ();
+	    }
+	  else
+	    {
+	      warning ("help: Texinfo formatting filter exited abnormally");
+	      warning ("help: raw Texinfo source of help text follows...");
+
+	      os << "\n" << msg;
+	    }
+
+	  file_ops::unlink (tmp_file_name);
+	}
+      else
+	os << msg;
+    }
+  else
+    os << msg;
+}
+
+static bool
+help_from_list (std::ostream& os, const help_list *list,
+		const std::string& nm, int usage)
+{
+  const char *name;
+
   while ((name = list->name) != 0)
     {
       if (strcmp (name, nm.c_str ()) == 0)
@@ -611,13 +687,60 @@ help_from_list (ostream& os, const help_list *list,
 	      os << "\n*** " << nm << ":\n\n";
 	    }
 
-	  os << list->help << "\n";
+	  display_help_text (os, list->help);
 
-	  return 1;
+	  os << "\n";
+
+	  return true;
 	}
       list++;
     }
-  return 0;
+
+  return false;
+}
+
+static bool
+help_from_symbol_table (std::ostream& os, const std::string& nm)
+{
+  bool retval = false;
+
+  symbol_record *sym_rec = lookup_by_name (nm, 0);
+
+  if (sym_rec && sym_rec->is_defined ())
+    {
+      std::string h = sym_rec->help ();
+
+      if (h.length () > 0)
+	{
+	  sym_rec->which (os);
+	  os << "\n";
+	  display_help_text (os, h);
+	  os << "\n";
+	  retval = true;
+	}
+    }
+
+  return retval;
+}
+
+static bool
+help_from_file (std::ostream& os, const std::string& nm)
+{
+  bool retval = false;
+
+  std::string path = fcn_file_in_path (nm);
+
+  std::string h = get_help_from_file (path);
+
+  if (! h.empty ())
+    {
+      os << nm << " is the file: " << path << "\n\n";
+      display_help_text (os, h);
+      os << "\n";
+      retval = true;
+    }
+
+  return retval;
 }
 
 static void
@@ -634,31 +757,11 @@ builtin_help (int argc, const string_vector& argv)
       if (help_from_list (octave_stdout, kw_help_list, argv[i], 0))
 	continue;
 
-      symbol_record *sym_rec = lookup_by_name (argv[i], 0);
+      if (help_from_symbol_table (octave_stdout, argv[i]))
+	continue;
 
-      if (sym_rec && sym_rec->is_defined ())
-	{
-	  string h = sym_rec->help ();
-
-	  if (h.length () > 0)
-	    {
-	      print_symbol_type (octave_stdout, sym_rec, argv[i], 1);
-	      octave_stdout << "\n" << h << "\n";
-	      continue;
-	    }
-	}
-
-      string path = fcn_file_in_path (argv[i]);
-
-      string h = get_help_from_file (path);
-
-      if (! h.empty ())
-	{
-	  octave_stdout << argv[i] << " is the file: "
-	    << path << "\n\n" << h << "\n";
-
-	  continue;
-	}
+      if (help_from_file (octave_stdout, argv[i]))
+	continue;
 
       octave_stdout << "\nhelp: sorry, `" << argv[i]
 		    << "' is not documented\n"; 
@@ -668,9 +771,23 @@ builtin_help (int argc, const string_vector& argv)
 }
 
 DEFUN_TEXT (help, args, ,
-  "help [-i] [topic ...]\n\
+  "-*- texinfo -*-\n\
+@deffn {Command} help\n\
+Octave's @code{help} command can be used to print brief usage-style\n\
+messages, or to display information directly from an on-line version of\n\
+the printed manual, using the GNU Info browser.  If invoked without any\n\
+arguments, @code{help} prints a list of all the available operators,\n\
+functions, and built-in variables.  If the first argument is @code{-i},\n\
+the @code{help} command searches the index of the on-line version of\n\
+this manual for the given topics.\n\
 \n\
-print cryptic yet witty messages")
+For example, the command @kbd{help help} prints a short message\n\
+describing the @code{help} command, and @kbd{help -i help} starts the\n\
+GNU Info browser at this node in the on-line version of the manual.\n\
+\n\
+Once the GNU Info browser is running, help for using it is available\n\
+using the command @kbd{C-h}.\n\
+@end deffn")
 {
   octave_value_list retval;
 
@@ -682,310 +799,221 @@ print cryptic yet witty messages")
     return retval;
 
   if (argc == 1)
-    {
-      simple_help ();
-    }
+    simple_help ();
   else
     {
-      if (argv[1].length () > 0 && argv[1] == "-i")
-	{
-	  help_from_info (argv, 2, argc);
-	}
+      if (argv[1] == "-i")
+	help_from_info (argv, 2, argc);
       else
-	{
-	  builtin_help (argc, argv);
-	}
+	builtin_help (argc, argv);
     }
 
   return retval;
 }
 
-DEFUN_TEXT (type, args, nargout,
-  "type NAME ...]\n\
-\n\
-display the definition of each NAME that refers to a function")
+static void
+do_type (std::ostream& os, const std::string& name, bool pr_type_info,
+	 bool quiet, bool pr_orig_txt)
 {
-  octave_value_list retval;
+  symbol_record *sym_rec = lookup_by_name (name, 0);
 
-  begin_unwind_frame ("Ftype");
+  if (sym_rec && sym_rec->is_defined ())
+    sym_rec->type (os, pr_type_info, quiet, pr_orig_txt);
+  else
+    {
+      std::string ff = fcn_file_in_path (name);
+
+      if (! ff.empty ())
+	{
+	  std::ifstream fs (ff.c_str (), std::ios::in);
+
+	  if (fs)
+	    {
+	      if (pr_type_info && ! quiet)
+		os << name << " is the script file: " << ff << "\n\n";
+
+	      char ch;
+
+	      while (fs.get (ch))
+		os << ch;
+	    }
+	  else
+	    os << "unable to open `" << ff << "' for reading!\n";
+	}
+      else
+	error ("type: `%s' undefined", name.c_str ());
+    }
+}
+
+DEFUN_TEXT (type, args, nargout,
+  "-*- texinfo -*-\n\
+\n\
+@deffn {Command} type options name @dots{}\n\
+Display the definition of each @var{name} that refers to a function.\n\
+\n\
+Normally also displays if each @var{name} is user-defined or builtin;\n\
+the @code{-q} option suppresses this behaviour.\n\
+\n\
+Currently, Octave can only display functions that can be compiled\n\
+cleanly, because it uses its internal representation of the function to\n\
+recreate the program text.\n\
+\n\
+Comments are not displayed because Octave's parser currently discards\n\
+them as it converts the text of a function file to its internal\n\
+representation.  This problem may be fixed in a future release.\n\
+@end deffn")
+{
+  octave_value retval;
 
   int argc = args.length () + 1;
 
   string_vector argv = args.make_argv ("type");
 
-  if (error_state)
-    return retval;
-
-  if (argc > 1)
+  if (! error_state)
     {
-      // XXX FIXME XXX -- we should really use getopt ()
-
-      bool quiet = false;
-      bool pr_orig_txt = true;
-
-      int idx;
-
-      for (idx = 1; idx < argc; idx++)
+      if (argc > 1)
 	{
-	  if (argv[idx] == "-q" || argv[idx] == "-quiet")
-	    quiet = true;
-	  else if (argv[idx] == "-t" || argv[idx] == "-transformed")
-	    pr_orig_txt = false;
-	  else
-	    break;
-	}
+	  // XXX FIXME XXX -- we should really use getopt ()
 
-      if (idx == argc)
-	{
-	  print_usage ("type");
-	  return retval;
-	}
+	  bool quiet = false;
+	  bool pr_orig_txt = true;
 
-      ostrstream output_buf;
+	  int idx;
 
-      for (int i = idx; i < argc; i++)
-	{
-	  string id = argv[i];
-	  string elts;
-
-	  if (id[id.length () - 1] != '.')
+	  for (idx = 1; idx < argc; idx++)
 	    {
-	      size_t pos = id.find ('.');
-
-	      if (pos != NPOS)
-		{
-		  elts = id.substr (pos+1);
-		  id = id.substr (0, pos);
-		}
+	      if (argv[idx] == "-q" || argv[idx] == "-quiet")
+		quiet = true;
+	      else if (argv[idx] == "-t" || argv[idx] == "-transformed")
+		pr_orig_txt = false;
+	      else
+		break;
 	    }
 
-	  symbol_record *sym_rec = lookup_by_name (id, 0);
-
-	  if (sym_rec && sym_rec->is_defined ())
+	  if (idx < argc)
 	    {
-	      if (sym_rec->is_user_function ())
+	      std::ostrstream output_buf;
+
+	      for (int i = idx; i < argc; i++)
 		{
-		  tree_fvc *defn = sym_rec->def ();
+		  std::string id = argv[i];
 
-		  string fn = defn->fcn_file_name ();
-		  string ff = fcn_file_in_path (fn);
-
-		  if (pr_orig_txt && ! ff.empty ())
-		    {
-		      ifstream fs (ff.c_str (), ios::in);
-
-		      if (fs)
-			{
-			  if (nargout == 0 && ! quiet)
-			    output_buf << argv[i]
-				       << " is the function defined from: "
-				       << ff << "\n\n";
-
-			  char ch;
-
-			  while (fs.get (ch))
-			    output_buf << ch;
-			}
-		      else
-			output_buf << "unable to open `" << ff
-				   << "' for reading!\n";
-		    }
+		  if (nargout == 0)
+		    do_type (octave_stdout, id, true, quiet, pr_orig_txt);
 		  else
-		    {
-		      if (nargout == 0 && ! quiet)
-			output_buf << argv[i]
-				   << " is a user-defined function:\n\n";
+		    do_type (output_buf, id, false, quiet, pr_orig_txt);
 
-		      tree_print_code tpc (output_buf, "", pr_orig_txt);
-
-		      defn->accept (tpc);
-		    }
+		  if (error_state)
+		    goto abort;
 		}
 
-	      // XXX FIXME XXX -- this code should be shared with
-	      // Fwhich.
-
-	      else if (sym_rec->is_text_function ())
-		output_buf << argv[i] << " is a builtin text-function\n";
-	      else if (sym_rec->is_builtin_function ())
-		output_buf << argv[i] << " is a builtin function\n";
-	      else if (sym_rec->is_user_variable ()
-		       || sym_rec->is_builtin_variable ())
+	      if (nargout != 0)
 		{
-		  tree_fvc *defn = sym_rec->def ();
+		  output_buf << std::ends;
 
-		  assert (defn && defn->is_constant ());
+		  char *s = output_buf.str ();
 
-		  tree_constant *tmp = (tree_constant *) defn;
+		  retval = s;
 
-		  int var_ok = 1;
-		  if (tmp && tmp->is_map ())
-		    {
-		      if (! elts.empty ())
-			{
-			  octave_value ult =
-			    tmp->lookup_map_element (elts, 0, 1);
-
-			  if (! ult.is_defined ())
-			    var_ok = 0;			    
-			}
-		    }
-
-		  if (nargout == 0 && ! quiet)
-		    {
-		      if (var_ok)
-			{
-			  output_buf << argv[i];
-			  if (sym_rec->is_user_variable ())
-			    output_buf << " is a user-defined variable\n";
-			  else
-			    output_buf << " is a built-in variable\n";
-			}
-		      else
-			{
-			  if (! elts.empty ())
-			    output_buf << "type: structure `" << id
-			      << "' has no member `" << elts << "'\n";
-			  else
-			    output_buf << "type: `" << id
-			      << "' has unknown type!\n";
-			}
-		    }
-		  if (! tmp->is_map ())
-		    {
-		      tree_print_code tpc (output_buf, "", pr_orig_txt);
-
-		      tmp->accept (tpc);
-
-		      if (nargout == 0)
-			output_buf << "\n";
-		    }
+		  delete [] s;
 		}
-	      else
-		output_buf << "type: `" << argv[i] << "' has unknown type!\n";
 	    }
 	  else
-	    {
-	      string ff = fcn_file_in_path (argv[i]);
-
-	      if (pr_orig_txt && ! ff.empty ())
-		{
-		  ifstream fs (ff.c_str (), ios::in);
-
-		  if (fs)
-		    {
-		      if (nargout == 0 && ! quiet)
-			output_buf << argv[i] << " is the script file: "
-				   << ff << "\n\n";
-
-		      char ch;
-
-		      while (fs.get (ch))
-			output_buf << ch;
-		    }
-		  else
-		    output_buf << "unable to open `" << ff
-			       << "' for reading!\n";
-		}
-	      else
-		output_buf << "type: `" << argv[i] << "' undefined\n";
-	    }	    
+	    print_usage ("type");
 	}
-
-      output_buf << ends;
-
-      char *s = output_buf.str ();
-
-      if (nargout == 0)
-	octave_stdout << s;
       else
-	retval = s;
-
-      delete [] s;
+	print_usage ("type");
     }
-  else
-    print_usage ("type");
+
+ abort:
 
   return retval;
 }
 
+static std::string
+do_which (const std::string& name)
+{
+  std::string retval;
+
+  symbol_record *sym_rec = lookup_by_name (name, 0);
+
+  if (sym_rec && sym_rec->is_defined ())
+    retval = sym_rec->which ();
+  else
+    {
+      std::string path = fcn_file_in_path (name);
+
+      if (! path.empty ())
+	retval = path;
+      else
+	retval = "undefined";
+    }
+
+  return retval;
+}
+
+static void
+do_which (std::ostream& os, const std::string& name)
+{
+  symbol_record *sym_rec = lookup_by_name (name, 0);
+
+  if (sym_rec && sym_rec->is_defined ())
+    sym_rec->which (os);
+  else
+    {
+      std::string path = fcn_file_in_path (name);
+
+      if (! path.empty ())
+	os << "which: `" << name << "' is the script file\n"
+	   << path << "\n";
+      else
+	os << "which: `" << name << "' is undefined\n";
+    }
+}
+
 DEFUN_TEXT (which, args, nargout,
-  "which NAME ...\n\
-\n\
-display the type of each NAME.  If NAME is defined from an function\n\
-file, print the full name of the file.")
+  "-*- texinfo -*-\n\
+@deffn {Command} which name @dots{}\n\
+Display the type of each @var{name}.  If @var{name} is defined from a\n\
+function file, the full name of the file is also displayed.\n\
+@end deffn")
 {
   octave_value_list retval;
 
-  int argc = args.length () + 1;
-
   string_vector argv = args.make_argv ("which");
 
-  if (error_state)
-    return retval;
-
-  if (argc > 1)
+  if (! error_state)
     {
+      int argc = argv.length ();
+
       if (nargout > 0)
 	retval.resize (argc-1, Matrix ());
 
-      for (int i = 1; i < argc; i++)
+      if (argc > 1)
 	{
-	  symbol_record *sym_rec = lookup_by_name (argv[i], 0);
-
-	  if (sym_rec && sym_rec->is_defined ())
+	  for (int i = 1; i < argc; i++)
 	    {
-	      int print = (nargout == 0);
-	      string tmp = print_symbol_type (octave_stdout, sym_rec,
-					      argv[i], print);
-	      if (! print)
-		retval(i) = tmp;
-	    }
-	  else
-	    {
-	      string path = fcn_file_in_path (argv[i]);
+	      std::string id = argv[i];
 
-	      if (! path.empty ())
-		{
-		  if (nargout == 0)
-		    octave_stdout << "which: `" << argv[i]
-				  << "' is the script file: "
-				  << path << "\n";
-		  else
-		    retval(i) = path;
-		}
+	      if (nargout == 0)
+		do_which (octave_stdout, id);
 	      else
-		{
-		  if (nargout == 0)
-		    octave_stdout << "which: `" << argv[i]
-				  << "' is undefined\n";
-		  else
-		    retval(i) = "undefined";
-		}
+		retval(i-1) = do_which (id);
 	    }
 	}
+      else
+	print_usage (argv[0]);
     }
-  else
-    print_usage ("which");
 
   return retval;
 }
 
-static int
-suppress_verbose_help_message (void)
-{
-  Vsuppress_verbose_help_message
-    = check_preference ("suppress_verbose_help_message");
-
-  return 0;
-}
-
 static int
 info_file (void)
 {
   int status = 0;
 
-  string s = builtin_string_variable ("INFO_FILE");
+  std::string s = builtin_string_variable ("INFO_FILE");
 
   if (s.empty ())
     {
@@ -1003,7 +1031,7 @@ info_prog (void)
 {
   int status = 0;
 
-  string s = builtin_string_variable ("INFO_PROGRAM");
+  std::string s = builtin_string_variable ("INFO_PROGRAM");
 
   if (s.empty ())
     {
@@ -1016,18 +1044,74 @@ info_prog (void)
   return status;
 }
 
+static int
+makeinfo_prog (void)
+{
+  int status = 0;
+
+  std::string s = builtin_string_variable ("MAKEINFO_PROGRAM");
+
+  if (s.empty ())
+    {
+      gripe_invalid_value_specified ("MAKEINFO_PROGRAM");
+      status = -1;
+    }
+  else
+    Vmakeinfo_prog = s;
+
+  return status;
+}
+
+static int
+suppress_verbose_help_message (void)
+{
+  Vsuppress_verbose_help_message
+    = check_preference ("suppress_verbose_help_message");
+
+  return 0;
+}
+
 void
 symbols_of_help (void)
 {
-  DEFVAR (INFO_FILE, Vinfo_file, 0, info_file,
-    "name of the Octave info file");
+  DEFVAR (INFO_FILE, Vinfo_file, info_file,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} INFO_FILE\n\
+The variable @code{INFO_FILE} names the location of the Octave info file.\n\
+The default value is @code{\"@var{octave-home}/info/octave.info\"}, in\n\
+which @var{octave-home} is the directory where all of Octave is installed.\n\
+@end defvr");
 
-  DEFVAR (INFO_PROGRAM, Vinfo_prog, 0, info_prog,
-    "name of the Octave info reader");
+  DEFVAR (INFO_PROGRAM, Vinfo_prog, info_prog,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} INFO_PROGRAM\n\
+The variable @code{INFO_PROGRAM} names the info program to run.  Its\n\
+default initial value is\n\
+@code{\"@var{octave-home}/libexec/octave/@var{version}/exec/@var{arch}/info\"}\n\
+in which @var{octave-home} is the directory where all of Octave is\n\
+installed, @var{version} is the Octave version number, and @var{arch}\n\
+is the system type (for example, @code{i686-pc-linux-gnu}).  The\n\
+default initial value may be overridden by the environment variable\n\
+@code{OCTAVE_INFO_PROGRAM}, or the command line argument\n\
+@code{--info-program NAME}, or by setting the value of\n\
+@code{INFO_PROGRAM} in a startup script\n\
+@end defvr");
 
-  DEFVAR (suppress_verbose_help_message, 0.0, 0, suppress_verbose_help_message,
-    "suppress printing of message pointing to additional help in the\n\
-help and usage functions");
+  DEFVAR (MAKEINFO_PROGRAM, Vmakeinfo_prog, makeinfo_prog,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} MAKEINFO_PROGRAM\n\
+The variable @code{MAKEINFO_PROGRAM} names the makeinfo program that\n\
+Octave runs to format help text that contains Texinfo markup commands.\n\
+Its default initial value is @code{\"makeinfo\"}.\n\
+@end defvr");
+
+  DEFVAR (suppress_verbose_help_message, 0.0, suppress_verbose_help_message,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} suppress_verbose_help_message\n\
+If the value of @code{suppress_verbose_help_message} is nonzero, Octave\n\
+will not add additional help information to the end of the output from\n\
+the @code{help} command and usage messages for built-in commands.\n\
+@end defvr");
 }
 
 /*
