@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,24 +23,21 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_load_save_h)
 #define octave_load_save_h 1
 
-class ostream;
-
-class octave_value;
+#include <iostream>
 
 #include <string>
 
-extern int save_ascii_data (ostream& os, const octave_value& t,
-			    const string& name = string (),
-			    int strip_nan_and_inf = 0,
-			    int mark_as_global = 0, int precision = 0);
+class octave_value;
 
-extern int save_three_d (ostream& os, const octave_value& t,
-			 int parametric = 0);
+extern bool
+save_ascii_data_for_plotting (std::ostream& os, const octave_value& t,
+			      const std::string& name = std::string ());
+
+extern bool save_three_d (std::ostream& os, const octave_value& t,
+			  bool parametric = false);
 
 extern void save_user_variables (void);
 
-extern void symbols_of_load_save (void);
-
 #endif
 
 /*
