@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -18,6 +18,10 @@ You should have received a copy of the GNU General Public License
 along with Octave; see the file COPYING.  If not, write to the Free
 Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
+*/
+
+/*
+
 The functions listed below were adapted from similar functions from
 GNU Bash, the Bourne Again SHell, copyright (C) 1987, 1989, 1991 Free
 Software Foundation, Inc.
@@ -31,13 +35,12 @@ Software Foundation, Inc.
 #include <config.h>
 #endif
 
-#include <csignal>
 #include <cstdlib>
 #include <cstring>
 
 #include <string>
 
-#include <fstream.h>
+#include <fstream>
 
 #ifdef HAVE_UNISTD_H
 #ifdef HAVE_SYS_TYPES_H
@@ -48,15 +51,19 @@ Software Foundation, Inc.
 
 #include "cmd-hist.h"
 #include "file-ops.h"
+#include "lo-mappers.h"
+#include "oct-env.h"
 #include "str-vec.h"
 
 #include <defaults.h>
 #include "defun.h"
 #include "error.h"
+#include "gripes.h"
 #include "input.h"
 #include "oct-hist.h"
 #include "oct-obj.h"
 #include "pager.h"
+#include "parse.h"
 #include "sighandlers.h"
 #include "sysdep.h"
 #include "toplev.h"
@@ -64,11 +71,17 @@ Software Foundation, Inc.
 #include "utils.h"
 #include "variables.h"
 
-// Nonzero means input is coming from temporary history file.
-int input_from_tmp_history_file = 0;
+// TRUE means input is coming from temporary history file.
+bool input_from_tmp_history_file = false;
 
-// Guess what?
-command_history octave_command_history;
+// Where history is saved.
+static std::string Vhistory_file;
+
+// The number of lines to keep in the history file.
+static int Vhistory_size;
+
+// TRUE if we are saving history.
+bool Vsaving_history = true;
 
 // Get some default values, possibly reading them from the
 // environment.
@@ -77,26 +90,30 @@ int
 default_history_size (void)
 {
   int size = 1024;
-  char *env_size = getenv ("OCTAVE_HISTSIZE");
-  if (env_size)
+
+  std::string env_size = octave_env::getenv ("OCTAVE_HISTSIZE");
+
+  if (! env_size.empty ())
     {
       int val;
-      if (sscanf (env_size, "%d", &val) == 1)
+
+      if (sscanf (env_size.c_str (), "%d", &val) == 1)
 	size = val > 0 ? val : 0;
     }
+
   return size;
 }
 
-string
+std::string
 default_history_file (void)
 {
-  string file;
+  std::string file;
 
-  char *env_file = getenv ("OCTAVE_HISTFILE");
+  std::string env_file = octave_env::getenv ("OCTAVE_HISTFILE");
 
-  if (env_file)
+  if (! env_file.empty ())
     {
-      fstream f (env_file, (ios::in | ios::out));
+      std::fstream f (env_file.c_str (), (std::ios::in | std::ios::out));
 
       if (f)
 	{
@@ -107,9 +124,11 @@ default_history_file (void)
 
   if (file.empty ())
     {
-      if (! Vhome_directory.empty ())
+      std::string home_dir = octave_env::get_home_directory ();
+
+      if (! home_dir.empty ())
 	{
-	  file = Vhome_directory;
+	  file = home_dir;
 	  file.append ("/.octave_hist");
 	}
       else
@@ -133,32 +152,32 @@ do_history (int argc, const string_vector& argv)
   int i;
   for (i = 1; i < argc; i++)
     {
-      string option = argv[i];
+      std::string option = argv[i];
 
       if (option == "-r" || option == "-w" || option == "-a"
 	  || option == "-n")
 	{
 	  if (i < argc - 1)
 	    {
-	      string file = oct_tilde_expand (argv[i+1]);
-	      octave_command_history.set_file (file);
+	      std::string file = file_ops::tilde_expand (argv[i+1]);
+	      command_history::set_file (file);
 	    }
 
 	  if (option == "-a")
 	    // Append `new' lines to file.
-	    octave_command_history.append ();
+	    command_history::append ();
 
 	  else if (option == "-w")
 	    // Write entire history.
-	    octave_command_history.write ();
+	    command_history::write ();
 
 	  else if (option == "-r")
 	    // Read entire file.
-	    octave_command_history.read ();
+	    command_history::read ();
 
 	  else if (option == "-n")
 	    // Read `new' history from file.
-	    octave_command_history.read_range ();
+	    command_history::read_range ();
 
 	  else
 	    panic_impossible ();
@@ -194,7 +213,7 @@ do_history (int argc, const string_vector& argv)
 	limit = -limit;
     }
 
-  string_vector hlist = octave_command_history.list (limit, numbered_output);
+  string_vector hlist = command_history::list (limit, numbered_output);
 
   int len = hlist.length ();
 
@@ -207,7 +226,7 @@ do_history (int argc, const string_vector& argv)
 // caller should free the storage.
 
 static char *
-edit_history_readline (fstream& stream)
+edit_history_readline (std::fstream& stream)
 {
   char c;
   int line_len = 128;
@@ -263,11 +282,11 @@ edit_history_readline (fstream& stream)
 // your heart's content.
 
 static void
-edit_history_repl_hist (const string& command)
+edit_history_repl_hist (const std::string& command)
 {
   if (! command.empty ())
     {
-      string_vector hlist = octave_command_history.list ();
+      string_vector hlist = command_history::list ();
 
       int len = hlist.length ();
 
@@ -275,11 +294,11 @@ edit_history_repl_hist (const string& command)
 	{
 	  int i = len - 1;
 
-	  string histent = octave_command_history.get_entry (i);
+	  std::string histent = command_history::get_entry (i);
 
 	  if (! histent.empty ())
 	    {
-	      string cmd = command;
+	      std::string cmd = command;
 
 	      int cmd_len = cmd.length ();
 
@@ -287,18 +306,18 @@ edit_history_repl_hist (const string& command)
 		cmd.resize (cmd_len - 1);
 
 	      if (! cmd.empty ())
-		octave_command_history.replace_entry (i, cmd);
+		command_history::replace_entry (i, cmd);
 	    }
 	}
     }
 }
 
 static void
-edit_history_add_hist (const string& line)
+edit_history_add_hist (const std::string& line)
 {
   if (! line.empty ())
     {
-      string tmp = line;
+      std::string tmp = line;
 
       int len = tmp.length ();
 	
@@ -306,17 +325,17 @@ edit_history_add_hist (const string& line)
 	tmp.resize (len - 1);
 
       if (! tmp.empty ())
-	octave_command_history.add (tmp);
+	command_history::add (tmp);
     }
 }
 
-static string
+static std::string
 mk_tmp_hist_file (int argc, const string_vector& argv,
-		  int insert_curr, char *warn_for) 
+		  int insert_curr, const char *warn_for) 
 {
-  string retval;
+  std::string retval;
 
-  string_vector hlist = octave_command_history.list ();
+  string_vector hlist = command_history::list ();
 
   int hist_count = hlist.length ();
 
@@ -326,7 +345,7 @@ mk_tmp_hist_file (int argc, const string_vector& argv,
   hist_count -= 2;
 
   if (! insert_curr)
-    octave_command_history.remove (hist_count);
+    command_history::remove (hist_count);
 
   hist_count--;
 
@@ -383,9 +402,9 @@ mk_tmp_hist_file (int argc, const string_vector& argv,
       reverse = 1;
     }
 
-  string name = oct_tempnam ();
+  std::string name = file_ops::tempnam ("", "oct-");
 
-  fstream file (name.c_str (), ios::out);
+  std::fstream file (name.c_str (), std::ios::out);
 
   if (! file)
     {
@@ -413,14 +432,14 @@ mk_tmp_hist_file (int argc, const string_vector& argv,
 static void
 do_edit_history (int argc, const string_vector& argv)
 {
-  string name = mk_tmp_hist_file (argc, argv, 0, "edit_history");
+  std::string name = mk_tmp_hist_file (argc, argv, 0, "edit_history");
 
   if (name.empty ())
     return;
 
   // Call up our favorite editor on the file of commands.
 
-  string cmd = Veditor;
+  std::string cmd = Veditor;
   cmd.append (" ");
   cmd.append (name);
 
@@ -437,7 +456,7 @@ do_edit_history (int argc, const string_vector& argv)
   // Write the commands to the history file since parse_and_execute
   // disables command line history while it executes.
 
-  fstream file (name.c_str (), ios::in);
+  std::fstream file (name.c_str (), std::ios::in);
 
   char *line;
   int first = 1;
@@ -465,15 +484,17 @@ do_edit_history (int argc, const string_vector& argv)
   // Turn on command echo, so the output from this will make better
   // sense.
 
-  begin_unwind_frame ("do_edit_history");
+  unwind_protect::begin_frame ("do_edit_history");
+
   unwind_protect_int (Vecho_executing_commands);
-  unwind_protect_int (input_from_tmp_history_file);
+  unwind_protect_bool (input_from_tmp_history_file);
+
   Vecho_executing_commands = ECHO_CMD_LINE;
-  input_from_tmp_history_file = 1;
+  input_from_tmp_history_file = true;
 
-  parse_and_execute (name, 1);
+  parse_and_execute (name);
 
-  run_unwind_frame ("do_edit_history");
+  unwind_protect::run_frame ("do_edit_history");
 
   // Delete the temporary file.  Should probably be done with an
   // unwind_protect.
@@ -484,7 +505,7 @@ do_edit_history (int argc, const string_vector& argv)
 static void
 do_run_history (int argc, const string_vector& argv)
 {
-  string name = mk_tmp_hist_file (argc, argv, 1, "run_history");
+  std::string name = mk_tmp_hist_file (argc, argv, 1, "run_history");
 
   if (name.empty ())
     return;
@@ -492,15 +513,17 @@ do_run_history (int argc, const string_vector& argv)
   // Turn on command echo so the output from this will make better
   // sense.
 
-  begin_unwind_frame ("do_run_history");
+  unwind_protect::begin_frame ("do_run_history");
+
   unwind_protect_int (Vecho_executing_commands);
-  unwind_protect_int (input_from_tmp_history_file);
+  unwind_protect_bool (input_from_tmp_history_file);
+
   Vecho_executing_commands = ECHO_CMD_LINE;
-  input_from_tmp_history_file = 1;
+  input_from_tmp_history_file = true;
 
-  parse_and_execute (name, 1);
+  parse_and_execute (name);
 
-  run_unwind_frame ("do_run_history");
+  unwind_protect::run_frame ("do_run_history");
 
   // Delete the temporary file.
 
@@ -510,9 +533,40 @@ do_run_history (int argc, const string_vector& argv)
 }
 
 DEFUN_TEXT (edit_history, args, ,
-  "edit_history [first] [last]\n\
+  "-*- texinfo -*-\n\
+@deffn {Command} edit_history options\n\
+If invoked with no arguments, @code{edit_history} allows you to edit the\n\
+history list using the editor named by the variable @code{EDITOR}.  The\n\
+commands to be edited are first copied to a temporary file.  When you\n\
+exit the editor, Octave executes the commands that remain in the file.\n\
+It is often more convenient to use @code{edit_history} to define functions \n\
+rather than attempting to enter them directly on the command line.\n\
+By default, the block of commands is executed as soon as you exit the\n\
+editor.  To avoid executing any commands, simply delete all the lines\n\
+from the buffer before exiting the editor.\n\
 \n\
-edit commands from the history list")
+The @code{edit_history} command takes two optional arguments specifying\n\
+the history numbers of first and last commands to edit.  For example,\n\
+the command\n\
+\n\
+@example\n\
+edit_history 13\n\
+@end example\n\
+\n\
+@noindent\n\
+extracts all the commands from the 13th through the last in the history\n\
+list.  The command\n\
+\n\
+@example\n\
+edit_history 13 169\n\
+@end example\n\
+\n\
+@noindent\n\
+only extracts commands 13 through 169.  Specifying a larger number for\n\
+the first command than the last command reverses the list of commands\n\
+before placing them in the buffer to be edited.  If both arguments are\n\
+omitted, the previous command in the history list is used.\n\
+@end deffn")
 {
   octave_value_list retval;
 
@@ -529,9 +583,33 @@ edit commands from the history list")
 }
 
 DEFUN_TEXT (history, args, ,
-  "history [N] [-w file] [-r file] [-q]\n\
+  "-*- texinfo -*-\n\
+@deffn {Command} history options\n\
+If invoked with no arguments, @code{history} displays a list of commands\n\
+that you have executed.  Valid options are:\n\
 \n\
-display, save, or load command history")
+@table @code\n\
+@item -w @var{file}\n\
+Write the current history to the file @var{file}.  If the name is\n\
+omitted, use the default history file (normally @file{~/.octave_hist}).\n\
+\n\
+@item -r @var{file}\n\
+Read the file @var{file}, replacing the current history list with its\n\
+contents.  If the name is omitted, use the default history file\n\
+(normally @file{~/.octave_hist}).\n\
+\n\
+@item @var{n}\n\
+Only display the most recent @var{n} lines of history.\n\
+\n\
+@item -q\n\
+Don't number the displayed lines of history.  This is useful for cutting\n\
+and pasting commands if you are using the X Window System.\n\
+@end table\n\
+\n\
+For example, to display the five most recent commands that you have\n\
+typed without displaying line numbers, use the command\n\
+@kbd{history -q 5}.\n\
+@end deffn")
 {
   octave_value_list retval;
 
@@ -548,9 +626,11 @@ display, save, or load command history")
 }
 
 DEFUN_TEXT (run_history, args, ,
-  "run_history [first] [last]\n\
-\n\
-run commands from the history list")
+  "-*- texinfo -*-\n\
+@deffn {Command} run_history [first] [last]\n\
+Similar to @code{edit_history}, except that the editor is not invoked,\n\
+and the commands are simply executed as they appear in the history list.\n\
+@end deffn")
 {
   octave_value_list retval;
 
@@ -566,6 +646,86 @@ run commands from the history list")
   return retval;
 }
 
+static int
+history_size (void)
+{
+  double val;
+  if (builtin_real_scalar_variable ("history_size", val)
+      && ! xisnan (val))
+    {
+      int ival = NINT (val);
+      if (ival >= 0 && ival == val)
+	{
+	  Vhistory_size = ival;
+	  command_history::set_size (ival);
+	  return 0;
+	}
+    }
+  gripe_invalid_value_specified ("history_size");
+  return -1;
+}
+
+static int
+history_file (void)
+{
+  int status = 0;
+
+  std::string s = builtin_string_variable ("history_file");
+
+  if (s.empty ())
+    {
+      gripe_invalid_value_specified ("history_file");
+      status = -1;
+    }
+  else
+    {
+      Vhistory_file = s;
+      command_history::set_file (file_ops::tilde_expand (s));
+    }
+
+  return status;
+}
+
+static int
+saving_history (void)
+{
+  Vsaving_history = check_preference ("saving_history");
+
+  command_history::ignore_entries (! Vsaving_history);
+
+  return 0;
+}
+
+void
+symbols_of_oct_hist (void)
+{
+  DEFVAR (history_file, default_history_file (), history_file,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} history_file\n\
+This variable specifies the name of the file used to store command\n\
+history.  The default value is @code{\"~/.octave_hist\"}, but may be\n\
+overridden by the environment variable @code{OCTAVE_HISTFILE}.\n\
+@end defvr");
+
+  double tmp_hist_size = default_history_size ();
+
+  DEFVAR (history_size, tmp_hist_size, history_size,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} history_size\n\
+This variable specifies how many entries to store in the history file.\n\
+The default value is @code{1024}, but may be overridden by the\n\
+environment variable @code{OCTAVE_HISTSIZE}.\n\
+@end defvr");
+
+  DEFVAR (saving_history, 1.0, saving_history,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} saving_history\n\
+If the value of @code{saving_history} is nonzero, command entered\n\
+on the command line are saved in the file specified by the variable\n\
+@code{history_file}.\n\
+@end defvr");
+}
+
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
