@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -30,7 +30,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // Position a stream at OFFSET relative to ORIGIN.
 
 int
-octave_base_iostream::seek (streamoff, ios::seek_dir)
+octave_base_iostream::seek (std::streamoff, std::ios::seekdir)
 {
   invalid_operation ();
   return -1;
@@ -54,20 +54,40 @@ octave_base_iostream::eof (void) const
   return false;
 }
 
-// The name of the file.
-
-string
-octave_base_iostream::name (void)
-{
-  return nm;
-}
-
 void
 octave_base_iostream::invalid_operation (void) const
 {
   ::error ("%s: invalid operation", stream_type ());
 }
 
+// Return non-zero if EOF has been reached on this stream.
+
+bool
+octave_istream::eof (void) const
+{
+  return is && is->eof ();
+}
+
+octave_stream
+octave_istream::create (std::istream *arg, const std::string& nm)
+{
+  return octave_stream (new octave_istream (arg, nm));
+}
+
+// Return non-zero if EOF has been reached on this stream.
+
+bool
+octave_ostream::eof (void) const
+{
+  return os && os->eof ();
+}
+
+octave_stream
+octave_ostream::create (std::ostream *arg, const std::string& nm)
+{
+  return octave_stream (new octave_ostream (arg, nm));
+}
+
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
