@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,27 +23,24 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_octave_iostream_h)
 #define octave_octave_iostream_h 1
 
-#include "oct-stream.h"
+#include <iostream>
 
-class istream;
-class ostream;
+#include "oct-stream.h"
 
 class
 octave_base_iostream : public octave_base_stream
 {
 public:
 
-  octave_base_iostream (const string& n = string (),
-			ios::openmode md = ios::in|ios::out,
+  octave_base_iostream (const std::string& n = std::string (),
+			std::ios::openmode md = std::ios::in|std::ios::out,
 			oct_mach_info::float_format flt_fmt =
 			oct_mach_info::native)
     : octave_base_stream (md, flt_fmt), nm (n) { }
 
-  ~octave_base_iostream (void) { }
-
   // Position a stream at OFFSET relative to ORIGIN.
 
-  int seek (streamoff offset, ios::seek_dir origin);
+  int seek (std::streamoff offset, std::ios::seekdir origin);
 
   // Return current stream position.
 
@@ -55,15 +52,17 @@ public:
 
   // The name of the file.
 
-  string name (void);
+  std::string name (void) const { return nm; }
 
 protected:
 
+  ~octave_base_iostream (void) { }
+
   void invalid_operation (void) const;
 
 private:
 
-  string nm;
+  std::string nm;
 
   virtual const char *stream_type (void) const = 0;
 
@@ -79,23 +78,28 @@ octave_istream : public octave_base_iostream
 {
 public:
 
-  octave_istream (istream *arg = 0, const string& nm = string ())
-    : octave_base_iostream (nm, ios::in, oct_mach_info::native),
+  octave_istream (std::istream *arg = 0, const std::string& nm = std::string ())
+    : octave_base_iostream (nm, std::ios::in, oct_mach_info::native),
       is (arg) { }
 
-  ~octave_istream (void) { }
+  static octave_stream
+  create (std::istream *arg = 0, const std::string& nm = std::string ());
 
   // Return non-zero if EOF has been reached on this stream.
 
   bool eof (void) const;
 
-  istream *input_stream (void) { return is; }
+  std::istream *input_stream (void) { return is; }
 
-  ostream *output_stream (void) { return 0; }
+  std::ostream *output_stream (void) { return 0; }
+
+protected:
+
+  ~octave_istream (void) { }
 
 private:
 
-  istream *is;
+  std::istream *is;
 
   const char *stream_type (void) const { return "octave_istream"; }
 
@@ -111,23 +115,28 @@ octave_ostream : public octave_base_iostream
 {
 public:
 
-  octave_ostream (ostream *arg, const string& nm = string ())
-    : octave_base_iostream (nm, ios::out, oct_mach_info::native),
+  octave_ostream (std::ostream *arg, const std::string& nm = std::string ())
+    : octave_base_iostream (nm, std::ios::out, oct_mach_info::native),
       os (arg) { }
 
+  static octave_stream
+  create (std::ostream *arg, const std::string& nm = std::string ());
+
   // Return non-zero if EOF has been reached on this stream.
 
   bool eof (void) const;
 
+  std::istream *input_stream (void) { return 0; }
+
+  std::ostream *output_stream (void) { return os; }
+
+protected:
+
   ~octave_ostream (void) { }
 
-  istream *input_stream (void) { return 0; }
-
-  ostream *output_stream (void) { return os; }
-
 private:
 
-  ostream *os;
+  std::ostream *os;
 
   const char *stream_type (void) const { return "octave_ostream"; }
 
