@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -25,16 +25,25 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "oct-stdstrm.h"
 
+// XXX FIXME XXX -- why don't these classes use iprocstream and
+// oprocstream, which in turn use the octave_procbuf class?
+
 class
 octave_iprocstream : public octave_istdiostream
 {
 public:
 
-  octave_iprocstream (const string& n,
-		      ios::openmode arg_md = ios::in,
+  octave_iprocstream (const std::string& n,
+		      std::ios::openmode arg_md = std::ios::in,
 		      oct_mach_info::float_format flt_fmt =
 		      oct_mach_info::native);
 
+  static octave_stream
+  create (const std::string& n, std::ios::openmode arg_md = std::ios::in,
+	  oct_mach_info::float_format flt_fmt = oct_mach_info::native);
+
+protected:
+
   ~octave_iprocstream (void);
 
 private:
@@ -51,11 +60,17 @@ octave_oprocstream : public octave_ostdiostream
 {
 public:
 
-  octave_oprocstream (const string& n,
-		      ios::openmode arg_md = ios::out,
+  octave_oprocstream (const std::string& n,
+		      std::ios::openmode arg_md = std::ios::out,
 		      oct_mach_info::float_format flt_fmt =
 		      oct_mach_info::native);
 
+  static octave_stream
+  create (const std::string& n, std::ios::openmode arg_md = std::ios::out,
+	  oct_mach_info::float_format flt_fmt = oct_mach_info::native);
+
+protected:
+
   ~octave_oprocstream (void);
 
 private:
