@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -26,7 +26,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <cerrno>
 
-#include <iostream.h>
+#include <iostream>
 
 #ifdef HAVE_UNISTD_H
 #ifdef HAVE_SYS_TYPES_H
@@ -39,6 +39,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "lo-utils.h"
 #include "oct-procbuf.h"
 #include "syswait.h"
+#include "variables.h"
 
 #include "defun.h"
 #include "gripes.h"
@@ -53,11 +54,6 @@ static int Vkluge_procbuf_delay = 0;
 
 // This class is based on the procbuf class from libg++, written by
 // Per Bothner, Copyright (C) 1993 Free Software Foundation.
-//
-// It should work with the filebuf class from libg++, but it might not
-// work with others since it depends on being able to get at the
-// underlying file descriptor with filebuf::fd(), which is not
-// standard.
 
 static octave_procbuf *octave_procbuf_list = 0;
 
@@ -68,7 +64,7 @@ octave_procbuf::open (const char *command, int mode)
 
   int pipe_fds[2];
 
-  volatile int child_std_end = (mode & ios::in) ? 1 : 0;
+  volatile int child_std_end = (mode & std::ios::in) ? 1 : 0;
 
   volatile int parent_end, child_end;
 
@@ -78,7 +74,7 @@ octave_procbuf::open (const char *command, int mode)
   if (pipe (pipe_fds) < 0)
     return 0;
 
-  if (mode & ios::in)
+  if (mode & std::ios::in)
     {
       parent_end = pipe_fds[0];
       child_end = pipe_fds[1];
@@ -103,7 +99,14 @@ octave_procbuf::open (const char *command, int mode)
 
       while (octave_procbuf_list)
 	{
-	  ::close (octave_procbuf_list->fd ());
+	  FILE *fp = octave_procbuf_list->f;
+
+	  if (fp)
+	    {
+	      ::fclose (fp);
+	      fp = 0;
+	    }
+
 	  octave_procbuf_list = octave_procbuf_list->next;
 	}
 
@@ -123,7 +126,12 @@ octave_procbuf::open (const char *command, int mode)
       return 0;
     }
 
-  attach (parent_end);
+  f = ::fdopen (parent_end, (mode & std::ios::in) ? "r" : "w");
+
+  if (mode & std::ios::out)
+    ::setvbuf (f, 0, _IOLBF, 0);
+
+  open_p = true;
 
   next = octave_procbuf_list;
   octave_procbuf_list = this;
@@ -137,44 +145,50 @@ octave_procbuf::open (const char *command, int mode)
 #endif
 }
 
-int
-octave_procbuf::sys_close (void)
+octave_procbuf *
+octave_procbuf::close (void)
 {
 #if defined (HAVE_SYS_WAIT_H)
 
-  pid_t wait_pid;
-
-  int status = -1;
-
-  for (octave_procbuf **ptr = &octave_procbuf_list;
-       *ptr != 0;
-       ptr = &(*ptr)->next)
+  if (f)
     {
-      if (*ptr == this)
+      pid_t wait_pid;
+
+      int status = -1;
+
+      for (octave_procbuf **ptr = &octave_procbuf_list;
+	   *ptr != 0;
+	   ptr = &(*ptr)->next)
 	{
-	  *ptr = (*ptr)->next;
-	  status = 0;
-	  break;
+	  if (*ptr == this)
+	    {
+	      *ptr = (*ptr)->next;
+	      status = 0;
+	      break;
+	    }
 	}
+
+      if (status == 0 && ::fclose (f) == 0)
+	{
+	  using namespace std;
+
+	  do
+	    {
+	      wait_pid = ::waitpid (proc_pid, &wstatus, 0);
+	    }
+	  while (wait_pid == -1 && errno == EINTR);
+	}
+
+      f = 0;
     }
 
-  if (status < 0 || ::close (fd ()) < 0)
-    return -1;
+  open_p = false;
 
-  do
-    {
-      wait_pid = ::waitpid (proc_pid, &wstatus, 0);
-    }
-  while (wait_pid == -1 && errno == EINTR);
-
-  if (wait_pid == -1)
-    return -1;
-
-  return wstatus;
+  return this;
 
 #else
 
-  return -1;
+  return 0;
 
 #endif
 }
@@ -183,7 +197,7 @@ static int
 kluge_procbuf_delay (void)
 {
   double val;
-  if (builtin_real_scalar_variable ("kluge_procbuf_delay", val)
+  if (builtin_real_scalar_variable ("__kluge_procbuf_delay__", val)
       && ! xisnan (val))
     {
       int ival = NINT (val);
@@ -193,16 +207,20 @@ kluge_procbuf_delay (void)
 	  return 0;
 	}
     }
-  gripe_invalid_value_specified ("kluge_procbuf_delay");
+  gripe_invalid_value_specified ("__kluge_procbuf_delay__");
   return -1;
 }
 
 void
 symbols_of_oct_procbuf (void)
 {
-  DEFVAR (kluge_procbuf_delay, (double) Vkluge_procbuf_delay, 0,
+  DEFVAR (__kluge_procbuf_delay__, static_cast<double> (Vkluge_procbuf_delay),
 	  kluge_procbuf_delay,
-    "number of microseconds to delay in the parent after forking");
+    "-*- texinfo -*-\n\
+@defvr __kluge_procbuf_delay__\n\
+Number of microseconds to delay in the parent after forking.\n\
+@end defvr");
+
 }
 
 /*
