@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,32 +23,76 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_octave_stream_h)
 #define octave_octave_stream_h 1
 
-#include <string>
+class Matrix;
+class string_vector;
+class octave_value;
+class octave_value_list;
 
-#include <iostream.h>
-#include <strstream.h>
+#include <iostream>
+#include <strstream>
+#include <string>
 
 #include "Array.h"
 #include "data-conv.h"
+#include "lo-utils.h"
 #include "mach-info.h"
 
-#include "oct-obj.h"
-#include "str-vec.h"
-
-struct
+class
 scanf_format_elt
 {
+public:
+
+  enum special_conversion
+    {
+      whitespace_conversion = 1,
+      literal_conversion = 2
+    };
+
   scanf_format_elt (const char *txt = 0, int w = 0, bool d = false,
-		    char typ = '\0', char mod = '\0')
-    : text (txt), width (w), discard (d), type (typ), modifier (mod) { }
+		    char typ = '\0', char mod = '\0',
+		    const std::string& ch_class = std::string ())
+    : text (strsave (txt)), width (w), discard (d), type (typ),
+      modifier (mod), char_class (ch_class) { }
 
-  ~scanf_format_elt (void) { delete text; }
+  scanf_format_elt (const scanf_format_elt& e)
+    : text (strsave (e.text)), width (e.width), discard (e.discard),
+      type (e.type), modifier (e.modifier), char_class (e.char_class) { }
 
+  scanf_format_elt& operator = (const scanf_format_elt& e)
+    {
+      if (this != &e)
+	{
+	  text = strsave (e.text);
+	  width = e.width;
+	  discard = e.discard;
+	  type = e.type;
+	  modifier = e.modifier;
+	  char_class = e.char_class;
+	}
+
+      return *this;
+    }
+
+  ~scanf_format_elt (void) { delete [] text; }
+
+  // The C-style format string.
   const char *text;
+
+  // The maximum field width.
   int width;
+
+  // TRUE if we are not storing the result of this conversion.
   bool discard;
+
+  // Type of conversion -- `d', `i', `o', `u', `x', `e', `f', `g',
+  // `c', `s', `p', `%', or `['.
   char type;
+
+  // A length modifier -- `h', `l', or `L'.
   char modifier;
+
+  // The class of characters in a `[' format.
+  std::string char_class;
 };
 
 class
@@ -56,7 +100,7 @@ scanf_format_list
 {
 public:
 
-  scanf_format_list (const string& fmt = string ());
+  scanf_format_list (const std::string& fmt = std::string ());
 
   ~scanf_format_list (void);
 
@@ -78,11 +122,17 @@ public:
   const scanf_format_elt *current (void) const
     { return list.length () > 0 ? list.elem (curr_idx) : 0; }
 
-  const scanf_format_elt *next (void)
+  const scanf_format_elt *next (bool cycle = true)
     {
       curr_idx++;
+
       if (curr_idx >= list.length ())
-	curr_idx = 0;
+	{
+	  if (cycle)
+	    curr_idx = 0;
+	  else
+	    return 0;
+	}
       return current ();
     }
 
@@ -90,7 +140,7 @@ public:
 
   bool ok (void) const { return (nconv >= 0); }
 
-  operator void* () const { return ok () ? (void *) -1 : (void *) 0; }
+  operator bool () const { return ok (); }
 
   bool all_character_conversions (void);
 
@@ -109,16 +159,17 @@ private:
   Array<scanf_format_elt*> list;
 
   // Temporary buffer.
-  ostrstream *buf;
+  std::ostrstream *buf;
 
   void add_elt_to_list (int width, bool discard, char type, char modifier,
-			int& num_elts);
+			int& num_elts,
+			const std::string& char_class = std::string ()); 
 
-  void process_conversion (const string& s, int& i, int n, int& width,
+  void process_conversion (const std::string& s, int& i, int n, int& width,
 			   bool& discard, char& type, char& modifier,
 			   int& num_elts);
 
-  int finish_conversion (const string& s, int& i, int n, int& width,
+  int finish_conversion (const std::string& s, int& i, int n, int& width,
 			 bool discard, char& type, char modifier,
 			 int& num_elts);
   // No copying!
@@ -128,18 +179,59 @@ private:
   scanf_format_list& operator = (const scanf_format_list&);
 };
 
-struct
+class
 printf_format_elt
 {
-  printf_format_elt (const char *txt = 0, int n = 0, char typ = '\0',
-		     char mod = '\0')
-    : text (txt), args (n), type (typ), modifier (mod) { }
+public:
 
-  ~printf_format_elt (void) { delete text; }
+  printf_format_elt (const char *txt = 0, int n = 0, int w = 0,
+		     int p = 0, const std::string& f = std::string (),
+		     char typ = '\0', char mod = '\0')
+    : text (strsave (txt)), args (n), fw (w), prec (p), flags (f),
+      type (typ), modifier (mod) { }
 
+  printf_format_elt (const printf_format_elt& e)
+    : text (strsave (e.text)), args (e.args), fw (e.fw), prec (e.prec),
+      flags (e.flags), type (e.type), modifier (e.modifier) { }
+
+  printf_format_elt& operator = (const printf_format_elt& e)
+    {
+      if (this != &e)
+	{
+	  text = strsave (e.text);
+	  args = e.args;
+	  fw = e.fw;
+	  prec = e.prec;
+	  flags = e.flags;
+	  type = e.type;
+	  modifier = e.modifier;
+	}
+
+      return *this;
+    }
+
+  ~printf_format_elt (void) { delete [] text; }
+ 
+  // The C-style format string.
   const char *text;
+
+  // How many args do we expect to consume?
   int args;
+
+  // Field width.
+  int fw;
+
+  // Precision.
+  int prec;
+
+  // Flags -- `-', `+', ` ', `0', or `#'.
+  std::string flags;
+
+  // Type of conversion -- `d', `i', `o', `x', `X', `u', `c', `s',
+  // `f', `e', `E', `g', `G', `p', or `%'
   char type;
+
+  // A length modifier -- `h', `l', or `L'.
   char modifier;
 };
 
@@ -148,7 +240,7 @@ printf_format_list
 {
 public:
 
-  printf_format_list (const string& fmt = string ());
+  printf_format_list (const std::string& fmt = std::string ());
 
   ~printf_format_list (void);
 
@@ -163,19 +255,28 @@ public:
   const printf_format_elt *current (void) const
     { return list.length () > 0 ? list.elem (curr_idx) : 0; }
 
-  const printf_format_elt *next (void)
+  const printf_format_elt *next (bool cycle = true)
     {
       curr_idx++;
+
       if (curr_idx >= list.length ())
-	curr_idx = 0;
+	{
+	  if (cycle)
+	    curr_idx = 0;
+	  else
+	    return 0;
+	}
+
       return current ();
     }
 
+  bool last_elt_p (void) { return (curr_idx + 1 == list.length ()); }
+
   void printme (void) const;
 
   bool ok (void) const { return (nconv >= 0); }
 
-  operator void* () const { return ok () ? (void *) -1 : (void *) 0; }
+  operator bool () const { return ok (); }
 
 private:
 
@@ -190,15 +291,19 @@ private:
   Array<printf_format_elt*> list;
 
   // Temporary buffer.
-  ostrstream *buf;
+  std::ostrstream *buf;
 
-  void add_elt_to_list (int args, char type, char modifier,
-			int& num_elts);
-
-  void process_conversion (const string& s, int& i, int n, int& args,
-			   char& modifier, char& type, int& num_elts);
-
-  void finish_conversion (const string& s, int& i, int args,
+  void add_elt_to_list (int args, const std::string& flags, int fw,
+			int prec, char type, char modifier,
+ 			int& num_elts);
+ 
+  void process_conversion (const std::string& s, int& i, int n,
+			   int& args, std::string& flags, int& fw,
+			   int& prec, char& modifier, char& type,
+			   int& num_elts); 
+ 
+  void finish_conversion (const std::string& s, int& i, int args,
+			  const std::string& flags, int fw, int prec,
 			  char modifier, char& type, int& num_elts);
 
   // No copying!
@@ -217,9 +322,10 @@ friend class octave_stream;
 
 public:
 
-  octave_base_stream (ios::openmode arg_md = ios::in|ios::out,
+  octave_base_stream (std::ios::openmode arg_md = std::ios::in|std::ios::out,
 		      oct_mach_info::float_format ff = oct_mach_info::native)
-    : md (arg_md), flt_fmt (ff), fail (false) { }
+    : count (0), md (arg_md), flt_fmt (ff), fail (false), open_state (true)
+  { }
 
   virtual ~octave_base_stream (void) { }
 
@@ -228,31 +334,46 @@ public:
 
   // Position a stream at OFFSET relative to ORIGIN.
 
-  virtual int seek (streamoff offset, ios::seek_dir origin) = 0;
+  virtual int seek (std::streamoff offset, std::ios::seekdir origin) = 0;
 
   // Return current stream position.
 
   virtual long tell (void) const = 0;
 
-  // Return non-zero if EOF has been reached on this stream.
+  // Return TRUE if EOF has been reached on this stream.
 
   virtual bool eof (void) const = 0;
 
   // The name of the file.
 
-  virtual string name (void) = 0;
+  virtual std::string name (void) const = 0;
 
   // If the derived class provides this function and it returns a
   // pointer to a valid istream, scanf(), read(), getl(), and gets()
   // will automatically work for this stream.
 
-  virtual istream *input_stream (void) { return 0; }
+  virtual std::istream *input_stream (void) { return 0; }
 
   // If the derived class provides this function and it returns a
   // pointer to a valid ostream, flush(), write(), and printf() will
   // automatically work for this stream.
 
-  virtual ostream *output_stream (void) { return 0; }
+  virtual std::ostream *output_stream (void) { return 0; }
+
+  // Return TRUE if this stream is open.
+
+  bool is_open (void) const { return open_state; }
+
+  virtual void do_close (void) { }
+
+  void close (void)
+    {
+      if (is_open ())
+	{
+	  open_state = false;
+	  do_close ();
+	}
+    }
 
   int file_number (void);
 
@@ -260,17 +381,17 @@ public:
 
   // Return current error message for this stream.
 
-  string error (bool clear, int& err_num);
+  std::string error (bool clear, int& err_num);
 
 protected:
 
-  int mode (void) { return md; }
+  int mode (void) const { return md; }
 
-  oct_mach_info::float_format float_format (void) { return flt_fmt; }
+  oct_mach_info::float_format float_format (void) const { return flt_fmt; }
 
   // Set current error state and set fail to TRUE.
 
-  void error (const string& msg);
+  void error (const std::string& msg);
 
   // Clear any error message and set fail to FALSE.
 
@@ -278,8 +399,11 @@ protected:
 
 private:
 
+  // A reference count.
+  int count;
+
   // The permission bits for the file.  Should be some combination of
-  // ios::open_mode bits.
+  // std::ios::open_mode bits.
   int md;
 
   // Data format.
@@ -288,23 +412,26 @@ private:
   // TRUE if an error has occurred.
   bool fail;
 
+  // TRUE if this stream is open.
+  bool open_state;
+
   // Should contain error message if fail is TRUE.
-  string errmsg;
+  std::string errmsg;
 
   // Functions that are defined for all input streams (input streams
   // are those that define is).
 
-  string do_gets (int max_len, bool& err, bool strip_newline,
+  std::string do_gets (int max_len, bool& err, bool strip_newline,
 		  const char *fcn);
 
-  string getl (int max_len, bool& err);
-  string gets (int max_len, bool& err);
+  std::string getl (int max_len, bool& err);
+  std::string gets (int max_len, bool& err);
 
   octave_value do_read (int nr, int nc, oct_data_conv::data_type dt,
 			int skip, oct_mach_info::float_format flt_fmt,
 			int& count);
 
-  octave_value read (const Matrix& size, oct_data_conv::data_type dt,
+  octave_value read (const Array<double>& size, oct_data_conv::data_type dt,
 		     int skip, oct_mach_info::float_format flt_fmt,
 		     int& count);
 
@@ -315,30 +442,27 @@ private:
 			      int nr, int nc, int& count);
 
   octave_value do_scanf (scanf_format_list& fmt_list, int nr, int nc,
-			 int& count);
+			 bool one_elt_size_spec, int& count);
 
-  octave_value scanf (const string& fmt, const Matrix& size, int& count);
+  octave_value scanf (const std::string& fmt, const Array<double>& size, int& count);
 
   bool do_oscanf (const scanf_format_elt *elt, octave_value&);
 
-  octave_value_list oscanf (const string& fmt);
+  octave_value_list oscanf (const std::string& fmt);
 
   // Functions that are defined for all output streams (output streams
   // are those that define os).
 
   int flush (void);
 
-  int do_write (const Matrix& m, oct_data_conv::data_type dt, int skip,
-		oct_mach_info::float_format flt_fmt);
-
   int write (const octave_value& data, oct_data_conv::data_type dt,
 	     int skip, oct_mach_info::float_format flt_fmt);
 
   int do_printf (printf_format_list& fmt_list, const octave_value_list& args);
 
-  int printf (const string& fmt, const octave_value_list& args);
+  int printf (const std::string& fmt, const octave_value_list& args);
 
-  int puts (const string& s);
+  int puts (const std::string& s);
 
   // We can always do this in terms of seek(), so the derived class
   // only has to provide that.
@@ -359,51 +483,54 @@ octave_stream
 {
 public:
 
-  octave_stream (octave_base_stream *bs = 0, bool pf = false)
-    : rep (bs), preserve (pf) { }
+  octave_stream (octave_base_stream *bs = 0);
 
-  ~octave_stream (void)
-    {
-      if (! preserve)
-	delete rep;
-    }
+  ~octave_stream (void);
+
+  octave_stream (const octave_stream&);
+
+  octave_stream& operator = (const octave_stream&);
 
   int flush (void);
 
-  string getl (int max_len, bool& err);
-  string getl (const octave_value& max_len, bool& err);
+  std::string getl (int max_len, bool& err);
+  std::string getl (const octave_value& max_len, bool& err);
 
-  string gets (int max_len, bool& err);
-  string gets (const octave_value& max_len, bool& err);
+  std::string gets (int max_len, bool& err);
+  std::string gets (const octave_value& max_len, bool& err);
 
-  int seek (streamoff offset, ios::seek_dir origin);
+  int seek (std::streamoff offset, std::ios::seekdir origin);
   int seek (const octave_value& offset, const octave_value& origin);
 
   long tell (void) const;
 
   int rewind (void);
 
-  octave_value read (const Matrix& size, oct_data_conv::data_type dt,
+  bool is_open (void) const;
+
+  void close (void);
+
+  octave_value read (const Array<double>& size, oct_data_conv::data_type dt,
 		     int skip, oct_mach_info::float_format flt_fmt,
 		     int& count);
 
   int write (const octave_value& data, oct_data_conv::data_type dt,
 	     int skip, oct_mach_info::float_format flt_fmt);
 
-  octave_value scanf (const string& fmt, const Matrix& size, int& count);
+  octave_value scanf (const std::string& fmt, const Array<double>& size, int& count);
 
-  octave_value_list oscanf (const string& fmt);
+  octave_value_list oscanf (const std::string& fmt);
 
-  int printf (const string& fmt, const octave_value_list& args);
+  int printf (const std::string& fmt, const octave_value_list& args);
 
-  int puts (const string& s);
+  int puts (const std::string& s);
   int puts (const octave_value& s);
 
   bool eof (void) const;
 
-  string error (bool clear, int& err_num);
+  std::string error (bool clear, int& err_num);
 
-  string error (bool clear = false)
+  std::string error (bool clear = false)
     {
       int err_num;
       return error (clear, err_num);
@@ -411,26 +538,29 @@ public:
 
   int file_number (void) { return rep ? rep->file_number () : -1; }
 
+  bool is_valid (void) const { return (rep != 0); }
+
   bool ok (void) const { return rep && rep->ok (); }
 
-  operator void* () const { return ok () ? (void *) -1 : (void *) 0; }
+  operator bool () const { return ok (); }
 
-  string name (void);
+  std::string name (void) const;
 
-  int mode (void);
+  int mode (void) const;
 
-  oct_mach_info::float_format float_format (void);
+  oct_mach_info::float_format float_format (void) const;
 
-  static string mode_as_string (int mode);
+  static std::string mode_as_string (int mode);
+
+  std::istream *input_stream (void) { return rep ? rep->input_stream () : 0; }
+
+  std::ostream *output_stream (void) { return rep ? rep->output_stream () : 0; }
 
 private:
 
   // The actual representation of this stream.
   octave_base_stream *rep;
 
-  // If true, do not delete rep.
-  bool preserve;
-
   void invalid_stream_error (const char *op) const;
 
   bool stream_ok (const char *op, bool clear = true) const
@@ -451,21 +581,11 @@ private:
       return retval;
     }
 
-  void error (const string& msg)
+  void error (const std::string& msg)
     {
       if (rep)
 	rep->error (msg);
     }
-
-  // Must create named streams.
-
-  octave_stream (void);
-
-  // No copying!
-
-  octave_stream (const octave_stream&);
-
-  octave_stream& operator = (const octave_stream&);
 };
 
 class
@@ -479,20 +599,24 @@ public:
 
   ~octave_stream_list (void) { }
 
-  static int insert (octave_base_stream *obs);
+  static bool instance_ok (void);
 
-  static octave_stream *lookup (int fid);
-  static octave_stream *lookup (const octave_value& fid);
+  static octave_value insert (const octave_stream& os);
 
-  static int remove (int fid);
-  static int remove (const octave_value& fid);
+  static octave_stream lookup (int fid, const std::string& who = std::string ());
+  static octave_stream lookup (const octave_value& fid,
+			       const std::string& who = std::string ());
+
+  static int remove (int fid, const std::string& who = std::string ());
+  static int remove (const octave_value& fid,
+		     const std::string& who = std::string ());
 
   static void clear (void);
 
   static string_vector get_info (int fid);
   static string_vector get_info (const octave_value& fid);
 
-  static string list_open_files (void);
+  static std::string list_open_files (void);
 
   static octave_value open_file_numbers (void);
 
@@ -500,26 +624,27 @@ public:
 
 private:
 
-  Array<octave_stream*> list;
+  Array<octave_stream> list;
 
   int curr_len;
 
   static octave_stream_list *instance;
 
-  int do_insert (octave_base_stream *obs);
+  octave_value do_insert (const octave_stream& os);
 
-  octave_stream *do_lookup (int fid) const;
-  octave_stream *do_lookup (const octave_value& fid) const;
+  octave_stream do_lookup (int fid, const std::string& who = std::string ()) const;
+  octave_stream do_lookup (const octave_value& fid,
+			   const std::string& who = std::string ()) const;
 
-  int do_remove (int fid);
-  int do_remove (const octave_value& fid);
+  int do_remove (int fid, const std::string& who = std::string ());
+  int do_remove (const octave_value& fid, const std::string& who = std::string ());
 
   void do_clear (void);
 
   string_vector do_get_info (int fid) const;
   string_vector do_get_info (const octave_value& fid) const;
 
-  string do_list_open_files (void) const;
+  std::string do_list_open_files (void) const;
 
   octave_value do_open_file_numbers (void) const;
 
