@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,19 +29,19 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // Position a stream at OFFSET relative to ORIGIN.
 
 int
-octave_base_strstream::seek (streamoff offset, ios::seek_dir origin)
+octave_base_strstream::seek (std::streamoff offset, std::ios::seekdir origin)
 {
   int retval = -1;
 
   if (! bad ())
     {
-      streambuf *sb = rdbuf ();
+      std::streambuf *sb = rdbuf ();
 
       if (sb)
 	{
 	  clear ();
 
-	  sb->seekoff (offset, origin);
+	  sb->pubseekoff (offset, origin);
 	  retval = bad () ? -1 : 0;
 	}
     }
@@ -60,11 +60,11 @@ octave_base_strstream::tell (void) const
     {
       // XXX FIXME XXX -- shouldn't have to do this!
 
-      streambuf *sb = ((octave_base_strstream *)this)->rdbuf ();
+      std::streambuf *sb = (const_cast<octave_base_strstream *>(this))->rdbuf ();
 
       if (sb)
 	{
-	  retval = (long) sb->seekoff (0, ios::cur);
+	  retval = static_cast<long> (sb->pubseekoff (0, std::ios::cur));
 
 	  if (bad ())
 	    retval = -1;
@@ -74,6 +74,27 @@ octave_base_strstream::tell (void) const
   return retval;
 }
 
+octave_stream
+octave_istrstream::create (const char *data, std::ios::openmode arg_md,
+			   oct_mach_info::float_format flt_fmt)
+{
+  return octave_stream (new octave_istrstream (data, arg_md, flt_fmt));
+}
+
+octave_stream
+octave_istrstream::create (const std::string& data, std::ios::openmode arg_md,
+			   oct_mach_info::float_format flt_fmt)
+{
+  return octave_stream (new octave_istrstream (data, arg_md, flt_fmt));
+}
+
+octave_stream
+octave_ostrstream::create (std::ios::openmode arg_md,
+			   oct_mach_info::float_format flt_fmt)
+{
+  return octave_stream (new octave_ostrstream (arg_md, flt_fmt));
+}
+
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
