@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -27,14 +27,13 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 
 #include <cassert>
-#include <csignal>
 #include <cstdlib>
 #include <cstring>
 #include <ctime>
 
-#include <fstream.h>
-#include <iostream.h>
-#include <strstream.h>
+#include <fstream>
+#include <iostream>
+#include <strstream>
 
 #ifdef HAVE_UNISTD_H
 #ifdef HAVE_SYS_TYPES_H
@@ -43,59 +42,46 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <unistd.h>
 #endif
 
-#ifdef HAVE_PWD_H
-#include <pwd.h>
-#endif
-
+#include "cmd-edit.h"
+#include "f77-fcn.h"
+#include "file-stat.h"
 #include "lo-error.h"
+#include "oct-env.h"
+#include "pathsearch.h"
 #include "str-vec.h"
 
-#include "builtins.h"
 #include <defaults.h>
 #include "defun.h"
-#include "dynamic-ld.h"
 #include "error.h"
 #include "file-io.h"
-#include "file-ops.h"
-#include "help.h"
 #include "input.h"
 #include "lex.h"
 #include "oct-hist.h"
+#include "oct-obj.h"
 #include "ops.h"
 #include "toplev.h"
 #include "parse.h"
-#include "pathsearch.h"
+#include "pt-plot.h"
 #include "procstream.h"
 #include "prog-args.h"
 #include "sighandlers.h"
 #include "sysdep.h"
 #include "ov.h"
-#include "pt-misc.h"
-#include "pt-plot.h"
 #include "unwind-prot.h"
 #include "utils.h"
 #include "variables.h"
 #include <version.h>
 
+// Kluge.
+extern "C" void F77_FCN (xerbla, XERBLA) (const char *, int);
+
+extern void install_builtins (void);
+
 #if !defined (HAVE_ATEXIT) && defined (HAVE_ON_EXIT)
 extern "C" int on_exit ();
 #define atexit on_exit
 #endif
 
-// Don't redefine the variables if glibc already has.
-#if defined (HAVE_PROGRAM_INVOCATION_NAME) || defined (WITH_KPATHSEARCH)
-extern char *program_invocation_name;
-extern char *program_invocation_short_name;
-#else
-char *program_invocation_name;
-char *program_invocation_short_name;
-#endif
-
-#if defined (USE_READLINE)
-// This is from readline's paren.c:
-extern int rl_blink_matching_paren;
-#endif
-
 // The command-line options.
 static string_vector octave_argv;
 
@@ -107,15 +93,15 @@ static bool read_init_files = true;
 // (--norc; --no-site-file; -f)
 static bool read_site_files = true;
 
-// Nonzero means we don't print the usual startup message.
+// TRUE means we don't print the usual startup message.
 // (--quiet; --silent; -q)
 static bool inhibit_startup_message = false;
 
-// Nonzero means we turn on compatibility options.
+// TRUE means we turn on compatibility options.
 // (--traditional)
 static bool traditional = false;
 
-// If nonzero, print verbose info in some cases.
+// If TRUE, print verbose info in some cases.
 // (--verbose; -V)
 static bool verbose_flag = false;
 
@@ -162,7 +148,7 @@ long_options long_opts[] =
     { "traditional",      prog_args::no_arg,       0, TRADITIONAL_OPTION },
     { "verbose",          prog_args::no_arg,       0, 'V' },
     { "version",          prog_args::no_arg,       0, 'v' },
-    { 0,                  0,                 0, 0 }
+    { 0,                  0,                       0, 0 }
   };
 
 // Store the command-line options for later use.
@@ -170,49 +156,21 @@ long_options long_opts[] =
 static void
 intern_argv (int argc, char **argv)
 {
+  bind_builtin_variable ("nargin", static_cast<double> (argc-1),
+			 true, true, 0);
+
+  octave_value_list octave_argv;
+
   if (argc > 1)
     {
       // Skip program name in argv.
+      while (--argc > 0)
+	octave_argv(argc-1) = octave_value (*(argv+argc));
 
-      octave_argv = string_vector (argv+1, argc-1);
-
-      bind_builtin_variable ("argv", octave_argv, 1, 1, 0);
-      bind_builtin_variable ("__argv__", octave_argv, 1, 1, 0);
     }
 
-  bind_builtin_variable ("nargin", (double) argc-1, 1, 1, 0);
-}
-
-// Initialize some global variables for later use.
-
-static void
-initialize_globals (const string& name)
-{
-  // Kpathsea needs this.
-
-#if ! defined (HAVE_PROGRAM_INVOCATION_NAME)
-  program_invocation_name = strsave (name.c_str ());
-  program_invocation_short_name = strrchr (program_invocation_name, '/');
-  if (! program_invocation_short_name)
-    program_invocation_short_name = program_invocation_name;
-#endif
-
-  Vprogram_invocation_name = name;
-  size_t pos = Vprogram_invocation_name.rfind ('/');
-  Vprogram_name = (pos == NPOS)
-    ? Vprogram_invocation_name : Vprogram_invocation_name.substr (pos+1);
-
-  struct passwd *entry = getpwuid (getuid ());
-  Vuser_name = entry ? entry->pw_name : "unknown";
-
-  char hostname[256];
-  int status = gethostname (hostname, 255);
-  Vhost_name = (status < 0) ? "unknown" : hostname;
-
-  char *hd = getenv ("HOME");
-  Vhome_directory = hd ? hd : "/";
-
-  install_defaults ();
+  bind_builtin_constant ("argv", octave_argv, true, true);
+  bind_builtin_constant ("__argv__", octave_argv, true, true);
 }
 
 static void
@@ -221,24 +179,19 @@ initialize_pathsearch (void)
   // This may seem odd, but doing it this way means that we don't have
   // to modify the kpathsea library...
 
-  char *odb = getenv ("OCTAVE_DB_PATH");
+  std::string odb = octave_env::getenv ("OCTAVE_DB_PATH");
 
   // For backward compatibility.
 
-  if (! odb)
-    odb = getenv ("OCTAVE_DB_DIR");
+  if (odb.empty ())
+    odb = octave_env::getenv ("OCTAVE_DB_DIR");
 
-  if (! odb)
-    {
-      string val = Vdata_dir + string ("/octave:")
-	+ Vlibexec_dir + string ("/octave");
+  if (odb.empty ())
+    odb = Vdata_dir + std::string ("/octave:") + Vlibexec_dir + std::string ("/octave");
 
-      oct_putenv ("TEXMFDBS", val.c_str ());
-    }
-  else
-    oct_putenv ("TEXMFDBS", odb);
+  octave_original_texmfdbs = octave_env::getenv ("TEXMFDBS");
 
-  dir_path::init_program_name (program_invocation_name);
+  octave_env::putenv ("TEXMFDBS", odb);
 }
 
 // Initialize by reading startup files.
@@ -246,14 +199,14 @@ initialize_pathsearch (void)
 static void
 execute_startup_files (void)
 {
-  begin_unwind_frame ("execute_startup_files");
+  unwind_protect::begin_frame ("execute_startup_files");
 
   // XXX FIXME XXX -- need to make it possible to set this in startup
   // files.
 
-  unwind_protect_int (input_from_startup_file);
+  unwind_protect_bool (input_from_startup_file);
 
-  input_from_startup_file = 1;
+  input_from_startup_file = true;
 
   int verbose = (verbose_flag && ! inhibit_startup_message);
 
@@ -262,11 +215,11 @@ execute_startup_files (void)
       // Execute commands from the site-wide configuration file.
       // First from the file $(prefix)/lib/octave/site/m/octaverc
       // (if it exists), then from the file
-      // $(prefix)/lib/octave/$(version)/m/octaverc (if it exists).
+      // $(prefix)/share/octave/$(version)/m/octaverc (if it exists).
 
-      parse_and_execute (Vlocal_site_defaults_file, 0, verbose);
+      parse_and_execute (Vlocal_site_defaults_file, verbose);
 
-      parse_and_execute (Vsite_defaults_file, 0, verbose);
+      parse_and_execute (Vsite_defaults_file, verbose);
     }
 
   if (read_init_files)
@@ -277,17 +230,19 @@ execute_startup_files (void)
 
       int home_rc_already_executed = 0;
 
-      char *initfile = getenv ("OCTAVE_INITFILE");
+      std::string initfile = octave_env::getenv ("OCTAVE_INITFILE");
 
-      if (! initfile)
+      if (initfile.empty ())
 	initfile = ".octaverc";
 
-      string home_rc = Vhome_directory + "/" + initfile;
-      string local_rc = string ("./") + initfile;
+      std::string home_dir = octave_env::get_home_directory ();
 
-      if (! Vhome_directory.empty ())
+      std::string home_rc = home_dir + "/" + initfile;
+      std::string local_rc = std::string ("./") + initfile;
+
+      if (! home_dir.empty ())
 	{
-	  parse_and_execute (home_rc, 0, verbose);
+	  parse_and_execute (home_rc, verbose);
 
 	  // Names alone are not enough.
 
@@ -303,10 +258,10 @@ execute_startup_files (void)
 	}
 
       if (! home_rc_already_executed)
-	parse_and_execute (local_rc, 0, verbose);
+	parse_and_execute (local_rc, verbose);
     }
 
-  run_unwind_frame ("execute_startup_files");
+  unwind_protect::run_frame ("execute_startup_files");
 }
 
 // Usage message with extra help.
@@ -314,7 +269,7 @@ execute_startup_files (void)
 static void
 verbose_usage (void)
 {
-  cout << OCTAVE_NAME_VERSION_AND_COPYRIGHT "\n\
+  std::cout << OCTAVE_NAME_VERSION_AND_COPYRIGHT "\n\
 \n\
 Usage: octave [options]\n\
 \n\
@@ -353,14 +308,14 @@ Please report bugs to the mailing list `bug-octave@bevo.che.wisc.edu'.\n";
 static void
 usage (void)
 {
-  cerr << "usage: " << usage_string << "\n";
+  std::cerr << "usage: " << usage_string << "\n";
   exit (1);
 }
 
 static void
 print_version_and_exit (void)
 {
-  cout << OCTAVE_NAME_AND_VERSION << "\n";
+  std::cout << OCTAVE_NAME_AND_VERSION << "\n";
   exit (0);
 }
 
@@ -368,6 +323,7 @@ static void
 initialize_error_handlers ()
 {
   set_liboctave_error_handler (error);
+  set_liboctave_warning_handler (warning);
 }
 
 // What happens on --traditional.
@@ -392,7 +348,6 @@ maximum_braindamage (void)
   bind_builtin_variable ("ok_to_lose_imaginary_part", 1.0);
   bind_builtin_variable ("page_screen_output", 0.0);
   bind_builtin_variable ("prefer_column_vectors", 0.0);
-  bind_builtin_variable ("prefer_zero_one_indexing", 1.0);
   bind_builtin_variable ("print_empty_dimensions", 0.0);
   bind_builtin_variable ("treat_neg_dim_as_zero", 1.0);
   bind_builtin_variable ("warn_function_name_clash", 0.0);
@@ -404,9 +359,13 @@ maximum_braindamage (void)
 int
 main (int argc, char **argv)
 {
+  octave_env::set_program_name (argv[0]);
+
+  dir_path::set_program_name (argv[0]);
+
   // The order of these calls is important.  The call to
-  // initialize_globals must come before install_builtins because
-  // default variable values must be available for the varaibles to be
+  // install_defaults must come before install_builtins because
+  // default variable values must be available for the variables to be
   // installed, and the call to install_builtins must come before the
   // options are processed because some command line options override
   // defaults by calling bind_builtin_variable.
@@ -415,7 +374,7 @@ main (int argc, char **argv)
 
   initialize_error_handlers ();
 
-  initialize_globals (argv[0]);
+  install_defaults ();
 
   initialize_pathsearch ();
 
@@ -461,7 +420,7 @@ main (int argc, char **argv)
 	  break;
 
 	case 'i':
-	  forced_interactive = 1;
+	  forced_interactive = true;
 	  break;
 
 	case 'p':
@@ -504,7 +463,7 @@ main (int argc, char **argv)
 	  break;
 
 	case NO_LINE_EDITING_OPTION:
-	  using_readline = false;
+	  line_editing = false;
 	  break;
 
 	case NO_SITE_FILE_OPTION:
@@ -527,43 +486,42 @@ main (int argc, char **argv)
   // leave some junk files around if we exit abnormally.
 
   atexit (do_octave_atexit);
-
-  atexit (cleanup_tmp_files);
 #endif
 
   // These can come after command line args since none of them set any
   // defaults that might be changed by command line options.
 
-  initialize_readline ();
-
-  init_dynamic_linker ();
+  initialize_command_input ();
 
   if (! inhibit_startup_message)
-    cout << OCTAVE_STARTUP_MESSAGE "\n" << endl;
+    std::cout << OCTAVE_STARTUP_MESSAGE "\n" << std::endl;
 
   if (traditional)
     maximum_braindamage ();
 
   execute_startup_files ();
 
-  octave_command_history.read (false);
+  command_history::read (false);
 
   if (! inhibit_startup_message && reading_startup_message_printed)
-    cout << endl;
+    std::cout << std::endl;
 
   // Avoid counting commands executed from startup files.
 
-  current_command_number = 1;
+  command_editor::reset_current_command_number (1);
 
   // If there is an extra argument, see if it names a file to read.
   // Additional arguments are taken as command line options for the
   // script.
 
   int last_arg_idx = args.optind ();
+
   int remaining_args = argc - last_arg_idx;
+
   if (remaining_args > 0)
     {
-      reading_script_file = 1;
+      reading_script_file = true;
+
       curr_fcn_file_name = argv[last_arg_idx];
       curr_fcn_file_full_name = curr_fcn_file_name;
 
@@ -571,21 +529,22 @@ main (int argc, char **argv)
 
       if (infile)
 	{
-	  input_from_command_line_file = 1;
+	  input_from_command_line_file = true;
 
 	  bind_builtin_variable ("program_invocation_name",
 				 curr_fcn_file_name);
 
 	  size_t pos = curr_fcn_file_name.rfind ('/');
 
-	  string tmp = (pos != NPOS)
+	  std::string tmp = (pos != NPOS)
 	    ? curr_fcn_file_name.substr (pos+1) : curr_fcn_file_name;
 
 	  bind_builtin_variable ("program_name", tmp);
 
 	  intern_argv (remaining_args, argv+last_arg_idx);
 
-	  rl_blink_matching_paren = 0;
+	  command_editor::blink_matching_paren (false);
+
 	  switch_to_buffer (create_buffer (infile));
 	}
       else
@@ -608,16 +567,16 @@ main (int argc, char **argv)
 
   if (! interactive && forced_interactive)
     {
-      rl_blink_matching_paren = 0;
+      command_editor::blink_matching_paren (false);
 
       // XXX FIXME XXX -- is this the right thing to do?
 
       bind_builtin_variable ("echo_executing_commands",
-			     (double) ECHO_CMD_LINE);
+			     static_cast<double> (ECHO_CMD_LINE));
     }
 
   if (! interactive)
-    using_readline = 0;
+    line_editing = false;
 
   int retval = main_loop ();
 
