@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,10 +29,9 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <cstdlib>
 
+#include <iostream>
 #include <string>
 
-class ostream;
-
 #include "mx-base.h"
 #include "str-vec.h"
 
@@ -40,6 +39,7 @@ class ostream;
 #include "ov.h"
 #include "ov-typeinfo.h"
 
+class Cell;
 class Octave_map;
 class octave_value_list;
 
@@ -65,25 +65,36 @@ public:
   octave_value *clone (void) { return new octave_base_value (*this); }
 
   type_conv_fcn numeric_conversion_function (void) const
-    { return (type_conv_fcn) 0; }
+    { return static_cast<type_conv_fcn> (0); }
 
   octave_value *try_narrowing_conversion (void)
-    { return (octave_value *) 0; }
+    { return static_cast<octave_value *> (0); }
 
-  octave_value index (const octave_value_list& idx) const;
+  octave_value do_index_op (const octave_value_list& idx);
+
+  octave_value_list
+  do_multi_index_op (int nargout, const octave_value_list& idx);
 
   idx_vector index_vector (void) const;
 
-  octave_value struct_elt_val (const string& nm, bool silent) const;
+  octave_value
+  do_struct_elt_index_op (const std::string& nm, const octave_value_list& idx,
+			  bool silent);
 
-  octave_value& struct_elt_ref (const string& nm);
+  octave_value do_struct_elt_index_op (const std::string& nm, bool silent);
+
+  octave_lvalue struct_elt_ref (octave_value *parent, const std::string& nm);
 
   int rows (void) const { return -1; }
 
   int columns (void) const { return -1; }
 
+  int length (void) const { return -1; }
+
   bool is_defined (void) const { return false; }
 
+  bool is_cell (void) const { return false; }
+
   bool is_real_scalar (void) const { return false; }
 
   bool is_real_matrix (void) const { return false; }
@@ -100,6 +111,10 @@ public:
 
   bool is_map (void) const { return false; }
 
+  bool is_stream (void) const { return false; }
+
+  bool is_list (void) const { return false; }
+
   bool is_magic_colon (void) const { return false; }
 
   bool is_all_va_args (void) const { return false; }
@@ -108,6 +123,8 @@ public:
 
   octave_value any (void) const { return 0.0; }
 
+  bool is_bool_type (void) const { return false; }
+
   bool is_real_type (void) const { return false; }
 
   bool is_complex_type (void) const { return false; }
@@ -132,64 +149,70 @@ public:
   bool is_zero_by_zero (void) const
     { return (rows () == 0 && columns () == 0); }
 
-  double double_value (bool) const;
+  bool is_constant (void) const { return false; }
 
-  Matrix matrix_value (bool frc_str_conv = false) const;
+  bool is_function (void) const { return false; }
 
-  Complex complex_value (bool frc_str_conv = false) const;
+  bool is_builtin_function (void) const { return false; }
 
-  ComplexMatrix complex_matrix_value (bool frc_str_conv = false) const;
+  bool is_dld_function (void) const { return false; }
 
-  charMatrix char_matrix_value (bool frc_str_conv = false) const;
+  int int_value (bool = false, bool = false) const;
+
+  int nint_value (bool = false) const;
+
+  double double_value (bool = false) const;
+
+  double scalar_value (bool frc_str_conv = false) const
+    { return double_value (frc_str_conv); }
+
+  Cell cell_value (void) const;
+
+  Matrix matrix_value (bool = false) const;
+
+  Complex complex_value (bool = false) const;
+
+  ComplexMatrix complex_matrix_value (bool = false) const;
+
+  charMatrix char_matrix_value (bool = false) const;
 
   string_vector all_strings (void) const;
 
-  string string_value (void) const;
+  std::string string_value (void) const;
 
   Range range_value (void) const;
 
   Octave_map map_value (void) const;
 
-  octave_value not (void) const;
+  octave_stream stream_value (void) const;
 
-  octave_value uminus (void) const;
+  int stream_number (void) const;
 
-  octave_value transpose (void) const;
+  octave_function *function_value (bool silent);
 
-  octave_value hermitian (void) const;
+  octave_value_list list_value (void) const;
 
-  void increment (void);
+  bool bool_value (void) const;
 
-  void decrement (void);
+  boolMatrix bool_matrix_value (void) const;
 
   octave_value convert_to_str (void) const;
 
   void convert_to_row_or_column_vector (void);
 
-  void print (ostream& os, bool pr_as_read_syntax = false);
+  void print (std::ostream& os, bool pr_as_read_syntax = false) const;
 
-  int type_id (void) const { return t_id; }
+  void print_raw (std::ostream& os, bool pr_as_read_syntax = false) const;
 
-  string type_name (void) const { return t_name; }
-
-  static int static_type_id (void) { return t_id; }
-
-  static void register_type (void)
-    { t_id = octave_value_typeinfo::register_type (t_name); }
+  bool print_name_tag (std::ostream& os, const std::string& name) const;
 
 private:
 
-  // Type id of base value objects, set by register_type().
-  static int t_id;
-
-  // Type name of base value objects, defined in ov-base.cc.
-  static const string t_name;
+  DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA
 };
 
 #endif
 
-extern void install_base_type_conversions (void);
-
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
