@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,18 +28,23 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 
 #include "error.h"
 #include "pr-output.h"
 #include "ov-colon.h"
 
-int octave_magic_colon::t_id = -1;
-
-const string octave_magic_colon::t_name ("magic-colon");
+DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_magic_colon, "magic-colon");
 
 void
-octave_magic_colon::print (ostream& os, bool)
+octave_magic_colon::print (std::ostream& os, bool) const
+{
+  indent (os);
+  print_raw (os);
+}
+
+void
+octave_magic_colon::print_raw (std::ostream& os, bool) const
 {
   os << ":";
 }
