@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,16 +29,16 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <cstdlib>
 
+#include <iostream>
 #include <string>
 
-class ostream;
-
 #include "mx-base.h"
 #include "oct-alloc.h"
 #include "str-vec.h"
 
 #include "error.h"
 #include "ov-base.h"
+#include "ov-base-mat.h"
 #include "ov-typeinfo.h"
 
 class Octave_map;
@@ -49,68 +49,48 @@ class tree_walker;
 // Complex matrix values.
 
 class
-octave_complex_matrix : public octave_base_value
+octave_complex_matrix : public octave_base_matrix<ComplexMatrix>
 {
 public:
 
   octave_complex_matrix (void)
-    : octave_base_value () { }
+    : octave_base_matrix<ComplexMatrix> () { }
 
   octave_complex_matrix (const ComplexMatrix& m)
-    : octave_base_value (), matrix (m) { }
+    : octave_base_matrix<ComplexMatrix> (m) { }
 
   octave_complex_matrix (const ComplexDiagMatrix& d)
-    : octave_base_value (), matrix (d) { }
+    : octave_base_matrix<ComplexMatrix> (ComplexMatrix (d)) { }
 
-  octave_complex_matrix (const ComplexRowVector& v, int pcv = -1);
+  octave_complex_matrix (const ComplexRowVector& v)
+    : octave_base_matrix<ComplexMatrix> (ComplexMatrix (v)) { }
 
-  octave_complex_matrix (const ComplexColumnVector& v, int pcv = -1);
+  octave_complex_matrix (const ComplexColumnVector& v)
+    : octave_base_matrix<ComplexMatrix> (ComplexMatrix (v)) { }
 
   octave_complex_matrix (const octave_complex_matrix& cm)
-    : octave_base_value (), matrix (cm.matrix) { }
+    : octave_base_matrix<ComplexMatrix> (cm) { }
 
   ~octave_complex_matrix (void) { }
 
   octave_value *clone (void) { return new octave_complex_matrix (*this); }
 
-  void *operator new (size_t size)
-    { return allocator.alloc (size); }
-
-  void operator delete (void *p, size_t size)
-    { allocator.free (p, size); }
-
   octave_value *try_narrowing_conversion (void);
 
-  octave_value index (const octave_value_list& idx) const;
-
   void assign (const octave_value_list& idx, const ComplexMatrix& rhs);
 
   void assign (const octave_value_list& idx, const Matrix& rhs);
 
-  int rows (void) const { return matrix.rows (); }
-  int columns (void) const { return matrix.columns (); }
-
-  bool is_defined (void) const { return true; }
-
   bool is_complex_matrix (void) const { return true; }
 
-  octave_value all (void) const { return matrix.all (); }
-  octave_value any (void) const { return matrix.any (); }
-
   bool is_complex_type (void) const { return true; }
 
-  bool is_matrix_type (void) const { return true; }
-
-  bool is_numeric_type (void) const { return true; }
-
   bool valid_as_scalar_index (void) const;
-  bool valid_as_zero_index (void) const;
 
-  bool is_true (void) const;
+  double double_value (bool = false) const;
 
-  bool is_empty (void) const { return (rows () == 0 && columns () == 0); }
-
-  double double_value (bool) const;
+  double scalar_value (bool frc_str_conv = false) const
+    { return double_value (frc_str_conv); }
 
   Matrix matrix_value (bool = false) const;
 
@@ -118,42 +98,15 @@ public:
 
   ComplexMatrix complex_matrix_value (bool = false) const;
 
-  octave_value not (void) const { return octave_value (! matrix); }
-
-  octave_value uminus (void) const { return octave_value (- matrix); }
-
-  octave_value transpose (void) const
-    { return octave_value (matrix.transpose ()); }
-
-  octave_value hermitian (void) const
-    { return octave_value (matrix.hermitian ()); }
-
   void increment (void) { matrix += Complex (1.0); }
 
   void decrement (void) { matrix -= Complex (1.0); }
 
-  void print (ostream& os, bool pr_as_read_syntax = false);
-
-  int type_id (void) const { return t_id; }
-
-  string type_name (void) const { return t_name; }
-
-  static int static_type_id (void) { return t_id; }
-
-  static void register_type (void)
-    { t_id = octave_value_typeinfo::register_type (t_name); }
-
 private:
 
-  ComplexMatrix matrix;
+  DECLARE_OCTAVE_ALLOCATOR
 
-  static octave_allocator allocator;
-
-  // Type id of complex matrix objects, set by register_type().
-  static int t_id;
-
-  // Type name of complex matrix objects, defined in ov-cx-mat.cc.
-  static const string t_name;
+  DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA
 };
 
 #endif
