@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,19 +29,18 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <cstdlib>
 
+#include <iostream>
 #include <string>
 
-class ostream;
-
 #include "Range.h"
 
+#include "lo-mappers.h"
 #include "lo-utils.h"
 #include "mx-base.h"
 #include "oct-alloc.h"
 #include "str-vec.h"
 
 #include "error.h"
-#include "mappers.h"
 #include "ov-base.h"
 #include "ov-typeinfo.h"
 
@@ -81,25 +80,23 @@ public:
 
   octave_value *clone (void) { return new octave_range (*this); }
 
-  void *operator new (size_t size)
-    { return allocator.alloc (size); }
-
-  void operator delete (void *p, size_t size)
-    { allocator.free (p, size); }
-
   type_conv_fcn numeric_conversion_function (void) const;
 
   octave_value *try_narrowing_conversion (void);
 
-  octave_value index (const octave_value_list& idx) const;
+  octave_value do_index_op (const octave_value_list& idx);
 
   idx_vector index_vector (void) const { return idx_vector (range); }
 
   int rows (void) const { return (columns () > 0); }
   int columns (void) const { return range.nelem (); }
 
+  int length (void) const { return range.nelem (); }
+
   bool is_defined (void) const { return true; }
 
+  bool is_constant (void) const { return true; }
+
   bool is_range (void) const { return true; }
 
   // XXX DO ME XXX
@@ -122,53 +119,41 @@ public:
 	      && NINT (range.base ()) == 0);
     }
 
+  bool is_numeric_type (void) const { return true; }
+
   // XXX DO ME XXX
   bool is_true (void) const;
 
-  double double_value (bool) const;
+  double double_value (bool = false) const;
+
+  double scalar_value (bool frc_str_conv = false) const
+    { return double_value (frc_str_conv); }
 
   Matrix matrix_value (bool = false) const
     { return range.matrix_value (); }
 
-  Complex complex_value (bool) const;
+  Complex complex_value (bool = false) const;
 
-  ComplexMatrix complex_matrix_value (bool) const
-    { return range.matrix_value (); }
+  ComplexMatrix complex_matrix_value (bool = false) const
+    { return ComplexMatrix (range.matrix_value ()); }
 
   Range range_value (void) const { return range; }
 
-  octave_value not (void) const;
-
-  octave_value uminus (void) const { return octave_value (- range); }
-
-  octave_value transpose (void) const;
-
-  octave_value hermitian (void) const;
-
   octave_value convert_to_str (void) const;
 
-  void print (ostream& os, bool pr_as_read_syntax = false);
+  void print (std::ostream& os, bool pr_as_read_syntax = false) const;
 
-  int type_id (void) const { return t_id; }
+  void print_raw (std::ostream& os, bool pr_as_read_syntax = false) const;
 
-  string type_name (void) const { return t_name; }
-
-  static int static_type_id (void) { return t_id; }
-
-  static void register_type (void)
-    { t_id = octave_value_typeinfo::register_type (t_name); }
+  bool print_name_tag (std::ostream& os, const std::string& name) const;
 
 private:
 
   Range range;
 
-  static octave_allocator allocator;
+  DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA
 
-  // Type id of range objects, set by register_type ().
-  static int t_id;
-
-  // Type name of scalar objects, defined in ov-range.cc.
-  static const string t_name;
+  DECLARE_OCTAVE_ALLOCATOR
 };
 
 #endif
