@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,38 +28,29 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
+#include <iostream>
+
 #include "lo-ieee.h"
 #include "lo-utils.h"
 #include "mx-base.h"
 
 #include "gripes.h"
-#include "mappers.h"
 #include "oct-obj.h"
+#include "oct-lvalue.h"
 #include "ops.h"
+#include "ov-base.h"
+#include "ov-base-mat.h"
+#include "ov-base-mat.cc"
 #include "ov-scalar.h"
 #include "ov-re-mat.h"
 #include "pr-output.h"
+#include "variables.h"
 
-octave_allocator
-octave_matrix::allocator (sizeof (octave_matrix));
+template class octave_base_matrix<Matrix>;
 
-int
-octave_matrix::t_id (-1);
+DEFINE_OCTAVE_ALLOCATOR (octave_matrix);
 
-const string
-octave_matrix::t_name ("matrix");
-
-octave_matrix::octave_matrix (const RowVector& v, int pcv)
-  : octave_base_value (),
-    matrix ((pcv < 0 && Vprefer_column_vectors) || pcv
-	    ? Matrix (v.transpose ()) : Matrix (v)) { }
-
-octave_matrix::octave_matrix (const ColumnVector& v, int pcv)
-  : octave_base_value (),
-    matrix ((pcv < 0 && Vprefer_column_vectors) || pcv
-	    ? Matrix (v) : Matrix (v.transpose ())) { }
-
-#include <iostream.h>
+DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_matrix, "matrix");
 
 octave_value *
 octave_matrix::try_narrowing_conversion (void)
@@ -75,44 +66,6 @@ octave_matrix::try_narrowing_conversion (void)
   return retval;
 }
 
-octave_value
-octave_matrix::index (const octave_value_list& idx) const
-{
-  octave_value retval;
-
-  int len = idx.length ();
-
-  switch (len)
-    {
-    case 2:
-      {
-	idx_vector i = idx (0).index_vector ();
-	idx_vector j = idx (1).index_vector ();
-
-	retval = Matrix (matrix.index (i, j));
-      }
-      break;
-
-    case 1:
-      {
-	idx_vector i = idx (0).index_vector ();
-
-	retval = Matrix (matrix.index (i));
-      }
-      break;
-
-    default:
-      error ("invalid number of indices (%d) for matrix value", len);
-      break;
-    }
-
-  return retval;
-}
-
-#if !defined (CXX_NEW_FRIEND_TEMPLATE_DECL)
-extern void assign (Array2<double>&, const Array2<double>&);
-#endif
-
 void
 octave_matrix::assign (const octave_value_list& idx, const Matrix& rhs)
 {
@@ -156,30 +109,6 @@ octave_matrix::valid_as_scalar_index (void) const
   return false;
 }
 
-bool
-octave_matrix::is_true (void) const
-{
-  bool retval = false;
-
-  if (rows () == 0 || columns () == 0)
-    {
-      int flag = Vpropagate_empty_matrices;
-
-      if (flag < 0)
-	warning ("empty matrix used in conditional expression");
-      else if (flag == 0)
-	error ("empty matrix used in conditional expression");
-    }
-  else
-    {
-      Matrix m = (matrix.all ()) . all ();
-
-      retval = (m.rows () == 1 && m.columns () == 1 && m (0, 0) != 0.0);
-    }
-
-  return retval;
-}
-
 double
 octave_matrix::double_value (bool) const
 {
@@ -262,12 +191,6 @@ octave_matrix::convert_to_str (void) const
   return retval;
 }
 
-void
-octave_matrix::print (ostream& os, bool pr_as_read_syntax)
-{
-  octave_print_internal (os, matrix, pr_as_read_syntax, struct_indent);
-}
-
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
