@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,17 +29,17 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <cstdlib>
 
+#include <iostream>
 #include <string>
 
-class ostream;
-
+#include "lo-mappers.h"
 #include "lo-utils.h"
 #include "mx-base.h"
 #include "oct-alloc.h"
 #include "str-vec.h"
 
-#include "mappers.h"
 #include "ov-base.h"
+#include "ov-base-scalar.h"
 #include "ov-typeinfo.h"
 
 class Octave_map;
@@ -50,45 +50,30 @@ class tree_walker;
 // Real scalar values.
 
 class
-octave_scalar : public octave_base_value
+octave_scalar : public octave_base_scalar<double>
 {
 public:
 
   octave_scalar (void)
-    : octave_base_value (), scalar (0.0) { }
+    : octave_base_scalar<double> (0.0) { }
 
   octave_scalar (double d)
-    : octave_base_value (), scalar (d) { }
+    : octave_base_scalar<double> (d) { }
 
   octave_scalar (const octave_scalar& s)
-    : octave_base_value (), scalar (s.scalar) { }
+    : octave_base_scalar<double> (s) { }
 
   ~octave_scalar (void) { }
 
   octave_value *clone (void) { return new octave_scalar (*this); }
 
-  void *operator new (size_t size)
-    { return allocator.alloc (size); }
-
-  void operator delete (void *p, size_t size)
-    { allocator.free (p, size); }
-
-  octave_value index (const octave_value_list& idx) const;
+  octave_value do_index_op (const octave_value_list& idx);
 
   idx_vector index_vector (void) const { return idx_vector (scalar); }
 
-  int rows (void) const { return 1; }
-  int columns (void) const { return 1; }
-
-  bool is_defined (void) const { return true; }
   bool is_real_scalar (void) const { return true; }
 
-  octave_value all (void) const { return (double) (scalar != 0.0); }
-  octave_value any (void) const { return (double) (scalar != 0.0); }
-
   bool is_real_type (void) const { return true; }
-  bool is_scalar_type (void) const { return true; }
-  bool is_numeric_type (void) const { return true; }
 
   bool valid_as_scalar_index (void) const
     { return (! xisnan (scalar) && NINT (scalar) == 1); }
@@ -96,55 +81,29 @@ public:
   bool valid_as_zero_index (void) const
     { return (! xisnan (scalar) && NINT (scalar) == 0); }
 
-  bool is_true (void) const { return (scalar != 0.0); }
-
   double double_value (bool = false) const { return scalar; }
 
-  Matrix matrix_value (bool = false) const { return Matrix (1, 1, scalar); }
+  double scalar_value (bool = false) const { return scalar; }
+
+  Matrix matrix_value (bool = false) const
+    { return Matrix (1, 1, scalar); }
 
   Complex complex_value (bool = false) const { return scalar; }
 
   ComplexMatrix complex_matrix_value (bool = false) const
     { return  ComplexMatrix (1, 1, Complex (scalar)); }
 
-  octave_value not (void) const { return (double) (! scalar); }
-
-  octave_value uminus (void) const { return octave_value (- scalar); }
-
-  octave_value transpose (void) const { return octave_value (scalar); }
-
-  octave_value hermitian (void) const { return octave_value (scalar); }
+  octave_value convert_to_str (void) const;
 
   void increment (void) { ++scalar; }
 
   void decrement (void) { --scalar; }
 
-  octave_value convert_to_str (void) const;
-
-  void print (ostream& os, bool pr_as_read_syntax = false);
-
-  int type_id (void) const { return t_id; }
-
-  string type_name (void) const { return t_name; }
-
-  static int static_type_id (void) { return t_id; }
-
-  static void register_type (void)
-    { t_id = octave_value_typeinfo::register_type (t_name); }
-
 private:
 
-  // The value of this scalar.
-  double scalar;
+  DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA
 
-  // For custom memory management.
-  static octave_allocator allocator;
-
-  // Type id of scalar objects, set by register_type().
-  static int t_id;
-
-  // Type name of scalar objects, defined in ov-scalar.cc.
-  static const string t_name;
+  DECLARE_OCTAVE_ALLOCATOR
 };
 
 #endif
