@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,14 +29,14 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <cstdlib>
 
+#include <iostream>
 #include <string>
 
-class ostream;
-
 #include "mx-base.h"
 #include "str-vec.h"
 
 #include "error.h"
+#include "ov.h"
 #include "ov-ch-mat.h"
 #include "ov-typeinfo.h"
 
@@ -59,10 +59,13 @@ public:
   octave_char_matrix_str (const charMatrix& chm)
     : octave_char_matrix (chm) { }
 
+  octave_char_matrix_str (char c)
+    : octave_char_matrix (c) { }
+
   octave_char_matrix_str (const char *s)
     : octave_char_matrix (s) { }
 
-  octave_char_matrix_str (const string& s)
+  octave_char_matrix_str (const std::string& s)
     : octave_char_matrix (s) { }
 
   octave_char_matrix_str (const string_vector& s)
@@ -80,47 +83,35 @@ public:
 
   type_conv_fcn numeric_conversion_function (void) const;
 
-  octave_value index (const octave_value_list& idx) const;
+  octave_value do_index_op (const octave_value_list& idx);
 
   void assign (const octave_value_list& idx, const charMatrix& rhs);
 
   bool is_string (void) const { return true; }
 
-  bool is_real_type (void) const { return true; }
+  bool is_real_type (void) const { return Vimplicit_str_to_num_ok; }
+
+  bool is_matrix_type (void) const { return Vimplicit_str_to_num_ok; }
+
+  bool is_numeric_type (void) const { return Vimplicit_str_to_num_ok; }
 
   bool valid_as_scalar_index (void) const;
-  bool valid_as_zero_index (void) const;
 
   Matrix matrix_value (bool = false) const;
 
   string_vector all_strings (void) const;
 
-  string string_value (void) const;
+  std::string string_value (void) const;
 
-  octave_value transpose (void) const
-    { return octave_value (matrix.transpose (), true); }
+  bool print_as_scalar (void) const { return (rows () <= 1); }
 
-  octave_value hermitian (void) const
-    { return octave_value (matrix.transpose (), true); }
-
-  void print (ostream& os, bool pr_as_read_syntax = false);
-
-  int type_id (void) const { return t_id; }
-
-  string type_name (void) const { return t_name; }
-
-  static int static_type_id (void) { return t_id; }
-
-  static void register_type (void)
-    { t_id = octave_value_typeinfo::register_type (t_name); }
+  void print_raw (std::ostream& os, bool pr_as_read_syntax = false) const;
 
 private:
 
-  // Type id of char_matrix_str objects, set by register_type().
-  static int t_id;
+  DECLARE_OCTAVE_ALLOCATOR
 
-  // Type name of char_matrix_strXX objects, defined in ov-str-mat.cc.
-  static const string t_name;
+  DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA
 };
 
 #endif
