@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -42,17 +42,40 @@ octave_value_typeinfo
 {
 public:
 
-  static int register_type (const string&);
+  static bool instance_ok (void);
+
+  static int register_type (const std::string&);
+
+  static bool register_unary_op (octave_value::unary_op, int, unary_op_fcn);
+
+  static bool register_non_const_unary_op (octave_value::unary_op, int,
+					   non_const_unary_op_fcn);
 
   static bool register_binary_op (octave_value::binary_op, int, int,
 				  binary_op_fcn);
 
-  static bool register_assign_op (int, int, assign_op_fcn);
+  static bool register_assign_op (octave_value::assign_op, int, int,
+				  assign_op_fcn);
+
+  static bool register_assignany_op (octave_value::assign_op, int,
+				     assign_op_fcn);
 
   static bool register_pref_assign_conv (int, int, int);
 
   static bool register_widening_op (int, int, type_conv_fcn);
 
+  static unary_op_fcn
+  lookup_unary_op (octave_value::unary_op op, int t)
+  {
+    return instance->do_lookup_unary_op (op, t);
+  }
+
+  static non_const_unary_op_fcn
+  lookup_non_const_unary_op (octave_value::unary_op op, int t)
+  {
+    return instance->do_lookup_non_const_unary_op (op, t);
+  }
+
   static binary_op_fcn
   lookup_binary_op (octave_value::binary_op op, int t1, int t2)
   {
@@ -60,9 +83,15 @@ public:
   }
 
   static assign_op_fcn
-  lookup_assign_op (int t_lhs, int t_rhs)
+  lookup_assign_op (octave_value::assign_op op, int t_lhs, int t_rhs)
   {
-    return instance->do_lookup_assign_op (t_lhs, t_rhs);
+    return instance->do_lookup_assign_op (op, t_lhs, t_rhs);
+  }
+
+  static assign_op_fcn
+  lookup_assignany_op (octave_value::assign_op op, int t_lhs)
+  {
+    return instance->do_lookup_assignany_op (op, t_lhs);
   }
 
   static int
@@ -85,10 +114,17 @@ public:
 protected:
 
   octave_value_typeinfo (void)
-    : num_types (0), types (init_tab_sz, string ()),
+    : num_types (0), types (init_tab_sz, std::string ()),
+      unary_ops (octave_value::num_unary_ops, init_tab_sz,
+		 (unary_op_fcn) 0),
+      non_const_unary_ops (octave_value::num_unary_ops, init_tab_sz,
+			   (non_const_unary_op_fcn) 0),
       binary_ops (octave_value::num_binary_ops, init_tab_sz,
 		  init_tab_sz, (binary_op_fcn) 0),
-      assign_ops (init_tab_sz, init_tab_sz, (assign_op_fcn) 0),
+      assign_ops (octave_value::num_assign_ops, init_tab_sz,
+		  init_tab_sz, (assign_op_fcn) 0),
+      assignany_ops (octave_value::num_assign_ops, init_tab_sz,
+		     (assign_op_fcn) 0),
       pref_assign_conv (init_tab_sz, init_tab_sz, -1),
       widening_ops (init_tab_sz, init_tab_sz, (type_conv_fcn) 0)  { }
 
@@ -100,31 +136,52 @@ private:
 
   int num_types;
 
-  Array<string> types;
+  Array<std::string> types;
+
+  Array2<unary_op_fcn> unary_ops;
+
+  Array2<non_const_unary_op_fcn> non_const_unary_ops;
 
   Array3<binary_op_fcn> binary_ops;
 
-  Array2<assign_op_fcn> assign_ops;
+  Array3<assign_op_fcn> assign_ops;
+
+  Array2<assign_op_fcn> assignany_ops;
 
   Array2<int> pref_assign_conv;
 
   Array2<type_conv_fcn> widening_ops;
 
-  int do_register_type (const string&);
+  int do_register_type (const std::string&);
+
+  bool do_register_unary_op (octave_value::unary_op, int, unary_op_fcn);
+
+  bool do_register_non_const_unary_op (octave_value::unary_op, int,
+				       non_const_unary_op_fcn);
 
   bool do_register_binary_op (octave_value::binary_op, int, int,
 			      binary_op_fcn);
 
-  bool do_register_assign_op (int, int, assign_op_fcn);
+  bool do_register_assign_op (octave_value::assign_op, int, int,
+			      assign_op_fcn);
+
+  bool do_register_assignany_op (octave_value::assign_op, int,
+				 assign_op_fcn);
 
   bool do_register_pref_assign_conv (int, int, int);
 
   bool do_register_widening_op (int, int, type_conv_fcn);
 
-  binary_op_fcn
-  do_lookup_binary_op (octave_value::binary_op, int, int);
+  unary_op_fcn do_lookup_unary_op (octave_value::unary_op, int);
 
-  assign_op_fcn do_lookup_assign_op (int, int);
+  non_const_unary_op_fcn do_lookup_non_const_unary_op
+    (octave_value::unary_op, int);
+
+  binary_op_fcn do_lookup_binary_op (octave_value::binary_op, int, int);
+
+  assign_op_fcn do_lookup_assign_op (octave_value::assign_op, int, int);
+
+  assign_op_fcn do_lookup_assignany_op (octave_value::assign_op, int);
 
   int do_lookup_pref_assign_conv (int, int);
 
