@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,18 +28,23 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <iostream>
 
 #include "error.h"
 #include "pr-output.h"
 #include "ov-va-args.h"
 
-int octave_all_va_args::t_id = -1;
-
-const string octave_all_va_args::t_name ("va-arg");
+DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA (octave_all_va_args, "va-arg");
 
 void
-octave_all_va_args::print (ostream& os, bool)
+octave_all_va_args::print (std::ostream& os, bool) const
+{
+  indent (os);
+  print (os);
+}
+
+void
+octave_all_va_args::print_raw (std::ostream& os, bool) const
 {
   os << "all_va_args";
 }
