@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -24,12 +24,11 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <csignal>
-
+#include <fstream>
 #include <string>
-#include <fstream.h>
 
-#include "oct-term.h"
+#include "cmd-edit.h"
+#include "oct-env.h"
 
 #include "procstream.h"
 
@@ -37,7 +36,6 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "defun.h"
 #include "error.h"
 #include "gripes.h"
-#include "help.h"
 #include "input.h"
 #include "oct-obj.h"
 #include "pager.h"
@@ -51,17 +49,17 @@ static pid_t octave_pager_pid = -1;
 // Our actual connection to the external pager.
 static oprocstream *external_pager = 0;
 
-// Nonzero means we write to the diary file.
-static int write_to_diary_file = 0;
+// TRUE means we write to the diary file.
+static bool write_to_diary_file = false;
 
 // The name of the current diary file.
-static string diary_file;
+static std::string diary_file;
 
 // The diary file.
-static ofstream external_diary_file;
+static std::ofstream external_diary_file;
 
 // The shell command to run as the pager.
-static string Vpager_binary;
+static std::string Vpager_binary;
 
 // TRUE means that if output is going to the pager, it is sent as soon
 // as it is available.  Otherwise, it is buffered and only sent to the
@@ -77,9 +75,9 @@ static bool Vpage_screen_output;
 static octave_interrupt_handler saved_interrupt_handler;
 static bool interrupt_handler_saved = false;
 
-static int really_flush_to_pager = 0;
+static bool really_flush_to_pager = false;
 
-static int flushing_output_to_pager = 0;
+static bool flushing_output_to_pager = false;
 
 static void
 clear_external_pager (void)
@@ -108,7 +106,7 @@ pager_death_handler (pid_t pid, int status)
 	  // Avoid warning() or error(), since that will put us back in
 	  // the pager, which would be bad news.
 
-	  cerr << "warning: connection to external pager (pid = "
+	  std::cerr << "warning: connection to external pager (pid = "
 	       << pid << ") lost --\n"
 	       << "warning: attempting to finish pending computations...\n";
 	}
@@ -122,14 +120,14 @@ do_sync (const char *msg, int len, bool bypass_pager)
     {
       if (bypass_pager)
 	{
-	  cout.write (msg, len);
-	  cout.flush ();
+	  std::cout.write (msg, len);
+	  std::cout.flush ();
 	}
       else
 	{
 	  if (! external_pager)
 	    {
-	      string pgr = Vpager_binary;
+	      std::string pgr = Vpager_binary;
 
 	      if (! pgr.empty ())
 		{
@@ -178,8 +176,8 @@ do_sync (const char *msg, int len, bool bypass_pager)
 	    }
 	  else
 	    {
-	      cout.write (msg, len);
-	      cout.flush ();
+	      std::cout.write (msg, len);
+	      std::cout.flush ();
 	    }
 	}
     }
@@ -192,9 +190,9 @@ more_than_a_screenful (const char *s, int len)
 {
   if (s)
     {
-      int available_rows = terminal_rows () - 2;
+      int available_rows = command_editor::terminal_rows () - 2;
 
-      int cols = terminal_columns ();
+      int cols = command_editor::terminal_cols ();
 
       int count = 0;
 
@@ -212,7 +210,7 @@ more_than_a_screenful (const char *s, int len)
 	}
 
       if (count > available_rows)
-	return true;
+ 	return true;
     }
 
   return false;
@@ -241,15 +239,33 @@ octave_pager_buf::sync (void)
 	{
 	  do_sync (buf, len, bypass_pager);
 
-	  seekoff (0, ios::beg);
+	  seekoff (0, std::ios::beg);
 
-	  octave_diary.write (buf, len);
+	  flush_current_contents_to_diary ();
 	}
     }
 
   return 0;
 }
 
+void
+octave_pager_buf::flush_current_contents_to_diary (void)
+{
+  char *buf = eback () + diary_skip;
+
+  size_t len = pptr () - buf;
+
+  octave_diary.write (buf, len);
+
+  diary_skip = 0;  
+}
+
+void
+octave_pager_buf::set_diary_skip (void)
+{
+  diary_skip = pptr () - eback ();
+}
+
 int
 octave_diary_buf::sync (void)
 {
@@ -261,14 +277,14 @@ octave_diary_buf::sync (void)
 	external_diary_file.write (eback (), len);
     }
 
-  seekoff (0, ios::beg);
+  seekoff (0, std::ios::beg);
 
   return 0;
 }
 
 octave_pager_stream *octave_pager_stream::instance = 0;
 
-octave_pager_stream::octave_pager_stream (void) : ostream (), pb (0)
+octave_pager_stream::octave_pager_stream (void) : std::ostream (0), pb (0)
 {
   pb = new octave_pager_buf;
   rdbuf (pb);
@@ -286,13 +302,27 @@ octave_pager_stream::stream (void)
 {
   if (! instance)
     instance = new octave_pager_stream ();
-      
+
   return *instance;
 }
 
+void
+octave_pager_stream::flush_current_contents_to_diary (void)
+{
+  if (pb)
+    pb->flush_current_contents_to_diary ();
+}
+
+void
+octave_pager_stream::set_diary_skip (void)
+{
+  if (pb)
+    pb->set_diary_skip ();
+}
+
 octave_diary_stream *octave_diary_stream::instance = 0;
 
-octave_diary_stream::octave_diary_stream (void) : ostream (), db (0)
+octave_diary_stream::octave_diary_stream (void) : std::ostream (0), db (0)
 {
   db = new octave_diary_buf;
   rdbuf (db);
@@ -319,26 +349,39 @@ flush_octave_stdout (void)
 {
   if (! flushing_output_to_pager)
     {
-      begin_unwind_frame ("flush_octave_stdout");
+      unwind_protect::begin_frame ("flush_octave_stdout");
 
-      unwind_protect_int (really_flush_to_pager);
-      unwind_protect_int (flushing_output_to_pager);
+      unwind_protect_bool (really_flush_to_pager);
+      unwind_protect_bool (flushing_output_to_pager);
 
-      really_flush_to_pager = 1;
-      flushing_output_to_pager = 1;
+      really_flush_to_pager = true;
+      flushing_output_to_pager = true;
 
       octave_stdout.flush ();
 
       if (external_pager)
 	clear_external_pager ();
 
-      run_unwind_frame ("flush_octave_stdout");
+      unwind_protect::run_frame ("flush_octave_stdout");
     }
 }
 
 static void
 close_diary_file (void)
 {
+  // Try to flush the current buffer to the diary now, so that things
+  // like
+  //
+  // function foo ()
+  //   diary on;
+  //   ...
+  //   diary off;
+  // endfunction
+  //
+  // will do the right thing.
+
+  octave_stdout.flush_current_contents_to_diary ();
+
   if (external_diary_file.is_open ())
     {
       octave_diary.flush ();
@@ -351,17 +394,37 @@ open_diary_file (void)
 {
   close_diary_file ();
 
-  external_diary_file.open (diary_file.c_str (), ios::app);
+  // If there is pending output in the pager buf, it should not go
+  // into the diary file.
+ 
+  octave_stdout.set_diary_skip ();
+
+  external_diary_file.open (diary_file.c_str (), std::ios::app);
 
   if (! external_diary_file)
     error ("diary: can't open diary file `%s'", diary_file.c_str ());
 }
 
 DEFUN_TEXT (diary, args, ,
-  "diary [on|off]\n\
-diary [file]\n\
+  "-*- texinfo -*-\n\
+@deffn {Command} diary options\n\
+Create a list of all commands @emph{and} the output they produce, mixed\n\
+together just as you see them on your terminal.  Valid options are:\n\
 \n\
-redirect all input and screen output to a file.")
+@table @code\n\
+@item on\n\
+Start recording your session in a file called @file{diary} in your\n\
+current working directory.\n\
+\n\
+@item off\n\
+Stop recording your session in the diary file.\n\
+\n\
+@item @var{file}\n\
+Record your session in the file named @var{file}.\n\
+@end table\n\
+\n\
+Without any arguments, @code{diary} toggles the current diary state.\n\
+@end deffn")
 {
   octave_value_list retval;
 
@@ -384,22 +447,22 @@ redirect all input and screen output to a file.")
 
     case 2:
       {
-	string arg = argv[1];
+	std::string arg = argv[1];
 
 	if (arg == "on")
 	  {
-	    write_to_diary_file = 1;
+	    write_to_diary_file = true;
 	    open_diary_file ();
 	  }	
 	else if (arg == "off")
 	  {
 	    close_diary_file ();
-	    write_to_diary_file = 0;
+	    write_to_diary_file = false;
 	  }
 	else
 	  {
 	    diary_file = arg;
-	    write_to_diary_file = 1;
+	    write_to_diary_file = true;
 	    open_diary_file ();
 	  }
       }
@@ -414,10 +477,13 @@ redirect all input and screen output to a file.")
 }
 
 DEFUN_TEXT (more, args, ,
-  "more on\n\
-more off\n\
-\n\
-Turn output pagination on or off.")
+  "-*- texinfo -*-\n\
+@deffn {Command} more\n\
+@deffnx {Command} more on\n\
+@deffnx {Command} more off\n\
+Turn output pagination on or off.  Without an argument, @code{more}\n\
+toggles the current state.\n\
+@end deffn")
 {
   octave_value_list retval;
 
@@ -430,7 +496,7 @@ Turn output pagination on or off.")
 
   if (argc == 2)
     {
-      string arg = argv[1];
+      std::string arg = argv[1];
 
       if (arg == "on")
 	bind_builtin_variable ("page_screen_output", 1.0);
@@ -445,25 +511,22 @@ Turn output pagination on or off.")
   return retval;
 }
 
-static string
+static std::string
 default_pager (void)
 {
-  string pager_binary;
+  std::string pager_binary = octave_env::getenv ("PAGER");
 
-  char *pgr = getenv ("PAGER");
-
-  if (pgr)
-    pager_binary = string (pgr);
-#ifdef DEFAULT_PAGER
-  else
+#ifdef OCTAVE_DEFAULT_PAGER
+  if (pager_binary.empty ())
     {
-      pager_binary = string (DEFAULT_PAGER);
+      pager_binary = std::string (OCTAVE_DEFAULT_PAGER);
 
       if (pager_binary == "less")
 	{
 	  pager_binary.append (" -e");
 
-	  if (! getenv ("LESS"))
+	  std::string lessflags = octave_env::getenv ("LESS");
+	  if (lessflags.empty ())
 	    pager_binary.append
 	      (" -P'-- less ?pB(%pB\\%):--. (f)orward, (b)ack, (q)uit$'");
 	}
@@ -478,7 +541,7 @@ pager_binary (void)
 {
   int status = 0;
 
-  string s = builtin_string_variable ("PAGER");
+  std::string s = builtin_string_variable ("PAGER");
 
   if (s.empty ())
     {
@@ -510,14 +573,36 @@ page_screen_output (void)
 void
 symbols_of_pager (void)
 {
-  DEFVAR (PAGER, default_pager (), 0, pager_binary,
-    "path to pager binary");
+  DEFVAR (PAGER, default_pager (), pager_binary,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} PAGER\n\
+The default value is normally @code{\"less\"}, @code{\"more\"}, or\n\
+@code{\"pg\"}, depending on what programs are installed on your system.\n\
+@xref{Installation}.\n\
+\n\
+When running interactively, Octave sends any output intended for your\n\
+terminal that is more than one screen long to the program named by the\n\
+value of the variable @code{PAGER}.\n\
+@end defvr");
 
-  DEFVAR (page_output_immediately, 0.0, 0, page_output_immediately,
-    "if paging output, start sending it as soon as it is available");
+  DEFVAR (page_output_immediately, 0.0, page_output_immediately,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} page_output_immediately\n\
+If the value of @code{page_output_immediately} is nonzero, Octave sends\n\
+output to the pager as soon as it is available.  Otherwise, Octave\n\
+buffers its output and waits until just before the prompt is printed to\n\
+flush it to the pager.  The default value is 0.\n\
+@end defvr");
 
-  DEFVAR (page_screen_output, 1.0, 0, page_screen_output,
-    "if possible, send output intended for the screen through the pager");
+  DEFVAR (page_screen_output, 1.0, page_screen_output,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} page_screen_output\n\
+If the value of @code{page_screen_output} is nonzero, all output\n\
+intended for the screen that is longer than one page is sent through a\n\
+pager.  This allows you to view one screenful at a time.  Some pagers\n\
+(such as @code{less}---see @ref{Installation}) are also capable of moving\n\
+backward on the output.  The default value is 1.\n\
+@end defvr");
 }
 
 /*
