@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,29 +23,37 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_pager_h)
 #define octave_pager_h 1
 
+#include <iostream>
+#include <strstream>
 #include <string>
 
-#include <iostream.h>
-#include <strstream.h>
-
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
 
 class
-octave_pager_buf : public strstreambuf
+octave_pager_buf : public std::strstreambuf
 {
 public:
 
-  octave_pager_buf (int size = 0) : strstreambuf (size) { }
+  octave_pager_buf (int size = 0)
+    : std::strstreambuf (size), diary_skip (0) { }
+
+  void flush_current_contents_to_diary (void);
+
+  void set_diary_skip (void);
 
 protected:
 
   int sync (void);
+
+private:
+
+  size_t diary_skip;
 };
 
 class
-octave_pager_stream : public ostream
+octave_pager_stream : public std::ostream
 {
 protected:
 
@@ -55,6 +63,10 @@ public:
 
   ~octave_pager_stream (void);
 
+  void flush_current_contents_to_diary (void);
+
+  void set_diary_skip (void);
+
   static octave_pager_stream& stream (void);
 
 private:
@@ -71,11 +83,11 @@ private:
 };
 
 class
-octave_diary_buf : public strstreambuf
+octave_diary_buf : public std::strstreambuf
 {
 public:
 
-  octave_diary_buf (int size = 0) : strstreambuf (size) { }
+  octave_diary_buf (int size = 0) : std::strstreambuf (size) { }
 
 protected:
 
@@ -83,7 +95,7 @@ protected:
 };
 
 class
-octave_diary_stream : public ostream
+octave_diary_stream : public std::ostream
 {
 protected:
 
@@ -114,8 +126,6 @@ private:
 
 extern void flush_octave_stdout (void);
 
-extern void symbols_of_pager (void);
-
 #endif
 
 /*
