@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,25 +29,25 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <cstdio>
 #include <cstring>
 
+#include <iomanip>
+#include <iostream>
+#include <strstream>
 #include <string>
 
-#include <iostream.h>
-#include <strstream.h>
-
 #include "CMatrix.h"
 #include "Range.h"
+#include "cmd-edit.h"
 #include "dMatrix.h"
+#include "lo-mappers.h"
 #include "mach-info.h"
 #include "oct-cmplx.h"
-#include "oct-term.h"
 #include "str-vec.h"
 
 #include "defun.h"
 #include "error.h"
 #include "gripes.h"
-#include "help.h"
-#include "mappers.h"
 #include "oct-obj.h"
+#include "oct-stream.h"
 #include "pager.h"
 #include "pr-output.h"
 #include "sysdep.h"
@@ -74,38 +74,133 @@ static bool Vprint_empty_dimensions;
 // smaller slices that fit on the screen.
 static bool Vsplit_long_rows;
 
-// Current format string for real numbers and the real part of complex
-// numbers.
-static char *curr_real_fmt = 0;
-
-// Current format string for the imaginary part of complex numbers.
-static char *curr_imag_fmt = 0;
-
-// Nonzero means don't do any fancy formatting.
+// TRUE means don't do any fancy formatting.
 static bool free_format = false;
 
-// Nonzero means print plus sign for nonzero, blank for zero.
+// TRUE means print plus sign for nonzero, blank for zero.
 static bool plus_format = false;
 
-// Nonzero means always print like dollars and cents.
+// TRUE means always print like dollars and cents.
 static bool bank_format = false;
 
-// Nonzero means print data in hexadecimal format.
-static bool hex_format = false;
+// TRUE means print data in hexadecimal format.
+static int hex_format = 0;
 
-// Nonzero means print data in binary-bit-pattern format.
+// TRUE means print data in binary-bit-pattern format.
 static int bit_format = 0;
 
-// Nonzero means don't put newlines around the column number headers.
+// TRUE means don't put newlines around the column number headers.
 static bool compact_format = false;
 
-// Nonzero means use an e format.
+// TRUE means use an e format.
 static bool print_e = false;
 
-// Nonzero means print E instead of e for exponent field.
+// TRUE means print E instead of e for exponent field.
 static bool print_big_e = false;
 
-// XXX FIXME XXX -- these should probably be somewhere else.
+class pr_formatted_float;
+
+class
+float_format
+{
+public:
+
+  float_format (int w = -1, int p = -1, int f = 0)
+    : fw (w), prec (p), fmt (f), up (0), sp (0) { }
+
+  float_format (const float_format& ff)
+    : fw (ff.fw), prec (ff.prec), fmt (ff.fmt), up (ff.up), sp (ff.sp) { }
+
+  float_format& operator = (const float_format& ff)
+    {
+      if (&ff != this)
+	{
+	  fw = ff.fw;
+	  prec = ff.prec;
+	  fmt = ff.fmt;
+	  up = ff.up;
+	  sp = ff.sp;
+	}
+
+      return *this;
+    }
+
+  ~float_format (void) { }
+
+  float_format& scientific (void) { fmt = std::ios::scientific; return *this; }
+  float_format& fixed (void) { fmt = std::ios::fixed; return *this; }
+  float_format& general (void) { fmt = 0; return *this; }
+
+  float_format& uppercase (void) { up = std::ios::uppercase; return *this; }
+  float_format& lowercase (void) { up = 0; return *this; }
+
+  float_format& precision (int p) { prec = p; return *this; }
+
+  float_format& width (int w) { fw = w; return *this; }
+
+  float_format& trailing_zeros (bool tz = true)
+    { sp = tz ? std::ios::showpoint : 0; return *this; }
+
+  friend std::ostream& operator << (std::ostream& os,
+				    const pr_formatted_float& pff);
+
+private:
+
+  // Field width.  Zero means as wide as necessary.
+  int fw;
+
+  // Precision.
+  int prec;
+
+  // Format.
+  int fmt;
+
+  // E or e.
+  int up;
+
+  // Show trailing zeros.
+  int sp;
+};
+
+class
+pr_formatted_float
+{
+public:
+
+  const float_format& f;
+
+  double val;
+
+  pr_formatted_float (const float_format& f_arg, double val_arg)
+    : f (f_arg), val (val_arg) { }
+};
+
+std::ostream&
+operator << (std::ostream& os, const pr_formatted_float& pff)
+{
+  if (pff.f.fw >= 0)
+    os << std::setw (pff.f.fw);
+
+  if (pff.f.prec >= 0)
+    os << std::setprecision (pff.f.prec);
+
+  std::ios::fmtflags oflags = 
+    os.flags (static_cast<std::ios::fmtflags> 
+              (pff.f.fmt | pff.f.up | pff.f.sp));
+
+  os << pff.val;
+
+  os.flags (oflags);
+
+  return os;
+}
+
+// Current format for real numbers and the real part of complex
+// numbers.
+static float_format *curr_real_fmt = 0;
+
+// Current format for the imaginary part of complex numbers.
+static float_format *curr_imag_fmt = 0;
 
 static double
 pr_max_internal (const Matrix& m)
@@ -118,13 +213,14 @@ pr_max_internal (const Matrix& m)
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
       {
-	double val = m (i, j);
+	double val = m(i,j);
 	if (xisinf (val) || xisnan (val))
 	  continue;
 
 	if (val > result)
 	  result = val;
       }
+
   return result;
 }
 
@@ -139,13 +235,14 @@ pr_min_internal (const Matrix& m)
   for (int j = 0; j < nc; j++)
     for (int i = 0; i < nr; i++)
       {
-	double val = m (i, j);
+	double val = m(i,j);
 	if (xisinf (val) || xisnan (val))
 	  continue;
 
 	if (val < result)
 	  result = val;
       }
+
   return result;
 }
 
@@ -153,10 +250,10 @@ pr_min_internal (const Matrix& m)
 // functions,..
 
 static void
-set_real_format (bool sign, int digits, bool inf_or_nan, bool nan_or_int,
+set_real_format (bool sign, int digits, bool inf_or_nan, bool int_only,
 		 int &fw)
 {
-  static char fmt_buf[128];
+  static float_format fmt;
 
   int prec = Voutput_precision;
 
@@ -180,13 +277,13 @@ set_real_format (bool sign, int digits, bool inf_or_nan, bool nan_or_int,
       fw = 8 * sizeof (double);
       rd = 0;
     }
-  else if (nan_or_int)
+  else if (inf_or_nan || int_only)
     {
       fw = digits;
       if (inf_or_nan && fw < 3)
 	fw = 3;
       fw += sign;
-      rd = 0;
+      rd = fw;
     }
   else
     {
@@ -221,17 +318,17 @@ set_real_format (bool sign, int digits, bool inf_or_nan, bool nan_or_int,
 	fw = 3;
       fw += sign;
 
-      if (print_big_e)
-	sprintf (fmt_buf, "%%%d.%dE", fw, prec - 1);
-      else
-	sprintf (fmt_buf, "%%%d.%de", fw, prec - 1);
-    }
-  else
-    {
-      sprintf (fmt_buf, "%%%d.%df", fw, rd);
-    }
+      fmt = float_format (fw, prec - 1, std::ios::scientific);
 
-  curr_real_fmt = &fmt_buf[0];
+      if (print_big_e)
+	fmt.uppercase ();
+    }
+  else if (inf_or_nan || int_only)
+    fmt = float_format (fw, rd);
+  else
+    fmt = float_format (fw, rd, std::ios::fixed);
+
+  curr_real_fmt = &fmt;
 }
 
 static void
@@ -247,14 +344,14 @@ set_format (double d, int& fw)
 
   bool inf_or_nan = (xisinf (d) || xisnan (d));
 
-  bool nan_or_int = (xisnan (d) || D_NINT (d) == d);
+  bool int_only = (! inf_or_nan && D_NINT (d) == d);
 
   double d_abs = d < 0.0 ? -d : d;
 
-  int digits = (inf_or_nan || d_abs == 0.0) ? 0
-    : (int) floor (log10 (d_abs) + 1.0);
+  int digits = (inf_or_nan || d_abs == 0.0)
+    ? 0 : static_cast<int> (floor (log10 (d_abs) + 1.0));
 
-  set_real_format (sign, digits, inf_or_nan, nan_or_int, fw);
+  set_real_format (sign, digits, inf_or_nan, int_only, fw);
 }
 
 static inline void
@@ -268,7 +365,7 @@ static void
 set_real_matrix_format (bool sign, int x_max, int x_min,
 			bool inf_or_nan, int int_or_inf_or_nan, int& fw)
 {
-  static char fmt_buf[128];
+  static float_format fmt;
 
   int prec = Voutput_precision;
 
@@ -308,7 +405,7 @@ set_real_matrix_format (bool sign, int x_max, int x_min,
       if (inf_or_nan && fw < 3)
 	fw = 3;
       fw += sign;
-      rd = 0;
+      rd = fw;
     }
   else
     {
@@ -362,17 +459,17 @@ set_real_matrix_format (bool sign, int x_max, int x_min,
 	fw = 3;
       fw += sign;
 
-      if (print_big_e)
-	sprintf (fmt_buf, "%%%d.%dE", fw, prec - 1);
-      else
-	sprintf (fmt_buf, "%%%d.%de", fw, prec - 1);
-    }
-  else
-    {
-      sprintf (fmt_buf, "%%%d.%df", fw, rd);
-    }
+      fmt = float_format (fw, prec - 1, std::ios::scientific);
 
-  curr_real_fmt = &fmt_buf[0];
+      if (print_big_e)
+	fmt.uppercase ();
+    }
+  else if (int_or_inf_or_nan)
+    fmt = float_format (fw, rd);
+  else
+    fmt = float_format (fw, rd, std::ios::fixed);
+
+  curr_real_fmt = &fmt;
 }
 
 static void
@@ -394,10 +491,13 @@ set_format (const Matrix& m, int& fw, double& scale)
   double max_abs = pr_max_internal (m_abs);
   double min_abs = pr_min_internal (m_abs);
 
-  int x_max = max_abs == 0.0 ? 0 : (int) floor (log10 (max_abs) + 1.0);
-  int x_min = min_abs == 0.0 ? 0 : (int) floor (log10 (min_abs) + 1.0);
+  int x_max = max_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (max_abs) + 1.0));
 
-  scale = (x_max == 0 || int_or_inf_or_nan) ? 1.0 : pow (10.0, x_max - 1);
+  int x_min = min_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (min_abs) + 1.0));
+
+  scale = (x_max == 0 || int_or_inf_or_nan) ? 1.0 : std::pow (10.0, x_max - 1);
 
   set_real_matrix_format (sign, x_max, x_min, inf_or_nan,
 			  int_or_inf_or_nan, fw);
@@ -415,8 +515,8 @@ static void
 set_complex_format (bool sign, int x_max, int x_min, int r_x,
 		    bool inf_or_nan, int int_only, int& r_fw, int& i_fw)
 {
-  static char r_fmt_buf[128];
-  static char i_fmt_buf[128];
+  static float_format r_fmt;
+  static float_format i_fmt;
 
   int prec = Voutput_precision;
 
@@ -451,7 +551,7 @@ set_complex_format (bool sign, int x_max, int x_min, int r_x,
       if (inf_or_nan && i_fw < 3)
 	i_fw = r_fw = 3;
       r_fw += sign;
-      rd = 0;
+      rd = r_fw;
     }
   else
     {
@@ -504,25 +604,28 @@ set_complex_format (bool sign, int x_max, int x_min, int r_x,
 	i_fw = r_fw = 3;
       r_fw += sign;
 
+      r_fmt = float_format (r_fw, prec - 1, std::ios::scientific);
+      i_fmt = float_format (i_fw, prec - 1, std::ios::scientific);
+
       if (print_big_e)
 	{
-	  sprintf (r_fmt_buf, "%%%d.%dE", r_fw, prec - 1);
-	  sprintf (i_fmt_buf, "%%%d.%dE", i_fw, prec - 1);
-	}
-      else
-	{
-	  sprintf (r_fmt_buf, "%%%d.%de", r_fw, prec - 1);
-	  sprintf (i_fmt_buf, "%%%d.%de", i_fw, prec - 1);
+	  r_fmt.uppercase ();
+	  i_fmt.uppercase ();
 	}
     }
+  else if (inf_or_nan || int_only)
+    {
+      r_fmt = float_format (r_fw, rd);
+      i_fmt = float_format (i_fw, rd);
+    }
   else
     {
-      sprintf (r_fmt_buf, "%%%d.%df", r_fw, rd);
-      sprintf (i_fmt_buf, "%%%d.%df", i_fw, rd);
+      r_fmt = float_format (r_fw, rd, std::ios::fixed);
+      i_fmt = float_format (i_fw, rd, std::ios::fixed);
     }
 
-  curr_real_fmt = &r_fmt_buf[0];
-  curr_imag_fmt = &i_fmt_buf[0];
+  curr_real_fmt = &r_fmt;
+  curr_imag_fmt = &i_fmt;
 }
 
 static void
@@ -546,8 +649,11 @@ set_format (const Complex& c, int& r_fw, int& i_fw)
   double r_abs = rp < 0.0 ? -rp : rp;
   double i_abs = ip < 0.0 ? -ip : ip;
 
-  int r_x = r_abs == 0.0 ? 0 : (int) floor (log10 (r_abs) + 1.0);
-  int i_x = i_abs == 0.0 ? 0 : (int) floor (log10 (i_abs) + 1.0);
+  int r_x = r_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (r_abs) + 1.0));
+
+  int i_x = i_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (i_abs) + 1.0));
 
   int x_max, x_min;
 
@@ -578,8 +684,8 @@ set_complex_matrix_format (bool sign, int x_max, int x_min,
 			   int r_x_max, int r_x_min, bool inf_or_nan,
 			   int int_or_inf_or_nan, int& r_fw, int& i_fw)
 {
-  static char r_fmt_buf[128];
-  static char i_fmt_buf[128];
+  static float_format r_fmt;
+  static float_format i_fmt;
 
   int prec = Voutput_precision;
 
@@ -622,7 +728,7 @@ set_complex_matrix_format (bool sign, int x_max, int x_min,
       if (inf_or_nan && i_fw < 3)
 	i_fw = r_fw = 3;
       r_fw += sign;
-      rd = 0;
+      rd = r_fw;
     }
   else
     {
@@ -676,25 +782,28 @@ set_complex_matrix_format (bool sign, int x_max, int x_min,
 	i_fw = r_fw = 3;
       r_fw += sign;
 
+      r_fmt = float_format (r_fw, prec - 1, std::ios::scientific);
+      i_fmt = float_format (i_fw, prec - 1, std::ios::scientific);
+
       if (print_big_e)
 	{
-	  sprintf (r_fmt_buf, "%%%d.%dE", r_fw, prec - 1);
-	  sprintf (i_fmt_buf, "%%%d.%dE", i_fw, prec - 1);
-	}
-      else
-	{
-	  sprintf (r_fmt_buf, "%%%d.%de", r_fw, prec - 1);
-	  sprintf (i_fmt_buf, "%%%d.%de", i_fw, prec - 1);
+	  r_fmt.uppercase ();
+	  i_fmt.uppercase ();
 	}
     }
+  else if (int_or_inf_or_nan)
+    {
+      r_fmt = float_format (r_fw, rd);
+      i_fmt = float_format (i_fw, rd);
+    }
   else
     {
-      sprintf (r_fmt_buf, "%%%d.%df", r_fw, rd);
-      sprintf (i_fmt_buf, "%%%d.%df", i_fw, rd);
+      r_fmt = float_format (r_fw, rd, std::ios::fixed);
+      i_fmt = float_format (i_fw, rd, std::ios::fixed);
     }
 
-  curr_real_fmt = &r_fmt_buf[0];
-  curr_imag_fmt = &i_fmt_buf[0];
+  curr_real_fmt = &r_fmt;
+  curr_imag_fmt = &i_fmt;
 }
 
 static void
@@ -724,16 +833,22 @@ set_format (const ComplexMatrix& cm, int& r_fw, int& i_fw, double& scale)
   double i_max_abs = pr_max_internal (i_m_abs);
   double i_min_abs = pr_min_internal (i_m_abs);
 
-  int r_x_max = r_max_abs == 0.0 ? 0 : (int) floor (log10 (r_max_abs) + 1.0);
-  int r_x_min = r_min_abs == 0.0 ? 0 : (int) floor (log10 (r_min_abs) + 1.0);
+  int r_x_max = r_max_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (r_max_abs) + 1.0));
 
-  int i_x_max = i_max_abs == 0.0 ? 0 : (int) floor (log10 (i_max_abs) + 1.0);
-  int i_x_min = i_min_abs == 0.0 ? 0 : (int) floor (log10 (i_min_abs) + 1.0);
+  int r_x_min = r_min_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (r_min_abs) + 1.0));
+
+  int i_x_max = i_max_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (i_max_abs) + 1.0));
+
+  int i_x_min = i_min_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (i_min_abs) + 1.0));
 
   int x_max = r_x_max > i_x_max ? r_x_max : i_x_max;
   int x_min = r_x_min > i_x_min ? r_x_min : i_x_min;
 
-  scale = (x_max == 0 || int_or_inf_or_nan) ? 1.0 : pow (10.0, x_max - 1);
+  scale = (x_max == 0 || int_or_inf_or_nan) ? 1.0 : std::pow (10.0, x_max - 1);
 
   set_complex_matrix_format (sign, x_max, x_min, r_x_max, r_x_min,
 			     inf_or_nan, int_or_inf_or_nan, r_fw, i_fw);
@@ -748,10 +863,9 @@ set_format (const ComplexMatrix& cm)
 }
 
 static void
-set_range_format (bool sign, int x_max, int x_min, int all_ints,
-		  int& fw)
+set_range_format (bool sign, int x_max, int x_min, int all_ints, int& fw)
 {
-  static char fmt_buf[128];
+  static float_format fmt;
 
   int prec = Voutput_precision;
 
@@ -777,7 +891,7 @@ set_range_format (bool sign, int x_max, int x_min, int all_ints,
     {
       int digits = x_max > x_min ? x_max : x_min;
       fw = sign + digits;
-      rd = 0;
+      rd = fw;
     }
   else if (Vfixed_point_format)
     {
@@ -830,17 +944,17 @@ set_range_format (bool sign, int x_max, int x_min, int all_ints,
 
       fw = sign + 2 + prec + exp_field;
 
-      if (print_big_e)
-	sprintf (fmt_buf, "%%%d.%dE", fw, prec - 1);
-      else
-	sprintf (fmt_buf, "%%%d.%de", fw, prec - 1);
-    }
-  else
-    {
-      sprintf (fmt_buf, "%%%d.%df", fw, rd);
-    }
+      fmt = float_format (fw, prec - 1, std::ios::scientific);
 
-  curr_real_fmt = &fmt_buf[0];
+      if (print_big_e)
+	fmt.uppercase ();
+    }
+  else if (all_ints)
+    fmt = float_format (fw, rd);
+  else
+    fmt = float_format (fw, rd, std::ios::fixed);
+
+  curr_real_fmt = &fmt;
 }
 
 static void
@@ -869,10 +983,13 @@ set_format (const Range& r, int& fw, double& scale)
   double max_abs = r_max < 0.0 ? -r_max : r_max;
   double min_abs = r_min < 0.0 ? -r_min : r_min;
 
-  int x_max = max_abs == 0.0 ? 0 : (int) floor (log10 (max_abs) + 1.0);
-  int x_min = min_abs == 0.0 ? 0 : (int) floor (log10 (min_abs) + 1.0);
+  int x_max = max_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (max_abs) + 1.0));
 
-  scale = (x_max == 0 || all_ints) ? 1.0 : pow (10.0, x_max - 1);
+  int x_min = min_abs == 0.0
+    ? 0 : static_cast<int> (floor (log10 (min_abs) + 1.0));
+
+  scale = (x_max == 0 || all_ints) ? 1.0 : std::pow (10.0, x_max - 1);
 
   set_range_format (sign, x_max, x_min, all_ints, fw);
 }
@@ -905,7 +1022,7 @@ union equiv
       stmp[6] = (ctmp & 0x02) ? '1' : '0'; \
       stmp[7] = (ctmp & 0x01) ? '1' : '0'; \
       stmp[8] = '\0'; \
-      os.form ("%s", stmp); \
+      os << stmp; \
     } \
   while (0)
 
@@ -923,12 +1040,12 @@ union equiv
       stmp[6] = (ctmp & 0x40) ? '1' : '0'; \
       stmp[7] = (ctmp & 0x80) ? '1' : '0'; \
       stmp[8] = '\0'; \
-      os.form ("%s", stmp); \
+      os << stmp; \
     } \
   while (0)
 
 static void
-pr_any_float (const char *fmt, ostream& os, double d, int fw = 0)
+pr_any_float (const float_format *fmt, std::ostream& os, double d, int fw = 0)
 {
 #if defined (SCO)
   // Apparently on some SCO systems NaN == -0.0 is true.  Compiler bug?
@@ -952,22 +1069,34 @@ pr_any_float (const char *fmt, ostream& os, double d, int fw = 0)
 	  // XXX FIXME XXX -- is it correct to swap bytes for VAX
 	  // formats and not for Cray?
 
+	  // XXX FIXME XXX -- will bad things happen if we are
+	  // interrupted before resetting the format flags and fill
+	  // character?
+
 	  oct_mach_info::float_format flt_fmt =
 	    oct_mach_info::native_float_format ();
 
+	  char ofill = os.fill ('0');
+
+	  std::ios::fmtflags oflags
+	    = os.flags (std::ios::right | std::ios::hex);
+
 	  if (hex_format > 1
 	      || flt_fmt == oct_mach_info::ieee_big_endian
 	      || flt_fmt == oct_mach_info::cray
 	      || flt_fmt == oct_mach_info::unknown)
 	    {
 	      for (size_t i = 0; i < sizeof (double); i++)
-		os.form ("%02x", (int) tmp.i[i]);
+		os << std::setw (2) << static_cast<int> (tmp.i[i]);
 	    }
 	  else
 	    {
 	      for (int i = sizeof (double) - 1; i >= 0; i--)
-		os.form ("%02x", (int) tmp.i[i]);
+		os << std::setw (2) << static_cast<int> (tmp.i[i]);
 	    }
+
+	  os.fill (ofill);
+	  os.setf (oflags);	  
 	}
       else if (bit_format)
 	{
@@ -1006,51 +1135,59 @@ pr_any_float (const char *fmt, ostream& os, double d, int fw = 0)
 	}
       else if (xisinf (d))
 	{
-	  char *s;
+	  const char *s;
 	  if (d < 0.0)
 	    s = "-Inf";
 	  else
 	    s = "Inf";
 
 	  if (fw > 0)
-	    os.form ("%*s", fw, s);
+	    os << std::setw (fw) << s;
 	  else
 	    os << s;
 	}
       else if (xisnan (d))
 	{
 	  if (fw > 0)
-	    os.form ("%*s", fw, "NaN");
+	    os << std::setw (fw) << "NaN";
 	  else
 	    os << "NaN";
 	}
       else
-	os.form (fmt, d);
+	os << pr_formatted_float (*fmt, d);
     }
   else
     os << d;
 }
 
 static inline void
-pr_float (ostream& os, double d, int fw = 0)
+pr_float (std::ostream& os, double d, int fw = 0, double scale = 1.0)
 {
+  if (Vfixed_point_format && scale != 1.0)
+    d /= scale;
+
   pr_any_float (curr_real_fmt, os, d, fw);
 }
 
 static inline void
-pr_imag_float (ostream& os, double d, int fw = 0)
+pr_imag_float (std::ostream& os, double d, int fw = 0)
 {
   pr_any_float (curr_imag_fmt, os, d, fw);
 }
 
 static void
-pr_complex (ostream& os, const Complex& c, int r_fw = 0, int i_fw = 0)
+pr_complex (std::ostream& os, const Complex& c, int r_fw = 0,
+	    int i_fw = 0, double scale = 1.0)
 {
-  double r = c.real ();
+  Complex tmp = (Vfixed_point_format && scale != 1.0) ? c / scale : c;
+
+  double r = tmp.real ();
+
   pr_float (os, r, r_fw);
+
   if (! bank_format)
     {
-      double i = c.imag ();
+      double i = tmp.imag ();
       if (! (hex_format || bit_format) && i < 0)
 	{
 	  os << " - ";
@@ -1071,7 +1208,7 @@ pr_complex (ostream& os, const Complex& c, int r_fw = 0, int i_fw = 0)
 }
 
 static void
-print_empty_matrix (ostream& os, int nr, int nc, bool pr_as_read_syntax)
+print_empty_matrix (std::ostream& os, int nr, int nc, bool pr_as_read_syntax)
 {
   assert (nr == 0 || nc == 0);
 
@@ -1087,16 +1224,20 @@ print_empty_matrix (ostream& os, int nr, int nc, bool pr_as_read_syntax)
       os << "[]";
       if (Vprint_empty_dimensions)
 	os << "(" << nr << "x" << nc << ")";
-      os << "\n";
     }
 }
 
 static void
-pr_scale_header (ostream& os, double scale)
+pr_scale_header (std::ostream& os, double scale)
 {
   if (Vfixed_point_format && scale != 1.0)
     {
-      os.form ("  %-8.1e *\n", scale);
+      os << "  "
+	 << std::setw (8) << std::setprecision (1)
+	 << std::setiosflags (std::ios::scientific|std::ios::left)
+	 << scale
+	 << std::resetiosflags (std::ios::scientific|std::ios::left)
+	 << " *\n";
 
       if (! compact_format)
 	os << "\n";
@@ -1104,17 +1245,17 @@ pr_scale_header (ostream& os, double scale)
 }
 
 static void
-pr_col_num_header (ostream& os, int total_width, int max_width,
+pr_col_num_header (std::ostream& os, int total_width, int max_width,
 		   int lim, int col, int extra_indent)
 {
   if (total_width > max_width && Vsplit_long_rows)
     {
       if (col != 0 && ! compact_format)
-	os << "\n";
+	os << "\n\n";
 
       int num_cols = lim - col;
 
-      os.form ("%*s", extra_indent, "");
+      os << std::setw (extra_indent) << "";
 
       if (num_cols == 1)
 	os << " Column " << col + 1 << ":\n";
@@ -1128,15 +1269,23 @@ pr_col_num_header (ostream& os, int total_width, int max_width,
     }
 }
 
+static inline void
+pr_plus_format (std::ostream& os, double d)
+{
+  if (d == 0.0)
+    os << " ";
+  else if (d < 0.0)
+    os << "-";
+  else
+    os << "+";
+}
+
 void
-octave_print_internal (ostream& os, double d, bool pr_as_read_syntax)
+octave_print_internal (std::ostream& os, double d, bool pr_as_read_syntax)
 {
   if (plus_format)
     {
-      if (d == 0.0)
-	os << " ";
-      else
-	os << "+";
+      pr_plus_format (os, d);
     }
   else
     {
@@ -1146,14 +1295,11 @@ octave_print_internal (ostream& os, double d, bool pr_as_read_syntax)
       else
 	pr_float (os, d);
     }
-
-  if (! pr_as_read_syntax)
-    os << "\n";
 }
 
 void
-octave_print_internal (ostream& os, const Matrix& m, bool pr_as_read_syntax,
-		       int extra_indent)
+octave_print_internal (std::ostream& os, const Matrix& m,
+		       bool pr_as_read_syntax, int extra_indent)
 {
   int nr = m.rows ();
   int nc = m.columns ();
@@ -1169,12 +1315,11 @@ octave_print_internal (ostream& os, const Matrix& m, bool pr_as_read_syntax,
 	      if (j == 0)
 		os << "  ";
 
-	      if (m (i, j) == 0.0)
-		os << " ";
-	      else
-		os << "+";
+	      pr_plus_format (os, m(i,j));
 	    }
-	  os << "\n";
+
+	  if (i < nr - 1)
+	    os << "\n";
 	}
     }
   else
@@ -1184,7 +1329,7 @@ octave_print_internal (ostream& os, const Matrix& m, bool pr_as_read_syntax,
       set_format (m, fw, scale);
       int column_width = fw + 2;
       int total_width = nc * column_width;
-      int max_width = terminal_columns ();
+      int max_width = command_editor::terminal_cols ();
 
       if (pr_as_read_syntax)
 	max_width -= 4;
@@ -1236,7 +1381,7 @@ octave_print_internal (ostream& os, const Matrix& m, bool pr_as_read_syntax,
 			    os << "  ";
 			}
 
-		      pr_float (os, m (i, j));
+		      pr_float (os, m(i,j));
 		    }
 
 		  col += inc;
@@ -1266,35 +1411,49 @@ octave_print_internal (ostream& os, const Matrix& m, bool pr_as_read_syntax,
 
 	      for (int i = 0; i < nr; i++)
 		{
-		  os.form ("%*s", extra_indent, "");
+		  os << std::setw (extra_indent) << "";
 
 		  for (int j = col; j < lim; j++)
 		    {
 		      os << "  ";
 
-		      double tmp = (Vfixed_point_format && scale != 1.0)
-			? m(i,j) / scale : m(i,j);
-
-		      pr_float (os, tmp, fw);
+		      pr_float (os, m(i,j), fw, scale);
 		    }
 
-		  os << "\n";
+		  if (i < nr - 1)
+		    os << "\n";
 		}
 	    }
 	}
     }
 }
 
+static inline void
+pr_plus_format (std::ostream& os, const Complex& c)
+{
+  double rp = c.real ();
+  double ip = c.imag ();
+
+  if (rp == 0.0)
+    {
+      if (ip == 0.0)
+	os << " ";
+      else
+	os << "i";
+    }
+  else if (ip == 0.0)
+    pr_plus_format (os, rp);
+  else
+    os << "c";
+}
+
 void
-octave_print_internal (ostream& os, const Complex& c,
+octave_print_internal (std::ostream& os, const Complex& c,
 		       bool pr_as_read_syntax)
 {
   if (plus_format)
     {
-      if (c == 0.0)
-	os << " ";
-      else
-	os << "+";
+      pr_plus_format (os, c);
     }
   else
     {
@@ -1304,13 +1463,10 @@ octave_print_internal (ostream& os, const Complex& c,
       else
 	pr_complex (os, c);
     }
-
-  if (! pr_as_read_syntax)
-    os << "\n";
 }
 
 void
-octave_print_internal (ostream& os, const ComplexMatrix& cm,
+octave_print_internal (std::ostream& os, const ComplexMatrix& cm,
 		       bool pr_as_read_syntax, int extra_indent)
 {
   int nr = cm.rows ();
@@ -1327,12 +1483,11 @@ octave_print_internal (ostream& os, const ComplexMatrix& cm,
 	      if (j == 0)
 		os << "  ";
 
-	      if (cm (i, j) == 0.0)
-		os << " ";
-	      else
-		os << "+";
+	      pr_plus_format (os, cm(i,j));
 	    }
-	  os << "\n";
+
+	  if (i < nr - 1)
+	    os << "\n";
 	}
     }
   else
@@ -1343,7 +1498,7 @@ octave_print_internal (ostream& os, const ComplexMatrix& cm,
       int column_width = i_fw + r_fw;
       column_width += (bank_format || hex_format|| bit_format) ? 2 : 7;
       int total_width = nc * column_width;
-      int max_width = terminal_columns ();
+      int max_width = command_editor::terminal_cols ();
 
       if (pr_as_read_syntax)
 	max_width -= 4;
@@ -1395,7 +1550,7 @@ octave_print_internal (ostream& os, const ComplexMatrix& cm,
 			    os << "  ";
 			}
 
-		      pr_complex (os, cm (i, j));
+		      pr_complex (os, cm(i,j));
 		    }
 
 		  col += inc;
@@ -1425,18 +1580,17 @@ octave_print_internal (ostream& os, const ComplexMatrix& cm,
 
 	      for (int i = 0; i < nr; i++)
 		{
-		  os.form ("%*s", extra_indent, "");
+		  os << std::setw (extra_indent) << "";
 
 		  for (int j = col; j < lim; j++)
 		    {
 		      os << "  ";
 
-		      Complex tmp = (Vfixed_point_format && scale != 1.0)
-			? cm(i,j) / scale : cm(i,j);
-
-		      pr_complex (os, tmp, r_fw, i_fw);
+		      pr_complex (os, cm(i,j), r_fw, i_fw, scale);
 		    }
-		  os << "\n";
+
+		  if (i < nr - 1) 
+		    os << "\n";
 		}
 	    }
 	}
@@ -1444,7 +1598,7 @@ octave_print_internal (ostream& os, const ComplexMatrix& cm,
 }
 
 void
-octave_print_internal (ostream& os, const Range& r,
+octave_print_internal (std::ostream& os, const Range& r,
 		       bool pr_as_read_syntax, int extra_indent)
 {
   double base = r.base ();
@@ -1495,7 +1649,7 @@ octave_print_internal (ostream& os, const Range& r,
 	{
 	  int column_width = fw + 2;
 	  int total_width = num_elem * column_width;
-	  int max_width = terminal_columns ();
+	  int max_width = command_editor::terminal_cols ();
 
 	  if (free_format)
 	    {
@@ -1526,7 +1680,7 @@ octave_print_internal (ostream& os, const Range& r,
 	      pr_col_num_header (os, total_width, max_width, lim, col,
 				 extra_indent);
 
-	      os.form ("%*s", extra_indent, "");
+	      os << std::setw (extra_indent) << "";
 
 	      for (int i = col; i < lim; i++)
 		{
@@ -1534,24 +1688,32 @@ octave_print_internal (ostream& os, const Range& r,
 
 		  os << "  ";
 
-		  if (Vfixed_point_format && scale != 1.0)
-		    val /= scale;
-
-		  pr_float (os, val, fw);
+		  pr_float (os, val, fw, scale);
 		}
 
-	      os << "\n";
-
 	      col += inc;
+
+	      if (col < num_elem)
+		os << "\n";
 	    }
 	}
     }
 }
 
 void
-octave_print_internal (ostream& os, const charMatrix& chm,
-		       bool pr_as_read_syntax, bool pr_as_string,
-		       int /* extra_indent XXX FIXME XXX */)
+octave_print_internal (std::ostream& os, const boolMatrix& bm,
+		       bool pr_as_read_syntax,
+		       int extra_indent)
+{
+  Matrix tmp (bm);
+  octave_print_internal (os, tmp, pr_as_read_syntax, extra_indent);
+}
+
+void
+octave_print_internal (std::ostream& os, const charMatrix& chm,
+		       bool pr_as_read_syntax,
+		       int /* extra_indent XXX FIXME XXX */,
+		       bool pr_as_string)
 {
   if (pr_as_string)
     {
@@ -1560,13 +1722,11 @@ octave_print_internal (ostream& os, const charMatrix& chm,
       if (pr_as_read_syntax && nstr > 1)
 	os << "[ ";
 
-      if (nstr == 0)
-	os << "\n";
-      else
+      if (nstr != 0)
 	{
 	  for (int i = 0; i < nstr; i++)
 	    {
-	      string row = chm.row_as_string (i);
+	      std::string row = chm.row_as_string (i);
 
 	      if (pr_as_read_syntax)
 		{
@@ -1576,7 +1736,12 @@ octave_print_internal (ostream& os, const charMatrix& chm,
 		    os << "; ";
 		}
 	      else
-		os << row << "\n";
+		{
+		  os << row;
+
+		  if (i < nstr - 1)
+		    os << "\n";
+		}
 	    }
 	}
 
@@ -1589,28 +1754,103 @@ octave_print_internal (ostream& os, const charMatrix& chm,
     }
 }
 
-DEFUN (disp, args, ,
-  "disp (X): display value without name tag")
+DEFUN (disp, args, nargout,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} disp (@var{x})\n\
+Display the value of @var{x}.  For example,\n\
+\n\
+@example\n\
+disp (\"The value of pi is:\"), disp (pi)\n\
+\n\
+     @print{} the value of pi is:\n\
+     @print{} 3.1416\n\
+@end example\n\
+\n\
+@noindent\n\
+Note that the output from @code{disp} always ends with a newline.\n\
+\n\
+If an output value is requested, @code{disp} prints nothing and\n\
+returns the formatted output in a string.\n\
+@end deftypefn\n\
+@seealso{fdisp}")
 {
-  octave_value_list retval;
+  octave_value retval;
 
   int nargin = args.length ();
 
-  if (nargin == 1)
-    args(0).print ();
+  if (nargin == 1 && nargout < 2)
+    {
+      if (nargout == 0)
+	args(0).print (octave_stdout);
+      else
+	{
+	  std::ostrstream buf;
+	  args(0).print (buf);
+	  buf << std::ends;
+	  char *tmp = buf.str ();
+	  retval = tmp;
+	  delete [] tmp;
+	}
+    }
   else
     print_usage ("disp");
 
   return retval;
 }
 
+DEFUN (fdisp, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} fdisp (@var{fid}, @var{x})\n\
+Display the value of @var{x} on the stream @var{fid}.  For example,\n\
+\n\
+@example\n\
+disp (stdout, \"The value of pi is:\"), disp (stdout, pi)\n\
+\n\
+     @print{} the value of pi is:\n\
+     @print{} 3.1416\n\
+@end example\n\
+\n\
+@noindent\n\
+Note that the output from @code{disp} always ends with a newline.\n\
+\n\
+If an output value is requested, @code{disp} prints nothing and\n\
+returns the formatted output in a string.\n\
+@end deftypefn\n\
+@seealso{disp}")
+{
+  octave_value retval;
+
+  int nargin = args.length ();
+
+  if (nargin == 2)
+    {
+      int fid = octave_stream_list::get_file_number (args (0));
+
+      octave_stream os = octave_stream_list::lookup (fid, "fdisp");
+
+      if (! error_state)
+	{
+	  std::ostream *osp = os.output_stream ();
+
+	  if (osp)
+	    args(1).print (*osp);
+	  else
+	    error ("fdisp: stream not open for writing");
+	}
+    }
+  else
+    print_usage ("fdisp");
+
+  return retval;
+}
+
 static void
 init_format_state (void)
 {
   free_format = false;
   plus_format = false;
   bank_format = false;
-  hex_format = false;
+  hex_format = 0;
   bit_format = 0;
   print_e = false;
   print_big_e = false;
@@ -1619,8 +1859,8 @@ init_format_state (void)
 static void
 set_output_prec_and_fw (int prec, int fw)
 {
-  bind_builtin_variable ("output_precision", (double) prec);
-  bind_builtin_variable ("output_max_field_width", (double) fw);
+  bind_builtin_variable ("output_precision", static_cast<double> (prec));
+  bind_builtin_variable ("output_max_field_width", static_cast<double> (fw));
 }
 
 static void
@@ -1630,7 +1870,7 @@ set_format_style (int argc, const string_vector& argv)
 
   if (--argc > 0)
     {
-      string arg = argv[idx++];
+      std::string arg = argv[idx++];
 
       if (arg == "short")
 	{
@@ -1693,7 +1933,7 @@ set_format_style (int argc, const string_vector& argv)
       else if (arg == "hex")
 	{
 	  init_format_state ();
-	  hex_format = true;
+	  hex_format = 1;
 	}
       else if (arg == "native-hex")
 	{
@@ -1749,9 +1989,93 @@ set_format_style (int argc, const string_vector& argv)
 }
 
 DEFUN_TEXT (format, args, ,
-  "format [style]\n\
+  "-*- texinfo -*-\n\
+@deffn {Command} format options\n\
+Control the format of the output produced by @code{disp} and Octave's\n\
+normal echoing mechanism.  Valid options are listed in the following\n\
+table.\n\
 \n\
-set output formatting style")
+@table @code\n\
+@item short\n\
+Octave will try to print numbers with at\n\
+least 3 significant figures within a field that is a maximum of 8\n\
+characters wide.\n\
+\n\
+If Octave is unable to format a matrix so that columns line up on the\n\
+decimal point and all the numbers fit within the maximum field width,\n\
+it switches to an @samp{e} format.\n\
+\n\
+@item long\n\
+Octave will try to print numbers with at least 15 significant figures\n\
+within a field that is a maximum of 24 characters wide.\n\
+\n\
+As will the @samp{short} format, Octave will switch to an @samp{e}\n\
+format if it is unable to format a matrix so that columns line up on the\n\
+decimal point and all the numbers fit within the maximum field width.\n\
+\n\
+@item long e\n\
+@itemx short e\n\
+The same as @samp{format long} or @samp{format short} but always display\n\
+output with an @samp{e} format.  For example, with the @samp{short e}\n\
+format, pi is displayed as @code{3.14e+00}.\n\
+\n\
+@item long E\n\
+@itemx short E\n\
+The same as @samp{format long e} or @samp{format short e} but always\n\
+display output with an uppercase @samp{E} format.  For example, with\n\
+the @samp{long E} format, pi is displayed as\n\
+@code{3.14159265358979E+00}.\n\
+\n\
+@item free\n\
+@itemx none\n\
+Print output in free format, without trying to line up columns of\n\
+matrices on the decimal point.  This also causes complex numbers to be\n\
+formatted like this @samp{(0.604194, 0.607088)} instead of like this\n\
+@samp{0.60419 + 0.60709i}.\n\
+\n\
+@item bank\n\
+Print in a fixed format with two places to the right of the decimal\n\
+point.\n\
+\n\
+@item +\n\
+Print a @samp{+} symbol for nonzero matrix elements and a space for zero\n\
+matrix elements.  This format can be very useful for examining the\n\
+structure of a large matrix.\n\
+\n\
+@item hex\n\
+Print the hexadecimal representation numbers as they are stored in\n\
+memory.  For example, on a workstation which stores 8 byte real values\n\
+in IEEE format with the least significant byte first, the value of\n\
+@code{pi} when printed in @code{hex} format is @code{400921fb54442d18}.\n\
+This format only works for numeric values.\n\
+\n\
+@item bit\n\
+Print the bit representation of numbers as stored in memory.\n\
+For example, the value of @code{pi} is\n\
+\n\
+@example\n\
+@group\n\
+01000000000010010010000111111011\n\
+01010100010001000010110100011000\n\
+@end group\n\
+@end example\n\
+\n\
+(shown here in two 32 bit sections for typesetting purposes) when\n\
+printed in bit format on a workstation which stores 8 byte real values\n\
+in IEEE format with the least significant byte first.  This format only\n\
+works for numeric types.\n\
+@end table\n\
+\n\
+By default, Octave will try to print numbers with at least 5 significant\n\
+figures within a field that is a maximum of 10 characters wide.\n\
+\n\
+If Octave is unable to format a matrix so that columns line up on the\n\
+decimal point and all the numbers fit within the maximum field width,\n\
+it switches to an @samp{e} format.\n\
+\n\
+If @code{format} is invoked without any options, the default format\n\
+state is restored.\n\
+@end deffn")
 {
   octave_value_list retval;
 
@@ -1783,7 +2107,7 @@ output_max_field_width (void)
       && ! xisnan (val))
     {
       int ival = NINT (val);
-      if (ival > 0 && (double) ival == val)
+      if (ival > 0 && ival == val)
 	{
 	  Voutput_max_field_width = ival;
 	  return 0;
@@ -1801,7 +2125,7 @@ output_precision (void)
       && ! xisnan (val))
     {
       int ival = NINT (val);
-      if (ival >= 0 && (double) ival == val)
+      if (ival >= 0 && ival == val)
 	{
 	  Voutput_precision = ival;
 	  return 0;
@@ -1830,20 +2154,103 @@ split_long_rows (void)
 void
 symbols_of_pr_output (void)
 {
-  DEFVAR (fixed_point_format, 0.0, 0, fixed_point_format,
-    "use scaled fixed point format for `format short' and `format long'");
+  DEFVAR (fixed_point_format, 0.0, fixed_point_format,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} fixed_point_format\n\
+If the value of this variable is nonzero, Octave will scale all values\n\
+in a matrix so that the largest may be written with one leading digit.\n\
+The scaling factor is printed on the first line of output.  For example,\n\
+\n\
+@example\n\
+@group\n\
+octave:1> logspace (1, 7, 5)'\n\
+ans =\n\
+\n\
+  1.0e+07  *\n\
+\n\
+  0.00000\n\
+  0.00003\n\
+  0.00100\n\
+  0.03162\n\
+  1.00000\n\
+@end group\n\
+@end example\n\
+\n\
+@noindent\n\
+Notice that first value appears to be zero when it is actually 1.  For\n\
+this reason, you should be careful when setting\n\
+@code{fixed_point_format} to a nonzero value.\n\
+\n\
+The default value of @code{fixed_point_format} is 0.\n\
+@end defvr");
 
-  DEFVAR (output_max_field_width, 10.0, 0, output_max_field_width,
-    "maximum width of an output field for numeric output");
+  DEFVAR (output_max_field_width, 10.0, output_max_field_width,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} output_max_field_width\n\
+This variable specifies the maximum width of a numeric output field.\n\
+The default value is 10.\n\
+@end defvr");
 
-  DEFVAR (output_precision, 5.0, 0, output_precision,
-    "number of significant figures to display for numeric output");
+  DEFVAR (output_precision, 5.0, output_precision,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} output_precision\n\
+This variable specifies the minimum number of significant figures to\n\
+display for numeric output.  The default value is 5.\n\
+@end defvr");
 
-  DEFVAR (print_empty_dimensions, 1.0, 0, print_empty_dimensions,
-    "also print dimensions of empty matrices");
+  DEFVAR (print_empty_dimensions, 1.0, print_empty_dimensions,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} print_empty_dimensions\n\
+If the value of @code{print_empty_dimensions} is nonzero, the\n\
+dimensions of empty matrices are printed along with the empty matrix\n\
+symbol, @samp{[]}.  For example, the expression\n\
+\n\
+@example\n\
+zeros (3, 0)\n\
+@end example\n\
+\n\
+@noindent\n\
+will print\n\
+\n\
+@example\n\
+ans = [](3x0)\n\
+@end example\n\
+@end defvr");
 
-  DEFVAR (split_long_rows, 1.0, 0, split_long_rows,
-    "split long matrix rows instead of wrapping");
+  DEFVAR (split_long_rows, 1.0, split_long_rows,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} split_long_rows\n\
+For large matrices, Octave may not be able to display all the columns of\n\
+a given row on one line of your screen.  This can result in missing\n\
+information or output that is nearly impossible to decipher, depending\n\
+on whether your terminal truncates or wraps long lines.\n\
+\n\
+If the value of @code{split_long_rows} is nonzero, Octave will display\n\
+the matrix in a series of smaller pieces, each of which can fit within\n\
+the limits of your terminal width.  Each set of rows is labeled so that\n\
+you can easily see which columns are currently being displayed.\n\
+For example:\n\
+\n\
+@smallexample\n\
+@group\n\
+octave:13> rand (2,10)\n\
+ans =\n\
+\n\
+ Columns 1 through 6:\n\
+\n\
+  0.75883  0.93290  0.40064  0.43818  0.94958  0.16467\n\
+  0.75697  0.51942  0.40031  0.61784  0.92309  0.40201\n\
+\n\
+ Columns 7 through 10:\n\
+\n\
+  0.90174  0.11854  0.72313  0.73326\n\
+  0.44672  0.94303  0.56564  0.82150\n\
+@end group\n\
+@end smallexample\n\
+\n\
+@noindent\n\
+The default value of @code{split_long_rows} is nonzero.\n\
+@end defvr");
 }
 
 /*
