@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -35,7 +35,7 @@ procstreambase::procstreambase (const char *command, int mode)
   pb_init ();
 
   if (! pb.open (command, mode))
-    set (ios::badbit);
+    std::ios::setstate (std::ios::badbit);
 }
 
 void
@@ -44,7 +44,7 @@ procstreambase::open (const char *command, int mode)
   clear ();
 
   if (! pb.open (command, mode))
-    set (ios::badbit);
+    std::ios::setstate (std::ios::badbit);
 }
 
 int
@@ -55,7 +55,7 @@ procstreambase::close (void)
   if (is_open ())
     {
       if (! pb.close ())
-	set (ios::failbit);
+	std::ios::setstate (std::ios::failbit);
 
       status = pb.wait_status ();
     }
