@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,17 +28,16 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <iostream.h>
-#include <strstream.h>
+#include <iostream>
+#include <strstream>
 
 #include "defun.h"
 #include "error.h"
 #include "oct-obj.h"
+#include "pt-arg-list.h"
+#include "pt-bp.h"
 #include "pt-exp.h"
-#include "pt-fvc.h"
 #include "pt-mat.h"
-#include "pt-misc.h"
-#include "pt-mvr.h"
 #include "pt-walk.h"
 #include "utils.h"
 #include "ov.h"
@@ -54,7 +53,7 @@ static int Vempty_list_elements_ok;
 static bool Vimplicit_num_to_str_ok;
 
 // The character to fill with when creating string arrays.
-static char Vstring_fill_char;
+char Vstring_fill_char = ' ';
 
 // General matrices.  This list type is much more work to handle than
 // constant matrices, but it allows us to construct matrices from
@@ -77,13 +76,11 @@ private:
 	all_str (false), some_str (false), is_cmplx (false),
 	all_mt (true), ok (false) { }
 
-    tm_row_const_rep (const tree_matrix_row& mr)
+    tm_row_const_rep (const tree_argument_list& row)
       : SLList<octave_value> (), count (1), nr (0), nc (0),
 	all_str (false), some_str (false), is_cmplx (false),
 	all_mt (true), ok (false)
-    {
-      init (mr);
-    }
+    { init (row); }
 
     ~tm_row_const_rep (void) { }
 
@@ -99,63 +96,64 @@ private:
 
     bool ok;
 
-    void init (const tree_matrix_row&);
+    void init (const tree_argument_list&);
 
   private:
 
     tm_row_const_rep (const tm_row_const_rep&);
 
-    tm_row_const_rep& operator =
-      (const tm_row_const_rep&);
+    tm_row_const_rep& operator = (const tm_row_const_rep&);
 
-
-    void eval_error (const char *msg, int l, int c) const;
+    void eval_error (const char *msg, int l, int c,
+		     int x = -1, int y = -1) const;
 
     void eval_warning (const char *msg, int l, int c) const;
   };
 
 public:
 
-  tm_row_const (void) : rep (0) { }
+  tm_row_const (void)
+    : rep (0) { }
 
-  tm_row_const (const tree_matrix_row& mr)
-    : rep (new tm_row_const_rep (mr)) { }
+  tm_row_const (const tree_argument_list& row)
+    : rep (new tm_row_const_rep (row)) { }
 
-  tm_row_const (const tm_row_const& x) : rep (x.rep)
-    {
-      if (rep)
-	rep->count++;
-    }
+  tm_row_const (const tm_row_const& x)
+    : rep (x.rep)
+  {
+    if (rep)
+      rep->count++;
+  }
 
   tm_row_const& operator = (const tm_row_const& x)
-    {
-      if (this != &x && rep != x.rep)
-	{
-	  if (rep && --rep->count == 0)
-	    delete rep;
+  {
+    if (this != &x && rep != x.rep)
+      {
+	if (rep && --rep->count == 0)
+	  delete rep;
 
-	  rep = x.rep;
+	rep = x.rep;
 
-	  if (rep)
-	    rep->count++;
-	}
+	if (rep)
+	  rep->count++;
+      }
 
-      return *this;
-    }
+    return *this;
+  }
 
   ~tm_row_const (void)
-    {
-      if (rep && --rep->count == 0)
-	delete rep;
-    }
+  {
+    if (rep && --rep->count == 0)
+      delete rep;
+  }
 
   int rows (void) { return rep->nr; }
   int cols (void) { return rep->nc; }
 
-  bool all_strings (void) const { return rep->all_str; }
-  bool some_strings (void) const { return rep->some_str; }
-  bool is_complex (void) const { return rep->is_cmplx; }
-  bool all_empty (void) const { return rep->all_mt; }
+  bool all_strings_p (void) const { return rep->all_str; }
+  bool some_strings_p (void) const { return rep->some_str; }
+  bool complex_p (void) const { return rep->is_cmplx; }
+  bool all_empty_p (void) const { return rep->all_mt; }
 
   octave_value& operator () (Pix p) { return rep->operator () (p); }
 
@@ -165,10 +163,7 @@ public:
   Pix first (void) const { return rep->first (); }
   void next (Pix& p) const { rep->next (p); }
   
-  operator void* () const
-    {
-      return (rep && rep->ok) ? (void *) -1 : (void *) 0;
-    }
+  operator bool () const { return (rep && rep->ok); }
 
 private:
 
@@ -176,17 +171,17 @@ private:
 };
 
 void
-tm_row_const::tm_row_const_rep::init (const tree_matrix_row& mr)
+tm_row_const::tm_row_const_rep::init (const tree_argument_list& row)
 {
   all_str = true;
 
   bool first_elem = true;
 
-  for (Pix p = mr.first (); p != 0; mr.next (p))
+  for (Pix p = row.first (); p != 0; row.next (p))
     {
-      tree_expression *elt = mr (p);
+      tree_expression *elt = row (p);
 
-      octave_value tmp = elt->eval (false);
+      octave_value tmp = elt->rvalue ();
 
       if (error_state || tmp.is_undefined ())
 	break;
@@ -220,7 +215,7 @@ tm_row_const::tm_row_const_rep::init (const tree_matrix_row& mr)
 	      else if (this_elt_nr != nr)
 		{
 		  eval_error ("number of rows must match",
-			      elt->line (), elt->column ());
+			      elt->line (), elt->column (), this_elt_nr, nr);
 		  break;
 		}
 
@@ -245,12 +240,22 @@ tm_row_const::tm_row_const_rep::init (const tree_matrix_row& mr)
 
 void
 tm_row_const::tm_row_const_rep::eval_error (const char *msg, int l,
-					    int c) const
+					    int c, int x, int y) const
 {
   if (l == -1 && c == -1)
-    ::error ("%s", msg);
+    {
+      if (x == -1 || y == -1)
+	::error ("%s", msg);
+      else
+	::error ("%s (%d != %d)", msg, x, y);
+    }
   else
-    ::error ("%s near line %d, column %d", msg, l, c);
+    {
+      if (x == -1 || y == -1)
+	::error ("%s near line %d, column %d", msg, l, c);
+      else
+	::error ("%s (%d != %d) near line %d, column %d", msg, x, y, l, c);
+    }
 }
 
 void
@@ -278,21 +283,19 @@ public:
     : SLList<tm_row_const> (), nr (0), nc (0),
       all_str (false), some_str (false), is_cmplx (false),
       all_mt (true), ok (false)
-  {
-    init (tm);
-  }
+      { init (tm); }
 
   ~tm_const (void) { }
 
   int rows (void) const { return nr; }
   int cols (void) const { return nc; }
 
-  bool all_strings (void) const { return all_str; }
-  bool some_strings (void) const { return some_str; }
-  bool is_complex (void) const { return is_cmplx; }
-  bool all_empty (void) const { return all_mt; }
+  bool all_strings_p (void) const { return all_str; }
+  bool some_strings_p (void) const { return some_str; }
+  bool complex_p (void) const { return is_cmplx; }
+  bool all_empty_p (void) const { return all_mt; }
 
-  operator void* () const { return ok ? (void *) -1 : (void *) 0; }
+  operator bool () const { return ok; }
 
 private:
 
@@ -329,22 +332,22 @@ tm_const::init (const tree_matrix& tm)
 
   for (Pix p = tm.first (); p != 0; tm.next (p))
     {
-      tree_matrix_row *elt = tm (p);
+      tree_argument_list *elt = tm (p);
 
       tm_row_const tmp (*elt);
 
       if (tmp)
 	{
-	  if (all_str && ! tmp.all_strings ())
+	  if (all_str && ! tmp.all_strings_p ())
 	    all_str = false;
 
-	  if (! some_str && tmp.some_strings ())
+	  if (! some_str && tmp.some_strings_p ())
 	    some_str = true;
 
-	  if (! is_cmplx && tmp.is_complex ())
+	  if (! is_cmplx && tmp.complex_p ())
 	    is_cmplx = true;
 
-	  if (all_mt && ! tmp.all_empty ())
+	  if (all_mt && ! tmp.all_empty_p ())
 	    all_mt = false;
 
 	  append (tmp);
@@ -389,7 +392,8 @@ tm_const::init (const tree_matrix& tm)
 		}
 	      else if (this_elt_nc != nc)
 		{
-		  ::error ("number of columns must match");
+		  ::error ("number of columns must match (%d != %d)",
+			   this_elt_nc, nc);
 		  break;
 		}
 
@@ -401,74 +405,13 @@ tm_const::init (const tree_matrix& tm)
   ok = ! error_state;
 }
 
-bool
-tree_matrix_row::all_elements_are_constant (void) const
+tree_matrix::~tree_matrix (void)
 {
-  for (Pix p = first (); p != 0; next (p))
+  while (! empty ())
     {
-      tree_expression *elt = this->operator () (p);
-
-      if (! elt->is_constant ())
-	return false;
+      tree_argument_list *t = remove_front ();
+      delete t;
     }
-
-  return true;
-}
-
-tree_return_list *
-tree_matrix_row::to_return_list (void)
-{
-  tree_return_list *retval = 0;
-
-  bool first_elem = true;
-
-  for (Pix p = first (); p != 0; next (p))
-    {
-      tree_expression *elt = this->operator () (p);
-
-      bool is_id = elt->is_identifier ();
-
-      bool is_idx_expr = elt->is_index_expression ();
-
-      if (is_id || is_idx_expr)
-	{
-	  tree_index_expression *idx_expr;
-
-	  if (is_id)
-	    {
-	      tree_identifier *id = (tree_identifier *) elt;
-	      idx_expr = new tree_index_expression (id);
-	    }
-	  else
-	    idx_expr = (tree_index_expression *) elt;
-
-	  if (first_elem)
-	    {
-	      first_elem = false;
-
-	      retval = new tree_return_list (idx_expr);
-	    }
-	  else
-	    retval->append (idx_expr);
-	}
-      else
-	{
-	  delete retval;
-	  retval = 0;
-	  break;
-	}
-    }
-
-  if (retval)
-    preserve_expr = true;
-
-  return retval;
-}
-
-void
-tree_matrix_row::accept (tree_walker& tw)
-{
-  tw.visit_matrix_row (*this);
 }
 
 bool
@@ -476,7 +419,7 @@ tree_matrix::all_elements_are_constant (void) const
 {
   for (Pix p = first (); p != 0; next (p))
     {
-      tree_matrix_row *elt = this->operator () (p);
+      tree_argument_list *elt = this->operator () (p);
 
       if (! elt->all_elements_are_constant ())
 	return false;
@@ -489,16 +432,31 @@ tree_matrix::all_elements_are_constant (void) const
 // Less ugly than before, anyway.
 // Looking better all the time.
 
+octave_value_list
+tree_matrix::rvalue (int nargout)
+{
+  octave_value_list retval;
+
+  MAYBE_DO_BREAKPOINT;
+
+  if (nargout > 1)
+    error ("invalid number of output arguments for matrix list");
+  else
+    retval = rvalue ();
+
+  return retval;
+}
+
 octave_value
-tree_matrix::eval (bool /* print */)
+tree_matrix::rvalue (void)
 {
   octave_value retval;
 
   tm_const tmp (*this);
 
-  bool all_strings = false;
-  bool some_strings = false;
-  bool all_empty = false;
+  bool all_strings_p = false;
+  bool some_strings_p = false;
+  bool all_empty_p = false;
 
   bool frc_str_conv = false;
 
@@ -514,15 +472,15 @@ tree_matrix::eval (bool /* print */)
       // Now, extract the values from the individual elements and
       // insert them in the result matrix.
 
-      bool found_complex = tmp.is_complex ();
+      bool found_complex = tmp.complex_p ();
 
-      all_strings = tmp.all_strings ();
-      some_strings = tmp.some_strings ();
-      all_empty = tmp.all_empty ();
+      all_strings_p = tmp.all_strings_p ();
+      some_strings_p = tmp.some_strings_p ();
+      all_empty_p = tmp.all_empty_p ();
 
-      frc_str_conv = some_strings && Vimplicit_num_to_str_ok;
+      frc_str_conv = Vimplicit_num_to_str_ok && some_strings_p;
 
-      if (all_strings)
+      if (all_strings_p)
 	chm.resize (nr, nc, Vstring_fill_char);
       else if (found_complex)
 	cm.resize (nr, nc, 0.0);
@@ -563,7 +521,7 @@ tree_matrix::eval (bool /* print */)
 		{
 		  if (elt.is_real_scalar ())
 		    m (put_row, put_col) = elt.double_value ();
-		  else if (elt.is_string () && all_strings)
+		  else if (elt.is_string () && all_strings_p)
 		    {
 		      charMatrix chm_elt = elt.char_matrix_value ();
 
@@ -583,7 +541,7 @@ tree_matrix::eval (bool /* print */)
 		    }
 		}
 
-	      if (all_strings && chm.rows () > 0 && chm.cols () > 0)
+	      if (all_strings_p && chm.rows () > 0 && chm.cols () > 0)
 		retval = octave_value (chm, true);
 	      else if (found_complex)
 		retval = cm;
@@ -601,9 +559,9 @@ done:
 
   if (! error_state)
     {
-      if (retval.is_undefined () && all_empty)
+      if (retval.is_undefined () && all_empty_p)
 	{
-	  if (all_strings)
+	  if (all_strings_p)
 	    retval = "";
 	  else
 	    retval = Matrix ();
@@ -642,7 +600,7 @@ string_fill_char (void)
 {
   int status = 0;
 
-  string s = builtin_string_variable ("string_fill_char");
+  std::string s = builtin_string_variable ("string_fill_char");
 
   switch (s.length ())
     {
@@ -666,14 +624,60 @@ string_fill_char (void)
 void
 symbols_of_pt_mat (void)
 {
-  DEFVAR (empty_list_elements_ok, "warn", 0, empty_list_elements_ok,
-    "ignore the empty element in expressions like `a = [[], 1]'");
+  DEFVAR (empty_list_elements_ok, "warn", empty_list_elements_ok,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} empty_list_elements_ok\n\
+This variable controls whether Octave ignores empty matrices in a matrix\n\
+list.\n\
+\n\
+For example, if the value of @code{empty_list_elements_ok} is\n\
+nonzero, Octave will ignore the empty matrices in the expression\n\
+\n\
+@example\n\
+a = [1, [], 3, [], 5]\n\
+@end example\n\
+\n\
+@noindent\n\
+and the variable @code{a} will be assigned the value @code{[ 1, 3, 5 ]}.\n\
+\n\
+The default value is @code{\"warn\"}.\n\
+@end defvr");
 
-  DEFVAR (implicit_num_to_str_ok, 0.0, 0, implicit_num_to_str_ok,
-    "make the result of things like `[97, 98, 99, \"123\"]' be a string");
+  DEFVAR (implicit_num_to_str_ok, 0.0, implicit_num_to_str_ok,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} implicit_num_to_str_ok\n\
+If the value of @code{implicit_num_to_str_ok} is nonzero, implicit\n\
+conversions of numbers to their ASCII character equivalents are\n\
+allowed when strings are constructed using a mixture of strings and\n\
+numbers in matrix notation.  Otherwise, an error message is printed and\n\
+control is returned to the top level. The default value is 0.  For\n\
+example,\n\
+\n\
+@example\n\
+@group\n\
+[ \"f\", 111, 111 ]\n\
+     @result{} \"foo\"\n\
+@end group\n\
+@end example\n\
+@end defvr");
 
-  DEFVAR (string_fill_char, " ", 0, string_fill_char,
-    "the character to fill with when creating string arrays.");
+  DEFVAR (string_fill_char, " ", string_fill_char,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} string_fill_char\n\
+The value of this variable is used to pad all strings in a string matrix\n\
+to the same length.  It should be a single character.  The default value\n\
+is @code{\" \"} (a single space).  For example,\n\
+\n\
+@example\n\
+@group\n\
+string_fill_char = \"X\";\n\
+[ \"these\"; \"are\"; \"strings\" ]\n\
+     @result{} \"theseXX\"\n\
+        \"areXXXX\"\n\
+        \"strings\"\n\
+@end group\n\
+@end example\n\
+@end defvr");
 }
 
 /*
