@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -27,10 +27,11 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #pragma interface
 #endif
 
-class ostream;
+#include <iostream>
 
 class octave_value;
-class tree_return_list;
+class octave_value_list;
+class tree_argument_list;
 
 class tree_walker;
 
@@ -42,67 +43,41 @@ class tree_walker;
 // other matrices, variables, and functions.
 
 class
-tree_matrix_row : public SLList<tree_expression *>
+tree_matrix : public tree_expression, public SLList<tree_argument_list *>
 {
 public:
 
-  tree_matrix_row (tree_expression *e = 0)
-    : SLList<tree_expression *> (), preserve_expr (false)
-    {
-      if (e)
-	append (e);
-    }
+  tree_matrix (tree_argument_list *row = 0, int line = -1, int column = -1)
+    : tree_expression (line, column), SLList<tree_argument_list *> ()
+  {
+    if (row)
+      append (row);
+  }
 
-  ~tree_matrix_row (void)
-    {
-      if (! preserve_expr)
-	while (! empty ())
-	  {
-	    tree_expression *e = remove_front ();
-	    delete e;
-	  }
-    }
+  ~tree_matrix (void);
 
   bool all_elements_are_constant (void) const;
 
-  tree_return_list *to_return_list (void);
+  bool rvalue_ok (void) const
+    { return true; }
+
+  octave_value rvalue (void);
+
+  octave_value_list rvalue (int nargout);
 
   void accept (tree_walker& tw);
 
 private:
 
-  bool preserve_expr;
+  // No copying!
+
+  tree_matrix (const tree_matrix&);
+
+  tree_matrix& operator = (const tree_matrix&);
 };
 
-class
-tree_matrix : public tree_expression, public SLList<tree_matrix_row *>
-{
-public:
-
-  tree_matrix (tree_matrix_row *mr = 0)
-    : tree_expression (), SLList<tree_matrix_row *> ()
-      {
-	if (mr)
-	  append (mr);
-      }
-
-  ~tree_matrix (void)
-    {
-      while (! empty ())
-	{
-	  tree_matrix_row *mr = remove_front ();
-	  delete mr;
-	}
-    }
-
-  bool all_elements_are_constant (void) const;
-
-  octave_value eval (bool print);
-
-  void accept (tree_walker& tw);
-};
-
-extern void symbols_of_pt_mat (void);
+// The character to fill with when creating string arrays.
+extern char Vstring_fill_char;
 
 #endif
 
