@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -30,12 +30,11 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <cstring>
 
+#include <fstream>
+#include <iostream>
+#include <strstream>
 #include <string>
 
-#include <fstream.h>
-#include <iostream.h>
-#include <strstream.h>
-
 #ifdef HAVE_UNISTD_H
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -47,14 +46,13 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "procstream.h"
 
 #include "file-ops.h"
+#include "lo-mappers.h"
 #include "str-vec.h"
 
 #include "defun.h"
 #include "error.h"
 #include "gripes.h"
-#include "help.h"
 #include "load-save.h"
-#include "mappers.h"
 #include "oct-obj.h"
 #include "pt-cmd.h"
 #include "pt-exp.h"
@@ -70,7 +68,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 static bool Vautomatic_replot;
 
 // The name of the shell command to execute to start gnuplot.
-static string Vgnuplot_binary;
+static std::string Vgnuplot_binary;
 
 // TRUE if gnuplot appears to support multiple plot windows with X11.
 static bool Vgnuplot_has_frames;
@@ -94,7 +92,7 @@ static bool clear_before_plotting = true;
 //
 // XXX FIXME XXX -- this should really be static, but that causes
 // problems on some systems.
-SLStack <string> tmp_files;
+SLStack <std::string> tmp_files;
 
 // Pipe to gnuplot.
 static oprocstream *plot_stream = 0;
@@ -103,14 +101,14 @@ static oprocstream *plot_stream = 0;
 static pid_t plot_stream_pid = 0;
 
 // Gnuplot command strings that we use.
-static string Vgnuplot_command_plot;
-static string Vgnuplot_command_replot;
-static string Vgnuplot_command_splot;
-static string Vgnuplot_command_using;
-static string Vgnuplot_command_with;
-static string Vgnuplot_command_axes;
-static string Vgnuplot_command_title;
-static string Vgnuplot_command_end;
+static std::string Vgnuplot_command_plot;
+static std::string Vgnuplot_command_replot;
+static std::string Vgnuplot_command_splot;
+static std::string Vgnuplot_command_using;
+static std::string Vgnuplot_command_with;
+static std::string Vgnuplot_command_axes;
+static std::string Vgnuplot_command_title;
+static std::string Vgnuplot_command_end;
 
 static void
 plot_stream_death_handler (pid_t pid, int)
@@ -138,7 +136,7 @@ open_plot_stream (void)
 
       plot_line_count = 0;
 
-      string plot_prog = Vgnuplot_binary;
+      std::string plot_prog = Vgnuplot_binary;
 
       if (plot_prog.empty ())
 	plot_prog = "gnuplot";
@@ -210,9 +208,11 @@ send_to_plot_stream (const char *cmd)
   int splot_len = Vgnuplot_command_splot.length ();
   int plot_len = Vgnuplot_command_plot.length ();
 
-  bool is_replot = (Vgnuplot_command_replot.compare (cmd, 0, replot_len) == 0);
-  bool is_splot = (Vgnuplot_command_splot.compare (cmd, 0, splot_len) == 0);
-  bool is_plot = (Vgnuplot_command_plot.compare (cmd, 0, plot_len) == 0);
+  std::string s = cmd;
+
+  bool is_replot = (Vgnuplot_command_replot == s.substr (0, replot_len));
+  bool is_splot = (Vgnuplot_command_splot == s.substr (0, splot_len));
+  bool is_plot = (Vgnuplot_command_plot == s.substr (0, plot_len));
 
   if (plot_line_count == 0 && is_replot)
     error ("replot: no previous plot");
@@ -224,7 +224,7 @@ send_to_plot_stream (const char *cmd)
 	  && plot_line_count > 0
 	  && Vautomatic_replot)
 	*plot_stream << Vgnuplot_command_replot << Vgnuplot_command_end;
-	
+
       plot_stream->flush ();
     }
 
@@ -247,7 +247,7 @@ tree_plot_command::eval (void)
 
   open_plot_stream ();
 
-  ostrstream plot_buf;
+  std::ostrstream plot_buf;
 
   switch (ndim)
     {
@@ -311,11 +311,11 @@ tree_plot_command::eval (void)
 	return;
     }
 
-  plot_buf << Vgnuplot_command_end << ends;
+  plot_buf << Vgnuplot_command_end << std::ends;
 
   // Just testing...
   //  char *message = plot_buf.str ();
-  //  cout << "[*]" << message << "[*]\n";
+  //  std::cout << "[*]" << message << "[*]\n";
 
   if (parametric_plot && ndim == 2)
     {
@@ -348,7 +348,7 @@ plot_limits::~plot_limits (void)
 }
 
 void
-plot_limits::print (int ndim, ostrstream& plot_buf)
+plot_limits::print (int ndim, std::ostrstream& plot_buf)
 {
   if (ndim  == 2 || ndim == 3)
     {
@@ -380,13 +380,14 @@ plot_range::~plot_range (void)
 }
 
 void
-plot_range::print (ostrstream& plot_buf)
+plot_range::print (std::ostrstream& plot_buf)
 {
   plot_buf << " [";
 
   if (lower)
     {
-      octave_value lower_val = lower->eval (false);
+      octave_value lower_val = lower->rvalue ();
+
       if (error_state)
 	{
 	  ::error ("evaluating lower bound of plot range");
@@ -403,7 +404,8 @@ plot_range::print (ostrstream& plot_buf)
 
   if (upper)
     {
-      octave_value upper_val = upper->eval (false);
+      octave_value upper_val = upper->rvalue ();
+
       if (error_state)
 	{
 	  ::error ("evaluating upper bound of plot range");
@@ -444,7 +446,8 @@ subplot_using::eval (int ndim, int n_max)
     {
       if (x[i])
 	{
-	  octave_value tmp = x[i]->eval (false);
+	  octave_value tmp = x[i]->rvalue ();
+
 	  if (error_state)
 	    {
 	      ::error ("evaluating plot using command");
@@ -493,14 +496,15 @@ subplot_using::values (int ndim, int n_max)
 {
   int status = eval (ndim, n_max);
 
+  // XXX FIXME XXX -- is the following really right?
   if (status < 0)
-    return -1;
+    return ColumnVector (1, -1.0);
 
   return val;
 }
 
 int
-subplot_using::print (int ndim, int n_max, ostrstream& plot_buf)
+subplot_using::print (int ndim, int n_max, std::ostrstream& plot_buf)
 {
   int status = eval (ndim, n_max);
 
@@ -533,7 +537,7 @@ subplot_style::~subplot_style (void)
 }
 
 int
-subplot_style::print (ostrstream& plot_buf)
+subplot_style::print (std::ostrstream& plot_buf)
 {
   if (! sp_style.empty ())
     {
@@ -541,7 +545,8 @@ subplot_style::print (ostrstream& plot_buf)
 
       if (sp_linetype)
 	{
-	  octave_value tmp = sp_linetype->eval (false);
+	  octave_value tmp = sp_linetype->rvalue ();
+
 	  if (! error_state && tmp.is_defined ())
 	    {
 	      double val = tmp.double_value ();
@@ -562,7 +567,8 @@ subplot_style::print (ostrstream& plot_buf)
 
       if (sp_pointtype)
 	{
-	  octave_value tmp = sp_pointtype->eval (false);
+	  octave_value tmp = sp_pointtype->rvalue ();
+
 	  if (! error_state && tmp.is_defined ())
 	    {
 	      double val = tmp.double_value ();
@@ -623,7 +629,7 @@ subplot_style::accept (tree_walker& tw)
 }
 
 int
-subplot_axes::print (ostrstream& plot_buf)
+subplot_axes::print (std::ostrstream& plot_buf)
 {
   if (! sp_axes.empty ())
     plot_buf << " " << Vgnuplot_command_axes << " " << sp_axes;
@@ -656,10 +662,11 @@ subplot::extract_plot_data (int ndim, octave_value& data)
       ColumnVector val = sp_using_clause->values (ndim);
 
       octave_value_list args;
+
       args(1) = val;
       args(0) = octave_value::magic_colon_t;
 
-      retval = data.index (args);
+      retval = data.do_index_op (args);
 
       if (error_state)
 	return octave_value ();
@@ -678,15 +685,15 @@ subplot::extract_plot_data (int ndim, octave_value& data)
 }
 
 int
-subplot::handle_plot_data (int ndim, ostrstream& plot_buf)
+subplot::handle_plot_data (int ndim, std::ostrstream& plot_buf)
 {
   if (sp_plot_data)
     {
-      octave_value data = sp_plot_data->eval (false);
+      octave_value data = sp_plot_data->rvalue ();
 
       if (! error_state && data.is_defined ())
 	{
-	  string file;
+	  std::string file;
 
 	  if (data.is_string ())
 	    {
@@ -696,9 +703,9 @@ subplot::handle_plot_data (int ndim, ostrstream& plot_buf)
 
 	      int n_max = 0;
 
-	      file = oct_tilde_expand (data.string_value ());
+	      file = file_ops::tilde_expand (data.string_value ());
 
-	      ifstream ftmp (file.c_str ());
+	      std::ifstream ftmp (file.c_str ());
 
 	      if (ftmp)
 		{
@@ -765,7 +772,7 @@ subplot::handle_plot_data (int ndim, ostrstream& plot_buf)
 }
 
 int
-subplot::print (int ndim, ostrstream& plot_buf)
+subplot::print (int ndim, std::ostrstream& plot_buf)
 {
   int status = handle_plot_data (ndim, plot_buf);
 
@@ -781,7 +788,8 @@ subplot::print (int ndim, ostrstream& plot_buf)
 
   if (sp_title_clause)
     {
-      octave_value tmp = sp_title_clause->eval (false);
+      octave_value tmp = sp_title_clause->rvalue ();
+
       if (! error_state && tmp.is_string ())
 	plot_buf << " " << Vgnuplot_command_title << " "
 	  << '"' << tmp.string_value () << '"';
@@ -822,7 +830,7 @@ subplot_list::~subplot_list (void)
 }
 
 int
-subplot_list::print (int ndim, ostrstream& plot_buf)
+subplot_list::print (int ndim, std::ostrstream& plot_buf)
 {
   int status = 0;
 
@@ -850,21 +858,21 @@ subplot_list::accept (tree_walker& tw)
   tw.visit_subplot_list (*this);
 }
 
-string
+std::string
 save_in_tmp_file (octave_value& t, int ndim, bool parametric)
 {
-  string name = oct_tempnam ();
+  std::string name = file_ops::tempnam ("", "oct-");
 
   if (! name.empty ())
     {
-      ofstream file (name.c_str ());
+      std::ofstream file (name.c_str ());
 
       if (file)
 	{
 	  switch (ndim)
 	    {
 	    case 2:
-	      save_ascii_data (file, t, name, 1);
+	      save_ascii_data_for_plotting (file, t, name);
 	      break;
 
 	    case 3:
@@ -887,7 +895,7 @@ save_in_tmp_file (octave_value& t, int ndim, bool parametric)
 }
 
 void
-mark_for_deletion (const string& file)
+mark_for_deletion (const std::string& file)
 {
   tmp_files.push (file);
 }
@@ -897,7 +905,7 @@ cleanup_tmp_files (void)
 {
   while (! tmp_files.empty ())
     {
-      string filename = tmp_files.pop ();
+      std::string filename = tmp_files.pop ();
       unlink (filename.c_str ());
     }
 }
@@ -918,12 +926,12 @@ close_plot_stream (void)
 }
 
 void
-do_external_plotter_cd (const string& newdir)
+do_external_plotter_cd (const std::string& newdir)
 {
   if (plot_stream && *plot_stream)
     {
-      ostrstream plot_buf;
-      plot_buf << "cd \"" << newdir << "\"" << Vgnuplot_command_end << ends;
+      std::ostrstream plot_buf;
+      plot_buf << "cd \"" << newdir << "\"" << Vgnuplot_command_end << std::ends;
       char *message = plot_buf.str ();
       send_to_plot_stream (message);
       delete [] message;
@@ -931,7 +939,18 @@ do_external_plotter_cd (const string& newdir)
 }
 
 DEFUN (clearplot, , ,
-  "clearplot (): clear the plot window")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} clearplot\n\
+@deftypefnx {Built-in Function} {} clg\n\
+Clear the plot window and any titles or axis labels.  The name\n\
+@code{clg} is aliased to @code{clearplot} for compatibility with\n\
+@sc{Matlab}.\n\
+\n\
+The commands @kbd{gplot clear}, @kbd{gsplot clear}, and @kbd{replot\n\
+clear} are equivalent to @code{clearplot}.  (Previously, commands like\n\
+@kbd{gplot clear} would evaluate @code{clear} as an ordinary expression\n\
+and clear all the visible variables.)\n\
+@end deftypefn")
 {
   octave_value_list retval;
   send_to_plot_stream ("clear\n");
@@ -957,7 +976,11 @@ DEFUN (clearplot, , ,
 DEFALIAS (clg, clearplot);
 
 DEFUN (closeplot, , ,
-  "closeplot (): close the stream to plotter")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} closeplot\n\
+Close stream to the @code{gnuplot} subprocess.  If you are using X11,\n\
+this will close the plot window.\n\
+@end deftypefn")
 {
   octave_value_list retval;
   close_plot_stream ();
@@ -965,10 +988,22 @@ DEFUN (closeplot, , ,
 }
 
 DEFUN_TEXT (hold, args, ,
-  "hold [on|off]\n\
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} hold @var{args}\n\
+Tell Octave to `hold' the current data on the plot when executing\n\
+subsequent plotting commands.  This allows you to execute a series of\n\
+plot commands and have all the lines end up on the same figure.  The\n\
+default is for each new plot command to clear the plot device first.\n\
+For example, the command\n\
 \n\
-determine whether the plot window is cleared before the next line is\n\
-drawn.  With no argument, toggle the current state.") 
+@example\n\
+hold on\n\
+@end example\n\
+\n\
+@noindent\n\
+turns the hold state on.  An argument of @code{off} turns the hold state\n\
+off, and @code{hold} with no arguments toggles the current hold state.\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -1003,31 +1038,46 @@ drawn.  With no argument, toggle the current state.")
 }
 
 DEFUN (ishold, , ,
-  "ishold\n\
-\n\
-Return 1 if hold is on, otherwise return 0.")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} ishold\n\
+Return 1 if the next line will be added to the current plot, or 0 if\n\
+the plot device will be cleared before drawing the next line.\n\
+@end deftypefn")
 {
-  return (double) (! clear_before_plotting);
+  return static_cast<double> (! clear_before_plotting);
 }
 
 DEFUN (purge_tmp_files, , ,
-  "delete temporary data files used for plotting")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} purge_tmp_files\n\
+Delete the temporary files created by the plotting commands.\n\
+\n\
+Octave creates temporary data files for @code{gnuplot} and then sends\n\
+commands to @code{gnuplot} through a pipe.  Octave will delete the\n\
+temporary files on exit, but if you are doing a lot of plotting you may\n\
+want to clean up in the middle of a session.\n\
+\n\
+A future version of Octave will eliminate the need to use temporary\n\
+files to hold the plot data.\n\
+@end deftypefn")
 {
   octave_value_list retval;
   cleanup_tmp_files ();
   return retval;
 }
 
+
 DEFUN (graw, args, ,
-  "graw (string)\n\
-\n\
-Send STRING directly to gnuplot subprocess.")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} graw (@var{string})\n\
+Send @var{string} directly to gnuplot subprocess.\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
   if (args.length () == 1 && args(0).is_string ())
     {
-      string cmd = args(0).string_value ();
+      std::string cmd = args(0).string_value ();
 
       if (! (plot_stream && *plot_stream))
 	open_plot_stream ();
@@ -1046,9 +1096,10 @@ Send STRING directly to gnuplot subprocess.")
 }
 
 DEFUN_TEXT (gset, args, ,
-  "gset [options]\n\
-\n\
-set plotting options for gnuplot")
+  "-*- texinfo -*-\n\
+@deffn {Command} gset options\n\
+Set plotting options for gnuplot\n\
+@end deffn")
 {
   octave_value_list retval;
 
@@ -1059,7 +1110,7 @@ set plotting options for gnuplot")
   if (error_state)
     return retval;
 
-  ostrstream plot_buf;
+  std::ostrstream plot_buf;
 
   if (argc > 1)
     {
@@ -1070,13 +1121,13 @@ set plotting options for gnuplot")
       else if (almost_match ("term", argv[1], 1))
 	{
 	  delete [] gnuplot_terminal_type;
-	  ostrstream buf;
+	  std::ostrstream buf;
 	  int i;
 	  for (i = 2; i < argc-1; i++)
 	    buf << argv[i] << " ";
 	  if (i < argc)
 	    buf << argv[i];
-	  buf << Vgnuplot_command_end << ends;
+	  buf << Vgnuplot_command_end << std::ends;
 	  gnuplot_terminal_type = buf.str ();
 	}
     }
@@ -1088,7 +1139,7 @@ set plotting options for gnuplot")
   if (i < argc)
     plot_buf << argv[i];
 
-  plot_buf << Vgnuplot_command_end << ends;
+  plot_buf << Vgnuplot_command_end << std::ends;
 
   char *plot_command = plot_buf.str ();
   send_to_plot_stream (plot_command);
@@ -1099,16 +1150,18 @@ set plotting options for gnuplot")
 }
 
 DEFUN_TEXT (set, args, nargout,
-  "This command is has been replaced by `gset'.")
+  "-*- texinfo -*-\n\
+This command is has been replaced by @code{gset}.")
 {
   warning ("set is obsolete -- use gset instead");
   return Fgset (args, nargout);
 }
 
 DEFUN_TEXT (gshow, args, ,
-  "gshow [options]\n\
-\n\
-show plotting options")
+  "-*- texinfo -*-\n\
+@deffn {Command} gshow options\n\
+Show plotting options.\n\
+@end deffn")
 {
   octave_value_list retval;
 
@@ -1119,16 +1172,15 @@ show plotting options")
   if (error_state)
     return retval;
 
-  ostrstream plot_buf;
+  std::ostrstream plot_buf;
 
   int i;
   for (i = 0; i < argc-1; i++)
     plot_buf << argv[i] << " ";
-
   if (i < argc)
     plot_buf << argv[i];
 
-  plot_buf << Vgnuplot_command_end << ends;
+  plot_buf << Vgnuplot_command_end << std::ends;
 
   char *plot_command = plot_buf.str ();
   send_to_plot_stream (plot_command);
@@ -1139,7 +1191,8 @@ show plotting options")
 }
 
 DEFUN_TEXT (show, args, nargout,
-  "This command is has been replaced by `gshow'.")
+  "-*- texinfo -*-\n\
+This command is has been replaced by @code{gshow}.")
 {
   warning ("show is obsolete -- use gshow instead");
   return Fgshow (args, nargout);
@@ -1154,11 +1207,11 @@ automatic_replot (void)
 }
 
 static int
-set_string_var (string& var, const char *nm)
+set_string_var (std::string& var, const char *nm)
 {
   int retval = 0;
 
-  string s = builtin_string_variable (nm);
+  std::string s = builtin_string_variable (nm);
 
   if (s.empty ())
     {
@@ -1244,35 +1297,61 @@ gnuplot_has_multiplot (void)
 void
 symbols_of_pt_plot (void)
 {
-  DEFVAR (automatic_replot, 0.0, 0, automatic_replot,
-    "if true, auto-insert a replot command when a plot changes");
+  DEFVAR (automatic_replot, 0.0, automatic_replot,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} automatic_replot\n\
+You can tell Octave to redisplay the plot each time anything about it\n\
+changes by setting the value of the builtin variable\n\
+@code{automatic_replot} to a nonzero value.  Since this is fairly\n\
+inefficient, the default value is 0.\n\
+@end defvr");
 
-  DEFVAR (gnuplot_binary, "gnuplot", 0, gnuplot_binary,
-    "path to gnuplot binary");
+  DEFVAR (gnuplot_binary, "gnuplot", gnuplot_binary,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_binary\n\
+The name of the program invoked by the plot command.  The default value\n\
+is @code{\"gnuplot\"}.  @xref{Installation}.\n\
+@end defvr");
 
-  DEFVAR (gnuplot_command_plot, "pl", 0, gnuplot_command_plot,
-    "");
+  DEFVAR (gnuplot_command_plot, "pl", gnuplot_command_plot,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_command_plot\n\
+@end defvr");
 
-  DEFVAR (gnuplot_command_replot, "rep", 0, gnuplot_command_replot,
-    "");
+  DEFVAR (gnuplot_command_replot, "rep", gnuplot_command_replot,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_command_replot\n\
+@end defvr");
 
-  DEFVAR (gnuplot_command_splot, "sp", 0, gnuplot_command_splot,
-    "");
+  DEFVAR (gnuplot_command_splot, "sp", gnuplot_command_splot,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_command_splot\n\
+@end defvr");
 
-  DEFVAR (gnuplot_command_using, "u", 0, gnuplot_command_using,
-    "");
+  DEFVAR (gnuplot_command_using, "u", gnuplot_command_using,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_command_using\n\
+@end defvr");
 
-  DEFVAR (gnuplot_command_with, "w", 0, gnuplot_command_with,
-    "");
+  DEFVAR (gnuplot_command_with, "w", gnuplot_command_with,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_command_with\n\
+@end defvr");
 
-  DEFVAR (gnuplot_command_axes, "ax", 0, gnuplot_command_axes,
-    "");
+  DEFVAR (gnuplot_command_axes, "ax", gnuplot_command_axes,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_command_axes\n\
+@end defvr");
 
-  DEFVAR (gnuplot_command_title, "t", 0, gnuplot_command_title,
-    "");
+  DEFVAR (gnuplot_command_title, "t", gnuplot_command_title,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_command_title\n\
+@end defvr");
 
-  DEFVAR (gnuplot_command_end, "\n", 0, gnuplot_command_end,
-    "");
+  DEFVAR (gnuplot_command_end, "\n", gnuplot_command_end,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_command_end\n\
+@end defvr");
 
 #ifdef GNUPLOT_HAS_FRAMES
   double with_frames = 1.0;
@@ -1280,8 +1359,15 @@ symbols_of_pt_plot (void)
   double with_frames = 0.0;
 #endif
 
-  DEFVAR (gnuplot_has_frames, with_frames, 0, gnuplot_has_frames,
-    "true if gnuplot supports multiple plot windows on X11, false otherwise");
+  DEFVAR (gnuplot_has_frames, with_frames, gnuplot_has_frames,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_has_frames\n\
+If the value of this variable is nonzero, Octave assumes that your copy\n\
+of gnuplot has support for multiple frames that is included in recent\n\
+3.6beta releases.  It's initial value is determined by configure, but it\n\
+can be changed in your startup script or at the command line in case\n\
+configure got it wrong, or if you upgrade your gnuplot installation.\n\
+@end defvr");
 
 #ifdef GNUPLOT_HAS_MULTIPLOT
   double with_multiplot = 1.0;
@@ -1289,8 +1375,15 @@ symbols_of_pt_plot (void)
   double with_multiplot = 0.0;
 #endif
 
-  DEFVAR (gnuplot_has_multiplot, with_multiplot, 0, gnuplot_has_multiplot,
-    "true if gnuplot supports multiplot, false otherwise");
+  DEFVAR (gnuplot_has_multiplot, with_multiplot, gnuplot_has_multiplot,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} gnuplot_has_multiplot\n\
+If the value of this variable is nonzero, Octave assumes that your copy\n\
+of gnuplot has the multiplot support that is included in recent\n\
+3.6beta releases.  It's initial value is determined by configure, but it\n\
+can be changed in your startup script or at the command line in case\n\
+configure got it wrong, or if you upgrade your gnuplot installation.\n\
+@end defvr");
 }
 
 /*
