@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -27,10 +27,10 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #pragma interface
 #endif
 
-class ostream;
-class ostrstream;
+#include <iostream>
+#include <strstream>
 
-class tree_command;
+class tree_expression;
 class tree_plot_command;
 class plot_limits;
 class plot_range;
@@ -42,17 +42,13 @@ class subplot_list;
 
 class tree_walker;
 
-#include <csignal>
-
 #include <string>
 
 #include <SLList.h>
 
 #include "dColVector.h"
 
-#include "idx-vector.h"
 #include "pt-cmd.h"
-#include "pt-exp.h"
 
 class
 tree_plot_command : public tree_command
@@ -85,6 +81,12 @@ private:
   // The list of plots for this plot command.  For example, the
   // command "plot sin(x), cos(x)" has two subplot commands.
   subplot_list *plot_list;
+
+  // No copying!
+
+  tree_plot_command (const tree_plot_command&);
+
+  tree_plot_command& operator = (const tree_plot_command&);
 };
 
 class
@@ -98,7 +100,7 @@ public:
 
   ~plot_limits (void);
 
-  void print (int ndim, ostrstream& plot_buf);
+  void print (int ndim, std::ostrstream& plot_buf);
 
   plot_range *x_limits (void) { return x_range; }
   plot_range *y_limits (void) { return y_range; }
@@ -113,6 +115,12 @@ private:
   plot_range *x_range;
   plot_range *y_range;
   plot_range *z_range;
+
+  // No copying!
+
+  plot_limits (const plot_limits&);
+
+  plot_limits& operator = (const plot_limits&);
 };
 
 class
@@ -125,7 +133,7 @@ public:
 
   ~plot_range (void);
 
-  void print (ostrstream& plot_buf);
+  void print (std::ostrstream& plot_buf);
 
   tree_expression *lower_bound (void) { return lower; }
 
@@ -139,6 +147,12 @@ private:
   // is specified, the range to display is determined from the data.
   tree_expression *lower;
   tree_expression *upper;
+
+  // No copying!
+
+  plot_range (const plot_range&);
+
+  plot_range& operator = (const plot_range&);
 };
 
 class
@@ -174,7 +188,7 @@ public:
 
   ColumnVector values (int ndim, int n_max = 0);
 
-  int print (int ndim, int n_max, ostrstream& plot_buf);
+  int print (int ndim, int n_max, std::ostrstream& plot_buf);
 
   int qualifier_count (void) { return qual_count; }
 
@@ -200,6 +214,12 @@ private:
 
   // A vector to hold using qualifiers.
   tree_expression *x[4];
+
+  // No copying!
+
+  subplot_using (const subplot_using&);
+
+  subplot_using& operator = (const subplot_using&);
 };
 
 class
@@ -207,17 +227,17 @@ subplot_style
 {
 public:
 
-  subplot_style (const string& s = string (),
+  subplot_style (const std::string& s = std::string (),
 		 tree_expression *lt = 0, tree_expression *pt = 0)
     : sp_style (s), sp_linetype (lt), sp_pointtype (pt) { }
 
   ~subplot_style (void);
 
-  int print (ostrstream& plot_buf);
+  int print (std::ostrstream& plot_buf);
 
   bool columns_ok (int nc);
 
-  string style (void) { return sp_style; }
+  std::string style (void) { return sp_style; }
 
   tree_expression *linetype (void) { return sp_linetype; }
 
@@ -228,13 +248,19 @@ public:
 private:
 
   // The style we are using: `lines', `points', etc.
-  string sp_style;
+  std::string sp_style;
 
   // The number of the line type to use.
   tree_expression *sp_linetype;
 
   // The number of the point type to use.
   tree_expression *sp_pointtype;
+
+  // No copying!
+
+  subplot_style (const subplot_style&);
+
+  subplot_style& operator = (const subplot_style&);
 };
 
 class
@@ -242,21 +268,27 @@ subplot_axes
 {
 public:
 
-  subplot_axes (const string& s = string ())
+  subplot_axes (const std::string& s = std::string ())
     : sp_axes (s) { }
 
   ~subplot_axes (void) { }
 
-  int print (ostrstream& plot_buf);
+  int print (std::ostrstream& plot_buf);
 
-  string axes (void) { return sp_axes; }
+  std::string axes (void) { return sp_axes; }
 
   void accept (tree_walker& tw);
 
 private:
 
   // The axes we are using: `x1y1', `x1y2', etc.
-  string sp_axes;
+  std::string sp_axes;
+
+  // No copying!
+
+  subplot_axes (const subplot_axes&);
+
+  subplot_axes& operator = (const subplot_axes&);
 };
 
 class
@@ -322,9 +354,9 @@ public:
 
   octave_value extract_plot_data (int ndim, octave_value& data);
 
-  int handle_plot_data (int ndim, ostrstream& plot_buf);
+  int handle_plot_data (int ndim, std::ostrstream& plot_buf);
 
-  int print (int ndim, ostrstream& plot_buf);
+  int print (int ndim, std::ostrstream& plot_buf);
 
   tree_expression *plot_data (void) { return sp_plot_data; }
 
@@ -354,6 +386,12 @@ private:
 
   // The `axes' option
   subplot_axes *sp_axes_clause;
+
+  // No copying!
+
+  subplot (const subplot&);
+
+  subplot& operator = (const subplot&);
 };
 
 class
@@ -369,23 +407,29 @@ public:
 
   ~subplot_list (void);
 
-  int print (int ndim, ostrstream& plot_buf);
+  int print (int ndim, std::ostrstream& plot_buf);
 
   void accept (tree_walker& tw);
+
+private:
+
+  // No copying!
+
+  subplot_list (const subplot_list&);
+
+  subplot_list& operator = (const subplot_list&);
 };
 
-extern string save_in_tmp_file (octave_value& t, int ndim = 2,
+extern std::string save_in_tmp_file (octave_value& t, int ndim = 2,
 				bool parametric = false);
 
-extern void mark_for_deletion (const string&);
+extern void mark_for_deletion (const std::string&);
 
 extern void cleanup_tmp_files (void);
 
 extern void close_plot_stream (void);
 
-extern void do_external_plotter_cd (const string& newdir);
-
-extern void symbols_of_pt_plot (void);
+extern void do_external_plotter_cd (const std::string& newdir);
 
 #endif
 
