@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -28,11 +28,15 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
-#include <iostream.h>
+#include <cctype>
 
+#include <iostream>
+
+#include "comment-list.h"
 #include "error.h"
+#include "ov-usr-fcn.h"
 #include "pr-output.h"
-#include "pt-pr-code.h"
+#include "pt-all.h"
 
 void
 tree_print_code::visit_argument_list (tree_argument_list& lst)
@@ -60,10 +64,7 @@ tree_print_code::visit_binary_expression (tree_binary_expression& expr)
 {
   indent ();
 
-  bool in_parens = expr.is_in_parens ();
-
-  if (in_parens)
-    os << "(";
+  print_parens (expr, "(");
 
   tree_expression *op1 = expr.lhs ();
 
@@ -77,8 +78,7 @@ tree_print_code::visit_binary_expression (tree_binary_expression& expr)
   if (op2)
     op2->accept (*this);
 
-  if (in_parens)
-    os << ")";
+  print_parens (expr, ")");
 }
 
 void
@@ -89,22 +89,12 @@ tree_print_code::visit_break_command (tree_break_command&)
   os << "break";
 }
 
-void
-tree_print_code::visit_builtin (tree_builtin& fcn)
-{
-  os << fcn.name ()
-     << " can't be printed because it is a built-in function\n";
-}
-
 void
 tree_print_code::visit_colon_expression (tree_colon_expression& expr)
 {
   indent ();
 
-  bool in_parens = expr.is_in_parens ();
-
-  if (in_parens)
-    os << "(";
+  print_parens (expr, "(");
 
   tree_expression *op1 = expr.base ();
 
@@ -129,8 +119,7 @@ tree_print_code::visit_colon_expression (tree_colon_expression& expr)
       op2->accept (*this);
     }
 
-  if (in_parens)
-    os << ")";
+  print_parens (expr, ")");
 }
 
 void
@@ -142,16 +131,70 @@ tree_print_code::visit_continue_command (tree_continue_command&)
 }
 
 void
-tree_print_code::visit_for_command (tree_for_command& cmd)
+tree_print_code::visit_decl_command (tree_decl_command& cmd)
 {
   indent ();
 
+  os << cmd.name () << " ";
+
+  tree_decl_init_list *init_list = cmd.initializer_list ();
+
+  if (init_list)
+    init_list->accept (*this);
+}
+
+void
+tree_print_code::visit_decl_elt (tree_decl_elt& cmd)
+{
+  tree_identifier *id = cmd.ident ();
+
+  if (id)
+    id->accept (*this);
+
+  tree_expression *expr = cmd.expression ();
+
+  if (expr)
+    {
+      os << " = ";
+
+      expr->accept (*this);
+    }
+}
+
+void
+tree_print_code::visit_decl_init_list (tree_decl_init_list& lst)
+{
+  Pix p = lst.first ();
+
+  while (p)
+    {
+      tree_decl_elt *elt = lst (p);
+
+      lst.next (p);
+
+      if (elt)
+	{
+	  elt->accept (*this);
+
+	  if (p)
+	    os << ", ";
+	}
+    }
+}
+
+void
+tree_print_code::visit_simple_for_command (tree_simple_for_command& cmd)
+{
+  print_comment_list (cmd.leading_comment ());
+
+  indent ();
+
   os << "for ";
 
-  tree_index_expression *id = cmd.ident ();
+  tree_expression *lhs = cmd.left_hand_side ();
 
-  if (id)
-    id->accept (*this);
+  if (lhs)
+    lhs->accept (*this);
 
   os << " = ";
 
@@ -167,37 +210,92 @@ tree_print_code::visit_for_command (tree_for_command& cmd)
   if (list)
     {
       increment_indent_level ();
+
       list->accept (*this);
+
       decrement_indent_level ();
     }
 
+  print_indented_comment (cmd.trailing_comment ());
+
   indent ();
 
   os << "endfor";
 }
 
 void
-tree_print_code::visit_function (tree_function& fcn)
+tree_print_code::visit_complex_for_command (tree_complex_for_command& cmd)
+{
+  print_comment_list (cmd.leading_comment ());
+
+  indent ();
+
+  os << "for [";
+
+  tree_argument_list *lhs = cmd.left_hand_side ();
+
+  if (lhs)
+    lhs->accept (*this);
+
+  os << "] = ";
+
+  tree_expression *expr = cmd.control_expr ();
+
+  if (expr)
+    expr->accept (*this);
+
+  newline ();
+
+  tree_statement_list *list = cmd.body ();
+
+  if (list)
+    {
+      increment_indent_level ();
+
+      list->accept (*this);
+
+      decrement_indent_level ();
+    }
+
+  print_indented_comment (cmd.trailing_comment ());
+
+  indent ();
+
+  os << "endfor";
+}
+
+void
+tree_print_code::visit_octave_user_function (octave_user_function& fcn)
 {
   reset ();
 
-  visit_function_header (fcn);
+  visit_octave_user_function_header (fcn);
 
   tree_statement_list *cmd_list = fcn.body ();
 
   if (cmd_list)
     {
       increment_indent_level ();
+
       cmd_list->accept (*this);
+
       decrement_indent_level ();
     }
 
-  visit_function_trailer (fcn);
+  visit_octave_user_function_trailer (fcn);
 }
 
 void
-tree_print_code::visit_function_header (tree_function& fcn)
+tree_print_code::visit_octave_user_function_header (octave_user_function& fcn)
 {
+  octave_comment_list *leading_comment = fcn.leading_comment ();
+
+  if (leading_comment)
+    {
+      print_comment_list (leading_comment);
+      newline ();
+    }
+
   indent ();
 
   os << "function ";
@@ -229,9 +327,9 @@ tree_print_code::visit_function_header (tree_function& fcn)
       os << " = ";
     }
 
-  string fcn_name = fcn.function_name ();
+  std::string fcn_name = fcn.function_name ();
 
-  os << (fcn_name.empty () ? string ("(empty)") : fcn_name) << " ";
+  os << (fcn_name.empty () ? std::string ("(empty)") : fcn_name) << " ";
 
   tree_parameter_list *param_list = fcn.parameter_list ();
 
@@ -268,8 +366,10 @@ tree_print_code::visit_function_header (tree_function& fcn)
 }
 
 void
-tree_print_code::visit_function_trailer (tree_function&)
+tree_print_code::visit_octave_user_function_trailer (octave_user_function& fcn)
 {
+  print_indented_comment (fcn.trailing_comment ());
+
   indent ();
 
   os << "endfunction";
@@ -277,69 +377,17 @@ tree_print_code::visit_function_trailer (tree_function&)
   newline ();
 }
 
-void
-tree_print_code::visit_global (tree_global& cmd)
-{
-  tree_identifier *id = cmd.ident ();
-
-  if (id)
-    id->accept (*this);
-
-  tree_simple_assignment_expression *ass_expr = cmd.assign_expr ();
-
-  if (ass_expr)
-    ass_expr->accept (*this);
-}
-
-void
-tree_print_code::visit_global_command (tree_global_command& cmd)
-{
-  indent ();
-
-  os << "global ";
-
-  tree_global_init_list *init_list = cmd.initializer_list ();
-
-  if (init_list)
-    init_list->accept (*this);
-}
-
-void
-tree_print_code::visit_global_init_list (tree_global_init_list& lst)
-{
-  Pix p = lst.first ();
-
-  while (p)
-    {
-      tree_global *elt = lst (p);
-
-      lst.next (p);
-
-      if (elt)
-	{
-	  elt->accept (*this);
-
-	  if (p)
-	    os << ", ";
-	}
-    }
-}
-
 void
 tree_print_code::visit_identifier (tree_identifier& id)
 {
   indent ();
 
-  bool in_parens = id.is_in_parens ();
+  print_parens (id, "(");
 
-  if (in_parens)
-    os << "(";
+  std::string nm = id.name ();
+  os << (nm.empty () ? std::string ("(empty)") : nm);
 
-  string nm = id.name ();
-  os << (nm.empty () ? string ("(empty)") : nm);
-
-  if (in_parens)
-    os << ")";
+  print_parens (id, ")");
 }
 
 void
@@ -352,12 +400,12 @@ tree_print_code::visit_if_clause (tree_if_clause& cmd)
 
   newline ();
 
-  increment_indent_level ();
-
   tree_statement_list *list = cmd.commands ();
 
   if (list)
     {
+      increment_indent_level ();
+
       list->accept (*this);
 
       decrement_indent_level ();
@@ -367,6 +415,8 @@ tree_print_code::visit_if_clause (tree_if_clause& cmd)
 void
 tree_print_code::visit_if_command (tree_if_command& cmd)
 {
+  print_comment_list (cmd.leading_comment ());
+
   indent ();
 
   os << "if ";
@@ -376,6 +426,8 @@ tree_print_code::visit_if_command (tree_if_command& cmd)
   if (list)
     list->accept (*this);
 
+  print_indented_comment (cmd.trailing_comment ());
+
   indent ();
 
   os << "endif";
@@ -396,6 +448,8 @@ tree_print_code::visit_if_command_list (tree_if_command_list& lst)
 	{
 	  if (! first_elt)
 	    {
+	      print_indented_comment (elt->leading_comment ());
+
 	      indent ();
 
 	      if (elt->is_else_clause ())
@@ -412,91 +466,23 @@ tree_print_code::visit_if_command_list (tree_if_command_list& lst)
     }
 }
 
-void
-tree_print_code::visit_switch_case (tree_switch_case& cs)
-{
-  indent ();
-
-  if (cs.is_default_case ())
-    os << "otherwise";
-  else
-    os << "case ";
-
-  tree_expression *label = cs.case_label ();
-
-  if (label)
-    label->accept (*this);
-
-  newline ();
-
-  increment_indent_level ();
-
-  tree_statement_list *list = cs.commands ();
-
-  if (list)
-    {
-      list->accept (*this);
-
-      decrement_indent_level ();
-    }
-}
-
-void
-tree_print_code::visit_switch_case_list (tree_switch_case_list& lst)
-{
-  Pix p = lst.first ();
-
-  while (p)
-    {
-      tree_switch_case *elt = lst (p);
-
-      if (elt)
-	elt->accept (*this);
-
-      lst.next (p);
-    }
-}
-
-void
-tree_print_code::visit_switch_command (tree_switch_command& cmd)
-{
-  indent ();
-
-  os << "switch ";
-
-  tree_expression *expr = cmd.switch_value ();
-
-  if (expr)
-    expr->accept (*this);
-
-  newline ();
-
-  increment_indent_level ();
-
-  tree_switch_case_list *list = cmd.case_list ();
-
-  if (list)
-    list->accept (*this);
-
-  indent ();
-
-  os << "endswitch";
-}
-
 void
 tree_print_code::visit_index_expression (tree_index_expression& expr)
 {
   indent ();
 
-  bool in_parens = expr.is_in_parens ();
+  print_parens (expr, "(");
 
-  if (in_parens)
-    os << "(";
+  bool expr_has_parens = false;
 
-  tree_indirect_ref *id = expr.ident ();
+  tree_expression *e = expr.expression ();
 
-  if (id)
-    id->accept (*this);
+  if (e)
+    {
+      e->accept (*this);
+
+      expr_has_parens = e->is_postfix_indexed ();
+    }
 
   tree_argument_list *list = expr.arg_list ();
 
@@ -506,9 +492,10 @@ tree_print_code::visit_index_expression (tree_index_expression& expr)
       list->accept (*this);
       os << ")";
     }
+  else if (expr_has_parens)
+    os << " ()";
 
-  if (in_parens)
-    os << ")";
+  print_parens (expr, ")");
 }
 
 void
@@ -516,18 +503,16 @@ tree_print_code::visit_indirect_ref (tree_indirect_ref& expr)
 {
   indent ();
 
-  bool in_parens = expr.is_in_parens ();
+  print_parens (expr, "(");
 
-  if (in_parens)
-    os << "(";
+  tree_expression *e = expr.expression ();
 
-  // The name of the indirect ref includes the sub-elements.
+  if (e)
+    e->accept (*this);
 
-  string nm = expr.name ();
-  os << (nm.empty () ? string ("(empty)") : nm);
+  os << "." << expr.elt_name ();
 
-  if (in_parens)
-    os << ")";
+  print_parens (expr, ")");
 }
 
 void
@@ -535,10 +520,7 @@ tree_print_code::visit_matrix (tree_matrix& lst)
 {
   indent ();
 
-  bool in_parens = lst.is_in_parens ();
-
-  if (in_parens)
-    os << "(";
+  print_parens (lst, "(");
 
   os << "[";
 
@@ -546,7 +528,7 @@ tree_print_code::visit_matrix (tree_matrix& lst)
 
   while (p)
     {
-      tree_matrix_row *elt = lst (p);
+      tree_argument_list *elt = lst (p);
 
       lst.next (p);
 
@@ -561,18 +543,23 @@ tree_print_code::visit_matrix (tree_matrix& lst)
 
   os << "]";
 
-  if (in_parens)
-    os << ")";
+  print_parens (lst, ")");
 }
 
 void
-tree_print_code::visit_matrix_row (tree_matrix_row& lst)
+tree_print_code::visit_cell (tree_cell& lst)
 {
+  indent ();
+
+  print_parens (lst, "(");
+
+  os << "{";
+
   Pix p = lst.first ();
 
   while (p)
     {
-      tree_expression *elt = lst (p);
+      tree_argument_list *elt = lst (p);
 
       lst.next (p);
 
@@ -581,23 +568,23 @@ tree_print_code::visit_matrix_row (tree_matrix_row& lst)
 	  elt->accept (*this);
 
 	  if (p)
-	    os << ", ";
+	    os << "; ";
 	}
     }
+
+  os << "}";
+
+  print_parens (lst, ")");
 }
 
 void
-tree_print_code::visit_multi_assignment_expression
-  (tree_multi_assignment_expression& expr)
+tree_print_code::visit_multi_assignment (tree_multi_assignment& expr)
 {
   indent ();
 
-  bool in_parens = expr.is_in_parens ();
+  print_parens (expr, "(");
 
-  if (in_parens)
-    os << "(";
-
-  tree_return_list *lhs = expr.left_hand_side ();
+  tree_argument_list *lhs = expr.left_hand_side ();
 
   if (lhs)
     {
@@ -612,15 +599,14 @@ tree_print_code::visit_multi_assignment_expression
 	os << "]";
     }
 
-  os << " = ";
+  os << " " << expr.oper () << " ";
 
-  tree_multi_val_ret *rhs = expr.right_hand_side ();
+  tree_expression *rhs = expr.right_hand_side ();
 
   if (rhs)
     rhs->accept (*this);
 
-  if (in_parens)
-    os << ")";
+  print_parens (expr, ")");
 }
 
 void
@@ -631,26 +617,16 @@ tree_print_code::visit_no_op_command (tree_no_op_command& cmd)
   os << cmd.original_command ();
 }
 
-void
-tree_print_code::visit_oct_obj (tree_oct_obj&)
-{
-  ::error ("visit_oct_obj: internal error");
-}
-
 void
 tree_print_code::visit_constant (tree_constant& val)
 {
   indent ();
 
-  bool in_parens = val.is_in_parens ();
+  print_parens (val, "(");
 
-  if (in_parens)
-    os << "(";
+  val.print_raw (os, true, print_original_text);
 
-  val.print (os, true, print_original_text);
-
-  if (in_parens)
-    os << ")";
+  print_parens (val, ")");
 }
 
 void
@@ -755,20 +731,16 @@ tree_print_code::visit_postfix_expression (tree_postfix_expression& expr)
 {
   indent ();
 
-  bool in_parens = expr.is_in_parens ();
+  print_parens (expr, "(");
 
-  if (in_parens)
-    os << "(";
+  tree_expression *e = expr.operand ();
 
-  tree_identifier *id = expr.ident ();
-
-  if (id)
-    id->accept (*this);
+  if (e)
+    e->accept (*this);
 
   os << expr.oper ();
 
-  if (in_parens)
-    os << ")";
+  print_parens (expr, ")");
 }
 
 void
@@ -776,20 +748,16 @@ tree_print_code::visit_prefix_expression (tree_prefix_expression& expr)
 {
   indent ();
 
-  bool in_parens = expr.is_in_parens ();
-
-  if (in_parens)
-    os << "(";
+  print_parens (expr, "(");
 
   os << expr.oper ();
 
-  tree_identifier *id = expr.ident ();
+  tree_expression *e = expr.operand ();
 
-  if (id)
-    id->accept (*this);
+  if (e)
+    e->accept (*this);
 
-  if (in_parens)
-    os << ")";
+  print_parens (expr, ")");
 }
 
 void
@@ -822,47 +790,32 @@ tree_print_code::visit_return_list (tree_return_list& lst)
 }
 
 void
-tree_print_code::visit_simple_assignment_expression
-  (tree_simple_assignment_expression& expr)
+tree_print_code::visit_simple_assignment (tree_simple_assignment& expr)
 {
   indent ();
 
-  bool in_parens = expr.is_in_parens ();
+  print_parens (expr, "(");
 
-  if (in_parens)
-    os << "(";
+  tree_expression *lhs = expr.left_hand_side ();
 
-  if (! expr.is_ans_assign ())
-    {
-      tree_indirect_ref *lhs = expr.left_hand_side ();
+  if (lhs)
+    lhs->accept (*this);
 
-      if (lhs)
-	lhs->accept (*this);
-
-      tree_argument_list *index = expr.lhs_index ();
-
-      if (index)
-	{
-	  os << " (";
-	  index->accept (*this);
-	  os << ")";
-	}
-
-      os << " = ";
-    }
+  os << " " << expr.oper () << " ";
 
   tree_expression *rhs = expr.right_hand_side ();
 
   if (rhs)
     rhs->accept (*this);
 
-  if (in_parens)
-    os << ")";
+  print_parens (expr, ")");
 }
 
 void
 tree_print_code::visit_statement (tree_statement& stmt)
 {
+  print_comment_list (stmt.comment_text ());
+
   tree_command *cmd = stmt.command ();
 
   if (cmd)
@@ -1016,11 +969,96 @@ tree_print_code::visit_subplot_using (subplot_using& cmd)
 }
 
 void
-tree_print_code::visit_try_catch_command (tree_try_catch_command& cmd)
+tree_print_code::visit_switch_case (tree_switch_case& cs)
 {
+  print_comment_list (cs.leading_comment ());
+
   indent ();
 
-  os << "try_catch";
+  if (cs.is_default_case ())
+    os << "otherwise";
+  else
+    os << "case ";
+
+  tree_expression *label = cs.case_label ();
+
+  if (label)
+    label->accept (*this);
+
+  newline ();
+
+  tree_statement_list *list = cs.commands ();
+
+  if (list)
+    {
+      increment_indent_level ();
+
+      list->accept (*this);
+
+      newline ();
+
+      decrement_indent_level ();
+    }
+}
+
+void
+tree_print_code::visit_switch_case_list (tree_switch_case_list& lst)
+{
+  Pix p = lst.first ();
+
+  while (p)
+    {
+      tree_switch_case *elt = lst (p);
+
+      if (elt)
+	elt->accept (*this);
+
+      lst.next (p);
+    }
+}
+
+void
+tree_print_code::visit_switch_command (tree_switch_command& cmd)
+{
+  print_comment_list (cmd.leading_comment ());
+
+  indent ();
+
+  os << "switch ";
+
+  tree_expression *expr = cmd.switch_value ();
+
+  if (expr)
+    expr->accept (*this);
+
+  newline ();
+
+  tree_switch_case_list *list = cmd.case_list ();
+
+  if (list)
+    {
+      increment_indent_level ();
+
+      list->accept (*this);
+
+      decrement_indent_level ();
+    }
+
+  print_indented_comment (cmd.leading_comment ());
+
+  indent ();
+
+  os << "endswitch";
+}
+
+void
+tree_print_code::visit_try_catch_command (tree_try_catch_command& cmd)
+{
+  print_comment_list (cmd.leading_comment ());
+
+  indent ();
+
+  os << "try";
 
   newline ();
 
@@ -1029,10 +1067,14 @@ tree_print_code::visit_try_catch_command (tree_try_catch_command& cmd)
   if (try_code)
     {
       increment_indent_level ();
+
       try_code->accept (*this);
+
       decrement_indent_level ();
     }
 
+  print_indented_comment (cmd.middle_comment ());
+
   indent ();
 
   os << "catch";
@@ -1044,50 +1086,25 @@ tree_print_code::visit_try_catch_command (tree_try_catch_command& cmd)
   if (catch_code)
     {
       increment_indent_level ();
+
       catch_code->accept (*this);
+
       decrement_indent_level ();
     }
 
+  print_indented_comment (cmd.trailing_comment ());
+
   indent ();
 
   os << "end_try_catch";
 }
 
-void
-tree_print_code::visit_unary_expression (tree_unary_expression& expr)
-{
-  indent ();
-
-  bool in_parens = expr.is_in_parens ();
-
-  if (in_parens)
-    os << "(";
-
-  tree_expression *op = expr.operand ();
-
-  if (expr.is_prefix_op ())
-    {
-      os << expr.oper ();
-
-      if (op)
-	op->accept (*this);
-    }
-  else
-    {
-      if (op)
-	op->accept (*this);
-
-      os << expr.oper ();
-    }
-
-  if (in_parens)
-    os << ")";
-}
-
 void
 tree_print_code::visit_unwind_protect_command
   (tree_unwind_protect_command& cmd)
 {
+  print_comment_list (cmd.leading_comment ());
+
   indent ();
 
   os << "unwind_protect";
@@ -1099,10 +1116,14 @@ tree_print_code::visit_unwind_protect_command
   if (unwind_protect_code)
     {
       increment_indent_level ();
+
       unwind_protect_code->accept (*this);
+
       decrement_indent_level ();
     }
 
+  print_indented_comment (cmd.middle_comment ());
+
   indent ();
 
   os << "unwind_protect_cleanup";
@@ -1114,10 +1135,14 @@ tree_print_code::visit_unwind_protect_command
   if (cleanup_code)
     {
       increment_indent_level ();
+
       cleanup_code->accept (*this);
+
       decrement_indent_level ();
     }
 
+  print_indented_comment (cmd.trailing_comment ());
+
   indent ();
 
   os << "end_unwind_protect";
@@ -1126,6 +1151,8 @@ tree_print_code::visit_unwind_protect_command
 void
 tree_print_code::visit_while_command (tree_while_command& cmd)
 {
+  print_comment_list (cmd.leading_comment ());
+
   indent ();
 
   os << "while ";
@@ -1142,20 +1169,54 @@ tree_print_code::visit_while_command (tree_while_command& cmd)
   if (list)
     {
       increment_indent_level ();
+
       list->accept (*this);
+
       decrement_indent_level ();
     }
 
+  print_indented_comment (cmd.trailing_comment ());
+
   indent ();
 
   os << "endwhile";
 }
 
-// Current indentation.
-int tree_print_code::curr_print_indent_level = 0;
+void
+tree_print_code::visit_do_until_command (tree_do_until_command& cmd)
+{
+  print_comment_list (cmd.leading_comment ());
 
-// Nonzero means we are at the beginning of a line.
-bool tree_print_code::beginning_of_line = true;
+  indent ();
+
+  os << "do";
+
+  newline ();
+
+  tree_statement_list *list = cmd.body ();
+
+  if (list)
+    {
+      increment_indent_level ();
+
+      list->accept (*this);
+
+      decrement_indent_level ();
+    }
+
+  print_indented_comment (cmd.trailing_comment ());
+
+  indent ();
+
+  os << "until";
+
+  tree_expression *expr = cmd.condition ();
+
+  if (expr)
+    expr->accept (*this);
+
+  newline ();
+}
 
 // Each print_code() function should call this before printing
 // anything.
@@ -1169,7 +1230,11 @@ tree_print_code::indent (void)
  
   if (beginning_of_line)
     {
-      os.form ("%s%*s", prefix.c_str (), curr_print_indent_level, "");
+      os << prefix;
+
+      for (int i = 0; i < curr_print_indent_level; i++)
+	os << " ";
+
       beginning_of_line = false;
     }
 }
@@ -1193,6 +1258,100 @@ tree_print_code::reset (void)
   curr_print_indent_level = 0;
 }
 
+void
+tree_print_code::print_parens (const tree_expression& expr, const char *txt)
+{
+  int n = expr.paren_count ();
+
+  for (int i = 0; i < n; i++)
+    os << txt;
+}
+
+void
+tree_print_code::print_comment_elt (const octave_comment_elt& elt)
+{
+  bool printed_something = false;
+
+  bool prev_char_was_newline = false;
+
+  std::string comment = elt.text ();
+
+  size_t len = comment.length ();
+
+  size_t i = 0;
+
+  while (i < len && comment[i++] == '\n')
+    ; /* Skip leading new lines. */
+  i--;
+
+  while (i < len)
+    {
+      char c = comment[i++];
+
+      if (c == '\n')
+	{
+	  if (prev_char_was_newline)
+	    os << "##";
+
+	  newline ();
+
+	  prev_char_was_newline = true;
+	}
+      else
+	{
+	  if (beginning_of_line)
+	    {
+	      printed_something = true;
+
+	      indent ();
+
+	      os << "##";
+
+	      if (! (isspace (c) || c == '!'))
+		os << " ";
+	    }
+
+	  os << (char) c;
+
+	  prev_char_was_newline = false;
+	}
+    }
+
+  if (printed_something && ! beginning_of_line)
+    newline ();
+}
+
+void
+tree_print_code::print_comment_list (octave_comment_list *comment_list)
+{
+  if (comment_list)
+    {
+      Pix p = comment_list->first ();
+
+      while (p)
+	{
+	  octave_comment_elt elt = comment_list->operator () (p);
+
+	  print_comment_elt (elt);
+
+	  comment_list->next (p);
+
+	  if (p)
+	    newline ();
+	}
+    }
+}
+
+void
+tree_print_code::print_indented_comment (octave_comment_list *comment_list)
+{
+  increment_indent_level ();
+
+  print_comment_list (comment_list);
+
+  decrement_indent_level ();
+}
+
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
