@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,8 +29,11 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <string>
 
+#include "comment-list.h"
 #include "pt-walk.h"
 
+class tree_expression;
+
 // How to print the code that the parse trees represent.
 
 class
@@ -38,9 +41,11 @@ tree_print_code : public tree_walker
 {
 public:
 
-  tree_print_code (ostream& os_arg, const string& pfx = string (),
+  tree_print_code (std::ostream& os_arg,
+		   const std::string& pfx = std::string (),
 		   bool pr_orig_txt = true)
-    : os (os_arg), prefix (pfx), print_original_text (pr_orig_txt) { }
+    : os (os_arg), prefix (pfx), print_original_text (pr_orig_txt),
+      curr_print_indent_level (0), beginning_of_line (true) { }
 
   ~tree_print_code (void) { }
 
@@ -50,25 +55,25 @@ public:
 
   void visit_break_command (tree_break_command&);
 
-  void visit_builtin (tree_builtin&);
-
   void visit_colon_expression (tree_colon_expression&);
 
   void visit_continue_command (tree_continue_command&);
 
-  void visit_for_command (tree_for_command&);
+  void visit_decl_command (tree_decl_command&);
 
-  void visit_function (tree_function&);
+  void visit_decl_elt (tree_decl_elt&);
 
-  void visit_function_header (tree_function&);
+  void visit_decl_init_list (tree_decl_init_list&);
 
-  void visit_function_trailer (tree_function&);
+  void visit_simple_for_command (tree_simple_for_command&);
 
-  void visit_global (tree_global&);
+  void visit_complex_for_command (tree_complex_for_command&);
 
-  void visit_global_command (tree_global_command&);
+  void visit_octave_user_function (octave_user_function&);
 
-  void visit_global_init_list (tree_global_init_list&);
+  void visit_octave_user_function_header (octave_user_function&);
+
+  void visit_octave_user_function_trailer (octave_user_function&);
 
   void visit_identifier (tree_identifier&);
 
@@ -78,26 +83,18 @@ public:
 
   void visit_if_command_list (tree_if_command_list&);
 
-  void visit_switch_case (tree_switch_case&);
-
-  void visit_switch_case_list (tree_switch_case_list&);
-
-  void visit_switch_command (tree_switch_command&);
-
   void visit_index_expression (tree_index_expression&);
 
   void visit_indirect_ref (tree_indirect_ref&);
 
   void visit_matrix (tree_matrix&);
 
-  void visit_matrix_row (tree_matrix_row&);
+  void visit_cell (tree_cell&);
 
-  void visit_multi_assignment_expression (tree_multi_assignment_expression&);
+  void visit_multi_assignment (tree_multi_assignment&);
 
   void visit_no_op_command (tree_no_op_command&);
 
-  void visit_oct_obj (tree_oct_obj&);
-
   void visit_constant (tree_constant&);
 
   void visit_parameter_list (tree_parameter_list&);
@@ -116,7 +113,7 @@ public:
 
   void visit_return_list (tree_return_list&);
 
-  void visit_simple_assignment_expression (tree_simple_assignment_expression&);
+  void visit_simple_assignment (tree_simple_assignment&);
 
   void visit_statement (tree_statement&);
 
@@ -132,24 +129,33 @@ public:
 
   void visit_subplot_using (subplot_using&);
 
-  void visit_try_catch_command (tree_try_catch_command&);
+  void visit_switch_case (tree_switch_case&);
 
-  void visit_unary_expression (tree_unary_expression&);
+  void visit_switch_case_list (tree_switch_case_list&);
+
+  void visit_switch_command (tree_switch_command&);
+
+  void visit_try_catch_command (tree_try_catch_command&);
 
   void visit_unwind_protect_command (tree_unwind_protect_command&);
 
   void visit_while_command (tree_while_command&);
 
+  void visit_do_until_command (tree_do_until_command&);
+
 private:
 
-  ostream& os;
+  std::ostream& os;
 
-  string prefix;
+  std::string prefix;
 
   bool print_original_text;
 
-  static int curr_print_indent_level;
-  static bool beginning_of_line;
+  // Current indentation.
+  int curr_print_indent_level;
+
+  // TRUE means we are at the beginning of a line.
+  bool beginning_of_line;
 
   void reset_indent_level (void)
     { curr_print_indent_level = 0; }
@@ -166,6 +172,14 @@ private:
 
   void reset (void);
 
+  void print_parens (const tree_expression& expr, const char *txt);
+
+  void print_comment_list (octave_comment_list *comment_list);
+
+  void print_comment_elt (const octave_comment_elt& comment_elt);
+
+  void print_indented_comment (octave_comment_list *comment_list);
+
   // Must create with an output stream!
 
   tree_print_code (void);
