@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -23,15 +23,51 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #if !defined (octave_tree_walker_h)
 #define octave_tree_walker_h 1
 
-#include "pt-cmd.h"
-#include "pt-const.h"
-#include "pt-exp.h"
-#include "pt-fcn.h"
-#include "pt-fvc.h"
-#include "pt-mat.h"
-#include "pt-misc.h"
-#include "pt-mvr.h"
-#include "pt-plot.h"
+class tree_argument_list;
+class tree_binary_expression;
+class tree_break_command;
+class tree_colon_expression;
+class tree_continue_command;
+class tree_decl_command;
+class tree_decl_elt;
+class tree_decl_init_list;
+class tree_simple_for_command;
+class tree_complex_for_command;
+class octave_user_function;
+class tree_identifier;
+class tree_if_clause;
+class tree_if_command;
+class tree_if_command_list;
+class tree_switch_case;
+class tree_switch_case_list;
+class tree_switch_command;
+class tree_index_expression;
+class tree_indirect_ref;
+class tree_matrix;
+class tree_cell;
+class tree_multi_assignment;
+class tree_no_op_command;
+class tree_constant;
+class tree_parameter_list;
+class tree_plot_command;
+class plot_limits;
+class plot_range;
+class tree_postfix_expression;
+class tree_prefix_expression;
+class tree_return_command;
+class tree_return_list;
+class tree_simple_assignment;
+class tree_statement;
+class tree_statement_list;
+class subplot;
+class subplot_axes;
+class subplot_list;
+class subplot_style;
+class subplot_using;
+class tree_try_catch_command;
+class tree_unwind_protect_command;
+class tree_while_command;
+class tree_do_until_command;
 
 class
 tree_walker
@@ -47,9 +83,6 @@ public:
   virtual void
   visit_break_command (tree_break_command&) = 0;
 
-  virtual void
-  visit_builtin (tree_builtin&) = 0;
-
   virtual void
   visit_colon_expression (tree_colon_expression&) = 0;
 
@@ -57,19 +90,22 @@ public:
   visit_continue_command (tree_continue_command&) = 0;
 
   virtual void
-  visit_for_command (tree_for_command&) = 0;
+  visit_decl_command (tree_decl_command&) = 0;
 
   virtual void
-  visit_function (tree_function&) = 0;
+  visit_decl_elt (tree_decl_elt&) = 0;
 
   virtual void
-  visit_global (tree_global&) = 0;
+  visit_decl_init_list (tree_decl_init_list&) = 0;
 
   virtual void
-  visit_global_command (tree_global_command&) = 0;
+  visit_simple_for_command (tree_simple_for_command&) = 0;
 
   virtual void
-  visit_global_init_list (tree_global_init_list&) = 0;
+  visit_complex_for_command (tree_complex_for_command&) = 0;
+
+  virtual void
+  visit_octave_user_function (octave_user_function&) = 0;
 
   virtual void
   visit_identifier (tree_identifier&) = 0;
@@ -102,17 +138,14 @@ public:
   visit_matrix (tree_matrix&) = 0;
 
   virtual void
-  visit_matrix_row (tree_matrix_row&) = 0;
+  visit_cell (tree_cell&) = 0;
 
   virtual void
-  visit_multi_assignment_expression (tree_multi_assignment_expression&) = 0;
+  visit_multi_assignment (tree_multi_assignment&) = 0;
 
   virtual void
   visit_no_op_command (tree_no_op_command&) = 0;
 
-  virtual void
-  visit_oct_obj (tree_oct_obj&) = 0;
-
   virtual void
   visit_constant (tree_constant&) = 0;
 
@@ -141,7 +174,7 @@ public:
   visit_return_list (tree_return_list&) = 0;
 
   virtual void
-  visit_simple_assignment_expression (tree_simple_assignment_expression&) = 0;
+  visit_simple_assignment (tree_simple_assignment&) = 0;
 
   virtual void
   visit_statement (tree_statement&) = 0;
@@ -167,15 +200,15 @@ public:
   virtual void
   visit_try_catch_command (tree_try_catch_command&) = 0;
 
-  virtual void
-  visit_unary_expression (tree_unary_expression&) = 0;
-
   virtual void
   visit_unwind_protect_command (tree_unwind_protect_command&) = 0;
 
   virtual void
   visit_while_command (tree_while_command&) = 0;
 
+  virtual void
+  visit_do_until_command (tree_do_until_command&) = 0;
+
 protected:
 
   tree_walker (void) { }
