@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,14 +20,28 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
+/*
+
+The signal blocking macros defined below were adapted from similar
+functions from GNU Bash, the Bourne Again SHell, copyright (C) 1994
+Free Software Foundation, Inc.
+
+*/
+
 // This file should always be included after config.h!
 
 #if !defined (octave_sighandlers_h)
 #define octave_sighandlers_h 1
 
-#include <Array.h>
+// Include signal.h, not csignal since the latter might only define
+// the ANSI standard C signal interface.
+
+#include <signal.h>
 
 #include "syswait.h"
+#include "siglist.h"
+
+#include <Array.h>
 
 // Signal handler return type.
 #ifndef RETSIGTYPE
@@ -37,8 +51,6 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define BADSIG (RETSIGTYPE (*)(int))-1
 #endif
 
-// The following signal blocking stuff is stolen from bash:
-
 #define BLOCK_SIGNAL(sig, nvar, ovar) \
   do \
     { \
@@ -77,8 +89,8 @@ octave_interrupt_handler
 // SIGPIPES.  We assume that the writer will eventually give up.
 extern int pipe_handler_error_count;
 
-// Nonzero means we can be interrupted.
-extern int can_interrupt;
+// TRUE means we can be interrupted.
+extern bool can_interrupt;
 
 extern sig_handler *octave_set_signal_handler (int, sig_handler *);
 
@@ -97,12 +109,6 @@ extern void octave_restore_signal_mask (void);
 
 // extern void ignore_sigchld (void);
 
-// This is taken directly from Emacs 19:
-
-#ifndef SYS_SIGLIST_DECLARED
-extern char *sys_siglist[];
-#endif
-
 // Maybe this should be in a separate file?
 
 class
@@ -148,26 +154,15 @@ public:
 
   ~octave_child_list (void) { }
 
+  static bool instance_ok (void);
+
   static void insert (pid_t pid, octave_child::dead_child_handler f);
 
   static void remove (pid_t pid);
 
-  static int length (void) { return instance ? instance->curr_len : 0; }
+  static int length (void);
 
-  static octave_child& elem (int i)
-    {
-      static octave_child foo;
-
-      if (instance)
-	{
-	  int n = length ();
-
-	  if (i >= 0 && i < n)
-	    return instance->list (i);
-	}
-
-      return foo;
-    }
+  static octave_child& elem (int i);
 
 private:
 
@@ -180,6 +175,10 @@ private:
   void do_insert (pid_t pid, octave_child::dead_child_handler f);
 
   void do_remove (pid_t pid);
+
+  int do_length (void) const;
+
+  octave_child& do_elem (int i);
 };
 
 #endif
