@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -20,14 +20,6 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-/*
-
-The function gethostname was adapted from a similar function from GNU
-Bash, the Bourne Again SHell, copyright (C) 1987, 1989, 1991 Free
-Software Foundation, Inc.
-
-*/
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -39,10 +31,9 @@ Software Foundation, Inc.
 #include <cstdlib>
 #include <cstring>
 
+#include <iostream>
 #include <string>
 
-#include <iostream.h>
-
 #ifdef HAVE_UNISTD_H
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -60,10 +51,6 @@ Software Foundation, Inc.
 LOSE! LOSE!
 #endif
 
-#if defined (HAVE_TERMCAP_H)
-#include <termcap.h>
-#endif
-
 #if defined (HAVE_SYS_IOCTL_H)
 #include <sys/ioctl.h>
 #endif
@@ -80,20 +67,16 @@ LOSE! LOSE!
 #include <sys/utsname.h>
 #endif
 
-#if defined (USE_READLINE)
-#include <readline/readline.h>
-#include <readline/tilde.h>
-#endif
-
+#include "cmd-edit.h"
+#include "file-ops.h"
+#include "lo-mappers.h"
 #include "mach-info.h"
+#include "oct-env.h"
 
 #include "defun.h"
 #include "error.h"
-#include "help.h"
 #include "input.h"
-#include "mappers.h"
 #include "oct-obj.h"
-#include "pathlen.h"
 #include "ov.h"
 #include "pager.h"
 #include "sysdep.h"
@@ -128,9 +111,7 @@ malloc_handler (int code)
   if (code == 5)
     warning ("hopefully recoverable malloc error: freeing wild pointer");
   else
-    {
-      panic ("probably irrecoverable malloc error: code %d", code);
-    }
+    panic ("probably irrecoverable malloc error: code %d", code);
 }
 
 static void
@@ -188,9 +169,9 @@ sysdep_init (void)
 // It doesn't matter whether an input \n is mapped to \r, or vice versa.
 
 void
-raw_mode (int on)
+raw_mode (bool on, bool wait)
 {
-  static int curr_on = 0;
+  static bool curr_on = false;
 
   int tty_fd = STDIN_FILENO;
   if (! isatty (tty_fd))
@@ -234,7 +215,7 @@ raw_mode (int on)
 #if defined (ONLRET)
 	s.c_oflag &= ~(ONLRET);
 #endif
-	s.c_cc[VMIN] = 1;
+	s.c_cc[VMIN] = wait ? 1 : 0;
 	s.c_cc[VTIME] = 0;
       }      
     else
@@ -243,6 +224,7 @@ raw_mode (int on)
 
 	s = save_term;
       }
+
     tcsetattr (tty_fd, TCSAFLUSH, &s);
   }
 #elif defined (HAVE_TERMIO_H)
@@ -276,8 +258,7 @@ raw_mode (int on)
 #if defined (ONLRET)
 	s.c_oflag &= ~(ONLRET);
 #endif
-	s.c_cc[VMIN] = 1;
-	s.c_cc[VTIME] = 0;
+	s.c_cc[VMIN] = wait ? 1 : 0;
       }      
     else
       {
@@ -285,6 +266,7 @@ raw_mode (int on)
 
 	s = save_term;
       }
+
     ioctl (tty_fd, TCSETAW, &s);
   }
 #elif defined (HAVE_SGTTY_H)
@@ -316,6 +298,7 @@ raw_mode (int on)
 
 	s = save_term;
       }
+
     ioctl (tty_fd, TIOCSETN, &s);
   }
 #else
@@ -328,80 +311,46 @@ LOSE! LOSE!
 // Read one character from the terminal.
 
 int
-kbhit (void)
+kbhit (bool wait)
 {
-  int c;
-  raw_mode (1);
-  c = cin.get ();
-  raw_mode (0);
+  raw_mode (true, wait);
+
+  int c = std::cin.get ();
+
+  if (std::cin.fail () || std::cin.eof ())
+    std::cin.clear ();
+
+  raw_mode (false, true);
+
   return c;
 }
 
-string
-octave_getcwd (void)
-{
-  string retval;
-
-  char buf[MAXPATHLEN];
-
-  char *tmp = 0;
-
-#if defined (__EMX__)
-  tmp = _getcwd2 (buf, MAXPATHLEN);
-#elif defined (HAVE_GETCWD)
-  tmp = getcwd (buf, MAXPATHLEN);
-#elif defined (HAVE_GETWD)
-  tmp = getwd (buf);
-#endif
-
-  if (tmp)
-    retval = tmp;
-  else
-    error ("unable to find current directory");
-
-  return retval;
-}
-
-int
-octave_chdir (const string& path)
-{
-#if defined (__EMX__)
-  int retval = -1;
-
-  char *tmp_path = strsave (path.c_str ());
-
-  if (path.length () == 2 && path[1] == ':')
-    {
-      char *upper_case_dir_name = strupr (tmp_path);
-      _chdrive (upper_case_dir_name[0]);
-      if (_getdrive () == upper_case_dir_name[0])
-	retval = _chdir2 ("/");
-    }
-  else
-    retval = _chdir2 (tmp_path);
-
-  delete [] tmp_path;
-
-  return retval;
-#else
-  return chdir (path.c_str ());
-#endif
-}
-
 DEFUN (clc, , ,
-  "clc (): clear screen")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} clc ()\n\
+@deftypefnx {Built-in Function} {} home ()\n\
+Clear the terminal screen and move the cursor to the upper left corner.\n\
+@end deftypefn")
 {
-  octave_value_list retval;
+  command_editor::clear_screen ();
 
-  rl_clear_screen (0, 0);
-
-  return retval;
+  return octave_value_list ();
 }
 
 DEFALIAS (home, clc);
 
 DEFUN (getenv, args, ,
-  "getenv (STRING): get environment variable values")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} getenv (@var{var})\n\
+Return the value of the environment variable @var{var}.  For example,\n\
+\n\
+@example\n\
+getenv (\"PATH\")\n\
+@end example\n\
+\n\
+@noindent\n\
+returns a string containing the value of your path.\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -409,17 +358,10 @@ DEFUN (getenv, args, ,
 
   if (nargin == 1)
     {
-      string tstr = args(0).string_value ();
-      const char *name = tstr.c_str ();
+      std::string name = args(0).string_value ();
 
       if (! error_state)
-	{
-	  char *value = getenv (name);
-	  if (value)
-	    retval = value;
-	  else
-	    retval = "";
-	}
+	retval = octave_env::getenv (name);
     }
   else
     print_usage ("getenv");
@@ -428,7 +370,10 @@ DEFUN (getenv, args, ,
 }
 
 DEFUN (putenv, args, ,
-  "putenv (VAR, VALUE): define environment variable VAR=VALUE")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} putenv (@var{var}, @var{value})\n\
+Set the value of the environment variable @var{var} to @var{value}.\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -436,14 +381,14 @@ DEFUN (putenv, args, ,
 
   if (nargin == 2)
     {
-      string var = args(0).string_value (); 
+      std::string var = args(0).string_value (); 
 
       if (! error_state)
 	{
-	  string val = args(1).string_value (); 
+	  std::string val = args(1).string_value (); 
 
 	  if (! error_state)
-	    oct_putenv (var.c_str (), val.c_str ());
+	    octave_env::putenv (var, val);
 	  else
 	    error ("putenv: second argument should be a string");
 	}
@@ -456,16 +401,42 @@ DEFUN (putenv, args, ,
   return retval;
 }
 
-DEFUN (kbhit, , ,
-  "kbhit: get a single character from the terminal")
+// XXX FIXME XXX -- perhaps kbhit should also be able to print a prompt?
+
+DEFUN (kbhit, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} kbhit ()\n\
+Read a single keystroke from the keyboard. If called with one\n\
+argument, don't wait for a keypress.  For example,\n\
+\n\
+@example\n\
+x = kbhit ();\n\
+@end example\n\
+\n\
+@noindent\n\
+will set @var{x} to the next character typed at the keyboard as soon as\n\
+it is typed.\n\
+\n\
+@example\n\
+x = kbhit (1);\n\
+@end example\n\
+\n\
+@noindent\n\
+identical to the above example, but don't wait for a keypress,\n\
+returning the empty string if no key is available.\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
   // XXX FIXME XXX -- add timeout and default value args?
 
-  if (interactive)
+  if (interactive || forced_interactive)
     {
-      int c = kbhit ();
+      int c = kbhit (args.length () == 0);
+
+      if (c == -1)
+	c = 0;
+
       char *s = new char [2];
       s[0] = c;
       s[1] = '\0';
@@ -476,7 +447,22 @@ DEFUN (kbhit, , ,
 }
 
 DEFUN (pause, args, ,
-  "pause (seconds): suspend program execution")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} pause (@var{seconds})\n\
+Suspend the execution of the program.  If invoked without any arguments,\n\
+Octave waits until you type a character.  With a numeric argument, it\n\
+pauses for the given number of seconds.  For example, the following\n\
+statement prints a message and then waits 5 seconds before clearing the\n\
+screen.\n\
+\n\
+@example\n\
+@group\n\
+fprintf (stderr, \"wait please...\n\");\n\
+pause (5);\n\
+clc;\n\
+@end group\n\
+@end example\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -519,7 +505,10 @@ DEFUN (pause, args, ,
 }
 
 DEFUN (sleep, args, ,
-  "sleep (seconds): suspend program execution")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} sleep (@var{seconds})\n\
+Suspend the execution of the program for the given number of seconds.\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -546,7 +535,13 @@ DEFUN (sleep, args, ,
 }
 
 DEFUN (usleep, args, ,
-  "usleep (microseconds): suspend program execution")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} usleep (@var{microseconds})\n\
+Suspend the execution of the program for the given number of\n\
+microseconds.  On systems where it is not possible to sleep for periods\n\
+of time less than one second, @code{usleep} will pause the execution for\n\
+@code{round (@var{microseconds} / 1e6)} seconds.\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -577,84 +572,46 @@ DEFUN (usleep, args, ,
 // point functions really work.
 
 DEFUN (isieee, , ,
-  "isieee (): return 1 if host uses IEEE floating point")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} isieee ()\n\
+Return 1 if your computer claims to conform to the IEEE standard for\n\
+floating point calculations.\n\
+@end deftypefn")
 {
   oct_mach_info::float_format flt_fmt =
     oct_mach_info::native_float_format ();
 
-  return (double) (flt_fmt == oct_mach_info::ieee_little_endian
-		   || flt_fmt == oct_mach_info::ieee_big_endian);
-}
-
-#if !defined (HAVE_GETHOSTNAME) && defined (HAVE_SYS_UTSNAME_H)
-int
-gethostname (char *name, int namelen)
-{
-  int i;
-  struct utsname ut;
-
-  --namelen;
-
-  uname (&ut);
-  i = strlen (ut.nodename) + 1;
-  strncpy (name, ut.nodename, i < namelen ? i : namelen);
-  name[namelen] = '\0';
-
-  return 0;
-}
-#endif
-
-// The check for error state allows us to do this:
-//
-//   string foo = oct_tilde_expand (args(0).string_value ());
-//
-// without having to use a temporary and check error_state before
-// calling oct_tilde_expand.
-
-string
-oct_tilde_expand (const string& name)
-{
-  string retval;
-
-  if (! error_state)
-    {
-      char *tmp = tilde_expand (name.c_str ());
-      retval = tmp;
-      delete [] tmp;
-    }
-
-  return retval;
-}
-
-// A vector version of the above.
-
-string_vector
-oct_tilde_expand (const string_vector& names)
-{
-  string_vector retval;
-
-  if (! error_state)
-    {
-      int n = names.length ();
-
-      retval.resize (n);
-
-      for (int i = 0; i < n; i++)
-	retval[i] = oct_tilde_expand (names[i]);
-    }
-
-  return retval;
+  return static_cast<double> (flt_fmt == oct_mach_info::ieee_little_endian
+			      || flt_fmt == oct_mach_info::ieee_big_endian);
 }
 
 DEFUN (tilde_expand, args, ,
-  "tilde_expand (STRING): perform tilde expansion on STRING")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} tilde_expand (@var{string})\n\
+Performs tilde expansion on @var{string}.  If @var{string} begins with a\n\
+tilde character, (@samp{~}), all of the characters preceding the first\n\
+slash (or all characters, if there is no slash) are treated as a\n\
+possible user name, and the tilde and the following characters up to the\n\
+slash are replaced by the home directory of the named user.  If the\n\
+tilde is followed immediately by a slash, the tilde is replaced by the\n\
+home directory of the user running Octave.  For example,\n\
+\n\
+@example\n\
+@group\n\
+tilde_expand (\"~joeuser/bin\")\n\
+     @result{} \"/home/joeuser/bin\"\n\
+tilde_expand (\"~/bin\")\n\
+     @result{} \"/home/jwe/bin\"\n\
+@end group\n\
+@end example\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
   int nargin = args.length ();
 
   if (nargin == 1)
-    retval = oct_tilde_expand (args(0).all_strings ());
+    retval = file_ops::tilde_expand (args(0).all_strings ());
   else
     print_usage ("tilde_expand");
 
@@ -664,7 +621,7 @@ DEFUN (tilde_expand, args, ,
 #if defined (__EMX__) && defined (OS2)
 
 DEFUN_TEXT (extproc, , ,
-  "extproc : ignored by Octave")
+  "extproc: ignored by Octave")
 {
   return octave_value_list ();
 }
