@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -26,21 +26,13 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <string>
 
 #include "lo-ieee.h"
+#include "lo-sysdep.h"
 
 extern void sysdep_init (void);
 
-extern void raw_mode (int);
-extern int kbhit (void);
+extern void raw_mode (bool, bool wait = true);
 
-extern string octave_getcwd (void);
-extern int octave_chdir (const string&);
-
-#if !defined (HAVE_GETHOSTNAME) && defined (HAVE_SYS_UTSNAME_H)
-extern int gethostname (char *, int);
-#endif
-
-extern string oct_tilde_expand (const string&);
-extern string_vector oct_tilde_expand (const string_vector&);
+extern int kbhit (bool wait = true);
 
 #endif
 
