@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -35,6 +35,7 @@ class
 token
 {
 public:
+
   enum token_type
     {
       generic_token,
@@ -42,7 +43,7 @@ public:
       double_token,
       ettype_token,
       pttype_token,
-      sym_rec_token,
+      sym_rec_token
     };
 
   enum end_tok_type
@@ -54,19 +55,20 @@ public:
       switch_end,
       while_end,
       try_catch_end,
-      unwind_protect_end,
+      unwind_protect_end
     };
 
   enum plot_tok_type
     {
       replot = 1,
       two_dee = 2,
-      three_dee = 3,
+      three_dee = 3
     };
 
   token (int l = -1, int c = -1);
-  token (const string& s, int l = -1, int c = -1);
-  token (double d, const string& s = string (), int l = -1, int c = -1);
+  token (const std::string& s, int l = -1, int c = -1);
+  token (double d, const std::string& s = std::string (),
+	 int l = -1, int c = -1);
   token (end_tok_type t, int l = -1, int c = -1);
   token (plot_tok_type t, int l = -1, int c = -1);
   token (symbol_record *s, int l = -1, int c = -1);
@@ -76,16 +78,20 @@ public:
   int line (void) { return line_num; }
   int column (void) { return column_num; }
 
-  string text (void);
+  std::string text (void);
   double number (void);
   end_tok_type ettype (void);
   plot_tok_type pttype (void);
   symbol_record *sym_rec (void);
 
-  string text_rep (void);
+  std::string text_rep (void);
 
 private:
+
+  // No copying!
+
   token (const token& tok);
+
   token& operator = (const token& tok);
 
   int line_num;
@@ -93,13 +99,13 @@ private:
   token_type type_tag;
   union
     {
-      string *str;
+      std::string *str;
       double num;
       end_tok_type et;
       plot_tok_type pt;
       symbol_record *sr;
     };
-  string orig_text;
+  std::string orig_text;
 };
 
 #endif
