@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -31,39 +31,19 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include <string>
 
-typedef void (*cleanup_func)(void *ptr);
-
-void add_unwind_protect (cleanup_func fptr, void *ptr);
-void run_unwind_protect (void);
-void discard_unwind_protect (void);
-void begin_unwind_frame (const string& tag);
-void run_unwind_frame (const string& tag);
-void discard_unwind_frame (const string& tag);
-void run_all_unwind_protects (void);
-void discard_all_unwind_protects (void);
-
-void unwind_protect_int_internal (int *ptr, int value);
-void unwind_protect_str_internal (string *ptr, const string& value);
-void unwind_protect_ptr_internal (void **ptr, void *value);
-void unwind_protect_var_internal (void *ptr, void *value, size_t size);
-
-#define unwind_protect_int(i) \
-  unwind_protect_int_internal (&(i), (i))
-
-#define unwind_protect_str(s) \
-  unwind_protect_str_internal (&(s), (s))
-
-#define unwind_protect_ptr(p) \
-  unwind_protect_ptr_internal ((void **) &(p), (void *) (p))
+#include <SLStack.h>
 
 class
 unwind_elem
 {
- public:
+public:
+
+  typedef void (*cleanup_func) (void *ptr);
+
   unwind_elem (void)
     : ue_tag (), ue_fptr (0), ue_ptr (0) { }
 
-  unwind_elem (const string &t)
+  unwind_elem (const std::string &t)
     : ue_tag (t), ue_fptr (0), ue_ptr (0) { }
 
   unwind_elem (cleanup_func f, void *p)
@@ -83,18 +63,71 @@ unwind_elem
       return *this;
     }
 
-  string tag (void) { return ue_tag; }
+  std::string tag (void) { return ue_tag; }
 
   cleanup_func fptr (void) { return ue_fptr; }
 
   void *ptr (void) { return ue_ptr; }
 
- private:
-  string ue_tag;
+private:
+
+  std::string ue_tag;
+
   cleanup_func ue_fptr;
+
   void *ue_ptr;
 };
 
+class
+unwind_protect
+{
+public:
+
+  static void add (unwind_elem::cleanup_func fptr, void *ptr);
+
+  static void run (void);
+
+  static void discard (void);
+
+  static void begin_frame (const std::string& tag);
+
+  static void run_frame (const std::string& tag);
+
+  static void discard_frame (const std::string& tag);
+
+  static void run_all (void);
+
+  static void discard_all (void);
+
+  // Ways to save variables.
+
+  static void save_bool (bool *ptr, bool value);
+
+  static void save_int (int *ptr, int value);
+
+  static void save_str (std::string *ptr, const std::string& value);
+
+  static void save_ptr (void **ptr, void *value);
+
+  static void save_var (void *ptr, void *value, size_t size);
+
+  static SLStack<unwind_elem> list;
+};
+
+// We could get by without these macros, but they are nice to have...
+
+#define unwind_protect_bool(b) \
+  unwind_protect::save_bool (&(b), (b))
+
+#define unwind_protect_int(i) \
+  unwind_protect::save_int (&(i), (i))
+
+#define unwind_protect_str(s) \
+  unwind_protect::save_str (&(s), (s))
+
+#define unwind_protect_ptr(p) \
+  unwind_protect::save_ptr (X_CAST (void **, &(p)), X_CAST (void *, (p)))
+
 #endif
 
 /*
