@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -24,16 +24,15 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <config.h>
 #endif
 
+#include <cerrno>
 #include <climits>
-#include <csetjmp>
 #include <cstring>
 
+#include <fstream>
+#include <iostream>
+#include <strstream>
 #include <string>
 
-#include <fstream.h>
-#include <iostream.h>
-#include <strstream.h>
-
 #ifdef HAVE_UNISTD_H
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -41,6 +40,11 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <unistd.h>
 #endif
 
+// Include setjmp.h, not csetjmp since the latter might only define
+// the ANSI standard C interface.
+
+#include <setjmp.h>
+
 #if defined (HAVE_TERMIOS_H)
 #include <termios.h>
 #elif defined (HAVE_TERMIO_H)
@@ -53,58 +57,50 @@ LOSE! LOSE!
 
 #include "SLStack.h"
 
+#include "dir-ops.h"
 #include "file-ops.h"
+#include "file-stat.h"
 #include "oct-cmplx.h"
+#include "oct-env.h"
+#include "pathsearch.h"
 #include "str-vec.h"
 
 #include <defaults.h>
 #include "defun.h"
-#include "dir-ops.h"
 #include "dirfns.h"
 #include "error.h"
 #include "gripes.h"
-#include "help.h"
 #include "input.h"
-#include "mappers.h"
 #include "oct-hist.h"
 #include "oct-obj.h"
 #include "pager.h"
-#include "pathsearch.h"
 #include "sysdep.h"
 #include "toplev.h"
 #include "unwind-prot.h"
 #include "utils.h"
 #include "variables.h"
 
+// Should expressions like ones (-1, 5) result in an empty matrix or
+// an error?  A positive value means yes.  A negative value means
+// yes, but print a warning message.  Zero means it should be
+// considered an error.
+static int Vtreat_neg_dim_as_zero;
+
 // Top level context (?)
 extern jmp_buf toplevel;
 
-// Save a string.
-
-char *
-strsave (const char *s)
-{
-  if (! s)
-    return 0;
-
-  int len = strlen (s);
-  char *tmp = new char [len+1];
-  tmp = strcpy (tmp, s);
-  return tmp;
-}
-
 // Return to the main command loop in octave.cc.
 
-extern "C" void
+void
 jump_to_top_level (void)
 {
-  run_all_unwind_protects ();
+  unwind_protect::run_all ();
 
   longjmp (toplevel, 1);
 }
 
 int
-almost_match (const string& std, const string& s, int min_match_len,
+almost_match (const std::string& std, const std::string& s, int min_match_len,
 	      int case_sens)
 {
   int stdlen = std.length ();
@@ -120,7 +116,7 @@ almost_match (const string& std, const string& s, int min_match_len,
 // Ugh.
 
 int
-keyword_almost_match (const char **std, int *min_len, const string& s,
+keyword_almost_match (const char * const *std, int *min_len, const std::string& s,
 		      int min_toks_to_match, int max_toks)
 {
   int status = 0;
@@ -148,9 +144,9 @@ keyword_almost_match (const char **std, int *min_len, const string& s,
     return status;
 
 
-  char **to_match = new char * [max_toks + 1];
-  const char **s1 = std;
-  char **s2 = to_match;
+  const char **to_match = new const char * [max_toks + 1];
+  const char * const *s1 = std;
+  const char **s2 = to_match;
 
   if (! s1 || ! s2)
     goto done;
@@ -237,18 +233,21 @@ empty_arg (const char *name, int nr, int nc)
 
 // See if the given file is in the path.
 
-string
-search_path_for_file (const string& path, const string& name)
+std::string
+search_path_for_file (const std::string& path, const std::string& name)
 {
   dir_path p (path);
 
-  return make_absolute (p.find (name), Vcurrent_directory);
+  return octave_env::make_absolute (p.find (name), octave_env::getcwd ());
 }
 
 DEFUN (file_in_loadpath, args, ,
-  "file_in_loadpath (NAME)\n\
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} file_in_loadpath (@var{name})\n\
 \n\
-Look up NAME in LOADPATH.  See also file_in_path")
+Look up @var{name} in Octave's @code{LOADPATH}.\n\
+@end deftypefn\n\
+@seealso{file_in_path}")
 {
   octave_value_list retval;
 
@@ -260,8 +259,8 @@ Look up NAME in LOADPATH.  See also file_in_path")
     return retval;
 
   if (argc == 2)
-    retval = make_absolute (Vload_path_dir_path.find (argv[1]),
-			    Vcurrent_directory);
+    retval = octave_env::make_absolute (Vload_path_dir_path.find (argv[1]),
+					octave_env::getcwd ());
   else
     print_usage ("file_in_loadpath");
 
@@ -269,11 +268,21 @@ Look up NAME in LOADPATH.  See also file_in_path")
 }
 
 DEFUN (file_in_path, args, ,
-  "file_in_path (PATH, NAME)\n\
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} file_in_path (@var{path}, @var{file})\n\
+Return the absolute name name of @var{file} if it can be found in\n\
+@var{path}.  The value of @var{path} should be a colon-separated list of\n\
+directories in the format described for the built-in variable\n\
+@code{LOADPATH}.\n\
 \n\
-Look up NAME in PATH.  Leading, trailing, or doubled colons are not\n\
-expanded in PATH.  To search for files in LOADPATH, it is generally\n\
-better to use the file_in_loadpath function.")
+If the file cannot be found in the path, an empty matrix is returned.\n\
+For example,\n\
+\n\
+@example\n\
+file_in_path (LOADPATH, \"nargchk.m\")\n\
+     @result{} \"@value{OCTAVEHOME}/share/octave/2.0/m/general/nargchk.m\"\n\
+@end example\n\
+@end deftypefn")
 {
   octave_value_list retval;
 
@@ -286,7 +295,7 @@ better to use the file_in_loadpath function.")
 
   if (argc == 3)
     {
-      string fname = search_path_for_file (argv[1], argv[2]);
+      std::string fname = search_path_for_file (argv[1], argv[2]);
 
       if (fname.empty ())
 	retval = Matrix ();
@@ -299,27 +308,25 @@ better to use the file_in_loadpath function.")
   return retval;
 }
 
-string
-file_in_path (const string& name, const string& suffix)
+std::string
+file_in_path (const std::string& name, const std::string& suffix)
 {
-  string nm = name;
+  std::string nm = name;
 
   if (! suffix.empty ())
     nm.append (suffix);
 
-  if (Vcurrent_directory.empty ())
-    get_working_directory ("file_in_path");
-
-  return make_absolute (Vload_path_dir_path.find (nm), Vcurrent_directory);
+  return octave_env::make_absolute (Vload_path_dir_path.find (nm),
+				    octave_env::getcwd ());
 }
 
 // See if there is an function file in the path.  If so, return the
 // full path to the file.
 
-string
-fcn_file_in_path (const string& name)
+std::string
+fcn_file_in_path (const std::string& name)
 {
-  string retval;
+  std::string retval;
 
   int len = name.length ();
   
@@ -337,10 +344,10 @@ fcn_file_in_path (const string& name)
 // See if there is an octave file in the path.  If so, return the
 // full path to the file.
 
-string
-oct_file_in_path (const string& name)
+std::string
+oct_file_in_path (const std::string& name)
 {
-  string retval;
+  std::string retval;
 
   int len = name.length ();
   
@@ -358,10 +365,10 @@ oct_file_in_path (const string& name)
 
 // Replace backslash escapes in a string with the real values.
 
-string
-do_string_escapes (const string& s)
+std::string
+do_string_escapes (const std::string& s)
 {
-  string retval;
+  std::string retval;
 
   size_t i = 0;
   size_t j = 0;
@@ -437,7 +444,10 @@ do_string_escapes (const string& s)
 }
 
 DEFUN (do_string_escapes, args, ,
-  "do_string_escapes (STRING)")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} do_string_escapes (@var{string})\n\
+Convert special characters in @var{string} to their escaped forms.\n\
+@end deftypefn")
 {
   octave_value retval;
 
@@ -501,10 +511,10 @@ undo_string_escape (char c)
     }
 }
 
-string
-undo_string_escapes (const string& s)
+std::string
+undo_string_escapes (const std::string& s)
 {
-  string retval;
+  std::string retval;
 
   for (size_t i = 0; i < s.length (); i++)
     retval.append (undo_string_escape (s[i]));
@@ -513,7 +523,32 @@ undo_string_escapes (const string& s)
 }
 
 DEFUN (undo_string_escapes, args, ,
-  "undo_string_escapes (STRING)")
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {} undo_string_escapes (@var{s})\n\
+Converts special characters in strings back to their escaped forms.  For\n\
+example, the expression\n\
+\n\
+@example\n\
+bell = \"\\a\";\n\
+@end example\n\
+\n\
+@noindent\n\
+assigns the value of the alert character (control-g, ASCII code 7) to\n\
+the string variable @code{bell}.  If this string is printed, the\n\
+system will ring the terminal bell (if it is possible).  This is\n\
+normally the desired outcome.  However, sometimes it is useful to be\n\
+able to print the original representation of the string, with the\n\
+special characters replaced by their escape sequences.  For example,\n\
+\n\
+@example\n\
+octave:13> undo_string_escapes (bell)\n\
+ans = \\a\n\
+@end example\n\
+\n\
+@noindent\n\
+replaces the unprintable alert character with its printable\n\
+representation.\n\
+@end deftypefn")
 {
   octave_value retval;
 
@@ -532,93 +567,31 @@ DEFUN (undo_string_escapes, args, ,
   return retval;
 }
 
-// This function was adapted from xputenv from Karl Berry's kpathsearch
-// library.
+#if 0
 
-void
-oct_putenv (const char *var_name, const char *value)
+// Octave could use some way to access the value of ERRNO, but this is
+// probably not the best interface, so don't depend on it...
+
+DEFUN (ERRNO, args, ,
+  "-*- texinfo -*-\n\
+@deftypefn {Built-in Function} {@var{system_error_number}} errno ()\n\
+Return the current value of the system-dependent variable errno.\n\
+@end deftypefn")
 {
-  static const char **saved_env_items = 0;
-  static unsigned saved_len;
-  char *old_item = 0;
+  octave_value retval;
 
-  int new_len = strlen (var_name) + strlen (value) + 2;
-
-  char *new_item = new char [new_len];
-
-  sprintf (new_item, "%s=%s", var_name, value);
-
-#ifndef SMART_PUTENV
-
-  // Check if we have saved anything yet.
-
-  if (! saved_env_items)
-    {
-      saved_env_items = new const char * [1];
-      saved_env_items[0] = var_name;
-      saved_len = 1;
-    }
+  if (args.length () == 0)
+    retval = static_cast<double> (errno);
   else
-    {
-      // Check if we've assigned VAR_NAME before.
+    print_usage ("errno");
 
-      unsigned len = strlen (var_name);
-
-      for (unsigned i = 0; i < saved_len && ! old_item; i++)
-        {
-          if (strcmp (saved_env_items[i], var_name) == 0)
-            {
-              old_item = getenv (var_name);
-
-              assert (old_item);
-
-              // Back up to the `NAME=' in the environment before the
-	      // value that getenv returns.
-
-              old_item -= (len + 1);
-            }
-        }
-      
-      if (! old_item)
-        {
-          // If we haven't seen VAR_NAME before, save it.  Assume it
-	  // is in safe storage.
-
-          saved_len++;
-
-	  const char **tmp = new const char * [saved_len];
-
-	  for (unsigned i = 0; i < saved_len - 1; i++)
-	    tmp[i] = saved_env_items[i];
-
-	  tmp[saved_len - 1] = var_name;
-
-          delete [] saved_env_items;
-
-	  saved_env_items = tmp;
-        }
-    }
-
-#endif
-
-  // As far as I can see there's no way to distinguish between the
-  // various errors; putenv doesn't have errno values.
-
-  if (putenv (new_item) < 0)
-    error ("putenv (%s) failed", new_item);
-  
-#ifndef SMART_PUTENV
-
-  // Can't free `new_item' because its contained value is now in
-  // `environ', but we can free `old_item', since it's been replaced.
-
-  delete [] old_item;
-
-#endif
+  return retval;
 }
 
+#endif
+
 static void
-warn_old_style_preference (bool val, const string& sval)
+warn_old_style_preference (bool val, const std::string& sval)
 {
   warning
     ("preference of \"%s\" is obsolete -- use numeric value of %d instead",
@@ -633,11 +606,11 @@ warn_old_style_preference (bool val, const string& sval)
 //   return of -1 => ok, but give me warning (default).
 
 int
-check_preference (const string& var)
+check_preference (const std::string& var)
 {
   int pref = -1;
 
-  string val = builtin_string_variable (var);
+  std::string val = builtin_string_variable (var);
 
   if (val.empty ())
     {
@@ -647,15 +620,12 @@ check_preference (const string& var)
     }
   else
     {
-      if (val.compare ("yes", 0, 3) == 0
-	  || val.compare ("true", 0, 4) == 0)
+      if (val == "yes" || val == "true")
 	{
 	  warn_old_style_preference (true, val);
 	  pref = 1;
 	}
-      else if (val.compare ("never", 0, 5) == 0
-	       || val.compare ("no", 0, 2) == 0
-	       || val.compare ("false", 0, 5) == 0)
+      else if (val == "never" || val == "no" || val == "false")
 	{
 	  warn_old_style_preference (false, val);
 	  pref = 0;
@@ -665,6 +635,151 @@ check_preference (const string& var)
   return pref;
 }
 
+static void
+check_dimensions (int& nr, int& nc, const char *warnfor)
+{
+  if (nr < 0 || nc < 0)
+    {
+      if (Vtreat_neg_dim_as_zero)
+	{
+	  nr = (nr < 0) ? 0 : nr;
+	  nc = (nc < 0) ? 0 : nc;
+
+	  if (Vtreat_neg_dim_as_zero < 0)
+	    warning ("%s: converting negative dimension to zero",
+		     warnfor);
+	}
+      else
+	error ("%s: can't create a matrix with negative dimensions",
+	       warnfor);
+    }
+}
+
+void
+get_dimensions (const octave_value& a, const char *warn_for,
+		int& nr, int& nc)
+{
+  if (a.is_scalar_type ())
+    {
+      nr = nc = a.nint_value ();
+    }
+  else
+    {
+      nr = a.rows ();
+      nc = a.columns ();
+
+      if ((nr == 1 && nc == 2) || (nr == 2 && nc == 1))
+	{
+	  Array<double> v = a.vector_value ();
+
+	  if (error_state)
+	    return;
+
+	  nr = NINT (v (0));
+	  nc = NINT (v (1));
+	}
+      else
+	warning ("%s (A): use %s (size (A)) instead", warn_for, warn_for);
+    }
+
+  check_dimensions (nr, nc, warn_for); // May set error_state.
+}
+
+void
+get_dimensions (const octave_value& a, const octave_value& b,
+		const char *warn_for, int& nr, int& nc)
+{
+  nr = a.is_empty () ? 0 : a.nint_value ();
+  nc = b.is_empty () ? 0 : b.nint_value ();
+
+  if (error_state)
+    error ("%s: expecting two scalar arguments", warn_for);
+  else
+    check_dimensions (nr, nc, warn_for); // May set error_state.
+}
+
+extern int
+octave_format (std::ostream& os, const char *fmt, ...)
+{
+  int retval = -1;
+
+  va_list args;
+  va_start (args, fmt);
+
+  retval = octave_vformat (os, fmt, args);
+
+  va_end (args);
+
+  return retval;
+}
+
+extern int
+octave_vformat (std::ostream& os, const char *fmt, va_list args)
+{
+  int retval = -1;
+
+#if defined (__GNUG__) && !CXX_ISO_COMPLIANT_LIBRARY
+
+  std::ostrstream buf;
+
+  buf.vform (fmt, args);
+
+  buf << std::ends;
+
+  char *s = buf.str ();
+
+  os << s;
+
+  retval = strlen (s);
+
+  delete [] s;
+
+#else
+
+  char *s = octave_vsnprintf (fmt, args);
+
+  if (s)
+    {
+      os << s;
+
+      retval = strlen (s);
+
+      free (s);
+    }
+
+#endif
+
+  return retval;
+}
+
+static int
+treat_neg_dim_as_zero (void)
+{
+  Vtreat_neg_dim_as_zero = check_preference ("treat_neg_dim_as_zero");
+
+  return 0;
+}
+
+void
+symbols_of_utils (void)
+{
+  DEFVAR (treat_neg_dim_as_zero, 0.0, treat_neg_dim_as_zero,
+    "-*- texinfo -*-\n\
+@defvr {Built-in Variable} treat_neg_dim_as_zero\n\
+If the value of @code{treat_neg_dim_as_zero} is nonzero, expressions\n\
+like\n\
+\n\
+@example\n\
+eye (-1)\n\
+@end example\n\
+\n\
+@noindent\n\
+produce an empty matrix (i.e., row and column dimensions are zero).\n\
+Otherwise, an error message is printed and control is returned to the\n\
+top level.  The default value is 0.\n\
+@end defvr");
+}
+
 /*
 ;;; Local Variables: ***
 ;;; mode: C++ ***
