@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1996 John W. Eaton
+Copyright (C) 1996, 1997 John W. Eaton
 
 This file is part of Octave.
 
@@ -33,6 +33,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "EIG.h"
 #include "dDiagMatrix.h"
 #include "dMatrix.h"
+#include "mx-cm-cdm.h"
 #include "oct-cmplx.h"
 
 #include "error.h"
@@ -65,7 +66,7 @@ xisint (double x)
 octave_value
 xpow (double a, double b)
 {
-  if (a < 0.0 && (int) b != b)
+  if (a < 0.0 && static_cast<int> (b) != b)
     {
       Complex atmp (a);
       return pow (atmp, b);
@@ -163,9 +164,9 @@ xpow (const Matrix& a, double b)
     error ("for A^b, A must be square");
   else
     {
-      if ((int) b == b)
+      if (static_cast<int> (b) == b)
 	{
-	  int btmp = (int) b;
+	  int btmp = static_cast<int> (b);
 	  if (btmp == 0)
 	    {
 	      retval = DiagMatrix (nr, nr, 1.0);
@@ -194,8 +195,19 @@ xpow (const Matrix& a, double b)
 		atmp = a;
 
 	      Matrix result (atmp);
-	      for (int i = 1; i < btmp; i++)
-		result = result * atmp;
+
+	      btmp--;
+
+	      while (btmp > 0)
+		{
+		  if (btmp & 1)
+		    result = result * atmp;
+
+		  btmp >>= 1;
+
+		  if (btmp > 0)
+		    atmp = atmp * atmp;
+		}
 
 	      retval = result;
 	    }
@@ -253,7 +265,7 @@ xpow (const Complex& a, double b)
   Complex result;
 
   if (xisint (b))
-    result = pow (a, (int) b);
+    result = pow (a, static_cast<int> (b));
   else
     result = pow (a, b);
 
@@ -348,9 +360,9 @@ xpow (const ComplexMatrix& a, double b)
     error ("for A^b, A must be square");
   else
     {
-      if ((int) b == b)
+      if (static_cast<int> (b) == b)
 	{
-	  int btmp = (int) b;
+	  int btmp = static_cast<int> (b);
 	  if (btmp == 0)
 	    {
 	      retval = DiagMatrix (nr, nr, 1.0);
@@ -379,8 +391,19 @@ xpow (const ComplexMatrix& a, double b)
 		atmp = a;
 
 	      ComplexMatrix result (atmp);
-	      for (int i = 1; i < btmp; i++)
-		result = result * atmp;
+
+	      btmp--;
+
+	      while (btmp > 0)
+		{
+		  if (btmp & 1)
+		    result = result * atmp;
+
+		  btmp >>= 1;
+
+		  if (btmp > 0)
+		    atmp = atmp * atmp;
+		}
 
 	      retval = result;
 	    }
@@ -446,6 +469,20 @@ xpow (const ComplexMatrix& a, const Complex& b)
 //
 //   * -> not needed.
 
+// XXX FIXME XXX -- these functions need to be fixed so that things
+// like
+//
+//   a = -1; b = [ 0, 0.5, 1 ]; r = a .^ b
+//
+// and
+//
+//   a = -1; b = [ 0, 0.5, 1 ]; for i = 1:3, r(i) = a .^ b(i), end
+//
+// produce identical results.  Also, it would be nice if -1^0.5
+// produced a pure imaginary result instead of a complex number with a
+// small real part.  But perhaps that's really a problem with the math
+// library...
+
 // -*- 1 -*-
 octave_value
 elem_xpow (double a, const Matrix& b)
@@ -505,7 +542,7 @@ elem_xpow (const Matrix& a, double b)
   int nr = a.rows ();
   int nc = a.cols ();
 
-  if ((int) b != b && a.any_element_is_negative ())
+  if (static_cast<int> (b) != b && a.any_element_is_negative ())
     {
       ComplexMatrix result (nr, nc);
       for (int j = 0; j < nc; j++)
@@ -554,7 +591,7 @@ elem_xpow (const Matrix& a, const Matrix& b)
       {
 	double atmp = a (i, j);
 	double btmp = b (i, j);
-	if (atmp < 0.0 && (int) btmp != btmp)
+	if (atmp < 0.0 && static_cast<int> (btmp) != btmp)
 	  {
 	    convert_to_complex = 1;
 	    goto done;
@@ -643,7 +680,7 @@ elem_xpow (const Complex& a, const Matrix& b)
       {
 	double btmp = b (i, j);
 	if (xisint (btmp))
-	  result (i, j) = pow (a, (int) btmp);
+	  result (i, j) = pow (a, static_cast<int> (btmp));
 	else
 	  result (i, j) = pow (a, btmp);
       }
@@ -679,7 +716,7 @@ elem_xpow (const ComplexMatrix& a, double b)
     {
       for (int j = 0; j < nc; j++)
 	for (int i = 0; i < nr; i++)
-	  result (i, j) = pow (a (i, j), (int) b);
+	  result (i, j) = pow (a (i, j), static_cast<int> (b));
     }
   else
     {
@@ -713,7 +750,7 @@ elem_xpow (const ComplexMatrix& a, const Matrix& b)
       {
 	double btmp = b (i, j);
 	if (xisint (btmp))
-	  result (i, j) = pow (a (i, j), (int) btmp);
+	  result (i, j) = pow (a (i, j), static_cast<int> (btmp));
 	else
 	  result (i, j) = pow (a (i, j), btmp);
       }
