@@ -1,3 +1,3 @@
 do_fortran_indexing = 1;
 a = 1;
-isempty (a(0))
+isempty (a(logical (0)))
